
*-- Author :
C
C--------------------------------------------------------------------
      SUBROUTINE FHAD(IPRMOD,IPRO,PLAB,ELAB,CX,CY,CZ,
     *               ITHKK,ITTA,IELINE,IREJFH)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C
C   MODIFIED VERSION OF FERHAD / FROM FLUKA86.S (DESY)
C   01/02/90
C
C--------------------------------------------------
C***  COLLISION OF HADRON IPRO WITH NUCLEON ITHKK FROM /HKKEVT/
C         (IPRO, ITTA - CONVENTIONAL PARTICLE NUMBERING FROM FLUKA)
C     IPRO HAS LAB-ENERGY ELAB, MOMENTUM PLAB, DIRECTIONS CX,CY,CZ
C
C                      IELINI=0    INELASTIC HADRIN COLLISIONS
C                      IELINE=1      ELASTIC ELHAIN COLLISIONS
C                      IELINE= ...       ...
C***
C***  ITHKK TAKES THE FERMI-MOMENTUM FROM /HKKEVT/
C
C*** CONSERVED IS THE ENERGY, THE MOMENTUM, ELECTRIC AND BARYON. CHARGE
C*** AND STRANGENESS
C--------------------------------------------------
*KEEP,HKKEVT.
c     INCLUDE (HKKEVT)
      PARAMETER (NMXHKK= 49998)
c     PARAMETER (NMXHKK=25000)
      COMMON /HKKEVT/ NHKK,NEVHKK,ISTHKK(NMXHKK),IDHKK(NMXHKK), JMOHKK
     +(2,NMXHKK),JDAHKK(2,NMXHKK), PHKK(5,NMXHKK),VHKK(4,NMXHKK),WHKK
     +(4,NMXHKK)
C
C                       WHKK(4,NMXHKK) GIVES POSITIONS AND TIMES IN
C                       PROJECTILE FRAME, THE CHAINS ARE CREATED ON
C                       THE POSITIONS OF THE PROJECTILE NUCLEONS
C                       IN THE PROJECTILE FRAME (TARGET NUCLEONS IN
C                       TARGET FRAME) BOTH POSITIONS ARE THREFORE NOT
C                       COMPLETELY CONSISTENT. THE TIMES IN THE
C                       PROJECTILE FRAME HOWEVER ARE OBTAINED BY
C                       LORENTZ TRANSFORMING FROM THE LAB SYSTEM.
C
C  Based on the proposed standard COMMON block (Sjostrand Memo 17.3,89)
C
C NMXHKK: maximum numbers of entries (partons/particles) that can be
C    stored in the commonblock.
C
C NHKK: the actual number of entries stored in current event. These are
C    found in the first NHKK positions of the respective arrays below.
C    Index IHKK, 1 <= IHKK <= NHKK, is below used to denote a given
C    entry.
C
C ISTHKK(IHKK): status code for entry IHKK, with following meanings:
C    = 0 : null entry.
C    = 1 : an existing entry, which has not decayed or fragmented.
C        This is the main class of entries which represents the
C        "final state" given by the generator.
C    = 2 : an entry which has decayed or fragmented and therefore
C        is not appearing in the final state, but is retained for
C        event history information.
C    = 3 : a documentation line, defined separately from the event
C        history. (incoming reacting
C        particles, etc.)
C    = 4 - 10 : undefined, but reserved for future standards.
C    = 11 - 20 : at the disposal of each model builder for constructs
C        specific to his program, but equivalent to a null line in the
C        context of any other program. One example is the cone defining
C        vector of HERWIG, another cluster or event axes of the JETSET
C        analysis routines.
C    = 21 - : at the disposal of users, in particular for event tracking
C        in the detector.
C
C IDHKK(IHKK) : particle identity, according to the Particle Data Group
C    standard.
C
C JMOHKK(1,IHKK) : pointer to the position where the mother is stored.
C    The value is 0 for initial entries.
C
C JMOHKK(2,IHKK) : pointer to position of second mother. Normally only
C    one mother exist, in which case the value 0 is used. In cluster
C    fragmentation models, the two mothers would correspond to the q
C    and qbar which join to form a cluster. In string fragmentation,
C    the two mothers of a particle produced in the fragmentation would
C    be the two endpoints of the string (with the range in between
C    implied).
C
C JDAHKK(1,IHKK) : pointer to the position of the first daughter. If an
C    entry has not decayed, this is 0.
C
C JDAHKK(2,IHKK) : pointer to the position of the last daughter. If an
C    entry has not decayed, this is 0. It is assumed that the daughters
C    of a particle (or cluster or string) are stored sequentially, so
C    that the whole range JDAHKK(1,IHKK) - JDAHKK(2,IHKK) contains
C    daughters. Even in cases where only one daughter is defined (e.g.
C    K0 -> K0S) both values should be defined, to make for a uniform
C    approach in terms of loop constructions.
C
C PHKK(1,IHKK) : momentum in the x direction, in GeV/c.
C
C PHKK(2,IHKK) : momentum in the y direction, in GeV/c.
C
C PHKK(3,IHKK) : momentum in the z direction, in GeV/c.
C
C PHKK(4,IHKK) : energy, in GeV.
C
C PHKK(5,IHKK) : mass, in GeV/c**2. For spacelike partons, it is allowed
C    to use a negative mass, according to PHKK(5,IHKK) = -sqrt(-m**2).
C
C VHKK(1,IHKK) : production vertex x position, in mm.
C
C VHKK(2,IHKK) : production vertex y position, in mm.
C
C VHKK(3,IHKK) : production vertex z position, in mm.
C
C VHKK(4,IHKK) : production time, in mm/c (= 3.33*10**(-12) s).
C********************************************************************
*KEEP,HADTHR.
      COMMON /HADTHR/ EHADTH,INTHAD
*KEEP,DFINLS.
      PARAMETER (MAXFIN=10)
      COMMON /DFINLS/ ITRH(MAXFIN),CXRH(MAXFIN),CYRH(MAXFIN), CZRH
     +(MAXFIN),ELRH(MAXFIN),PLRH(MAXFIN),IRH
*KEEP,DPAR.
C     /DPAR/   CONTAINS PARTICLE PROPERTIES
C        ANAME  = LITERAL NAME OF THE PARTICLE
C        AAM    = PARTICLE MASS IN GEV
C        GA     = DECAY WIDTH
C        TAU    = LIFE TIME OF INSTABLE PARTICLES
C        IICH   = ELECTRIC CHARGE OF THE PARTICLE
C        IIBAR  = BARYON NUMBER
C        K1,K1  = BIGIN AND END OF DECAY CHANNELS OF PARTICLE
C
      CHARACTER*8  ANAME
      COMMON /DPAR/ ANAME(210),AAM(210),GA(210),TAU(210),IICH(210),
     +IIBAR(210),K1(210),K2(210)
C------------------
*KEEP,PROJK.
      COMMON /PROJK/ IPROJK
*KEEP,DPRIN.
      COMMON /DPRIN/  IPRI,IPEV,IPPA,IPCO,INIT,IPHKK,ITOPD,IPAUPR
*KEND.
      ZERO=0
      IREJFH=0
C---------------------------------------------------------------
C   TEST OPTION: FORCE TYPE OF INTERACTION IF DESIRED
      IF(INTHAD.EQ.1) THEN
        IIELIN=0
      ELSEIF(INTHAD.EQ.2) THEN
        IIELIN=1
      ELSE
        IIELIN=IELINE
      ENDIF
C--------------------------------------------------
C*** COLLISION KINEMATICS
C*** LORENTZ-TRANSFORMATION INTO TARGET-NUCLEON-REST-SYSTEM
C--------------------------------------------------
      AMTAR=PHKK(5,ITHKK)
C                               RECALCULATE MOMENTA FOR KINEMATICAL
C                               CONSISTENCY OF LORENTZ-TRANSFORMATION
      PPTAR=SQRT(PHKK(1,ITHKK)**2 + PHKK(2,ITHKK)**2 + PHKK(3,ITHKK)**2)
      PPTARM=SQRT(ABS(PHKK(4,ITHKK)-AMTAR)*(PHKK(4,ITHKK)+AMTAR))
C
      BGX=PHKK(1,ITHKK)/AMTAR
      BGY=PHKK(2,ITHKK)/AMTAR
      BGZ=PHKK(3,ITHKK)/AMTAR
      IF(PPTAR.GT.ZERO) THEN
        BGX=BGX*PPTARM/PPTAR
        BGY=BGY*PPTARM/PPTAR
        BGZ=BGZ*PPTARM/PPTAR
      ENDIF
C
      PPLAB=PLAB
      GAM=PHKK(4,ITHKK)/AMTAR
      PXPRO=CX*PPLAB
      PYPRO=CY*PPLAB
      PZPRO=CZ*PPLAB
C
      ETES = ELAB + PHKK(4,ITHKK)
      PXTES= PXPRO + PHKK(1,ITHKK)
      PYTES= PYPRO + PHKK(2,ITHKK)
      PZTES= PZPRO + PHKK(3,ITHKK)
C
      CALL DALTRA(GAM,-BGX,-BGY,-BGZ, PXPRO,PYPRO,PZPRO,ELAB, PPROF,
     +PXPROF,PYPROF,PZPROF,EPROF)
      IF(IPEV.GT.3) THEN
        WRITE(6,'(2A/A,4E12.5/A,5E12.5/A,4E12.5/A,4E12.5/A,4I4)')
     &        ' FHAD:  projectile after LT into target',
     &        ' nucleon rest system',
     &        ' GAM,BGX,BGY,BGZ ', GAM,BGX,BGY,BGZ,
     &        ' PHKK(target):', (PHKK(IK,ITHKK),IK=1,5),
     &        ' PX/Y/Z/PRO, ELAB:', PXPRO,PYPRO,PZPRO,ELAB,
     &        ' Proj. after LT:', PXPROF,PYPROF,PZPROF,EPROF,
     &        ' IPRO, ITTA, ITHKK, IELINE:', IPRO,ITTA,ITHKK,IELINE
      ENDIF
      IF(EPROF.LE.AAM(IPRO)) THEN
        WRITE(6,'(2A/A,5E12.5/A,4E12.5/A,4E12.5/A,4I4)')
     &        ' FHAD: inconsistent projectile after LT into target',
     &        ' nucleon rest system',
     &        ' PHKK(target):', (PHKK(IK,ITHKK),IK=1,5),
     &        ' PX/Y/Z/PRO, ELAB:', PXPRO,PYPRO,PZPRO,ELAB,
     &        ' Proj. after LT:', PXPROF,PYPROF,PZPROF,EPROF,
     &        ' IPRO, ITTA, ITHKK, IELINE:', IPRO,ITTA,ITHKK,IELINE
        IREJFH=1
        RETURN
      ENDIF
C                                     CONSISTENCY TEST OF LOR. TRSF.
C                                     INTO TARGET REST SYSTEM
      IF(IPAUPR.GT.5) THEN
        CALL DALTRA(GAM,-BGX,-BGY,-BGZ, PHKK(1,ITHKK),PHKK(2,ITHKK),PHKK
     +  (3,ITHKK),PHKK(4,ITHKK), PPTAR,PXTARF,PYTARF,PZTARF,ETARF)
 
        WRITE(6,'(A)') 'FHAD: TARGET MOM. BEFORE/AFTER LORENTZ TRANSF.'
        WRITE(6,'(3X,A,5(1PE12.4))') ' PHKK(1-4,ITHKK)', (PHKK
     +  (JJ,ITHKK),JJ=1,4)
        WRITE(6,'(3X,A,5(1PE12.4))') ' PXTARF,PYTARF,PZTARF,ETARF',
     +  PXTARF,PYTARF,PZTARF,ETARF
        WRITE(6,'(A)') 'FHAD: PROJ. MOM. BEFORE/AFTER LORENTZ TRANSF.'
        WRITE(6,'(3X,A,5(1PE12.4))') ' PXPRO,PYPRO,PZPRO,ELAB', PXPRO,
     +  PYPRO,PZPRO,ELAB
        WRITE(6,'(3X,A,5(1PE12.4))') ' PXPROF,PYPROF,PZPROF,EPROF',
     +  PXPROF,PYPROF,PZPROF,EPROF
      ENDIF
C
C--------------------------------------------------
C***  FOR PARTICLES OF THE H-N-COLLISION, STORE THE KINEM.VARIABLES IN
C*** COMMON /FINLSP/
C--------------------------------------------------
      CXF=PXPROF/PPROF
      CYF=PYPROF/PPROF
      CZF=PZPROF/PPROF
      IREJ=0
      IF (IIELIN.EQ.0)THEN
        CALL DHADRI(IPRO,PPROF,EPROF,CXF,CYF,CZF,ITTA)
        IF(IRH.EQ.1) IREJ=1
        IF (IPAUPR.GT.2)WRITE(6,1000)IPRO,PPROF,EPROF,CXF,CYF,CZF,ITTA
 1000   FORMAT (' FHAD IPRO,PPROF,EPROF,CXF,CYF,CZF,ITTA',I5,5F10.2,I5)
      ELSEIF(IIELIN.EQ.1) THEN
        CALL ELHAIN(IPRO,PPROF,EPROF,CXF,CYF,CZF,ITTA,IREJ)
      ENDIF
      IF(IREJ.EQ.1) THEN
C                           RETURN ORIGINAL MOMENTA (SEE ELHAIN)
        IRH=2
        ITRH(1)=IPRO
        CXRH(1)=CX
        CYRH(1)=CY
        CZRH(1)=CZ
        ELRH(1)=ELAB
        PLRH(1)=PLAB
        ITRH(2)=ITTA
        CXRH(2)=PHKK(1,ITHKK)/PPTAR
        CYRH(2)=PHKK(2,ITHKK)/PPTAR
        CZRH(2)=PHKK(3,ITHKK)/PPTAR
        ELRH(2)=PHKK(4,ITHKK)
        PLRH(2)=PPTAR
        RETURN
      ENDIF
C
C--------------------------------------------------
C*** LORENTZ-TRANSFORM FROM TRS INTO LS
C--------------------------------------------------
      DO 10 III=1,IRH
      CRSUM=CXRH(III)**2 + CYRH(III)**2 + CZRH(III)**2
        IF(ABS(CRSUM-1.0).GT.1E-4) THEN
          WRITE(6,'(A,I3,1PE12.4)')
     +    ' FHAD: INCORRECT NORM. OF DIRECTION COSINES - III,CRSUM',
     +    III,CRSUM
          RCRSUM=SQRT(CRSUM)
        CXRH(III)=CXRH(III)/RCRSUM
        CYRH(III)=CYRH(III)/RCRSUM
        CZRH(III)=CZRH(III)/RCRSUM
        ENDIF
      AMI=AAM(ITRH(III))
C?      PPS=SQRT(ABS((ELRH(III)-AMI)*(ELRH(III)+AMI))+1.E-6)
      PPS=PLRH(III)
      PSX=CXRH(III)*PPS
      PSY=CYRH(III)*PPS
      PSZ=CZRH(III)*PPS
        IF(IPAUPR.GT.7) THEN
          WRITE(6,'(A,I3,6(1PE12.4))')
     +    ' FHAD: ITRH(I), AMI,ELR,PPS,PSX,PSY,PSZ', ITRH(III),AMI,ELRH
     +    (III),PPS,PSX,PSY,PSZ
        ENDIF
      CALL DALTRA(GAM,BGX,BGY,BGZ, PSX,PSY,PSZ,ELRH(III), PPPS,PPSX,
     +  PPSY,PPSZ,ELRH(III))
      IF(ELRH(III).LT.(PPPS-1D-4)) THEN
          WRITE(6,'(2A/3I3,6(1PE12.4))')
     +    ' FHAD: INCONSISTENT KINEMATICS AFTER ALTRA: ',
     +    ' IIELIN,III,ITRH(III),ELRH(III),PPPS,PSX,PSY,PSZ,AMI',IIELIN,
     +    III,ITRH(III),ELRH(III),PPPS,PSX,PSY,PSZ,AMI
        ELRH(III)=SQRT(PPPS**2 + AMI**2)
        WRITE(6,'(A,1PE12.4)') ' CORRECTED ENERGY ELRH:',ELRH(III)
      WRITE(6,'(2A/2I5,5(1PE12.4))')
     +    '      FHAD: 4-MOM. OF TARGET NUCLEON -',
     +    ' ITHKK, IDHKK , PHKK(1-4)', ITHKK, IDHKK(ITHKK), (PHKK
     +    (K,ITHKK),K=1,5)
        ENDIF
      CXRH(III)=PPSX/PPPS
      CYRH(III)=PPSY/PPPS
      CZRH(III)=PPSZ/PPPS
      PLRH(III)=PPPS
      ETES = ETES - ELRH(III)
        PXTES= PXTES- PPSX
        PYTES= PYTES- PPSY
        PZTES= PZTES- PPSZ
   10 CONTINUE
C
      IF(ABS(ETES).GT.0.001D0) THEN
C     IF(ABS(ETES).GT.0.1041D0) THEN
        IF(IPRI.GE.1) THEN
          WRITE(6,'(A,I5)') ' FHAD: TEST OF E-P CONSERVATION IELINE=',
     +    IIELIN
          WRITE(6,'(3X,A,5(1PE12.4))') ' ETES,PXTES,PYTES,PZTES', ETES,
     +    PXTES,PYTES,PZTES
          WRITE(6,1000)IPRO,PPROF,EPROF,CXF,CYF,CZF,ITTA
        ENDIF
      DO 20 III=1,IRH
        AMI=AAM(ITRH(III))
        PPS=SQRT((ELRH(III)-AMI)*(ELRH(III)+AMI))
        PSX=CXRH(III)*PPS
        PSY=CYRH(III)*PPS
        PSZ=CZRH(III)*PPS
          IF(IPRI.GE.1) THEN
            WRITE(6,'(A,I3,6(1PE12.4))')
     +      ' FHAD: ITRH(I), AMI,ELRH,PPS,PSX,PSY,PSZ', ITRH(III),AMI,
     +      ELRH(III),PPS,PSX,PSY,PSZ
          ENDIF
   20   CONTINUE
      ENDIF
C
      RETURN
      END
**sr 19-11-95: ELHAIN replaced
*
*===elhain=============================================================*
*
      SUBROUTINE ELHAIN(IP,PLA,ELAB,CX,CY,CZ,IT,IREJ)

************************************************************************
* Elastic hadron-hadron scattering.                                    *
* This is a revised version of the original.                           *
* This version dated 26.10.95 is written by S. Roesler                 *
************************************************************************

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      PARAMETER (LOUT=6,LLOOK=9)
      PARAMETER (TWO=2.0D0,ONE=1.0D0,OHALF=0.5D0,ZERO=0.0D0,
     &           TINY10=1.0D-10)

      PARAMETER (ENNTHR = 3.5D0)
      PARAMETER (PLOWH=0.01D0,PHIH=9.0D0,
     &           BLOWB=0.05D0,BHIB=0.2D0,
     &           BLOWM=0.1D0, BHIM=2.0D0)

      CHARACTER*8 ANAME
      COMMON /DPAR/   ANAME(210),AAM(210),GA(210),TAU(210),
     &                IICH(210),IIBAR(210),K1(210),K2(210)

      PARAMETER (MAXFIN=10)
      COMMON /DFINLS/ ITRH(MAXFIN),CXRH(MAXFIN),CYRH(MAXFIN),
     &                CZRH(MAXFIN),ELRH(MAXFIN),PLRH(MAXFIN),IRH

C     DATA TSLOPE /10.0D0/

      IREJ = 0

      PLAB = SQRT( (ELAB-AAM(IP))*(ELAB+AAM(IP)) )
      EKIN = ELAB-AAM(IP)
*   kinematical quantities in cms of the hadrons
      AMP2 = AAM(IP)**2
      AMT2 = AAM(IT)**2
      S    = AMP2+AMT2+TWO*ELAB*AAM(IT)
      ECM  = SQRT(S)
      ECMP = OHALF*ECM+(AMP2-AMT2)/(TWO*ECM)
      PCM  = SQRT( (ECMP-AAM(IP))*(ECMP+AAM(IP)) )

* nucleon-nucleon scattering at E_kin<3.5: use TSAMCS (HETC-KFA)
      IF ( ((IP.EQ.1).OR.(IP.EQ.8)).AND.
     &     ((IT.EQ.1).OR.(IT.EQ.8)).AND.(EKIN.LT.ENNTHR) ) THEN
*   TSAMCS treats pp and np only, therefore change pn into np and
*   nn into pp
         IF (IT.EQ.1) THEN
            KPROJ = IP
         ELSE
            KPROJ = 8
            IF (IP.EQ.8) KPROJ = 1
         ENDIF
         CALL TSAMCS(KPROJ,EKIN,CTCMS)
         T = TWO*PCM**2*(CTCMS-ONE)

* very crude treatment otherwise: sample t from exponential dist.
      ELSE
*   momentum transfer t
         TMAX = TWO*TWO*PCM**2
         RR = (PLAB-PLOWH)/(PHIH-PLOWH)
         IF (IIBAR(IP).NE.0) THEN
            TSLOPE = BLOWB+RR*(BHIB-BLOWB)
         ELSE
            TSLOPE = BLOWM+RR*(BHIM-BLOWM)
         ENDIF
         FMAX = EXP(-TSLOPE*TMAX)-ONE
         R = RNDM(V)
         T = LOG(ONE+R*FMAX+TINY10)/TSLOPE
         IF (T.GT.ZERO) T = LOG(ONE+R*FMAX)/TSLOPE
      ENDIF

*   target hadron in Lab after scattering
      ELRH(2) = (TWO*AMT2-T)/(TWO*AAM(IT))
      PLRH(2) = SQRT( (ELRH(2)-AAM(IT))*(ELRH(2)+AAM(IT)) )
*   projectile hadron in Lab after scattering
      ELRH(1) = ELAB+AAM(IT)-ELRH(2)
      PLRH(1) = SQRT( (ELRH(1)-AAM(IP))*(ELRH(1)+AAM(IP)) )
*   scattering angle of projectile in Lab
      CTLABP = (T-TWO*AMP2+TWO*ELAB*ELRH(1))/(TWO*PLAB*PLRH(1))
      STLABP = SQRT( (ONE-CTLABP)*(ONE+CTLABP) )
      CALL DSFECF(SPLABP,CPLABP)
*   direction cosines of projectile in Lab
**sr mod. for DPMJET: STTRAN-->DRTRAN
      CALL DRTRAN(CX,CY,CZ,CTLABP,STLABP,SPLABP,CPLABP,
     &                          CXRH(1),CYRH(1),CZRH(1))
*   scattering angle of target in Lab
      PLLABT = PLAB-CTLABP*PLRH(1)
      CTLABT = PLLABT/PLRH(2)
      STLABT = SQRT( (ONE-CTLABT)*(ONE+CTLABT) )
*   direction cosines of target in Lab
**sr mod. for DPMJET: STTRAN-->DRTRAN
      CALL DRTRAN(CX,CY,CZ,CTLABT,STLABT,-SPLABP,-CPLABP,
     &                            CXRH(2),CYRH(2),CZRH(2))
*   fill /DFINLS/
      IRH = 2
      ITRH(1) = IP
      ITRH(2) = IT

      RETURN
      END

*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C**************************************************
C
C   ELASTIC CROSS SECTION SUBROUTINES FOR HKK89
C
C   HJM 10/89
C
C******************************************************
C
      SUBROUTINE SIHNEL(IPROJ,ITAR,POO,SIEL)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C********************************************************************
C     VERSION BY HJM 10/89
C     LAST CHANGES HJM 30/08/90
C                      - assignment for several particle types
C                      - low-energy parametrization for K+/-, PBAR - P
C
C     USES SIGEL (NEEDS: SIHNIN, SHPTOT, SIHAEL)
C
C     NOTE: TO BE RENEWED URGENTLY!!!!!!!!!!!!!!!!!!!!!!!!!!
C
C     INPUT VARIABLES:
C     IPROJ  = INCIENT PARTICLE TYPE
C     ITAR   = TARGET NUCLEON TYPE
C     POO    = PARTICLE MOMENTUM IN GEV/C
C
C     OUTPUT VARIABLES:
C     SIEL   = ELASTIC CROSS SECTION IN MB
C
C
C  CONVENTION: ISOSPIN INVARIANCE FOR
C                          NUCLEON-NUCLEON CROSSS SECTIONS
C                          PI+/- NUCLEON
C                          K+/-  NUCLEON
C              TO USE THE IMPROVED LOW-ENERGY CROSS SECTIONS
C              FROM SIHAEL
C********************************************************************
C
      DIMENSION SIKPP(8),SIKMP(8),SIAPP(8),P(8)
      DATA P /0.3D0,0.4D0,0.5D0,0.6D0,0.8D0,1.D0,1.5D0,2.D0/
      DATA SIKPP / 12.0D0, 12.5D0, 13.0D0, 13.0D0, 12.7D0,
     +  12.0D0, 10.2D0, 6.82D0/
      DATA SIKMP / 42.0D0, 33.0D0, 21.0D0, 16.0D0, 19.0D0,
     + 22.0D0,  9.0D0, 7.5D0 /
      DATA SIAPP / 73.0D0, 70.0D0, 62.0D0, 53.0D0, 48.0D0,
     + 43.0D0, 38.0D0, 33.0D0/
C-----------------------------------------------------------------------
      ZERO=0
      ONEONE=1
      AA=ONEONE
      PPOO=POO
      IPPR=IPROJ
C
      IF(ITAR.EQ.8) THEN
        IF(IPROJ.EQ.13) THEN
          IPPR=14
        ELSEIF(IPROJ.EQ.14) THEN
          IPPR=13
        ELSEIF(IPROJ.EQ.1) THEN
          IPPR=8
        ELSEIF(IPROJ.EQ.8) THEN
          IPPR=1
        ELSEIF(IPROJ.EQ.15) THEN
          IPPR=16
        ELSEIF(IPROJ.EQ.16) THEN
          IPPR=15
        ELSEIF(IPROJ.EQ.24) THEN
          IPPR=25
        ELSEIF(IPROJ.EQ.25) THEN
          IPPR=24
        ENDIF
      ENDIF
C
      IF(IPPR.EQ.9) THEN
        IPPR=2
      ELSEIF(IPPR.EQ.17) THEN
        IPPR=1
      ELSEIF(IPPR.EQ.18) THEN
        IPPR=2
      ELSEIF(IPPR.EQ.24) THEN
        IPPR=15
      ELSEIF(IPPR.EQ.25) THEN
        IPPR=16
      ELSEIF(IPPR.GE.20.AND.IPPR.LE.22) THEN
        IPPR=1
      ENDIF
C-----------------------------------------------------------------
C                                          K+/-, PBAR  - P
C                                          Plab < 10 GeV/c
      IF(IPPR.EQ.15.OR.IPPR.EQ.16.OR.IPPR.EQ.2) THEN
C***
        IF(PPOO.LE.2.0) THEN
C
C    CALCULATE THE MOMENTUM INDEX K FOR INTERPOLATION
C
          DO 10 JK=1,8
            IF(PPOO.LE.P(JK)) THEN
              K=JK
                                                                 GOTO 20
            ENDIF
   10     CONTINUE
          K=8
   20     CONTINUE
          KK=K-1
          IF(K.EQ.1) KK=1
C*
          IF(IPPR.EQ.15) THEN
C                                K+  - P
            S1=SIKPP(KK)
            S2=SIKPP(K)
          ELSEIF(IPPR.EQ.16) THEN
C                                K-  - P
            S1=SIKMP(KK)
            S2=SIKMP(K)
          ELSEIF(IPPR.EQ.2) THEN
C                                PBAR - P
            S1=SIAPP(KK)
            S2=SIAPP(K)
          ELSE
            WRITE(6,'(A)')
     +      ' LOGICAL ERROR IN SIHNEL - EXECUTION STOPPED'
            STOP
          ENDIF
          SIEL=S1 + (S2-S1)*(PPOO-P(KK))/(P(K)-P(KK)+1D-7)
          RETURN
C***
        ELSEIF(PPOO.LE.10.0D0) THEN
          IF(IPPR.EQ.15) THEN
C                                K+  - P
            A1=5.84
            A2=17.2
            AN=-3.06
            A3=0.206
            A4=-1.71
          ELSEIF(IPPR.EQ.16) THEN
C                                K-  - P
            A1=7.24
            A2=46.0
            AN=-4.71
            A3=0.279
            A4=-2.35
          ELSEIF(IPPR.EQ.2) THEN
C                                PBAR - P
            A1=10.6
            A2=53.1
            AN=-1.19
            A3=0.136
            A4=-1.41
          ENDIF
C
          ALP=LOG(PPOO)
          SIEL=A1 + A2*PPOO**AN + A3*ALP**2 + A4*ALP
          RETURN
C***
        ELSE
                                                                 GOTO 30
        ENDIF
      ENDIF
C-----------------------------------------------------------------
   30 CONTINUE
      CALL DSIGE(IPPR,AA,PPOO,SIEL,ZLEL)
      RETURN
      END
*-- Author :
C
C++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE DSIGE(IT,AA,POO,SEL,ZL)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C********************************************************************
C     VERSION BY                     J. RANFT
C                                    LEIPZIG
C     LAST CHANGE 01. MAY 84 BY      HJM
C                                    LEIPZIG
C !!  LAST CHANGE  30/08/90    HJM:
C !!           NIZL replaced by SIHNIN, i.e. only useful
C !!                 for hadron-proton scattering in  DTUNUC
C
C
C
C     INPUT VARIABLES:
C     IT     = PARTICLE TYPE
C     AA     = ATOMIC WEIGHT OF THE NUCLEUS
C     POO    = PARTICLE MOMENTUM IN GEV/C
C
C     OUTPUT VARIABLES:
C     SI     = ELASTIC CROSS SECTION IN MB
C     ZL     = INTERACTION LENGTH IN G/CM**2
C
C     OTHER IMPORTANT VARIABLES:
C        SIG    = PROTON/NUCLEI CROSS SECTIONS
C        SEG    = PION/NUCLEI CROSS SECTIONS
C        P      = MOMENTUMS FOR WHICH THE CROSS SECTIONS ARE GIVEN IN
C                 SIG AND SEG
C        A      = NUCLEI FOR WHICH THE CROSS SECTIONS ARE GIVEN IN
C                 SIG AND SEG
C        PLAB   = MOMENTUMS FOR WHICH THE TOTAL CROSS SECTIONS ARE
C                 GIVEN IN SITO
C        SITO   = TOTAL HADRON NUCLEON CROSS SECTIONS FOR NUCLEONS,
C                 PIONS, KAONS AND ANTI-NUCLEONS.
C        ALP    =  EXPONENT OF THE PARAMETRIZATION FOR ANTI-PROTONS,
C                  RANTI-NEUTRONS AND KAONS
C        BET    =  MULTIPLIER OF PARAMETRIZATION FOR ANTI-PROTONS,
C                  ANTI-NEUTRONS AND KAONS
C
C     NOTE1: PRESENTLY CROSS SECTIONS ARE ASSUMED TO BE CONSTANT
C     ABOVE 10.0 GEV/C FOR ALL PARTICLES AND
C     BELOW 0.3 GEV/C FOR NUCLEONS AND BELOW 0.13 GEV/C FOR PIONS
C
C     NOTE2: FOR HADRONS OTHER THAN (1=PROTON,2=ANTI PROTON,8=
C     NEUTRON,9=ANTI NEUTRON,13=POSITIVE PION,14=NEGATIVE PION,15=
C     POSITIVE KAON,16=NEGATIVE KAON,24=NEUTRAL KAON,25=NEUTRAL ANTI
C     KAON) SEE TABLE ITT TO SEE THE CORRESPONDANCE
C
C     NOTE3: FOR LEPTONS AND PHOTONS PRACTICALLY ZERO CROSS SECTION
C     IS RETURNED.
C
C********************************************************************
C
*KEEP,DPAR.
C     /DPAR/   CONTAINS PARTICLE PROPERTIES
C        ANAME  = LITERAL NAME OF THE PARTICLE
C        AAM    = PARTICLE MASS IN GEV
C        GA     = DECAY WIDTH
C        TAU    = LIFE TIME OF INSTABLE PARTICLES
C        IICH   = ELECTRIC CHARGE OF THE PARTICLE
C        IIBAR  = BARYON NUMBER
C        K1,K1  = BIGIN AND END OF DECAY CHANNELS OF PARTICLE
C
      CHARACTER*8  ANAME
      COMMON /DPAR/ ANAME(210),AAM(210),GA(210),TAU(210),IICH(210),
     +IIBAR(210),K1(210),K2(210)
C------------------
*KEND.
C--------------------------------------------------------------
C--------------------------------------------------------------------
      DIMENSION SIG(13,9),SEG(16,9),P(16),A(9),ITT(39)
      DIMENSION PLAB(19),SITO(19,4),ALP(3),BET(3)
      DIMENSION REA(9,9),STOT(9)
      SAVE A, P, SIG, SEG, ITT, SITO, PLAB, ALP, BET, STOT, REA
      DATA A/9.D0,12.D0,27.D0,47.9D0,55.9D0,63.5D0,112.4D0,
     &207.2D0,238.1D0/
      DATA P/.13D0,.19D0,.25D0,.3D0,.4D0,.5D0,.6D0,.8D0,1.D0,
     &1.5D0,2.D0,3.D0,4.D0,5.D0,6.D0,10.D0/
      DATA SIG/ 485.D0,223.D0,112.D0,82.D0,66.D0,78.D0,96.D0,102.D0,
     &100.D0,98.D0,95.D0,90.D0,79.D0,
     (680.D0,348.D0,175.D0,103.D0,84.D0,87.D0,106.D0,112.D0,111.D0,
     &108.D0,107.D0,105.D0,101.D0,
     (1200.D0,738.D0,387.D0,196.D0,191.D0,200.D0,248.D0,264.D0,
     &264.D0,257.D0,252.D0,247.D0,228.D0,
     (1658.D0,1110.D0,635.D0,364.D0,332.D0,356.D0,404.D0,408.D0,
     &407.D0,404.D0,398.D0,396.D0,384.D0,
     (1730.D0,1270.D0,725.D0,400.D0,375.D0,412.D0,495.D0,505.D0,
     &495.D0,492.D0,487.D0,485.D0,475.D0,
     (1875.D0,1470.D0,835.D0,480.D0,450.D0,450.D0,535.D0,
     &580.D0,555.D0,540.D0,535.D0,530.D0,
     (525.D0,2040.D0,2160.D0,1335.D0,850.D0,740.D0,760.D0,880.D0,
     &905.D0,860.D0,840.D0,820.D0,815.D0,800.D0,
     (2340.D0,2980.D0,2270.D0,1450.D0,1230.D0,1230.D0,
     &1380.D0,1420.D0,1410.D0,1380.D0,1360.D0,
     (1350.D0,1320.D0,2680.D0,3220.D0,2530.D0,1630.D0,1420.D0,1450.D0,
     &1570.D0,1600.D0,1590.D0,1575.D0,1560.D0,1550.D0,1540.D0/
      DATA SEG/24.D0,128.D0,249.D0,256.D0,202.D0,124.D0,73.D0,60.D0,
     &64.D0,69.D0,62.D0,50.D0,44.D0,42.D0,42.D0,41.D0,21.D0,156.D0,
     (273.D0,280.D0,220.D0,212.D0,94.D0,80.D0,82.D0,85.D0,80.D0,73.D0,
     (69.D0,67.D0,66.D0,64.D0,56.D0,296.D0,560.D0,574.D0,467.D0,350.D0,
     &235.D0,210.D0,210.D0,200.D0,190.D0,183.D0,176.D0,170.D0,165.D0,
     (155.D0,100.D0,500.D0,895.D0,880.D0,690.D0,520.D0,378.D0,
     (355.D0,384.D0,373.D0,352.D0,320.D0,300.D0,288.D0,280.D0,
     &262.D0,75.D0,500.D0,965.D0,990.D0,775.D0,525.D0,410.D0,410.D0,
     (433.D0,440.D0,425.D0,395.D0,374.D0,355.D0,340.D0,303.D0,125.D0,
     (570.D0,1025.D0,1100.D0,825.D0,575.D0,418.D0,458.D0,500.D0,
     &480.D0,460.D0,440.D0,422.D0,400.D0,384.D0,355.D0,300.D0,880.D0,
     (1480.D0,1550.D0,1380.D0,940.D0,710.D0,720.D0,810.D0,760.D0,
     (740.D0,700.D0,665.D0,645.D0,620.D0,570.D0,550.D0,1475.D0,
     &2250.D0,2350.D0,1850.D0,1500.D0,
     (1120.D0,1210.D0,1480.D0,1440.D0,1400.D0,1320.D0,
     &1250.D0,1210.D0,1170.D0,1065.D0,540.D0,
     (1300.D0,2220.D0,2560.D0,1980.D0,1650.D0,1160.D0,
     &1360.D0,1600.D0,1560.D0,1510.D0,1410.D0,
     (1350.D0,1300.D0,1270.D0,1200.D0/
C     DATA ITT/1,7,0,0,0,0,0,2,8,0,0,9,3,4,6,5,1,2,9,1,1,1,3,9,10,
      DATA ITT/1,7,0,0,0,0,0,2,8,0,0,9,3,4,6,5,2,8,9,1,1,2,3,9,10,
     &         3,0,0,0,0,7,2,7,2,8,1,7,1,7/
      DATA PLAB/.3D0,.4D0,.5D0,.6D0,.7D0,.8D0,.9D0,1.D0,1.1D0,
     &1.2D0,1.3D0,1.4D0,1.5D0,2.D0,3.D0,4.D0,
     *5.D0,6.D0,10.D0/
      DATA SITO/66.8D0,63.6D0,40.35D0,31.25D0,31.1D0,
     *35.1D0,36.7D0,44.15D0,38.3D0,33.25D0,
     *29.75D0,29.3D0,29.95D0,26.55D0,24.6D0,22.95D0,
     *22.75D0,22.95D0,21.55D0,
     *12.5D0,14.1D0,13.5D0,12.75D0,12.85D0,13.9D0,15.6D0,
     *17.25D0,18.9D0,19.5D0,18.95D0,18.85D0,
     *18.45D0,18.2D0,17.5D0,17.7D0,17.5D0,17.25D0,17.4D0,
     *39.65D0,38.75D0,26.9D0,22.D0,22.D0,24.5D0,26.15D0,30.7D0,28.6D0,
     &26.4D0,24.35D0,24.1D0,24.2D0
     (,22.4D0,21.05D0,20.3D0,20.1D0,20.1D0,19.5D0,
     (280.D0,199.7D0,171.1D0,154.3D0,140.D0,130.D0,116.8D0,117.4D0,
     &111.6D0,109.D0,106.5D0,
     (102.8D0,100.D0,90.2D0,76.7D0,68.D0,62.8D0,60.7D0,56.D0/
      DATA ALP/0.823D0,0.843D0,0.630D0/
      DATA BET/1.26D0,1.31D0,0.90D0/
      DATA STOT /15.D0,20.D0,30.D0,40.D0,60.D0,80.D0,
     &100.D0,150.D0,200.D0/
      DATA REA / .20D0,.23D0,.27D0,.30D0,.35D0,.40D0,.47D0,.55D0,.60D0,
     2           .22D0,.26D0,.31D0,.35D0,.40D0,.45D0,.51D0,.59D0,.63D0,
     3           .24D0,.29D0,.36D0,.42D0,.50D0,.56D0,.60D0,.66D0,.68D0,
     4           .26D0,.32D0,.42D0,.49D0,.58D0,.63D0,.66D0,.71D0,.72D0,
     5           .27D0,.33D0,.44D0,.51D0,.61D0,.65D0,.68D0,.72D0,.74D0,
     6           .28D0,.35D0,.46D0,.53D0,.63D0,.66D0,.69D0,.73D0,.745D0,
     7           .35D0,.42D0,.53D0,.62D0,.69D0,.72D0,.74D0,.77D0,.78D0,
     8           .42D0,.51D0,.62D0,.69D0,.75D0,.77D0,.79D0,.81D0,.82D0,
     9           .44D0,.53D0,.64D0,.70D0,.76D0,.78D0,.80D0,.81D0,.82D0 /
C
C
C
C-------------------------------------------------------------
      SEL=1.0D-20
      ZL=1.0D+20
      IF(AA.LT.0.99)RETURN
      IPOL=0
      PO=POO
      IIT=ITT(IT)
      IF(IT.GT.25)IIT=0
      IF(IIT.EQ.0)RETURN
C---------------------------------------------------------
C**                          ELASTIC SCATTERING ON PROTONS
C         HJM 10/88             REASONABLE FOR P, N, PI+/-
C**
      IPR=IT
      IF(IT.EQ.23) IPR=13
      IF((AA.LT.1.5).AND. (IPR.EQ.1.OR.IPR.EQ.8.OR.IPR.EQ.13.OR.IPR.EQ.
     +14)) THEN
      EKE=SQRT(PO**2+AAM(IPR)**2) - AAM(IPR)
        CALL DSIHAE(IPR,EKE,PO,AA,SEL)
                                                                GOTO 220
      ENDIF
C**
C                            NEUTRON-NUCLEUS ELASTIC SCATTERING
C                            DATA FROM HETKFA2 FOR  EKIN .GT. 15 MEV
C                            FOR PLOTS SEE
C                               P. CLOTH ET AL.,
C                               HERMES - A MC PROGRAM SYSTEM ...
C                               JUEL-2203 (MAY 1988)
C
      IF(IT.EQ.8.AND.PO.LT.20.0D0) THEN
        IF(PO.GT.10) THEN
          IPOL=1
          PO=10.0
        ENDIF
      EKE=SQRT(PO**2+AAM(IT)**2) - AAM(IT)
        CALL DSIHAE(IT,EKE,PO,AA,SEL)
        IF(IPOL.EQ.1)                                           GOTO 240
                                                                GOTO 220
      ENDIF
C-----------------------------------------------------------
C
C
C********************************************************************
C     CALCULATE THE NEW PARTICLE NUMBER IIT:   1=P,2=N,3=PI+,4=PI-,
C     5=K-,6=K+,7=P BAR,8=N BAR,9=K ZERO ,10=K ZERO BAR
C********************************************************************
C
      IF((IIT.EQ.7).OR.(IIT.EQ.8))                              GOTO 250
      IF (PO.GT.20.D0)                                         GOTO 250
      IF(PO.LE.10.D0)                                          GOTO 10
      PO=10.
      IPOL=1
   10 CONTINUE
      IF(IIT.LE.4)                                              GO TO 40
C
C********************************************************************
C     MOMENTUM INDEX K FOR KAONS ANTI KAONS AND ANTI NUCLEONS
C********************************************************************
C
      DO 20 K=1,19
        IF(PO.LE.PLAB(K))                                       GO TO 30
   20 CONTINUE
      K=19
   30                                                           GO TO 90
C
C********************************************************************
C     CALCULATE THE MOMENTUM INDEX K FOR NUCLEONS AND PIONS
C     CALCULATE THE MASS INDEX J OF THE NUCLEUS
C********************************************************************
C
   40 CONTINUE
      DO 50 K=1,16
        IF(PO.LE.P(K))                                          GO TO 60
   50 CONTINUE
      K=16
   60 CONTINUE
      DO 80 I=2,8
        IF(AA.LE.A(I))                                          GO TO 70
                                                                GO TO 80
   70   CONTINUE
        J=I-1
                                                                GO TO 90
   80 CONTINUE
      J=8
C
C********************************************************************
C     SELECT THE FORMULEI TO BE USED FOR DIFFERENT PARTICLE TYPES
C********************************************************************
C
   90 CONTINUE
C             P , N ,PI+,PI-,K- ,K+ ,AP ,AN ,K0 ,AK0
      GO TO (100,100,110,110,120,130,140,150,130,120),IIT
C******************** PROTONS,NEUTRONS,OTHERS
  100 K=K-3
      IF(K.LT.1) K=1
      ALOGA=LOG(A(J+1)/A(J))
      AAA=AA/A(J)
      SI1=SIG(K,J)* AAA     **(LOG(SIG(K,J+1)/SIG(K,J))/ALOGA)
      IF(K.EQ.1)                                               GO TO 230
      KK=K-1
      SI2=SIG(KK,J)* AAA     **(LOG(SIG(KK,J+1)/SIG(KK,J))/ALOGA)
      K=K+3
      KK=KK+3
      SI=SI1+(PO-P(K))*(SI2-SI1)/(P(KK)-P(K))
C
      SEL=SI
C
                                                               GO TO 210
C******************** CHARGED PIONS
  110 CONTINUE
      ALOGA=LOG(A(J+1)/A(J))
      AAA=AA/A(J)
      SI1=SEG(K,J)* AAA     **(LOG(SEG(K,J+1)/SEG(K,J))/ALOGA)
      IF(K.EQ.1)                                               GO TO 230
      KK=K-1
      SI2=SEG(KK,J)* AAA     **(LOG(SEG(KK,J+1)/SEG(KK,J))/ALOGA)
      SI=SI1+(PO-P(K))*(SI2-SI1)/(P(KK)-P(K))
C
      SEL=SI
C
                                                               GO TO 210
C******************** K-,K ZERO BAR
  120 CONTINUE
      IA=1
      IS=1
                                                               GO TO 160
C******************** K+, K ZERO
  130 CONTINUE
      IA=2
      IS=2
                                                               GO TO 160
C******************** P BAR
  140 CONTINUE
C******************** N BAR
  150 CONTINUE
C
      PO=POO
                                                                GOTO 250
C
C
C********************************************************************
C     KAONS, ANTI KAONS
C********************************************************************
C
  160 KK=K-1
      IF(K.EQ.1)                                               GO TO 170
      PKK=PLAB(KK)
      SIKK=SITO(KK,IS)
      SI=(SITO(K,IS)-SIKK)*(PO-PKK)/(PLAB(K)-PKK)+SIKK
                                                               GO TO 180
  170 SI=SITO(K,IS)
  180 SI1=SI
      SI=BET(IA)*SI*AA**ALP(IA)
      IV=IT
      IF(IV.NE.24)                                             GO TO 190
      IV=15
      SI=SI*2.06
                                                               GO TO 200
  190 IF(IV.EQ.25) IV=16
C*** 151  CALL NIZL(IV,AA,PO,SINEL,ZLIN)      *** 30/08/90
  200 CALL SIHNIN(IV,1,PO,SINEL)
C
      SEL=SI-SINEL
      IF(IPOL.EQ.1)                                             GOTO 240
                                                                GOTO 210
C
C********************************************************************
C     AND NOW THE SCATTERING LENGTH IN G/CM**2
C********************************************************************
C
  210 CONTINUE
      IF(IPOL.EQ.1)                                             GOTO 240
  220 CONTINUE
C
      IF(SEL.LT.1.D-15) SEL=1.D-15
      ZL=10000.D0*AA/(6.022*SEL)
      RETURN
C
C********************************************************************
C     WE ARE IN THE LOWEST MOMENTUM BIN
C********************************************************************
C
  230 SI=SI1
      SEL=SI
                                                               GO TO 210
C***
C   ENTRY FOR SMOOTHING OF SIGEL BETWEEN 10. AND 20. GEV/C
C***
  240 CONTINUE
      PO=20.
C***
C   APPROXIMATION FOR HIGH ENERGIES
C***
  250 CONTINUE
C
      IT1=IT
      IF((IT.EQ.2).OR.(IT.EQ.9)) IT1=1
C
      STO=DSHPTO(IT1,PO)
C
C   MASS NUMBER INDEX
C***
      DO 260 IA=2,8
        IF(AA.GT.A(IA))                                         GOTO 260
        JA=IA-1
                                                                GOTO 270
  260 CONTINUE
      JA=8
  270 CONTINUE
C***
C   SIGTOT INDEX
C***
      DO 280 IS=2,8
        IF(STO.GT.STOT(IS))                                     GOTO 280
        JS=IS-1
                                                                GOTO 290
  280 CONTINUE
      JS=8
  290 CONTINUE
C
      DA1=A(JA+1)-A(JA)
      DA2=AA - A(JA)
      RR=REA(JS,JA)
      R1=RR + DA2*(REA(JS,JA+1)-RR)/DA1
      RR=REA(JS+1,JA)
      R2=RR + DA2*(REA(JS+1,JA+1)-RR)/DA1
      RACT=R1 + (STO-STOT(JS))*(R2-R1)/(STOT(JS+1)-STOT(JS))
C
C***     CALL NIZL(IT,AA,PO,SINEL1,ZLIN)          ***  30/08/90
      CALL SIHNIN(IT,1,PO,SINEL1)
      SEL1=RACT*SINEL1
      IF(IPOL.EQ.1)                                             GOTO 300
      SEL=SEL1
                                                                GOTO 220
C
  300 CONTINUE
      SEL=SEL + (SEL1-SEL)*(POO-10.)/10.
                                                                GOTO 220
C
C
C********************************************************************
C     FORMATS
C********************************************************************
C
 1000 FORMAT('          WARNING AT CALL SIGEL  ',I5)
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE DSIHAE(KPROJ,EKIN,PLAB,ANUC,SIGELA)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C***
C        HJM 22/10/88
C        HJM 29/08/90 :
C                  correction of pi- proton data (Plab < 1.8 GeV/c)
C
C        CROSS SECTIONS FOR ELASTIC SCATTERING
C
C        INCLUDING - PION/NUCLEON PROTON DATA FROM BERTINI (HETKFA2)
C
C                  - ...  HIGH-ENERGY APPROXIMATION:
C                                       SIGEL/SIGTOT = CONST
C
C                  - NUCLEON-NUCLEUS DATA FROM HETKFA2
C***
*KEEP,DPAR.
C     /DPAR/   CONTAINS PARTICLE PROPERTIES
C        ANAME  = LITERAL NAME OF THE PARTICLE
C        AAM    = PARTICLE MASS IN GEV
C        GA     = DECAY WIDTH
C        TAU    = LIFE TIME OF INSTABLE PARTICLES
C        IICH   = ELECTRIC CHARGE OF THE PARTICLE
C        IIBAR  = BARYON NUMBER
C        K1,K1  = BIGIN AND END OF DECAY CHANNELS OF PARTICLE
C
      CHARACTER*8  ANAME
      COMMON /DPAR/ ANAME(210),AAM(210),GA(210),TAU(210),IICH(210),
     +IIBAR(210),K1(210),K2(210)
C------------------
*KEND.
      PARAMETER (NEN=106)
      PARAMETER (NEA=23)
      PARAMETER (NNAA=10)
      DIMENSION EKIHN(NEN),EKIHA(NEA),AMASS(NNAA)
      DIMENSION SEPIMP(NEN),SEPIPP(NEN),SEPP(NEN),SENP(NEN)
      DIMENSION SENA(NEA,NNAA),SEPA(NEA,NNAA)
      DIMENSION TSIG(2)
      DIMENSION RELTO(14)
C*************************************************************8*
*                                                                     *
*=== dblprc ==========================================================*
*                                                                     *
*---------------------------------------------------------------------*
*                                                                     *
*      Dblprc: included in any routine                                *
*                                                                     *
*  !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!  *
*  !!!! O N   M A C H I N E S   W H E R E   T H E   D O U B L E !!!!  *
*  !!!! P R E C I S I O N   I S   N O T   R E Q U I R E D  R E -!!!!  *
*  !!!! M O V E   T H E   D O U B L E   P R E C I S I O N       !!!!  *
*  !!!! S T A T E M E N T,  S E T   K A L G N M = 1   A N D     !!!!  *
*  !!!! C H A N G E   A L L   N U M E R I C A L   C O N S -     !!!!  *
*  !!!! T A N T S   T O   S I N G L E   P R E C I S I O N       !!!!  *
*  !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!  *
*                                                                     *
*         Kalgnm = real address alignment, 2 for double precision,    *
*                  1 for single precision                             *
*         Anglgb = this parameter should be set equal to the machine  *
*                  "zero" with respect to unit                        *
*         Anglsq = this parameter should be set equal to the square   *
*                  of Anglgb                                          *
*         Axcssv = this parameter should be set equal to the number   *
*                  for which unity is negligible for the machine      *
*                  accuracy                                           *
*         Andrfl = "underflow" of the machine for floating point      *
*                  operation                                          *
*         Avrflw = "overflow"  of the machine for floating point      *
*                  operation                                          *
*         Ainfnt = code "infinite"                                    *
*         Azrzrz = code "zero"                                        *
*         Einfnt = natural logarithm of the code "infinite"           *
*         Ezrzrz = natural logarithm of the code "zero"               *
*         Onemns = 1- of the machine, it is 1 - 2 x Anglgb            *
*         Onepls = 1+ of the machine, it is 1 + 2 x Anglgb            *
*         Csnnrm = maximum tolerable error on cosine normalization,   *
*                  u**2+v**2+w**2: assuming a typical anglgb relative *
*                  error on each component we would get 2xanglgb: use *
*                  4xanglgb to avoid too many normalizations          *
*         Dmxtrn = "infinite" distance for transport (cm)             *
*                                                                     *
*---------------------------------------------------------------------*
*                                                                     *
      PARAMETER ( KALGNM = 2 )
      PARAMETER ( ANGLGB = 5.0D-16 )
      PARAMETER ( ANGLSQ = 2.5D-31 )
      PARAMETER ( AXCSSV = 0.2D+16 )
      PARAMETER ( ANDRFL = 1.0D-38 )
      PARAMETER ( AVRFLW = 1.0D+38 )
      PARAMETER ( AINFNT = 1.0D+30 )
      PARAMETER ( AZRZRZ = 1.0D-30 )
      PARAMETER ( EINFNT = +69.07755278982137 D+00 )
      PARAMETER ( EZRZRZ = -69.07755278982137 D+00 )
      PARAMETER ( ONEMNS = 0.999999999999999  D+00 )
      PARAMETER ( ONEPLS = 1.000000000000001  D+00 )
      PARAMETER ( CSNNRM = 2.0D-15 )
      PARAMETER ( DMXTRN = 1.0D+08 )
*
*======================================================================*
*======================================================================*
*=========                                                   ==========*
*=========    M A T H E M A T I C A L   C O N S T A N T S    ==========*
*=========                                                   ==========*
*======================================================================*
*======================================================================*
*                                                                      *
*   Numerical constants:                                               *
*                                                                      *
*         Zerzer = 0                                                   *
*         Oneone = 1                                                   *
*         Twotwo = 2                                                   *
*         Thrthr = 3                                                   *
*         Foufou = 4                                                   *
*         Fivfiv = 5                                                   *
*         Sixsix = 6                                                   *
*         Sevsev = 7                                                   *
*         Eigeig = 8                                                   *
*         Aninen = 9                                                   *
*         Tenten = 10                                                  *
*         Hlfhlf = 1/2                                                 *
*         Onethi = 1/3                                                 *
*         Twothi = 2/3                                                 *
*         Pipipi = Circumference / diameter                            *
*         Eneper = "e", base of natural logarithm                      *
*         Sqrent = square root of "e"                                  *
*                                                                      *
*----------------------------------------------------------------------*
*
      PARAMETER ( ZERZER = 0.D+00 )
      PARAMETER ( ONEONE = 1.D+00 )
      PARAMETER ( TWOTWO = 2.D+00 )
      PARAMETER ( THRTHR = 3.D+00 )
      PARAMETER ( FOUFOU = 4.D+00 )
      PARAMETER ( FIVFIV = 5.D+00 )
      PARAMETER ( SIXSIX = 6.D+00 )
      PARAMETER ( SEVSEV = 7.D+00 )
      PARAMETER ( EIGEIG = 8.D+00 )
      PARAMETER ( ANINEN = 9.D+00 )
      PARAMETER ( TENTEN = 10.D+00 )
      PARAMETER ( HLFHLF = 0.5D+00 )
      PARAMETER ( ONETHI = ONEONE / THRTHR )
      PARAMETER ( TWOTHI = TWOTWO / THRTHR )
      PARAMETER ( PIPIPI = 3.1415926535897932270 D+00 )
      PARAMETER ( ENEPER = 2.7182818284590452354 D+00 )
      PARAMETER ( SQRENT = 1.6487212707001281468 D+00 )
*
*======================================================================*
*======================================================================*
*=========                                                   ==========*
*=========       P H Y S I C A L   C O N S T A N T S         ==========*
*=========                                                   ==========*
*======================================================================*
*======================================================================*
*                                                                      *
*   Primary constants:                                                 *
*                                                                      *
*         Clight = speed of light in cm s-1                            *
*         Avogad = Avogadro number                                     *
*         Amelgr = electron mass (g)                                   *
*         Plckbr = reduced Planck constant (erg s)                     *
*         Elccgs = elementary charge (CGS unit)                        *
*         Elcmks = elementary charge (MKS unit)                        *
*         Amugrm = Atomic mass unit (g)                                *
*         Ammumu = Muon mass (amu)                                     *
*                                                                      *
*   Derived constants:                                                 *
*                                                                      *
*         Alpfsc = Fine structure constant  = e^2/(hbar c)             *
*         Amelct = Electron mass (GeV) = 10^-16Amelgr Clight^2 / Elcmks*
*         Amugev = Atomic mass unit (GeV) = 10^-16Amelgr Clight^2      *
*                                           / Elcmks                   *
*         Ammuon = Muon mass (GeV) = Ammumu * Amugev                   *
*         Fscto2 = (Fine structure constant)^2                         *
*         Fscto3 = (Fine structure constant)^3                         *
*         Fscto4 = (Fine structure constant)^4                         *
*         Plabrc = Reduced Planck constant times the light velocity    *
*                  expressed in GeV fm                                 *
*         Rclsel = Classical electron radius (cm) = e^2 / (m_e c^2)    *
*   Conversion constants:                                              *
*         GeVMeV = from GeV to MeV                                     *
*         eMVGeV = from MeV to GeV                                     *
*         Raddeg = from radians to degrees                             *
*         Degrad = from degrees to radians                             *
*                                                                      *
*----------------------------------------------------------------------*
*
      PARAMETER ( CLIGHT = 2.99792458         D+10 )
      PARAMETER ( AVOGAD = 6.0221367          D+23 )
      PARAMETER ( AMELGR = 9.1093897          D-28 )
      PARAMETER ( PLCKBR = 1.05457266         D-27 )
      PARAMETER ( ELCCGS = 4.8032068          D-10 )
      PARAMETER ( ELCMKS = 1.60217733         D-19 )
      PARAMETER ( AMUGRM = 1.6605402          D-24 )
      PARAMETER ( AMMUMU = 0.113428913        D+00 )
*     PARAMETER ( ALPFSC = 1.D+00 / 137.035989561D+00 )
*     PARAMETER ( FSCTO2 = ALPFSC * ALPFSC )
*     PARAMETER ( FSCTO3 = FSCTO2 * ALPFSC )
*     PARAMETER ( FSCTO4 = FSCTO3 * ALPFSC )
*    It is important to set the electron mass exactly with the same
*    rounding as in the mass tables, so use the explicit expression
*     PARAMETER ( AMELCT = 1.D-16 * AMELGR * CLIGHT * CLIGHT / ELCMKS )
*    It is important to set the amu mass exactly with the same
*    rounding as in the mass tables, so use the explicit expression
*     PARAMETER ( AMUGEV = 1.D-16 * AMUGRM * CLIGHT * CLIGHT / ELCMKS )
*    It is important to set the muon mass exactly with the same
*    rounding as in the mass tables, so use the explicit expression
*     PARAMETER ( AMMUON = AMMUMU * AMUGEV ELCMKS )
*     PARAMETER ( RCLSEL = ELCCGS * ELCCGS / CLIGHT / CLIGHT / AMELGR )
      PARAMETER ( ALPFSC = 7.2973530791728595 D-03 )
      PARAMETER ( FSCTO2 = 5.3251361962113614 D-05 )
      PARAMETER ( FSCTO3 = 3.8859399018437826 D-07 )
      PARAMETER ( FSCTO4 = 2.8357075508200407 D-09 )
      PARAMETER ( PLABRC = 0.197327053        D+00 )
      PARAMETER ( AMELCT = 0.51099906         D-03 )
      PARAMETER ( AMUGEV = 0.93149432         D+00 )
      PARAMETER ( AMMUON = 0.105658389        D+00 )
      PARAMETER ( RCLSEL = 2.8179409183694872 D-13 )
      PARAMETER ( GEVMEV = 1.0                D+03 )
      PARAMETER ( EMVGEV = 1.0                D-03 )
      PARAMETER ( RADDEG = 180.D+00 / PIPIPI )
      PARAMETER ( DEGRAD = PIPIPI / 180.D+00 )
  
*$ CREATE IOUNIT.ADD
*COPY IOUNIT
*                                                                     *
*=== iounit ==========================================================*
*                                                                     *
*---------------------------------------------------------------------*
*                                                                     *
*      Iounit: included in any routine                                *
*                                                                     *
*         lunin  = standard input unit                                *
*         lunout = standard output unit                               *
*         lunerr = standard error unit                                *
*         lunber = input file for bertini nuclear data                *
*         lunech = echo file for pegs dat                             *
*         lunflu = input file for photoelectric edges and X-ray fluo- *
*                  rescence data                                      *
*         lungeo = scratch file for combinatorial geometry            *
*         lunpgs = input file for pegs material data                  *
*         lunran = output file for the final random number seed       *
*         lunxsc = input file for low energy neutron cross sections   *
*         lunrdb = unit number for reading (extra) auxiliary external *
*                  files to be closed just after reading              *
*                                                                     *
*---------------------------------------------------------------------*
*                                                                     *
      PARAMETER ( LUNIN  = 5  )
      PARAMETER ( LUNOUT = 6  )
      PARAMETER ( LUNERR = 66 )
      PARAMETER ( LUNBER = 14 )
      PARAMETER ( LUNECH = 8  )
      PARAMETER ( LUNFLU = 86 )
      PARAMETER ( LUNGEO = 16 )
      PARAMETER ( LUNPGS = 12 )
      PARAMETER ( LUNRAN = 2  )
      PARAMETER ( LUNXSC = 81 )
      PARAMETER ( LUNRDB = 1  )

*$ CREATE DIMPAR.ADD
*COPY DIMPAR
*                                                                     *
*=== dimpar ==========================================================*
*                                                                     *
*---------------------------------------------------------------------*
*                                                                     *
*      DIMPAR: included in any routine                                *
*                                                                     *
*          Mxxrgn = maximum number of regions                         *
*          Mxxmdf = maximum number of media in Fluka                  *
*          Mxxmde = maximum number of media in Emf                    *
*          Mfstck = stack dimension in Fluka                          *
*          Mestck = stack dimension in Emf                            *
*          Nallwp = number of allowed particles                       *
*          Mpdpdx = number of particle types for which EM dE/dx pro-  *
*                   cesses (ion,pair,bremss) have to be computed      *
*          Icomax = maximum number of materials for compounds (equal  *
*                   to the sum of the number of materials for every   *
*                   compound )                                        *
*          Nstbis = number of stable isotopes recorded in common iso- *
*                   top                                               *
*          Idmaxp = number of particles/resonances defined in common  *
*                   part                                              *
*                                                                     *
*---------------------------------------------------------------------*
*                                                                     *
      PARAMETER ( MXXRGN = 500  )
      PARAMETER ( MXXMDF = 56   )
      PARAMETER ( MXXMDE = 50   )
      PARAMETER ( MFSTCK = 1000 )
      PARAMETER ( MESTCK = 100  )
      PARAMETER ( NALLWP = 39   )
      PARAMETER ( MPDPDX = 8    )
      PARAMETER ( ICOMAX = 180  )
      PARAMETER ( NSTBIS = 304  )
      PARAMETER ( IDMAXP = 210  )


C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
*
      SAVE EKIHN, EKIHA, AMASS, SEPIMP, SEPIPP, SEPP, SENP, SENA, SEPA,
     &     TSIG , RELTO
* Statement functions: A.Ferrari 28-4-93
      SIGMLW (E) = 3.D+03 * PIPIPI
     &           / ( 1.206D+03 * E + ( -1.86D+00
     &           + 0.09415D+03 * E + 0.0001306D+06 * E**2
     &           )**2 ) + 1.D+03 * PIPIPI / ( 1.206D+03 * E
     &           + ( 0.4223D+00 + 0.13D+03 * E )**2 )
      SIGMPN (BETAPR) = 34.10D+00 / BETAPR**2 - 82.2D+00 / BETAPR
     &                + 82.2D+00
      SIGMPP (BETAPR) = 10.63D+00 / BETAPR**2 - 29.92D+00 / BETAPR
     &                + 42.9D+00
C***
C   KINETIC ENERGIES FOR TABLE LOOK-UP

      DATA EKIHN /
     &   0.00D0, 0.02D0, 0.04D0, 0.06D0, 0.08D0, 0.10D0, 0.12D0, 0.14D0,
     &   0.16D0, 0.18D0, 0.20D0, 0.22D0, 0.24D0, 0.26D0, 0.28D0, 0.30D0,
     &   0.32D0, 0.34D0, 0.36D0, 0.38D0, 0.40D0, 0.42D0, 0.44D0, 0.46D0,
     &   0.48D0, 0.50D0, 0.52D0, 0.54D0, 0.56D0, 0.58D0, 0.60D0, 0.62D0,
     &   0.64D0, 0.66D0, 0.68D0, 0.70D0, 0.72D0, 0.74D0, 0.76D0, 0.78D0,
     &   0.80D0, 0.82D0, 0.84D0, 0.86D0, 0.88D0, 0.90D0, 0.92D0, 0.94D0,
     &   0.96D0, 0.98D0, 1.00D0, 1.02D0, 1.04D0, 1.06D0, 1.08D0, 1.10D0,
     &   1.12D0, 1.14D0, 1.16D0, 1.18D0, 1.20D0, 1.22D0, 1.24D0, 1.26D0,
     &   1.28D0, 1.30D0, 1.32D0, 1.34D0, 1.36D0, 1.38D0, 1.40D0, 1.42D0,
     &   1.44D0, 1.46D0, 1.48D0, 1.50D0, 1.52D0, 1.54D0, 1.56D0, 1.58D0,
     &   1.60D0, 1.62D0, 1.64D0, 1.66D0, 1.68D0, 1.70D0, 1.72D0, 1.74D0,
     &   1.76D0, 1.78D0, 1.80D0, 1.82D0, 1.84D0, 1.86D0, 1.88D0, 1.90D0,
     &   1.92D0, 1.94D0, 1.96D0, 1.98D0, 2.00D0, 2.5D0,  3.0D0,  3.5D0,
     &   5.0D0, 10.0D0/
      DATA EKIHA /
     &   0.015D0, 0.02D0, 0.025D0, 0.03D0,  0.04D0, 0.05D0, 0.06D0,
     &   0.08D0,  0.10D0, 0.125D0, 0.15D0, 0.175D0, 0.20D0, 0.225D0,
     &   0.25D0,  0.3D0,  0.4D0,   0.6D0,  1.0D0,   2.0D0,  5.0D0,
     &   10.0D0,  22.5D0/
      DATA AMASS /
     &   4.D0, 9.D0, 12.D0, 27.D0, 47.9D0, 55.9D0, 63.5D0, 112.4D0,
     &   207.2D0, 238.1D0/
C-------------------------------------------------------------------
C
C***     PI(-)-P ELASTIC CROSS SECTION DATA
      DATA (SEPIMP(IE),IE=1,50) /
     *     1.250D+00,  1.500D+00,  1.750D+00,  2.450D+00,  3.800D+00,
     *     6.000D+00,  9.700D+00,  1.500D+01,  2.140D+01,  2.310D+01,
     *     2.295D+01,  2.070D+01,  1.795D+01,  1.550D+01,  1.360D+01,
     *     1.230D+01,  1.130D+01,  1.070D+01,  1.050D+01,  1.070D+01,
     *     1.120D+01,  1.175D+01,  1.235D+01,  1.300D+01,  1.400D+01,
     *     1.500D+01,  1.600D+01,  1.700D+01,  1.835D+01,  1.970D+01,
     *     2.050D+01,  1.915D+01,  1.770D+01,  1.650D+01,  1.570D+01,
     *     1.520D+01,  1.510D+01,  1.525D+01,  1.550D+01,  1.600D+01,
     *     1.685D+01,  1.800D+01,  2.000D+01,  2.230D+01,  2.475D+01,
     *     2.635D+01,  2.510D+01,  2.300D+01,  2.140D+01,  2.000D+01/
      DATA (SEPIMP(IE),IE=51,106) /
     *     1.870D+01,  1.750D+01,  1.670D+01,  1.585D+01,  1.505D+01,
     *     1.440D+01,  1.395D+01,  1.340D+01,  1.299D+01,  1.260D+01,
     *     1.215D+01,  1.175D+01,  1.140D+01,  1.099D+01,  1.060D+01,
     *     1.040D+01,  1.010D+01,  9.990D+00,  9.900D+00,  9.750D+00,
     *     9.600D+00,  9.550D+00,  9.450D+00,  9.350D+00,  9.250D+00,
     *     9.250D+00,  9.350D+00,  9.650D+00,  9.850D+00,  1.000D+01,
     *     1.015D+01,  1.030D+01,  1.060D+01,  1.080D+01,  1.095D+01,
     *     1.100D+01,  1.095D+01,  1.090D+01,  1.070D+01,  1.035D+01,
     *     1.000D+01,  9.600D+00,  9.050D+00,  8.550D+00,  8.200D+00,
     *     8.000D+00,  7.850D+00,  7.800D+00,  7.750D+00,  7.700D+00,
     *     7.650D+00,
     *     7.600D+00,  7.240D+00,  6.770D+00,  5.840D+00,  4.570D+00/
* *** The previous 5 points have been substituted to the erroneous
* *** ones from H.J. Mohring by A. Ferrari
C---------------------------------------------------------------------
C
C***     PI(+)-P ELASTIC CROSS SECTION DATA
      DATA (SEPIPP(IE),IE=1,50) /
     *     1.800D+00,  4.000D+00,  9.900D+00,  2.170D+01,  4.000D+01,
     *     6.580D+01,  9.680D+01,  1.392D+02,  1.800D+02,  2.000D+02,
     *     1.655D+02,  1.420D+02,  1.225D+02,  1.032D+02,  8.400D+01,
     *     6.725D+01,  5.510D+01,  4.725D+01,  4.130D+01,  3.690D+01,
     *     3.230D+01,  2.885D+01,  2.600D+01,  2.300D+01,  2.090D+01,
     *     1.875D+01,  1.675D+01,  1.500D+01,  1.340D+01,  1.200D+01,
     *     1.100D+01,  9.980D+00,  9.200D+00,  8.600D+00,  8.200D+00,
     *     8.100D+00,  8.100D+00,  8.250D+00,  8.500D+00,  8.750D+00,
     *     9.000D+00,  9.400D+00,  9.750D+00,  1.000D+01,  1.030D+01,
     *     1.075D+01,  1.130D+01,  1.200D+01,  1.275D+01,  1.330D+01/
      DATA (SEPIPP(IE),IE=51,106) /
     *     1.350D+01,  1.335D+01,  1.330D+01,  1.330D+01,  1.345D+01,
     *     1.355D+01,  1.380D+01,  1.400D+01,  1.460D+01,  1.500D+01,
     *     1.555D+01,  1.625D+01,  1.700D+01,  1.800D+01,  1.875D+01,
     *     1.920D+01,  1.925D+01,  1.890D+01,  1.830D+01,  1.790D+01,
     *     1.725D+01,  1.690D+01,  1.640D+01,  1.600D+01,  1.550D+01,
     *     1.505D+01,  1.475D+01,  1.430D+01,  1.400D+01,  1.365D+01,
     *     1.335D+01,  1.300D+01,  1.280D+01,  1.250D+01,  1.225D+01,
     *     1.205D+01,  1.195D+01,  1.175D+01,  1.150D+01,  1.135D+01,
     *     1.105D+01,  1.095D+01,  1.080D+01,  1.060D+01,  1.030D+01,
     *     1.020D+01,  1.005D+01,  9.900D+00,  9.800D+00,  9.700D+00,
     *     9.600D+00,
     *     7.350D+00,  7.200D+00,  7.000D+00,  5.800D+00,  4.800D+00/
C---------------------------------------------------------------------
C
C***     P-P ELASTIC CROSS SECTION DATA
      DATA (SEPP(IE),IE=1,50) /
     *     6.750D+02,  1.550D+02,  6.750D+01,  4.420D+01,  3.230D+01,
     *     2.800D+01,  2.520D+01,  2.370D+01,  2.300D+01,  2.275D+01,
     *     2.260D+01,  2.260D+01,  2.260D+01,  2.260D+01,  2.270D+01,
     *     2.280D+01,  2.295D+01,  2.300D+01,  2.310D+01,  2.330D+01,
     *     2.350D+01,  2.380D+01,  2.395D+01,  2.420D+01,  2.460D+01,
     *     2.485D+01,  2.500D+01,  2.530D+01,  2.565D+01,  2.600D+01,
     *     2.620D+01,  2.640D+01,  2.660D+01,  2.675D+01,  2.690D+01,
     *     2.700D+01,  2.705D+01,  2.710D+01,  2.715D+01,  2.720D+01,
     *     2.725D+01,  2.725D+01,  2.720D+01,  2.715D+01,  2.710D+01,
     *     2.700D+01,  2.695D+01,  2.680D+01,  2.670D+01,  2.660D+01/
      DATA (SEPP(IE),IE=51,106) /
     *     2.640D+01,  2.625D+01,  2.605D+01,  2.590D+01,  2.570D+01,
     *     2.545D+01,  2.525D+01,  2.500D+01,  2.480D+01,  2.470D+01,
     *     2.450D+01,  2.430D+01,  2.410D+01,  2.395D+01,  2.370D+01,
     *     2.360D+01,  2.340D+01,  2.325D+01,  2.305D+01,  2.290D+01,
     *     2.275D+01,  2.270D+01,  2.260D+01,  2.250D+01,  2.230D+01,
     *     2.225D+01,  2.210D+01,  2.200D+01,  2.195D+01,  2.190D+01,
     *     2.175D+01,  2.165D+01,  2.150D+01,  2.140D+01,  2.125D+01,
     *     2.120D+01,  2.105D+01,  2.100D+01,  2.090D+01,  2.075D+01,
     *     2.065D+01,  2.055D+01,  2.045D+01,  2.030D+01,  2.020D+01,
     *     2.005D+01,  2.000D+01,  1.995D+01,  1.980D+01,  1.975D+01,
     *     1.965D+01,
     *     17.15D+00,  14.45D+00,  13.00D+00,  11.50D+00,  10.50D+00/
C--------------------------------------------------------------------
C
C***     N-P ELASTIC CROSS SECTION DATA
      DATA (SENP(IE),IE=1,50) /
     *     1.965D+03,  4.750D+02,  2.200D+02,  1.300D+02,  9.180D+01,
     *     7.300D+01,  6.030D+01,  5.180D+01,  4.680D+01,  4.320D+01,
     *     4.080D+01,  3.910D+01,  3.760D+01,  3.650D+01,  3.550D+01,
     *     3.480D+01,  3.415D+01,  3.370D+01,  3.325D+01,  3.290D+01,
     *     3.275D+01,  3.250D+01,  3.255D+01,  3.275D+01,  3.285D+01,
     *     3.275D+01,  3.220D+01,  3.150D+01,  3.075D+01,  2.990D+01,
     *     2.875D+01,  2.775D+01,  2.695D+01,  2.630D+01,  2.590D+01,
     *     2.565D+01,  2.560D+01,  2.560D+01,  2.560D+01,  2.565D+01,
     *     2.570D+01,  2.575D+01,  2.578D+01,  2.580D+01,  2.585D+01,
     *     2.580D+01,  2.575D+01,  2.560D+01,  2.540D+01,  2.505D+01/
      DATA (SENP(IE),IE=51,106) /
     *     2.470D+01,  2.425D+01,  2.375D+01,  2.315D+01,  2.275D+01,
     *     2.230D+01,  2.200D+01,  2.175D+01,  2.155D+01,  2.145D+01,
     *     2.130D+01,  2.125D+01,  2.115D+01,  2.105D+01,  2.100D+01,
     *     2.095D+01,  2.090D+01,  2.080D+01,  2.070D+01,  2.060D+01,
     *     2.050D+01,  2.045D+01,  2.040D+01,  2.030D+01,  2.025D+01,
     *     2.020D+01,  2.015D+01,  2.010D+01,  2.005D+01,  2.002D+01,
     *     2.000D+01,  1.999D+01,  1.990D+01,  1.985D+01,  1.975D+01,
     *     1.970D+01,  1.965D+01,  1.960D+01,  1.950D+01,  1.945D+01,
     *     1.940D+01,  1.925D+01,  1.920D+01,  1.915D+01,  1.910D+01,
     *     1.900D+01,  1.898D+01,  1.895D+01,  1.890D+01,  1.880D+01,
     *     1.875D+01,
     *     17.00D+00,  14.40D+00,  12.00D+00,  11.00D+00,  10.00D+00/
C---------------------------------------------------------------------
C
C***     N-A ELASTIC CROSS SECTION DATA
C*                  NEUTRON - HELIUM
      DATA (SENA(IE,1),IE=1,NEA) /
     *     5.103D-01,  5.157D-01,  5.103D-01,  4.777D-01,  4.072D-01,
     *     3.420D-01,  2.714D-01,  1.683D-01,  6.700D-02,  6.100D-02,
     *     5.800D-02,  4.900D-02,  3.800D-02,  3.300D-02,  3.000D-02,
     *     2.400D-02,  2.300D-02,  2.900D-02,  3.600D-02,  4.100D-02,
     *     4.000D-02,  3.700D-02,  3.400D-02/
C
C*                  NEUTRON - BERYLLIUM
      DATA (SENA(IE,2),IE=1,NEA) /
     *     8.762D-01,  8.856D-01,  8.762D-01,  8.203D-01,  6.991D-01,
     *     5.873D-01,  4.661D-01,  2.890D-01,  1.401D-01,  1.305D-01,
     *     1.238D-01,  1.069D-01,  8.495D-02,  7.480D-02,  6.750D-02,
     *     5.565D-02,  5.230D-02,  6.470D-02,  7.765D-02,  8.722D-02,
     *     8.440D-02,  7.821D-02,  7.259D-02/
C
C*                  NEUTRON - CARBON
      DATA (SENA(IE,3),IE=1,NEA) /
     *     9.200D-01,  9.500D-01,  9.400D-01,  8.800D-01,  7.500D-01,
     *     6.100D-01,  5.000D-01,  3.700D-01,  1.820D-01,  1.710D-01,
     *     1.620D-01,  1.410D-01,  1.130D-01,  1.000D-01,  9.000D-02,
     *     7.500D-02,  7.000D-02,  8.600D-02,  1.020D-01,  1.140D-01,
     *     1.100D-01,  1.020D-01,  9.500D-02/
C
C*                  NEUTRON - ALUMINUM
      DATA (SENA(IE,4),IE=1,NEA) /
     *     1.090D+00,  1.180D+00,  1.240D+00,  1.280D+00,  1.260D+00,
     *     1.160D+00,  9.300D-01,  6.300D-01,  3.580D-01,  3.450D-01,
     *     3.350D-01,  2.990D-01,  2.480D-01,  2.220D-01,  2.020D-01,
     *     1.730D-01,  1.610D-01,  1.920D-01,  2.200D-01,  2.420D-01,
     *     2.370D-01,  2.220D-01,  2.060D-01/
C
C*                  NEUTRON - TITANIUM
      DATA (SENA(IE,5),IE=1,NEA) /
     *     1.029D+00,  9.469D-01,  1.091D+00,  1.284D+00,  1.591D+00,
     *     1.691D+00,  1.258D+00,  9.241D-01,  5.620D-01,  5.493D-01,
     *     5.375D-01,  4.907D-01,  4.182D-01,  3.800D-01,  3.484D-01,
     *     3.038D-01,  2.823D-01,  3.307D-01,  3.720D-01,  4.040D-01,
     *     3.959D-01,  3.743D-01,  3.517D-01/
C
C*                  NEUTRON - IRON
      DATA (SENA(IE,6),IE=1,NEA) /
     *     1.178D+00,  9.793D-01,  1.090D+00,  1.271D+00,  1.650D+00,
     *     1.799D+00,  1.339D+00,  1.009D+00,  6.223D-01,  6.132D-01,
     *     6.042D-01,  5.572D-01,  4.812D-01,  4.402D-01,  4.053D-01,
     *     3.554D-01,  3.304D-01,  3.814D-01,  4.244D-01,  4.603D-01,
     *     4.523D-01,  4.293D-01,  4.053D-01/
C
C*                  NEUTRON - COPPER
      DATA (SENA(IE,7),IE=1,NEA) /
     *     1.386D+00,  1.050D+00,  1.134D+00,  1.302D+00,  1.722D+00,
     *     1.922D+00,  1.449D+00,  1.103D+00,  6.762D-01,  6.686D-01,
     *     6.602D-01,  6.131D-01,  5.344D-01,  4.912D-01,  4.541D-01,
     *     4.004D-01,  3.728D-01,  4.273D-01,  4.725D-01,  5.103D-01,
     *     5.022D-01,  4.781D-01,  4.524D-01/
C
C*                  NEUTRON - CADMIUM
      DATA (SENA(IE,8),IE=1,NEA) /
     *     2.029D+00,  1.537D+00,  1.660D+00,  1.906D+00,  2.520D+00,
     *     2.812D+00,  2.121D+00,  1.614D+00,  1.014D+00,  1.012D+00,
     *     1.006D+00,  9.557D-01,  8.607D-01,  8.038D-01,  7.541D-01,
     *     6.775D-01,  6.334D-01,  7.080D-01,  7.669D-01,  8.156D-01,
     *     8.074D-01,  7.769D-01,  7.404D-01/
C
C*                  NEUTRON - LEAD
      DATA (SENA(IE,9),IE=1,NEA) /
     *     3.050D+00,  2.310D+00,  2.495D+00,  2.865D+00,  3.789D+00,
     *     4.228D+00,  3.188D+00,  2.426D+00,  1.536D+00,  1.538D+00,
     *     1.536D+00,  1.488D+00,  1.384D+00,  1.317D+00,  1.256D+00,
     *     1.153D+00,  1.089D+00,  1.185D+00,  1.255D+00,  1.315D+00,
     *     1.307D+00,  1.269D+00,  1.224D+00/
C
C*                  NEUTRON - URANIUM
      DATA (SENA(IE,10),IE=1,NEA) /
     *     3.346D+00,  2.535D+00,  2.738D+00,  3.143D+00,  4.157D+00,
     *     4.639D+00,  3.498D+00,  2.662D+00,  1.685D+00,  1.687D+00,
     *     1.685D+00,  1.632D+00,  1.518D+00,  1.445D+00,  1.378D+00,
     *     1.265D+00,  1.194D+00,  1.300D+00,  1.377D+00,  1.443D+00,
     *     1.434D+00,  1.392D+00,  1.343D+00/
C---------------------------------------------------------------------
C    p-A data changed by A.Ferrari: corresponding n-A data are used at
C        low energies since this is a much better approximation than
C        neglecting "tout court" the elastic scattering
C***     P-A ELASTIC CROSS SECTION DATA
C*                  PROTON - HELIUM
      DATA (SEPA(IE,1),IE=1,NEA) /
*    *   8*0.000D+00,                          6.700D-02,  6.100D-02,
     *     5.103D-01,  5.157D-01,  5.103D-01,  4.777D-01,  4.072D-01,
     *     3.420D-01,  2.714D-01,  1.683D-01,  6.700D-02,  6.100D-02,
     *     5.800D-02,  4.900D-02,  3.800D-02,  3.300D-02,  3.000D-02,
     *     2.400D-02,  2.300D-02,  2.900D-02,  3.600D-02,  4.100D-02,
     *     4.000D-02,  3.700D-02,  3.400D-02/
C
C*                  PROTON - BERYLLIUM
      DATA (SEPA(IE,2),IE=1,NEA) /
*    *   8*0.000D+00,                          1.401D-01,  1.305D-01,
     *     8.762D-01,  8.856D-01,  8.762D-01,  8.203D-01,  6.991D-01,
     *     5.873D-01,  4.661D-01,  2.890D-01,  1.401D-01,  1.305D-01,
     *     1.238D-01,  1.069D-01,  8.495D-02,  7.480D-02,  6.750D-02,
     *     5.565D-02,  5.230D-02,  6.470D-02,  7.765D-02,  8.722D-02,
     *     8.440D-02,  7.821D-02,  7.259D-02/
C
C*                  PROTON - CARBON
      DATA (SEPA(IE,3),IE=1,NEA) /
*    *   8*0.000D+00,                          1.820D-01,  1.710D-01,
     *     9.200D-01,  9.500D-01,  9.400D-01,  8.800D-01,  7.500D-01,
     *     6.100D-01,  5.000D-01,  3.700D-01,  1.820D-01,  1.710D-01,
     *     1.620D-01,  1.410D-01,  1.130D-01,  1.000D-01,  9.000D-02,
     *     7.500D-02,  7.000D-02,  8.600D-02,  1.020D-01,  1.140D-01,
     *     1.100D-01,  1.020D-01,  9.500D-02/
C
C*                  PROTON - ALUMINUM
      DATA (SEPA(IE,4),IE=1,NEA) /
*    *   8*0.000D+00,                          3.650D-01,  3.540D-01,
     *     1.090D+00,  1.180D+00,  1.240D+00,  1.280D+00,  1.260D+00,
     *     1.160D+00,  9.300D-01,  6.300D-01,  3.650D-01,  3.540D-01,
     *     3.420D-01,  3.060D-01,  2.530D-01,  2.260D-01,  2.040D-01,
     *     1.750D-01,  1.610D-01,  1.900D-01,  2.200D-01,  2.430D-01,
     *     2.370D-01,  2.220D-01,  2.070D-01/
C
C*                  PROTON - TITANIUM
      DATA (SEPA(IE,5),IE=1,NEA) /
*    *   8*0.000D+00,                          5.828D-01,  5.726D-01,
     *     1.029D+00,  9.469D-01,  1.091D+00,  1.284D+00,  1.591D+00,
     *     1.691D+00,  1.258D+00,  9.241D-01,  5.828D-01,  5.726D-01,
     *     5.594D-01,  5.100D-01,  4.310D-01,  3.897D-01,  3.561D-01,
     *     3.084D-01,  2.829D-01,  3.262D-01,  3.714D-01,  4.066D-01,
     *     3.985D-01,  3.764D-01,  3.517D-01/
C
C*                  PROTON - IRON
      DATA (SEPA(IE,6),IE=1,NEA) /
*    *   8*0.000D+00,                          6.383D-01,  6.313D-01,
     *     1.178D+00,  9.793D-01,  1.090D+00,  1.271D+00,  1.650D+00,
     *     1.799D+00,  1.339D+00,  1.009D+00,  6.383D-01,  6.313D-01,
     *     6.212D-01,  5.732D-01,  4.913D-01,  4.483D-01,  4.113D-01,
     *     3.594D-01,  3.304D-01,  3.764D-01,  4.243D-01,  4.623D-01,
     *     4.543D-01,  4.313D-01,  4.053D-01/
C
C*                  PROTON - COPPER
      DATA (SEPA(IE,7),IE=1,NEA) /
*    *   8*0.000D+00,                          6.950D-01,  6.895D-01,
     *     1.386D+00,  1.050D+00,  1.134D+00,  1.302D+00,  1.722D+00,
     *     1.922D+00,  1.449D+00,  1.103D+00,  6.950D-01,  6.895D-01,
     *     6.803D-01,  6.322D-01,  5.471D-01,  5.014D-01,  4.619D-01,
     *     4.048D-01,  3.728D-01,  4.211D-01,  4.722D-01,  5.135D-01,
     *     5.051D-01,  4.804D-01,  4.527D-01/
C
C*                  PROTON - CADMIUM
      DATA (SEPA(IE,8),IE=1,NEA) /
*    *   8*0.000D+00,                          1.045D+00,  1.043D+00,
     *     2.029D+00,  1.537D+00,  1.660D+00,  1.906D+00,  2.520D+00,
     *     2.812D+00,  2.121D+00,  1.614D+00,  1.045D+00,  1.043D+00,
     *     1.036D+00,  9.718D-01,  8.822D-01,  8.211D-01,  7.679D-01,
     *     6.828D-01,  6.325D-01,  6.951D-01,  7.647D-01,  8.232D-01,
     *     8.138D-01,  7.935D-01,  7.415D-01/
C
C*                  PROTON - LEAD
      DATA (SEPA(IE,9),IE=1,NEA) /
*    *   8*0.000D+00,                          1.589D+00,  1.584D+00,
     *     3.050D+00,  2.310D+00,  2.495D+00,  2.865D+00,  3.789D+00,
     *     4.228D+00,  3.188D+00,  2.426D+00,  1.589D+00,  1.584D+00,
     *     1.577D+00,  1.528D+00,  1.417D+00,  1.345D+00,  1.277D+00,
     *     1.159D+00,  1.086D+00,  1.159D+00,  1.252D+00,  1.331D+00,
     *     1.320D+00,  1.278D+00,  1.256D+00/
C
C*                  PROTON - URANIUM
      DATA (SEPA(IE,10),IE=1,NEA) /
*    *   8*0.000D+00,                          1.743D+00,  1.738D+00,
     *     3.346D+00,  2.535D+00,  2.738D+00,  3.143D+00,  4.157D+00,
     *     4.639D+00,  3.498D+00,  2.662D+00,  1.743D+00,  1.738D+00,
     *     1.730D+00,  1.676D+00,  1.554D+00,  1.475D+00,  1.401D+00,
     *     1.271D+00,  1.191D+00,  1.271D+00,  1.373D+00,  1.460D+00,
     *     1.448D+00,  1.402D+00,  1.378D+00/
C
      DATA RELTO / 0.175D+00, 6*0.D+00, 0.175D+00, 4*0.D+00, 0.14D+00,
     *             0.14 D+00/
C
C--------------------------------------------------------------------

C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C--------------------------------------------------------------------
C
      IF(ANUC.LT.1.5D0) THEN
C                               HADRON-PROTON ELASTIC CROSS SECTIONS
        IPOL=0
        EK1=EKIN
        IF(EKIN.GT.20.0D0) THEN
          SIGELA=RELTO(KPROJ)*DSHPTO(KPROJ,PLAB)
          RETURN
        ELSEIF(EKIN.GT.10.0D0) THEN
          IPOL=1
          PO2=20.0
        EK2=SQRT(PO2**2+AAM(KPROJ)**2) - AAM(KPROJ)
          SEL2=RELTO(KPROJ)*DSHPTO(KPROJ,PO2)
          EK1=10.0
C
         ELSE IF ( EKIN .LT. 0.06D+00 ) THEN
            IF ( KPROJ .EQ. 1 ) THEN
               IF ( EKIN .LT. 0.02D+00 ) THEN
                  SIGELA = ONETHI * SIGMLW (EKIN)
               ELSE
                  BETAPR = PLAB / ( EKIN + AAM (KPROJ) )
                  SIGELA = SIGMPP (BETAPR)
               END IF
               RETURN
            ELSE IF ( KPROJ .EQ. 8 ) THEN
               IF ( EKIN .LT. 0.04D+00 ) THEN
                  SIGELA = SIGMLW (EKIN)
               ELSE
                  BETAPR = PLAB / ( EKIN + AAM (KPROJ) )
                  SIGELA = SIGMPN (BETAPR)
               END IF
               RETURN
            END IF

        ENDIF
C
        DO 10 IE=1,NEN
          IF(EK1.LT.EKIHN(IE)) THEN
            JE1=IE-1
            JE2=IE
C           WRITE (6,'(F12.8,I5,F12.8,I5,F12.8)')EK1,IE,
C    *                                           EKIHN(IE),KPROJ,EKIN
            DDEE=EKIHN(JE2) - EKIHN(JE1)
                                                                 GOTO 20
          ENDIF
   10   CONTINUE
        JE1=NEN
        JE2=NEN
        DDEE=1.
   20   CONTINUE
C****
C                                  PROTON-PROTON
        IF(KPROJ.EQ.1) THEN
          S1=SEPP(JE1)
          S2=SEPP(JE2)
C                                  NEUTRON-PROTON
        ELSEIF(KPROJ.EQ.8) THEN
          S1=SENP(JE1)
          S2=SENP(JE2)
C                                  PI(+)-PROTON
        ELSEIF(KPROJ.EQ.13) THEN
          S1=SEPIPP(JE1)
          S2=SEPIPP(JE2)
C                                  PI(-)-PROTON
        ELSEIF(KPROJ.EQ.14) THEN
          S1=SEPIMP(JE1)
          S2=SEPIMP(JE2)
C                                  UNDEFINED ENTRY CONDITIONS
        ELSE
          SIGELA=0.
          RETURN
        ENDIF
C
        SIGELA=S1 + (S2-S1)*(EK1-EKIHN(JE1))/DDEE
C
C                                  INTERPOLATION BETWEEN 10/20 GEV
        IF(IPOL.EQ.1) THEN
          SEL1=SIGELA
          SIGELA=SEL1 + (SEL2-SEL1)*(EKIN-EK1)/(EK2-EK1)
        ENDIF
C
        RETURN
C
      ENDIF
C***************************************
C                               HADRON-NUCLEUS ELASTIC CROSS SECTIONS
      DO 30 IE=1,NEA
        IF(EKIN.LT.EKIHA(IE)) THEN
          JE=IE - 1
                                                                 GOTO 40
        ENDIF
   30 CONTINUE
      IF(EKIN.EQ.EKIHA(NEA)) THEN
        JE=NEA - 1
      ELSE
        JE=-1
      ENDIF
   40 CONTINUE
C
      DO 50 IA=1,NNAA
        IF(ANUC.LT.AMASS(IA)) THEN
          JA=IA - 1
                                                                 GOTO 60
        ENDIF
   50 CONTINUE
      IF(ANUC.EQ.AMASS(NNAA)) THEN
        JA=NNAA - 1
      ELSE
        JA=-1
      ENDIF
   60 CONTINUE
C
      IF (JA) 140,110,70
   70 IF (JE) 190,150,80
   80 TEMP1=ANUC/AMASS(JA)
      TEMP2=LOG(AMASS(JA+1)/AMASS(JA))
      KE=JE
      DO 90 I=1,2
        IF(KPROJ.EQ.8) THEN
          SLOW=SENA(KE,JA)
          POWER=LOG(SENA(KE,JA+1)/SLOW)/TEMP2
        ELSE
          SLOW=SEPA(KE,JA)
          POWER=LOG(SEPA(KE,JA+1)/SLOW)/TEMP2
        ENDIF
        TSIG(I)=SLOW*TEMP1**POWER
        KE=KE+1
   90 CONTINUE
C
  100 SIGELA=TSIG(1) + (EKIN-EKIHA(JE))*(TSIG(2)-TSIG(1)) /(EKIHA(JE+1)
     +-EKIHA(JE))
 
      SIGELA=SIGELA * 1D3
      RETURN
C*
C                                          A IS LESS THAN A MIN
  110 JA=1
      TEMP1= (ANUC/AMASS(JA)) **0.66667D0
  120 IF (JE) 200,170,130
  130 IF(KPROJ.EQ.8) THEN
        TSIG(1) = SENA(JE,JA) * TEMP1
        TSIG(2) = SENA(JE+1,JA) *TEMP1
      ELSE
        TSIG(1) = SEPA(JE,JA) * TEMP1
        TSIG(2) = SEPA(JE+1,JA) *TEMP1
      ENDIF
                                                               GO TO 100
C*
C                                         A IS GREATER THAN A MAX
  140 JA=NNAA
      TEMP1= (ANUC/AMASS(JA))**.66667
                                                               GO TO 120
C*
C                                         EKIN  LT.  EMIN
  150 JE=1
  160 TEMP1=ANUC/AMASS(JA)
      TEMP2=LOG(AMASS(JA+1)/AMASS(JA))
      IF(KPROJ.EQ.8) THEN
        SLOW=SENA(JE,JA)
        POWER=LOG(SENA(JE,JA+1)/SLOW)/TEMP2
      ELSE
        SLOW=SEPA(JE,JA)
        POWER=LOG(SEPA(JE,JA+1)/SLOW)/TEMP2
      ENDIF
      SIGELA=SLOW*TEMP1**POWER
      SIGELA=SIGELA * 1D3
      RETURN
C
  170 JE=1
  180 IF(KPROJ.EQ.8) THEN
        SIGELA=SENA(JE,JA)*TEMP1
      ELSE
        SIGELA=SEPA(JE,JA)*TEMP1
      ENDIF
      SIGELA=SIGELA * 1D3
      RETURN
C*
C                                         EKIN  GT.  EMAX
  190 JE=NEA
                                                               GO TO 160
  200 JE=NEA
                                                               GO TO 180
      END
*-- Author :
C
C++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      DOUBLE PRECISION FUNCTION DSHPTO(IT,PO)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C-----------------------------------------------------
C   TOTAL HADRON-PROTON CROSS SECTIONS
C                                        Version based on DSHNTO
C                                        in d4diff.f
C                                        used after October 1993
CC++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
*KEEP,DPAR.
C     /DPAR/   CONTAINS PARTICLE PROPERTIES
C        ANAME  = LITERAL NAME OF THE PARTICLE
C        AAM    = PARTICLE MASS IN GEV
C        GA     = DECAY WIDTH
C        TAU    = LIFE TIME OF INSTABLE PARTICLES
C        IICH   = ELECTRIC CHARGE OF THE PARTICLE
C        IIBAR  = BARYON NUMBER
C        K1,K1  = BIGIN AND END OF DECAY CHANNELS OF PARTICLE
C
      CHARACTER*8  ANAME
      COMMON /DPAR/ ANAME(210),AAM(210),GA(210),TAU(210),IICH(210),
     +IIBAR(210),K1(210),K2(210)
C------------------
*KEND.
      AMIT2=AAM(IT)**2
      UMO2=AMIT2 + AAM(1)**2 + 2.*AAM(1)*(PO+0.5*AMIT2/PO)
      UMO=SQRT(UMO2)
      DSHPTO=DSHNTO(IT,1,UMO)
C
      RETURN
      END
C*******************************************************************
      DOUBLE PRECISION FUNCTION XSHPTO(IT,PO)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C-----------------------------------------------------
C   TOTAL HADRON-PROTON CROSS SECTIONS
C   PLAB.GE.10 GEV
C                                       This is the version used before
C                                       October 1993
C   PARAMETRZATION OF HJM 1982
C   CORRECTION FOR ANTIPARTICLES 16/08/90 HJM
C
C   extension below 10 GeV/c   29/08/90   HJM
C      - Plab > 4 GeV/c : Fit from REv. of Part. Prop.
C      - Plab < 4 GeV/c : SIG(el) + SIG(inel) = SIHNEL + SIHNIN
C----------------------------------------------------
*KEEP,DPAR.
C     /DPAR/   CONTAINS PARTICLE PROPERTIES
C        ANAME  = LITERAL NAME OF THE PARTICLE
C        AAM    = PARTICLE MASS IN GEV
C        GA     = DECAY WIDTH
C        TAU    = LIFE TIME OF INSTABLE PARTICLES
C        IICH   = ELECTRIC CHARGE OF THE PARTICLE
C        IIBAR  = BARYON NUMBER
C        K1,K1  = BIGIN AND END OF DECAY CHANNELS OF PARTICLE
C
      CHARACTER*8  ANAME
      COMMON /DPAR/ ANAME(210),AAM(210),GA(210),TAU(210),IICH(210),
     +IIBAR(210),K1(210),K2(210)
C------------------
*KEND.
C---------
      POO=PO
      KPRO=IT
      IF(POO.LT.4.0) THEN
        CALL SIHNEL(KPRO,1,POO,SIEL)
        CALL SIHNIN(KPRO,1,POO,SIIN)
        XSHPTO=SIEL + SIIN
        RETURN
      ENDIF
C-----------------------------------------------------
C                                     J.R.10.2.91
C                             SPECIAL TREATMENT OF P-P CROSS-SECTIONS
      IF (IT.EQ.1)THEN
        IF (POO.LT.2100.)THEN
          XSHPTO=45.6+219.*POO**(-4.23)+0.41*LOG(POO)**2-3.41*LOG(POO)
          RETURN
        ELSEIF(POO.LE.432000.) THEN
          XSHPTO=41.1+77.2*POO**(-0.68)+0.293*LOG(POO)**2-1.82*LOG(POO)
          RETURN
        ELSE
        AMIT2=AAM(1)**2
        UMO2=AMIT2 + AAM(1)**2 + 2.*AAM(1)*(PO+0.5*AMIT2/PO)
          UMO=SQRT(UMO2)
          IF (UMO.LT.1800.) THEN
            XSHPTO=61.65+(UMO-900.)*6.6/900.
            RETURN
          ELSEIF(UMO.LT.16000.)THEN
            XSHPTO=68.3+(UMO-1800.)*25./14200.
            RETURN
          ELSE
            XSHPTO=93.3+(UMO-16000.)*12.5/24000.
            RETURN
          ENDIF
        ENDIF
      ENDIF
C------------------------------------------------------
      A4=0.
      A5=0.
      A6=0.
      ITT=IT
C
      IF(POO.LT.10.0) THEN
        IPIO=0
        GOTO (10,20,260,260,260,260,260,30,40,260,260,50,60,70,80,90,
     +  100,20,50, 10,10,10,110,120,130), ITT
C***
   10   CONTINUE
C                               P - P
C                               SIGMA - P
        A1=45.6
        A2=219.
        A3=-4.23
        A4=0.410
        A5=-3.41
                                                                GOTO 140
C***
   20   CONTINUE
C                               PBAR - P
C                               LAMBDA-BAR  -  P
        A1=41.1
        A2=77.2
        A3=-0.68
        A4=0.293
        A5=-1.82
                                                                GOTO 140
C***
   30   CONTINUE
C                               N - P
        A1=47.7
        A2=100.
        A3=-4.57
        A4=0.512
        A5=-4.29
                                                                GOTO 140
C***
   40   CONTINUE
C                               NBAR - P  =  PBAR - N
        A1=41.9
        A2=96.2
        A3=-0.99
        A4=-0.154
        A5=0.0
                                                                GOTO 140
C***
   50   CONTINUE
C                               KLONG - P  =  KSHORT - P
        IF(RNDM(V).GE.0.5D0)                                     GOTO 80
                                                                 GOTO 90
C***
   60   CONTINUE
C                               PI+ - P
        A1=32.1
        A2=48700.
        A3=-7.85
        A4=0.540
        A5=-4.41
                                                                GOTO 140
C***
   70   CONTINUE
C                               PI-  P
        A1=33.1
        A2=15.0
        A3=-1.41
        A4=0.458
        A5=-4.06
                                                                GOTO 140
C***
   80   CONTINUE
C                               K+ - P
        A1=17.1
        A2=5.54
        A3=-2.67
        A4=0.139
        A5=-0.270
                                                                GOTO 140
C***
   90   CONTINUE
C                               K-  P
        A1=-21.1
        A2=56.2
        A3=-0.27
        A4=-0.155
        A5=6.24
                                                                GOTO 140
C***
  100   CONTINUE
C                               LAMBDA  -  P
        A1=18.0
        A2=0.121
        A3=-3.92
        A4=6.38
        A5=0.0
                                                                GOTO 140
C***
  110   CONTINUE
C                               PIZERO - P
C                               PRESENTLY PI0 = PI+
C                                could be   0.5 (PI+ & PI-) with IPIO=1
        IPIO=0
                                                                 GOTO 60
C***
  120   CONTINUE
C                               K0 - P  =  K+  - P
                                                                 GOTO 80
C                               K0 - P  =  K+  - N
C         A1=18.4
C         A2=175
C         A3=-7.85
C         A4=0.198
C         A5=-0.753
C         GOTO 200
C***
  130   CONTINUE
C                               K0BAR - P  =  K-  - P
                                                                 GOTO 90
C                               K0BAR - P  =  K-  - N
C         A1=-1040.
C         A2=1060.
C         A3=-0.03
C         A4=0.0
C         A5=27.8
C***
  140   CONTINUE
        ALP=LOG(POO)
        XSHPTO=A1 + A2*POO**A3 + A4*ALP**2 + A5*ALP
        IF(IPIO.EQ.1) THEN
          S1=XSHPTO
          IPIO=2
                                                                 GOTO 70
        ELSEIF(IPIO.EQ.2) THEN
          XSHPTO=0.5*(XSHPTO+S1)
        ENDIF
        RETURN
      ENDIF
C
      F1=1.
      AMIT2=AAM(ITT)**2
      UMO2=AMIT2 + AAM(1)**2 + 2.*AAM(1)*(PO+0.5*AMIT2/PO)
      UMO=SQRT(UMO2)
C
      GOTO (150,150,260,260,260,260,260,160,160,260,260,210,170,170,190,
     +190,240,240,210,240,240,240,250,220,230), ITT
C
  150 CONTINUE
C                               P-P
      A1=38.4
      A2=0.46
      A3=125.
      IF(ITT.EQ.1)                                              GOTO 270
C                               PBAR-P
      A5=84.1
      A6=-0.57
                                                                GOTO 270
C
  160 CONTINUE
C                              N-P = P-N
      A1=38.5
      A2=0.46
      A3=125.
      A4=15.
      IF(ITT.EQ.8)                                              GOTO 270
C                              NBAR-P = PBAR-N
      A5=77.43
      A6=-0.60
                                                                GOTO 270
C
  170 CONTINUE
      IF(UMO.LT.47.0)                                           GOTO 180
      F1=0.6667
      ITT=1
                                                                GOTO 150
  180 CONTINUE
C                             (PI-) - P
      A1=24.0
      A2=0.60
      A3=160.
      IF(ITT.EQ.14)                                             GOTO 270
C                             (PI+) - P
      A5=-7.9
      A6=-0.46
                                                                GOTO 270
C
  190 CONTINUE
      IF(UMO.LT.110.)                                           GOTO 200
      F1=0.6667
      ITT=1
                                                                GOTO 150
  200 CONTINUE
C                             (K-) - P
      A1=20.3
      A2=0.59
      A3=140.
      IF(ITT.EQ.16)                                             GOTO 270
C                             (K+) - P
      A5=-30.13
      A6=-0.58
                                                                GOTO 270
C
  210 CONTINUE
      ITT=15
      IF(RNDM(V).LT.0.5D0) ITT=16
                                                                GOTO 190
C
  220 CONTINUE
C***
C   K-ZERO:  SET EQUAL TO K+/PROTON
C            (SHOULD BE K+/NEUTRON)
C***
      ITT=15
                                                                GOTO 190
C
  230 CONTINUE
C***
C   K-ZERO BAR:  SET EQUAL TO K-/PROTON
C                (SHOULD BE K-/NEUTRON)
C***
      ITT=16
                                                                GOTO 190
C
  240 CONTINUE
C***
C   SIGMA +/-/0  AND  LAMBDA/LAMBDA BAR:  SET EQUAL TO P-P
C***
      ITT=1
                                                                GOTO 150
C
  250 CONTINUE
C***
C   PI0:   SET EQUAL TO PI+
C***
      ITT=13
                                                                GOTO 170
C
  260 CONTINUE
C***
C   LEPTONS AND PI0
C***
      XSHPTO=1.E-10
      RETURN
C
  270 CONTINUE
C
      XSHPTO=A1 + A2*(LOG(UMO2/A3))** 2+ A4/UMO2 + A5*UMO2**A6
 
      XSHPTO=F1*XSHPTO
C
      RETURN
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE SIHNIN(IPROJ,ITAR,PO,SIIN)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C********************************************************************
C     VERSION OCTOBER 89 BY          H. MOEHRING
C                                    LEIPZIG
C     LAST CHANGE 30/08/90 BY HJM: modification of SIG(pi+ p) = SEGP
C
C
C     SEE: H.J. MOEHRING, HADRON-NUCLEUS INELASTIC CROSS-SECTIONS FOR
C     USE IN HADRON-CASCADE CALCULATIONS AT HIGH ENERGIES,
C     TIS DIVISION REPORT 14. OCTOBER 1983, TIS-RP/116, CERN GENEVA
C
C     INPUT VARIABLES:
C        IPROJ  = TYPE OF THE PROJECTILE
C        ITAR   = TYPE OF THE TARGET
C        PO     = PARTICLE MOMENTUM IN GEV/C
C
C     OUTPUT VARIABLES:
C        SIIN   = INTERPOLATED INELASTIC CROSS SECTION IN MILLIBARNS
C
C
C     OTHER IMPORTANT VARIABLES:
C        SIG    = PROTON/NUCLEI CROSS SECTIONS
C        SEG    = PION-/NUCLEI CROSS SECTIONS ABOVE 0.3 GEV/C
C        SEGP   = PION+/NUCLEI CROSS SECTIONS ABOVE 0.3 GEV/C
C        SIGKM  = K+ AND K0/NUCLEI CROSS SECTIONS ABOVE 3.0 GEV/C
C        SIGKP  = K+ AND K0 BAR/NUCLEI CROSS SECTIONS ABOVE 3.0 GEV/C
C        SIGAP  = ANTINUCLEON/NUCLEI CROSS SECTIONS ABOVE 3.0 GEV/C
C        SEEG   = PION/NUCLEI CROSS SECTIONS BELOW 0.3 GEV/C
C        P      = MOMENTA FOR WHICH THE CROSS SECTIONS ARE GIVEN IN
C                 SIG, SEG, SEGP, SIGKM, SIGKP AND SIGAP
C        PEE    = MOMENTA FOR WHICH THE CROSS SECTIONS ARE GIVEN IN
C                 SEEG
C        A      = NUCLEI FOR WHICH THE CROSS SECTIONS ARE GIVEN IN
C                 SIG, SEG, SEGP, SIGKM, SIGKP, SIGAP AND SEEG
C        PLAB   = MOMENTA FOR WHICH THE TOTAL CROSS SECTIONS ARE
C                 GIVEN IN TOTCRS
C        TOTCRS = TOTAL CROSS SECTIONS AS A FUNCTION OF MOMENTUM
C                 TOTCRS(K,I) WHERE K=MOMENTUM INDEX,I=REACTION TYPE
C                 I=1:NEGATIVE KAON-PROTON  = KAON ZERO BAR-NEUTRON
C                 I=2:NEGATIVE KAON-NEUTRON = KAON ZERO BAR-PROTON
C                 I=3:POSITIVE KAON-PROTON  = KAON ZERO NEUTRON
C                 I=4:POSITIVE KAON-NEUTRON = KAON ZERO-PROTON
C                 I=5:ANTI NUCLEON-NUCLEON
C
C
C     NOTE1: PRESENTLY CROSS SECTIONS ARE ASSUMED TO BE CONSTANT
C     ABOVE 10000.0 GEV/C FOR ALL PARTICLES AND
C     BELOW 0.13 GEV/C FOR PIONS AND BELOW 0.3 GEV/C FOR OTHERS
C
C     NOTE2: SEE TABLE ITT TO FIND OUT HOW DIFFERENT HADRONS
C     ARE TREATED. ALL PARTICLES WITH PARTICLE NUMBER BIGGER THAN
C     25 ARE TREATED AS PROTONS.
C
C     NOTE3: FOR LEPTONS AND PHOTONS PRACTICALLY ZERO CROSS SECTION
C     IS RETURNED.
C********************************************************************
C
*KEEP,DPRIN.
      COMMON /DPRIN/  IPRI,IPEV,IPPA,IPCO,INIT,IPHKK,ITOPD,IPAUPR
*KEND.
      DIMENSION SEEG(4),PEE(4),SIGKP(20),SIGKM(20),SIGAP(20)
      DIMENSION SEG(20),SIG(20),SEGP(20),P(20)
C
      DATA P/0.3D0,0.4D0,0.5D0,0.6D0,0.8D0,1.D0,
     +1.5D0,2.D0,3.D0,4.D0,5.D0,6.D0,10.D0,
     *20.D0,50.D0,100.D0,200.D0,400.D0,1000.D0,10000.D0/
C
      DATA SEEG/0.1D0,16.D0,35.D0,42.D0/
      DATA PEE /0.13D0,0.19D0,0.25D0,0.30D0/
C
      DATA (SIG(IE),IE=1,20) / 3*0.0001D0,0.1D0,1.D0,4.D0,
     +24.5D0,25.D0,27.2D0,27.8D0,
     +28.5D0,29.2D0,29.7D0, 30.5D0,31.5D0,
     +31.7D0,32.1D0,32.9D0,34.5D0,41.2D0/
 
C
      DATA (SEG(IE),IE=1,20) / 42.D0,19.D0,16.1D0,17.D0,
     +22.7D0,32.5D0,24.6D0,26.2D0,
     +25.0D0,23.7D0,23.0D0,22.5D0,22.D0,
     + 21.2D0,20.8D0,20.7D0,21.D0,21.9D0,23.8D0,28.4D0/
 
C
      DATA (SEGP(IE),IE=1,20) / 0.1D0,0.1D0,0.1D0,0.1D0,
     +11.D0,12.5D0,22.D0,19.2D0,21.5D0,
     +21.4D0,20.8D0,20.6D0,20.2D0, 19.8D0,19.9D0,
     +20.D0,20.5D0,21.5D0,23.5D0,32.2D0/
 
C
      DATA SIGAP/ 164.D0,126.D0,114.D0,98.D0,86.D0,
     +72.4D0,59.D0,57.D0,53.D0,52.D0,48.D0,45.5D0,
     +43.5D0, 40.4D0,36.5D0,35.2D0,34.5D0,34.5D0,
     +35.4D0,41.5D0/
 
C
      DATA SIGKM/ 38.D0,43.D0,23.D0,18.5D0,20.D0,
     +29.D0,25.D0,23.D0,22.5D0,21.D0,20.5D0,20.D0,
     +19.2D0, 18.5D0,17.8D0,17.8D0,18.3D0,19.2D0,
     +21.2D0,28.9D0/
 
C
      DATA SIGKP/ 0.001D0,0.001D0,0.001D0,0.001D0,
     +0.2D0,4.5D0,8.9D0,11.6D0,12.2D0,13.4D0,
     +13.6D0, 13.7D0,13.7D0,14.9D0,15.9D0,16.5D0,
     +17.4D0,18.6D0,20.9D0,28.8D0/
 
C
C---------------------------------------------------------------------
C
      SIIN=1.0D-20
      IF(ITAR.NE.1.AND.ITAR.NE.8) THEN
        IF(IPRI.GE.1) WRITE(6,'(A/A,2I5,2(1PE15.6))')
     +  ' WRONG CALL OF SIHNIN/ITAR',
     +  '    IPROJ,ITAR,PO,SIIN :', IPROJ,ITAR,PO,SIIN
 
        RETURN
      ENDIF
C
      IF(IPROJ.GE.3.AND.IPROJ.LE.7) RETURN
C
      IIPP=IPROJ
      IF(IPROJ.EQ.23) IIPP=13
      IITT=ITAR
C-----------------------------------------------------------------------
C                                      NEUTRON TARGET TO BE IMPLEMENTED!
      IF(IITT.EQ.8) IITT=1
C-----------------------------------------------------------------------
      IF(IPROJ.EQ.19.OR.IPROJ.EQ.12) THEN
        IIPP=24
        RND=RNDM(V)
        IF(RND.GT.0.5D0) IIPP=25
      END IF
C
C********************************************************************
C
C     CALCULATE THE MOMENTUM INDEX K
C
      DO 10 JK=1,20
        IF(PO.LE.P(JK)) THEN
          K=JK
          KK=K-1
                                                                GO TO 20
        ENDIF
   10 CONTINUE
      K=21
   20 CONTINUE
C
C*******************************************************************
C
      IF(IITT.EQ.1) THEN
C                                                PROTON TARGET
        IF(IIPP.EQ.1.OR.IIPP.EQ. 8.OR.IIPP.EQ.17.OR.(IIPP.GE.20.AND
     +  .IIPP.LE.22)) THEN
C                                        PROTON/NEUTRON
C                                        LAMBDA/ALL SIGMAS
          IF(K.EQ.1) THEN
            SIIN=SIG(K)
                                                                 GOTO 70
          ELSEIF(K.EQ.21) THEN
            SIIN=SIG(20)
                                                                 GOTO 70
          ELSE
            SI1=SIG(K)
            SI2=SIG(KK)
          ENDIF
        ELSEIF(IIPP.EQ.14) THEN
C                                        PI -
          IF(K.EQ.1) THEN
C                                        LOW ENERGY PI- (<0.3GEV/C)
            DO 30 JK=1,4
              IF(PO.LE.PEE(JK)) THEN
                kkK=JK
                                                                 GOTO 40
              ENDIF
   30       CONTINUE
            kkK=4
   40       CONTINUE
            KK=kkK-1
            IF(kkK.EQ.1) THEN
              SIIN=SEEG(kkK)
                                                                 GOTO 70
            ENDIF
            SI1=SEEG(kkK)
            SI2=SEEG(KK)
C                         INTERPOLATE LINEARLY WITH RESPECT TO MOMENTUM
C
            SIIN=SI1 + (PO-PEE(kkK))*(SI2-SI1)/(PEE(KK)-PEE(kkK))
                                                                 GOTO 70
          ELSEIF(K.EQ.21) THEN
            SIIN=SEG(20)
                                                                 GOTO 70
          ELSE
            SI1=SEG(K)
            SI2=SEG(KK)
          ENDIF
C                                                      PI +
        ELSEIF(IIPP.EQ.13) THEN
   50     CONTINUE
          IF(K.EQ.1) THEN
            SIIN=SEGP(K)
                                                                 GOTO 70
          ELSEIF(K.EQ.21) THEN
            SIIN=SEGP(20)
                                                                 GOTO 70
          ENDIF
          SI1=SEGP(K)
          SI2=SEGP(KK)
C                                                 K -  AND K0 BAR
        ELSEIF(IIPP.EQ.16.OR.IIPP.EQ.25) THEN
          IF(K.EQ.1) THEN
            SIIN=SIGKM(K)
                                                                 GOTO 70
          ELSEIF(K.EQ.21) THEN
            SIIN=SIGKM(20)
                                                                 GOTO 70
          ENDIF
          SI1=SIGKM(K)
          SI2=SIGKM(KK)
C                                                 K +  AND K0
        ELSEIF(IIPP.EQ.15.OR.IIPP.EQ.24) THEN
          IF(K.EQ.1) THEN
            SIIN=SIGKP(K)
                                                                 GOTO 70
          ELSEIF(K.EQ.21) THEN
            SIIN=SIGKP(20)
                                                                 GOTO 70
          ENDIF
          SI1=SIGKP(K)
          SI2=SIGKP(KK)
C                                                 ANTI-NUCLEONS
C                                                 ANTI-LAMBDA
        ELSEIF(IIPP.EQ.2.OR.IIPP.EQ.9.OR.IIPP.EQ.18) THEN
          IF(K.EQ.1) THEN
            SIIN=SIGAP(K)
                                                                 GOTO 70
          ELSEIF(K.EQ.21) THEN
            SIIN=SIGAP(20)
                                                                 GOTO 70
          ENDIF
          SI1=SIGAP(K)
          SI2=SIGAP(KK)
        ENDIF
      ENDIF
C
C********************************************************************
C     INTERPOLATE LINEARLY WITH RESPECT TO MOMENTUM
C
   60 SIIN=SI1 + (PO-P(K))*(SI1-SI2)/(P(K)-P(KK))
C
   70 CONTINUE
C     ZL=10000.D0*AA/(6.022D0*SIIN)
      RETURN
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE DHADRI(N,PLAB,ELAB,CX,CY,CZ,ITTA)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C
C-----------------------------
C*** INPUT VARIABLES LIST:
C*** SAMPLING OF HADRON NUCLEON INTERACTION FOR (ABOUT) 0.1 LE PLAB LE 6
C*** GEV/C LABORATORY MOMENTUM REGION
C*** N    - PROJECTILE HADRON INDEX
C*** PLAB - LABORATORY MOMENTUM OF N (GEV/C)
C*** ELAB - LABORATORY ENERGY OF N (GEV)
C*** CX,CY,CZ - DIRECTION COSINES OF N IN THE LABORATORY SYSTEM
C*** ITTA - TARGET NUCLEON INDEX
C*** OUTPUT VARIABLES LIST OF PARTICLE CHARACTERISTICS IN /FINLSP/
C  IR COUNTS THE NUMBER OF PRODUCED PARTICLES
C*** ITR - PARTICLE INDEX, CXR,CYR,CZR - DIRECTION COSINES (LAB. SYST.)
C*** ELR,PLR LAB. ENERGY AND LAB. MOMENTUM OF THE SAMPLED PARTICLE
C*** RESPECT., UNITS (GEV/C AND GEV)
C----------------------------
      COMMON /DGAMRE/ REDU,AMO,AMM(15 )
      COMMON /DREDVE/ THRESH(268), IRII(17),IKII(17),IEII(17)
      COMMON/DREAC/UMO(296),PLABF(296),SIIN(296),WK(5184),
     *NRK(2,268),NURE(30,2)
      COMMON /DABLTI/ AMH(110),GAH(110),TAUH(110),ICHH(110),IBARH(110),
     +K1H(110),K2H(110)
      COMMON /DSPLI/NZK(460,3),WT(460)
      COMMON /DMETLS/ CXS(149),CYS(149), 
     +CZS(149),ELS(149),PLS(149),
     +IS,ITS(149)
      COMMON /DRUN/ RUNTES,EFTES
*KEEP,DPAR.
C     /DPAR/   CONTAINS PARTICLE PROPERTIES
C        ANAME  = LITERAL NAME OF THE PARTICLE
C        AAM    = PARTICLE MASS IN GEV
C        GA     = DECAY WIDTH
C        TAU    = LIFE TIME OF INSTABLE PARTICLES
C        IICH   = ELECTRIC CHARGE OF THE PARTICLE
C        IIBAR  = BARYON NUMBER
C        K1,K1  = BIGIN AND END OF DECAY CHANNELS OF PARTICLE
C
      CHARACTER*8  ANAME
      COMMON /DPAR/ ANAME(210),AAM(210),GA(210),TAU(210),IICH(210),
     +IIBAR(210),K1(210),K2(210)
C------------------
*KEEP,DFINLS.
      PARAMETER (MAXFIN=10)
      COMMON /DFINLS/ ITRH(MAXFIN),CXRH(MAXFIN),CYRH(MAXFIN), CZRH
     +(MAXFIN),ELRH(MAXFIN),PLRH(MAXFIN),IRH
*KEEP,DPRIN.
      COMMON /DPRIN/  IPRI,IPEV,IPPA,IPCO,INIT,IPHKK,ITOPD,IPAUPR
*KEND.
      DIMENSION ITPRF(110)
      DATA NNN/0/
C     DATA UMODA/0./
      COMMON /KAINIT/  UMODA,INICH1,INICH2,INICH3,INICH4,INICH5,
     *                 INICH6,INICH7,INICH8,INICH9,IRETUR,KAIS,INIPRI,
     *                 NUSEPT,MUSEPT,ISTART
      DOUBLE PRECISION UMODA
      INTEGER          INICH1,INICH2,INICH3,INICH4,INICH5,
     *                 INICH6,INICH7,INICH8,INICH9,IRETUR,KAIS,INIPRI,
     *                 NUSEPT,MUSEPT
      LOGICAL          ISTART
      DATA ITPRF/-1,-1,5*1,-1,-1,1,1,1,-1,-1,-1,-1,6*1,-1,-1,-1,85*1/
      LOWP=0
      IF (N.LE.0.OR.N.GE.111)N=1
      IF (ITPRF( N ).GT.0 .OR. ITTA.GT.8) THEN
        GOTO 280
*       WRITE (6,1000)
*    +  ' FALSE USE OF THE PARTICLE TYPE INDEX: N, ITTA', N, ITTA
*       STOP
*1000   FORMAT (3(5H ****/),A,2I4,3(5H ****/))
*    +  45H FALSE USE OF THE PARTICLE TYPE INDEX, N,LUE ,I4,3(5H ****/))
      ENDIF
      IATMPT=0
      IF (ABS(PLAB-5.).LT.4.99999D0)                            GO TO 20
      IF(IPRI.GE.1) WRITE (6,1010) PLAB
C     STOP
 1010 FORMAT ( '  PROJECTILE HADRON MOMENTUM OUTSIDE OF THE
     + ALLOWED REGION, PLAB=',1E15.5)
 
   20 CONTINUE
      UMODAT=N*1.11111D0+ITTA*2.19291D0
      IF(UMODAT.NE.UMODA) CALL DCALUM(N,ITTA)
      UMODA=UMODAT
   30 IATMPT=0
      LOWP=LOWP+1
   40 CONTINUE
      IMACH=0
      REDU=2.
      IF (LOWP.GT.20)                                          GO TO 280
      NNN=N
      IF (NNN.EQ.N)                                             GO TO 50
      RUNTES=0.
      EFTES=0.
   50 CONTINUE
      IS=1
      IRH=0
      IST=1
      NSTAB=23
      IRE=NURE(N,1)
      IF(ITTA.GT.1) IRE=NURE(N,2)
C
C-----------------------------
C*** IE,AMT,ECM,SI DETERMINATION
C----------------------------
      CALL DSIGIN(IRE,PLAB,N,IE,AMT ,AMN,ECM,SI,ITTA)
      IANTH=-1
      IF (AMH(1).NE.0.9383D0) IANTH=1
      IF (IANTH.GE.0) SI=1.
      ECMMH=ECM
C
C-----------------------------
C    ENERGY INDEX
C  IRE CHARACTERIZES THE REACTION
C  IE IS THE ENERGY INDEX
C----------------------------
      IF (SI.LT.1.D-6)                                         GO TO 280
      IF (N.LE.NSTAB)                                           GO TO 60
      RUNTES=RUNTES+1.
      IF (RUNTES.LT.20.D0) WRITE(6,1020)N
 1020 FORMAT(3H N=,I10,30H THE PROEKTILE IS A RESONANCE )
      IF(IBARH(N).EQ.1) N=8
      IF(IBARH(N).EQ.-1)  N=9
   60 CONTINUE
      IMACH=IMACH+1
      IF (IMACH.GT.10)                                         GO TO 280
      ECM =ECMMH
      AMN2=AMN**2
      AMT2=AMT**2
      ECMN=(ECM**2+AMN2-AMT2)/(2.*ECM    )
      IF(ECMN.LE.AMN) ECMN=AMN
      PCMN=SQRT(ECMN**2-AMN2)
      GAM=(ELAB+AMT)/ECM
      BGAM=PLAB/ECM
      IF (IANTH.GE.0) ECM=2.1
C
C-----------------------------
C*** RANDOM CHOICE OF REACTION CHANNEL
C----------------------------
      IST=0
      CALL
     *DRANDM(VV)
      VV=VV-1.D-17
C
C-----------------------------
C***  PLACE REDUCED VERSION
C----------------------------
      IIEI=IEII(IRE)
      IDWK=IEII(IRE+1)-IIEI
      IIWK=IRII(IRE)
      IIKI=IKII(IRE)
C
C-----------------------------
C***  SHRINKAGE TO THE CONSIDERED ENERGY REGION FOR THE USE OF WEIGHTS
C----------------------------
      HECM=ECM
      HUMO=2.*UMO(IIEI+IDWK)-UMO(IIEI+IDWK-1)
      IF (HUMO.LT.ECM) ECM=HUMO
C
C-----------------------------
C*** INTERPOLATION PREPARATION
C----------------------------
      ECMO=UMO(IE)
      ECM1=UMO(IE-1)
      DECM=ECMO-ECM1
      DEC=ECMO-ECM
C
C-----------------------------
C*** RANDOM LOOP
C----------------------------
      IK=0
      WKK=0.
      WICOR=0.
   70 IK=IK+1
      IWK=IIWK+(IK-1)*IDWK+IE-IIEI
      WOK=WK(IWK)
      WDK=WOK-WK(IWK-1)
C
C-----------------------------
C*** TESTVARIABLE WICO/WICOR: IF CHANNEL IK HAS THE SAME WEIGHTS LIKE IK
C    GO TO NEXT CHANNEL, BECAUSE WKK((IK))-WKK((IK-1))=0, IK CAN NOT
C    CONTRIBUTE
C----------------------------
      IF (PLAB.LT.PLABF(IIEI+2)) WDK=0.
      WICO=WOK*1.23459876D0+WDK*1.735218469D0
      IF (WICO.EQ.WICOR)                                        GO TO 70
      IF (UMO(IIEI+IDWK).LT.HECM) WDK=0.
      WICOR=WICO
C
C-----------------------------
C*** INTERPOLATION IN CHANNEL WEIGHTS
C----------------------------
      EKLIM=-THRESH(IIKI+IK)
      IELIM=IEFUND(EKLIM,IRE)
      DELIM=UMO(IELIM)+EKLIM
     *+1.E-16
      DETE=(ECM-(ECMO-EKLIM)*.5)*2.
      IF (DELIM*DELIM-DETE*DETE) 90,90,80
   80 DECC=DELIM
                                                               GO TO 100
   90 DECC=DECM
  100 CONTINUE
      WKK=WOK-WDK*DEC/(DECC+1.D-9)
C
C-----------------------------
C*** RANDOM CHOICE
C----------------------------
C
      IF (VV.GT.WKK)                                            GO TO 70
C
C***IK IS THE REACTION CHANNEL
C----------------------------
      INRK=IKII(IRE)+IK
      ECM=HECM
      I1001 =0
C
  110 CONTINUE
      IT1=NRK(1,INRK)
      AM1=DAMG(IT1)
      IT2=NRK(2,INRK)
      AM2=DAMG(IT2)
      AMS=AM1+AM2
      I1001=I1001+1
      IF (I1001.GT.50)                                          GO TO 60
C
      IF (IT2*AMS.GT.IT2*ECM)                                  GO TO 110
      IT11=IT1
      IT22=IT2
      IF (IANTH.GE.0) ECM=ELAB+AMT+0.00001D0
      AM11=AM1
      AM22=AM2
      IF (IT2.GT.0)                                            GO TO 120
C
C-----------------------------
C  INCLUSION OF DIRECT RESONANCES
C  RANDOM CHOICE OF DECAY CHANNELS OF THE DIRECT RESONANCE  IT1
C------------------------
      KZ1=K1H(IT1)
      IST=IST+1
      IECO=0
      ECO=ECM
      GAM=(ELAB+AMT)/ECO
      BGAM=PLAB/ECO
      CXS(1)=CX
      CYS(1)=CY
      CZS(1)=CZ
                                                               GO TO 170
  120 CONTINUE
      CALL DRANDM(WW)
      IF(WW.LT. 0.5D0)                                         GO TO 130
      IT1=IT22
      IT2=IT11
      AM1=AM22
      AM2=AM11
  130 CONTINUE
C
C-----------------------------
C   THE FIRST PARTICLE IS DEFINED TO BE THE FORWARD GOING ONE AT SMALL T
      IBN=IBARH(N)
      IB1=IBARH(IT1)
      IT11=IT1
      IT22=IT2
      AM11=AM1
      AM22=AM2
      IF(IB1.EQ.IBN)                                           GO TO 140
      IT1=IT22
      IT2=IT11
      AM1=AM22
      AM2=AM11
  140 CONTINUE
C-----------------------------
C***IT1,IT2 ARE THE CREATED PARTICLES
C***MOMENTA AND DIRECTION COSINA IN THE CM - SYSTEM
C------------------------
      CALL DTWOPA(ECM1,ECM2,PCM1,PCM2,COD1,COD2,COF1,COF2,SIF1,SIF2,
     *IT1,IT2,ECM,ECMN,PCMN,N,AM1,AM2)
      IST=IST+1
      ITS(IST)=IT1
      AMM(IST)=AM1
C
C-----------------------------
C***TRANSFORMATION INTO LAB SYSTEM AND ROTATION
C----------------------------
      CALL DTRAFO(GAM,BGAM,CX,CY,CZ,COD1,COF1,SIF1,PCM1,ECM1,PLS(IST),
     *CXS(IST),CYS(IST),CZS(IST),ELS(IST))
      IST=IST+1
      ITS(IST)=IT2
      AMM(IST)=AM2
      CALL DTRAFO(GAM,BGAM,CX,CY,CZ,COD2,COF2,SIF2,
     *PCM2,ECM2,PLS(IST),CXS(IST),CYS(IST),CZS(IST),ELS(IST))
  150 CONTINUE
C
C-----------------------------
C***TEST   STABLE OR UNSTABLE
C----------------------------
      IF(ITS(IST).GT.NSTAB)                                    GO TO 160
      IRH=IRH+1
C
C-----------------------------
C***IRH IS THE NUMBER OF THE FINAL STABLE PARTICLE
C----------------------------
C*    IF (REDU.LT.0.D0) GO TO 1009
      ITRH(IRH)=ITS(IST)
      PLRH(IRH)=PLS(IST)
      CXRH(IRH)=CXS(IST)
      CYRH(IRH)=CYS(IST)
      CZRH(IRH)=CZS(IST)
      ELRH(IRH)=ELS(IST)
      IST=IST-1
      IF(IST.GE.1)                                             GO TO 150
                                                               GO TO 260
  160 CONTINUE
C
C  RANDOM CHOICE OF DECAY CHANNELS
C----------------------------
C
      IT=ITS(IST)
      ECO=AMM(IST)
      GAM=ELS(IST)/ECO
      BGAM=PLS(IST)/ECO
      IECO=0
      KZ1=K1H(IT)
  170 CONTINUE
      IECO=IECO+1
      CALL DRANDM(VV)
      VV=VV-1.D-17
      IIK=KZ1-1
  180 IIK=IIK+1
      IF (VV.GT.WT(IIK))                                       GO TO 180
C
C  IIK IS THE DECAY CHANNEL
C----------------------------
      IT1=NZK(IIK,1)
      I310=0
  190 CONTINUE
      I310=I310+1
      AM1=DAMG(IT1)
      IT2=NZK(IIK,2)
      AM2=DAMG(IT2)
      IF (IT2-1.LT.0)                                          GO TO 240
      IT3=NZK(IIK,3)
      AM3=DAMG(IT3)
      AMS=AM1+AM2+AM3
C
C  IF  IIK-KIN.LIM.GT.ACTUAL TOTAL CM-ENERGY, DO AGAIN RANDOM IIK-CHOICE
C----------------------------
      IF (IECO.LE.10)                                          GO TO 200
      IATMPT=IATMPT+1
      IF(IATMPT.GT.3)                                          GO TO 280
                                                                GO TO 40
  200 CONTINUE
      IF (I310.GT.50)                                          GO TO 170
      IF (AMS.GT.ECO)                                          GO TO 190
C
C  FOR THE DECAY CHANNEL
C  IT1,IT2, IT3 ARE THE PRODUCED PARTICLES FROM  IT
C----------------------------
      IF (REDU.LT.0.D0)                                        GO TO 30
      ITWTHC=0
      REDU=2.
      IF(IT3.EQ.0)                                             GO TO 220
  210 CONTINUE
      ITWTH=1
      CALL DTHREP(ECO,ECM1,ECM2,ECM3,PCM1,PCM2,PCM3,COD1,COF1,SIF1,
     *COD2,COF2,SIF2,COD3,COF3,SIF3,AM1,AM2,AM3)
                                                               GO TO 230
  220 CALL DTWOPD(ECO,ECM1,ECM2,PCM1,PCM2,COD1,COF1,SIF1,COD2,COF2,SIF2,
     +AM1,AM2)
      ITWTH=-1
      IT3=0
  230 CONTINUE
      ITWTHC=ITWTHC+1
      IF (REDU.GT.0.D0)                                        GO TO 240
      REDU=2.
      IF (ITWTHC.GT.100)                                        GO TO 30
      IF (ITWTH) 220,220,210
  240 CONTINUE
      ITS(IST  )=IT1
      IF (IT2-1.LT.0)                                          GO TO 250
      ITS(IST+1)  =IT2
      ITS(IST+2)=IT3
      RX=CXS(IST)
      RY=CYS(IST)
      RZ=CZS(IST)
      AMM(IST)=AM1
      CALL DTRAFO(GAM,BGAM,RX,RY,RZ,COD1,COF1,SIF1,PCM1,ECM1,
     *PLS(IST),CXS(IST),CYS(IST),CZS(IST),ELS(IST))
      IST=IST+1
      AMM(IST)=AM2
      CALL DTRAFO(GAM,BGAM,RX,RY,RZ,COD2,COF2,SIF2,PCM2,ECM2,
     *PLS(IST),CXS(IST),CYS(IST),CZS(IST),ELS(IST))
      IF (IT3.LE.0)                                            GO TO 250
      IST=IST+1
      AMM(IST)=AM3
      CALL DTRAFO(GAM,BGAM,RX,RY,RZ,COD3,COF3,SIF3,PCM3,ECM3,
     *PLS(IST),CXS(IST),CYS(IST),CZS(IST),ELS(IST))
  250 CONTINUE
                                                               GO TO 150
  260 CONTINUE
  270 CONTINUE
      RETURN
  280 CONTINUE
C
C----------------------------
C
C   ZERO CROSS SECTION CASE
C----------------------------
C
      IRH=1
      ITRH(1)=N
      CXRH(1)=CX
      CYRH(1)=CY
      CZRH(1)=CZ
      ELRH(1)=ELAB
      PLRH(1)=PLAB
      RETURN
      END
*-- Author :
c+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
      BLOCK DATA  RUNTT
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      COMMON/DRUN/RUNT(2)
      DATA RUNT/100.D0,100.D0/
      END
*-- Author :
      DOUBLE PRECISION FUNCTION REXP(W)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C*****EXPONENTIELL VERTEILTE ZUFALLSZAHL, VERTEILUNG F=EXP(-W*X)
      A=-1.
   10 CALL DRANDM(XO)
      A=A+1.
      B=0.
      N=0
      CALL DRANDM(V)
   20 B=B+V
      N=N+1
      IF(B-XO) 20,20,30
   30 NN=N/2
      IF(N.EQ.2*NN)                                             GO TO 10
      REXP=(A+XO)/W
      RETURN
      END
*-- Author :
c++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
      BLOCK DATA NONAME
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C*****  BLOCK DATA WITHOUT NAMES
C     INTEGER * 2 IEII,IKII
      COMMON /DSLOPE/ AMBMBB(75)
      COMMON /DREDVE/ THRESH(268), IRII(17),IKII(17),IEII(17)
C     DATAS     DATAS    DATAS      DATAS     DATAS
C******          *********
      DATA IKII/ 0, 15, 41, 67, 82, 93, 110, 133, 148, 159, 172, 183,
     &           207, 224, 241, 252, 268 /
      DATA IEII/ 0, 21, 46, 71, 92, 109, 126, 143, 160, 173, 186, 199,
     &           220, 241, 262, 279, 296 /
      DATA IRII/ 0, 315, 965, 1615, 1930, 2117, 2406, 2797, 3052, 3195,
     &           3364, 3507, 4011, 4368, 4725, 4912, 5184/
 
C
C     MASSES FOR THE SLOPE B(M) IN GEV
C     SLOPE B(M) FOR AN MESONIC SYSTEM
C     SLOPE B(M) FOR A BARYONIC SYSTEM

*
      DATA AMBMBB/  0.8D0, 0.85D0,  0.9D0, 0.95D0, 1.D0,
     &     1.05D0,  1.1D0, 1.15D0,  1.2D0, 1.25D0,
     &      1.3D0,  1.35D0, 1.4D0,  1.45D0,  1.5D0,
     &     1.55D0,  1.6D0,  1.65D0, 1.7D0,   1.75D0,
     &      1.8D0,  1.85D0, 1.9D0,  1.95D0,  2.D0,
     &     15.6D0, 14.95D0, 14.3D0, 13.65D0, 13.D0,
     &    12.35D0, 11.7D0, 10.85D0, 10.D0,  9.15D0,
     &      8.3D0,  7.8D0,  7.3D0,  7.25D0,  7.2D0,
     &     6.95D0,  6.7D0,  6.6D0,  6.5D0,   6.3D0,
     &      6.1D0,  5.85D0, 5.6D0,  5.35D0,  5.1D0,
     &      15.D0,   15.D0, 15.D0,  15.D0,   15.D0, 15.D0, 15.D0,
     &     14.2D0,  13.4D0, 12.6D0,
     &     11.8D0, 11.2D0, 10.6D0,  9.8D0,    9.D0,
     &     8.25D0,  7.5D0, 6.25D0,  5.D0,    4.5D0, 5*4.D0 /
*
      END
*-- Author :
c+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
      DOUBLE PRECISION FUNCTION DAMG(IT)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C*** RANDOM SELECTION OF MASSES OF DECAYING PARTICLES
C     INTEGER * 2 ICH,IBAR,K1,K2,NZK,NRK
      COMMON/DABLTI/AMM(110),GA(110),TAU(110),ICH(110)
     *,IBAR(110),K1(110),K2(110)
      COMMON /DGAMRE/ REDU,AMO,AM (15 )
      DIMENSION GASUNI(14)
      DATA GASUNI/
     *-1.D0,-.98D0,-.95D0,-.87D0,-.72D0,-.48D0,
     *-.17D0,.17D0,.48D0,.72D0,.87D0,.95D0,.98D0,1.D0/
      DATA GAUNO/2.352D0/
      DATA GAUNON/2.4D0/
      DATA IO/14/
      DATA NSTAB/23/
      I=1
      IF (IT.LE.0)                                              GO TO 30
      IF (IT.LE.NSTAB)                                          GO TO 20
      DGAUNI=GAUNO*GAUNON/(IO-1.)
      CALL DRANDM(VV)
      VV=VV*2.-1.+1.D-16
   10 CONTINUE
      VO=GASUNI(I)
      I=I+1
      V1=GASUNI(I)
      IF (VV.GT.V1)                                             GO TO 10
      UNIGA=DGAUNI*(I-2.+(VV-VO+1.E-16)/(V1-VO)-(IO-1.)*.5)
      DAM=GA(IT)*UNIGA/GAUNO
      AAM=AMM(IT)+DAM
      DAMG=AAM
      RETURN
   20 CONTINUE
      DAMG=AMM(IT)
      RETURN
   30 CONTINUE
      DAMG=0.
      RETURN
      END
*-- Author :
      SUBROUTINE DCALUM(N,ITTA)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C*** C.M.S.-ENERGY AND REACTION CHANNEL THRESHOLD CALCULATION
C     INTEGER * 2 ICH,IBAR,K1,K2,NZK,NRK
C    *,IEII,IKII,NURE
      COMMON/DABLTI/AM(110),GA(110),TAU(110),ICH(110)
     *,IBAR(110),K1(110),K2(110)
      COMMON /DREDVE/ THRESH(268), IRII(17),IKII(17),IEII(17)
      COMMON/DSPLI/NZK(460,3),WT(460)
      COMMON /DREAC/UMO( 296),PLABF( 296),SIIN( 296),WK( 5184),
     *NRK(2, 268),NURE(30,2)
      IRE=NURE(N,ITTA/8+1)
      IEO=IEII(IRE)+1
      IEE=IEII(IRE +1)
      AM1=AM(N   )
      AM12=AM1**2
      AM2=AM(ITTA)
      AM22=AM2**2
      DO 10 IE=IEO,IEE
        PLAB2=PLABF(IE)**2
        ELAB=SQRT(AM12+AM22+2.*SQRT(PLAB2+AM12)*AM2)
        UMO(IE)=ELAB
   10 CONTINUE
      IKO=IKII(IRE)+1
      IKE=IKII(IRE +1)
      UMOO=UMO(IEO)
      DO 30 IK=IKO,IKE
        IF(NRK(2,IK).GT.0)                                      GO TO 30
        IKI=NRK(1,IK)
        AMSS=5.
        K11=K1(IKI)
        K22=K2(IKI)
        DO 20 IK1=K11,K22
          IN=NZK(IK1,1)
          AMS=AM(IN)
          IN=NZK(IK1,2)
          IF(IN.GT.0)AMS=AMS+AM(IN)
          IN=NZK(IK1,3)
          IF(IN.GT.0) AMS=AMS+AM(IN)
          IF (AMS.LT.AMSS) AMSS=AMS
   20   CONTINUE
        IF(UMOO.LT.AMSS) UMOO=AMSS
        THRESH(IK)=UMOO
   30 CONTINUE
      RETURN
      END
*-- Author :
      SUBROUTINE DCHANH
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      COMMON/DABLTI/AM(110),GA(110),TAU(110),ICH(110)
     *,IBAR(110),K1(110),K2(110)
      COMMON/DSPLI/ NZK(460,3),WT(460)
      DIMENSION HWT(460)
      COMMON /DREDVE/ THRESH(268), IRII(17),IKII(17),IEII(17)
      DIMENSION HWK(40)
      COMMON /DREAC/UMO( 296),PLABF( 296),SIIN( 296),WK( 5184),
     *NRK(2, 268),NURE(30,2)
      DIMENSION SI(5184)
      EQUIVALENCE (WK(1),SI(1))
C--------------------
C*** USE ONLY FOR DATAPREPARATION OF PURE HADRIN
C*** CALCULATION OF REACTION- AND DECAY-CHANNEL-WEIGHTS,
C*** THRESHOLD ENERGIES+MOMENTA OF REACTION CHNLS.
C*** CHANGE OF WT- AND WK-INPUTDATA INTO WEIGHTS FOR THE M.-C.-PROCEDURE
C*** (ADDED ONE TO EACH OTHER FOR CORRESPONDING CHANNELS)
C--------------------------
      IREG=16
      DO 90 IRE=1,IREG
        IWKO=IRII(IRE)
        IEE=IEII(IRE+1)-IEII(IRE)
        IKE=IKII(IRE+1)-IKII(IRE)
        IEO=IEII(IRE)+1
        IIKA=IKII(IRE)
*   modifications to suppress elestic scattering  24/07/91
        DO 80 IE=1,IEE
          SIS=1.E-14
          SINORC=0.0
          DO 10 IK=1,IKE
            IWK=IWKO+IEE*(IK-1)+IE
            IF(NRK(2,IIKA+IK).EQ.0) SINORC=1.0
            SIS=SIS+SI(IWK)*SINORC
   10     CONTINUE
          SIIN(IEO+IE-1)=SIS
          SIO=0.
          IF (SIS.GE.1.D-12)                                    GO TO 20
          SIS=1.
          SIO=1.
   20     CONTINUE
          SINORC=0.0
          DO 30 IK=1,IKE
            IWK=IWKO+IEE*(IK-1)+IE
            IF(NRK(2,IIKA+IK).EQ.0) SINORC=1.0
            SIO=SIO+SI(IWK)*SINORC/SIS
            HWK(IK)=SIO
   30     CONTINUE
          DO 40 IK=1,IKE
            IWK=IWKO+IEE*(IK-1)+IE
   40     WK(IWK)=HWK(IK)
          IIKI=IKII(IRE)
          DO 70 IK=1,IKE
            AM111=0.
            INRK1=NRK(1,IIKI+IK)
            IF (INRK1.GT.0) AM111=AM(INRK1)
            AM222=0.
            INRK2=NRK(2,IIKI+IK)
            IF (INRK2.GT.0) AM222=AM(INRK2)
            THRESH(IIKI+IK)=AM111 +AM222
            IF (INRK2-1.GE.0)                                   GO TO 60
            INRKK=K1(INRK1)
            AMSS=5.
            INRKO=K2(INRK1)
            DO 50 INRK1=INRKK,INRKO
              INZK1=NZK(INRK1,1)
              INZK2=NZK(INRK1,2)
              INZK3=NZK(INRK1,3)
              IF (INZK1.LE.0.OR.INZK1.GT.110)                   GO TO 50
              IF (INZK2.LE.0.OR.INZK2.GT.110)                   GO TO 50
              IF (INZK3.LE.0.OR.INZK3.GT.110)                   GO TO 50
C     WRITE (6,310)INRK1,INZK1,INZK2,INZK3
 1000 FORMAT (4I10)
              AMS=AM(INZK1)+AM(INZK2)
              IF (INZK3-1.GE.0) AMS=AMS+AM(INZK3)
              IF (AMSS.GT.AMS) AMSS=AMS
   50       CONTINUE
            AMS=AMSS
            IF (AMS.LT.UMO(IEO)) AMS=UMO(IEO)
            THRESH(IIKI+IK)=AMS
   60       CONTINUE
   70     CONTINUE
   80   CONTINUE
   90 CONTINUE
      DO 100 J=1,460
  100 HWT(J)=0.
      DO 120 I=1,110
        IK1=K1(I)
        IK2=K2(I)
        HV=0.
        IF (IK2.GT.460)IK2=460
        IF (IK1.LE.0)IK1=1
        DO 110 J=IK1,IK2
          HV=HV+WT(J)
          HWT(J)=HV
          JI=J
  110   CONTINUE
C       IF (ABS(HV-1.).GT.1.E-4) WRITE(6,1010)I,JI,HV
C1010 FORMAT (35H ERROR IN HWT, FALSE USE OF CHANWH ,2I6,F10.2)
  120 CONTINUE
      DO 130 J=1,460
  130 WT(J)=HWT(J)
      RETURN
      END
*-- Author :
      SUBROUTINE DHADDE
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      CHARACTER*8 ANAMC,ZKNAMC,ANAME,ZKNAME,RKNAME,ANAMZ,ZKNAMZ
C
      COMMON/DPAR/ANAMC(210),AMC(210),GAC(210),TAUC(210),ICHC(210),
     *IBARC(210),K1C(210),K2C(210)
C      COMMON /DDECAC/ ZKNAMC(540),NZKC(540,3),WTC(540)
  
      PARAMETER (IDMAX9=602)
C      CHARACTER*8 ZKNAME
      COMMON/DDECAC/ ZKNAMC(IDMAX9),WTC(IDMAX9),NZKC(IDMAX9,3)


      COMMON /DNAMS/ ANAME(110),ZKNAME(460),RKNAME(268)
      COMMON /DABLTI/AM(110),GA(110),TAU(110),ICH(110)
     *,IBAR(110),K1(110),K2(110)
      COMMON /DSPLI/NZK(460,3),WT(460)
      COMMON /DADDHP/ AMZ(16),GAZ(16),TAUZ(16),ICHZ(16),IBARZ(16),K1Z
     +(16),K2Z(16),WTZ(153),II22, NZKZ(153,3)
 
      COMMON/DADDHN/ANAMZ(16),ZKNAMZ(153)
      DATA IRETUR/0/
      IRETUR=IRETUR+1
      AM(31)=0.48
      IF (IRETUR.GT.1) RETURN
      DO 10 I=1,94
        ANAME(I)=ANAM C(I)
        AM (I)=AMC(I)
        GA( I)=GA C(I)
        TAU( I)=TAU C(I)
        ICH( I)=ICH C(I)
        IBAR( I)=IBARC (I)
        K1( I)=K1C(I)
        K2( I)=K2 C(I)
   10 CONTINUE
      AM(1)=0.9383D0
      AM(2)=AM(1)
      DO 20 I=26,30
        K1(I)=452
        K2(I)=452
   20 CONTINUE
      DO 30 I=1,307
        ZKNAME(I)=ZKNAMC(I)
        WT( I)=WT C(I)
        NZK( I,1)=NZK C(I, 1)
        NZK( I,2)=NZK C(I, 2)
        NZK( I,3)=NZK C(I, 3)
   30 CONTINUE
      DO 40 I=1,16
        L=I+94
        ANAME(L)=ANAMZ (I)
        AM (L)=AMZ(I)
        GA( L)=GA Z(I)
        TAU( L)=TAU Z(I)
        ICH( L)=ICH Z(I)
        IBAR( L)=IBARZ (I)
        K1( L)=K1Z(I)
        K2( L)=K2 Z(I)
   40 CONTINUE
      DO 50 I=1,153
        L=I+307
        ZKNAME(L)=ZKNAMZ(I)
        WT( L)=WT Z(I)
        NZK( L,3)=NZK Z(I, 3)
        NZK( L,2)=NZK Z(I, 2)
        NZK( L,1)=NZK Z(I, 1)
   50 CONTINUE
      RETURN
      END
*-- Author :
      FUNCTION IEFUND(PL,IRE)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C*****IEFUN CALCULATES A MOMENTUM INDEX
C     INTEGER * 2 ICH,IBAR,K1,K2,NZK,NRK
C    *,IEII,IKII,NURE
      COMMON /DRUN/ RUNTES,EFTES
      COMMON /DREDVE/ THRESH(268), IRII(17),IKII(17),IEII(17)
      COMMON /DREAC/UMO( 296),PLABF( 296),SIIN( 296),WK( 5184),
     *NRK(2, 268),NURE(30,2)
      IPLA=IEII(IRE)+1
     *+1
      IPLE=IEII(IRE+1)
      IF (PL.LT.0.)                                             GO TO 30
      DO 10 I=IPLA,IPLE
        J=I-IPLA+1
        IF (PL.LE.PLABF(I))                                     GO TO 60
   10 CONTINUE
      I=IPLE
      IF ( EFTES.GT.40.D0)                                      GO TO 20
      EFTES=EFTES+1.
      WRITE(6,1000)PL,J
   20 CONTINUE
                                                                GO TO 70
   30 CONTINUE
      DO 40 I=IPLA,IPLE
        J=I-IPLA+1
        IF (-PL.LE.UMO(I))                                      GO TO 60
   40 CONTINUE
      I=IPLE
      IF ( EFTES.GT.40.D0)                                      GO TO 50
      EFTES=EFTES+1.
      WRITE(6,1000)PL,I
   50 CONTINUE
   60 CONTINUE
   70 CONTINUE
      IEFUND=I
      RETURN
 1000 FORMAT(14H PLAB OR -ECM=,E12.4,27H IS OUT OF CONSIDERED RANGE ,
     +7H IEFUN=,I5)
      END
*-- Author :
      SUBROUTINE DSIGIN(IRE ,PLAB,N,IE ,AMT ,AMN,ECM ,SI ,ITAR)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      COMMON/DABLTI/AM(110),GA(110),TAU(110),ICH(110)
     *,IBAR(110),K1(110),K2(110)
      COMMON /DREDVE/ THRESH(268), IRII(17),IKII(17),IEII(17)
      COMMON /DREAC/UMO( 296),PLABF( 296),SIIN( 296),WK( 5184),
     *NRK(2, 268),NURE(30,2)
      IE=IEFUND(PLAB,IRE)
      IF (IE.LE.IEII(IRE)) IE=IE+1
      AMT=AM(ITAR)
      AMN=AM(N)
      AMN2=AMN*AMN
      AMT2=AMT*AMT
      ECM=SQRT(AMN2+AMT2+2.*AMT*SQRT(AMN2+PLAB**2))
C*** INTERPOLATION PREPARATION
      ECMO=UMO(IE)
      ECM1=UMO(IE-1)
      DECM=ECMO-ECM1
      DEC=ECMO-ECM
      IIKI=IKII(IRE)+1
      EKLIM=-THRESH(IIKI)
      WOK=SIIN(IE)
      WDK=WOK-SIIN(IE-1)
      IF (ECM.GT.ECMO) WDK=0.
C*** INTERPOLATION IN CHANNEL WEIGHTS
      IELIM=IEFUND(EKLIM,IRE)
      DELIM=UMO(IELIM)+EKLIM
     *+1.E-16
      DETE=(ECM-(ECMO-EKLIM)*.5)*2.
      IF (DELIM*DELIM-DETE*DETE) 20,20,10
   10 DECC=DELIM
                                                                GO TO 30
   20 DECC=DECM
   30 CONTINUE
      WKK=WOK-WDK*DEC/(DECC+1.D-9)
      IF (WKK.LT.0.) WKK=0.
      SI=WKK+1.D-12
      IF (-EKLIM.GT.ECM) SI=1.D-14
      RETURN
      END
*-- Author :
      SUBROUTINE DTCHOI(T,P,PP,E,EE,I,II,N,AM1,AM2)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C     ****************************
C     TCHOIC CALCULATES A RANDOM VALUE
C     FOR THE FOUR-MOMENTUM-TRANSFER T
C     ****************************
      COMMON /DABLTI/ AM(110),GA(110),TAU(110),ICH(110), IBAR(110),K1
     +(110),K2(110)
      COMMON /DSLOPE/ SM(25),BBM(25),BBB(25)
      AMA=AM1
      AMB=AM2
      IF (I.GT.30.AND.II.GT.30)                                 GO TO 20
      III=II
      AM3=AM2
      IF (I.LE.30)                                              GO TO 10
      III=I
      AM3=AM1
   10 CONTINUE
                                                                GO TO 30
   20 CONTINUE
      III=II
      AM3=AM2
      IF (AMA.LE.AMB)                                           GO TO 30
      III=I
      AM3=AM1
   30 CONTINUE
      IB=IBAR(III)
      AMA=AM3
      K=(AMA-0.75)/0.05
      IF (K-2.LT.0) K=1
      IF (K-26.GE.0) K=25
      IF (IB)50,40,50
   40 BM=BBM(K)
                                                                GO TO 60
   50 BM=BBB(K)
   60 CONTINUE
C     NORMALIZATION
      TMIN=-2.*(E*EE-P*PP)+AM(N)**2+AM1  **2
      TMAX=-2.*(E*EE+P*PP)+AM(N)**2+AM1  **2
      CALL DRANDM(VB)
**sr 19-11-95  
C     IF (VB.LT.0.2D0) BM=BM*0.1
C    **0.5
      BM = BM*5.0D0
**
      TMI=BM*TMIN
      TMA=BM*TMAX
      ETMA=0.
      IF (ABS(TMA).GT.120.D0)                                   GO TO 70
      ETMA=EXP(TMA)
   70 CONTINUE
      AN=(1./BM)*(EXP(TMI)-ETMA)
C*** RANDOM CHOICE OF THE T - VALUE
      CALL DRANDM(R)
      T=(1./BM)*LOG(ETMA+R*AN*BM)
      RETURN
      END
*-- Author :
      SUBROUTINE DTWOPA(E1,E2,P1,P2,COD1,COD2,COF1,COF2,SIF1,SIF2,
     1IT1,IT2,UMOO,ECM,P,N,AM1,AM2)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C     ******************************************************
C     QUASI TWO PARTICLE PRODUCTION
C     TWOPAR CALCULATES THE ENERGYS AND THE MOMENTA
C     FOR THE CREATED PARTICLES OR RESONANCES IT1 AND IT2
C     IN THE CM - SYSTEM
C     COD1,COD2,COF1,COF2,SIF1,SIF2 ARE THE ANGLES FOR
C     SPHERICAL COORDINATES
C     ******************************************************
      COMMON /DABLTI/ AM(110),GA(110),TAU(110),ICH(110), IBAR(110),K1
     +(110),K2(110)
C
      AMA=AM1
      AMB=AM2
      AMA2=AMA*AMA
      E1=((UMOO-AMB)*(UMOO+AMB) + AMA2)/(2.*UMOO)
      E2=UMOO - E1
      IF (E1.LT.AMA*1.00001D0) E1=AMA*1.00001D0
      AMTE=(E1-AMA)*(E1+AMA)
      AMTE=AMTE+1.D-18
      P1=SQRT(AMTE)
      P2=P1
C     / P2 / = / P1 /  BUT OPPOSITE DIRECTIONS
C     DETERMINATION  OF  THE ANGLES
C     COS(THETA1)=COD1      COS(THETA2)=COD2
C     SIN(PHI1)=SIF1        SIN(PHI2)=SIF2
C     COS(PHI1)=COF1        COS(PHI2)=COF2
C     PHI IS UNIFORMLY DISTRIBUTED IN ( 0,2*PI )
      CALL DCOSI(COF1,SIF1)
      COF2=-COF1
      SIF2=-SIF1
C     CALCULATION OF THETA1
      CALL DTCHOI(TR,P,P1,ECM,E1,IT1,IT2,N,AM1,AM2)
      COD1=(TR-AMA2-AM(N)*AM(N)+2.*ECM*E1)/(2.*P*P1+1.E-18)
      IF (COD1.GT.0.9999999D0) COD1=0.9999999D0
      COD2=-COD1
      RETURN
      END
*-- Author :
      SUBROUTINE DCOSI(SFE,CFE)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
   10 X=RNDM(A)
      Y=RNDM(B)
      XX=X*X
      YY=Y*Y
      XY=XX+YY
      IF(XY.GT.1.)                                              GO TO 10
      CFE=(XX-YY)/XY
      SFE=2.*X*Y/XY
      IF(RNDM(C).LT.0.5D0)                                      GO TO 20
      RETURN
   20 SFE=-SFE
      RETURN
      END
*-- Author :
      SUBROUTINE DGAUSS(X,A,S)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C     DATA IS/0/
      COMMON /KAINIT/  UMODA,INICH1,INICH2,INICH3,INICH4,INICH5,
     *                 INICH6,INICH7,INICH8,INICH9,IRETUR,KAIS,INIPRI,
     *                 NUSEPT,MUSEPT,ISTART
      DOUBLE PRECISION UMODA
      INTEGER          INICH1,INICH2,INICH3,INICH4,INICH5,
     *                 INICH6,INICH7,INICH8,INICH9,IRETUR,KAIS,INIPRI,
     *                 NUSEPT,MUSEPT
      LOGICAL          ISTART
      IF(KAIS.NE.0)                                             GO TO 10
      CALL DRANDM(X)
      RO=SQRT(ABS(2.*LOG(X)))
      CALL DCOSI(SFE,CFE)
      X=RO*SFE
      KAIS=1
                                                                GO TO 20
   10 X=RO*CFE
      KAIS=0
   20 X=A+X*S
      RETURN
      END
*-- Author :
      SUBROUTINE DRANDM(X)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      X=RNDM(V)
      RETURN
      END
*-- Author :
C++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

*=== blkdt5 ===========================================================*
*==                                                                    *
      BLOCK DATA ZK
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      CHARACTER*8 ZKNAM5,ZKNAM6,ANAMZ,ZKNAM4
      COMMON /DADDHP/ AMZ(16),GAZ(16),TAUZ(16),ICHZ(16),IBARZ(16),
     &       K1Z(16),K2Z(16),WTZ(153),II22,NZK1(153),NZK2(153),NZK3(153)
      COMMON /DADDHN/ ANAMZ(16),ZKNAM4(9),ZKNAM5(90),ZKNAM6(54)
*     Particle masses in GeV                                           *
      DATA AMZ/ 3*2.2D0, 0.9576D0, 3*1.887D0, 2.4D0, 2.03D0, 2*1.44D0,
     &          2*1.7D0, 3*0.D0/
*     Resonance width Gamma in GeV                                     *
      DATA GAZ/ 3*.2D0, .1D0, 4*.2D0, .18D0, 2*.2D0, 2*.15D0, 3*0.D0 /
*     Mean life time in seconds                                        *
      DATA TAUZ / 16*0.D0 /
*     Charge of particles and resonances                               *
      DATA ICHZ/ 0, 1, 3*0, 1, -1, 0, 1, -1, 0, 0, 1 , 3*0 /
*     Baryonic charge                                                  *
      DATA IBARZ/ 2, 7*0, 1, -1, -1, 1, 1, 3*0 /
*     First number of decay channels used for resonances               *
*     and decaying particles                                           *
      DATA K1Z/ 308,310,313,317,322,365,393,421,425,434,440,446,449,
     &          3*460/
*     Last number of decay channels used for resonances                *
*     and decaying particles                                           *
      DATA K2Z/ 309,312,316,321,364,392,420,424,433,439,445,448,451,
     &          3*460/
*     Weight of decay channel                                          *
      DATA WTZ/ .17D0, .83D0, 2*.33D0, .34D0, .17D0, 2*.33D0, .17D0,
     & .01D0, .13D0, .36D0, .27D0, .23D0, .0014D0, .0029D0, .0014D0,
     & .0029D0, 4*.0007D0, .0517D0, .0718D0, .0144D0, .0431D0, .0359D0,
     & .0718D0, .0014D0, .0273D0, .0014D0, .0431D0, 2*.0129D0, .0259D0,
     & .0517D0, .0359D0, .0014D0, 2*.0144D0, .0129D0, .0014D0, .0259D0,
     & .0359D0, .0072D0, .0474D0, .0948D0, .0259D0, .0072D0, .0144D0,
     & .0287D0, .0431D0, .0144D0, .0287D0, .0474D0, .0144D0, .0075D0,
     & .0057D0, .0019D0, .0038D0, .0095D0, 2*.0014D0, .0191D0, .0572D0,
     & .1430D0, 2*.0029D0, 5*.0477D0, .0019D0, .0191D0, .0686D0,.0172D0,
     & .0095D0, .1888D0, .0172D0, .0191D0, .0381D0, 2*.0571D0, .0190D0,
     & .0057D0, .0019D0, .0038D0, .0095D0, .0014D0, .0014D0, .0191D0,
     & .0572D0, .1430D0, 2*.0029D0, 5*.0477D0, .0019D0, .0191D0,.0686D0,
     & .0172D0, .0095D0, .1888D0, .0172D0, .0191D0, .0381D0, 2*.0571D0,
     & .0190D0, 4*.25D0, 2*.2D0, .12D0, .1D0, .07D0, .07D0, .14D0,
     & 2*.05D0, .0D0, .3334D0, .2083D0, 2*.125D0, .2083D0, .0D0, .125D0,
     & .2083D0, .3334D0, .2083D0, .125D0, .3D0, .05D0, .65D0, .3D0,
     & .05D0, .65D0, 9*1.D0 /
*     Particle numbers in decay channel                                *
      DATA NZK1/ 8, 1, 2, 9, 1, 2, 9, 2, 9, 7, 13, 31, 15, 24, 23, 13,
     & 23, 13, 2*23, 14, 13, 23, 31, 98, 2*33, 32, 23, 14, 13, 35, 2*23,
     & 14, 13, 33, 23, 98, 31, 23, 14, 13, 35, 2*33, 32, 23, 35, 33, 32,
     & 98, 5*35, 4*13, 23, 13, 98, 32, 33, 23, 13, 23, 13, 14, 13, 32,
     & 13, 98, 23, 13, 2*32, 13, 33, 32, 98, 2*35, 4*14, 23, 14, 98,
     & 2*34, 23, 14, 23, 2*14, 13, 34, 14, 98, 23, 14, 2*34, 14, 33, 32,
     & 98, 2*35, 104, 61, 105, 62, 1, 17, 21, 17, 22, 2*21, 22, 21, 2,
     & 67, 68, 69, 2, 2*9, 68, 69, 70, 2, 9, 2*24, 15, 2*25, 16, 9*0/
      DATA NZK2/ 2*8, 1, 8, 9, 2*8, 2*1, 7, 14, 13, 16, 25, 23, 14, 23,
     & 14, 31, 33, 32, 34, 35, 31, 23, 31, 33, 34, 31, 32, 34, 31, 33,
     & 32, 2*33, 35, 31, 33, 31, 33, 32, 34, 35, 31, 33, 34, 35, 31,
     & 4*33, 32, 3*35,  2*23, 13, 31, 32, 33, 13, 31, 32, 2*31, 32, 33,
     & 32, 32, 35, 31, 2*32, 33, 31, 33, 35, 33, 3*32, 35, 2*23, 14,
     & 31, 34, 33, 14, 31, 33, 2*31, 34, 32, 33, 34, 35, 31, 2*34, 33,
     & 31, 33, 35, 33, 2*34, 33, 35, 1, 2, 8, 9, 25, 13, 35, 2*32, 33,
     & 31, 13, 23, 31, 13, 23, 14, 79, 80, 31, 13, 23, 14, 78, 79, 8,
     & 1, 8, 1, 8, 1, 9*0 /
      DATA NZK3/ 23, 14, 2*13, 23, 13, 2*23, 14, 0, 7, 14, 4*0, 2*23,
     & 10*0, 33, 2*31, 0, 33, 34, 32, 34, 0, 35, 0, 31, 3*35, 0, 3*31,
     & 35, 31, 33, 34, 31, 33, 34, 31, 33, 35, 0, 23, 14, 6*0, 32, 3*33,
     & 32, 34, 0, 35, 0, 2*35, 2*31, 35, 32, 34, 31, 33, 32, 0, 23, 13,
     & 6*0, 34, 2*33, 34, 33, 34, 0, 35, 0,2*35, 2*31, 35, 2*34, 31,
     & 2*34, 25*0, 23, 2*14, 23, 2*13, 9*0 /
*     Particle  names                                                  *
      DATA ANAMZ / 'NNPI', 'ANPPI', 'ANNPI', ' ETS  ',' PAP  ',' PAN  ',
     & 'APN', 'DEO   ', 'S+2030', 'AN*-14', 'AN*014','KONPI ','AKOPPI',
     & 3*'BLANK' /
*     Name of decay channel                                            *
      DATA ZKNAM4/'NNPI0','PNPI-','APPPI+','ANNPI+','ANPPI0','APNPI+',
     & 'ANNPI0','APPPI0','ANPPI-'/
      DATA ZKNAM5/' GAGA ','P+P-GA','ETP+P-','K+K-  ','K0AK0 ',
     & ' POPO ',' P+P- ','POPOPO','P+P0P-','P0ET  ','&0R0  ','P-R+  ',
     & 'P+R-  ','POOM  ',' ETET ','ETSP0 ','R0ET  ',' R0R0 ','R+R-  ',
     & 'P0ETR0','P-ETR+','P+ETR-',' OMET ','P0R0R0','P0R+R-','P-R+R0',
     & 'P+R-R0','R0OM  ','P0ETOM','ETSR0 ','ETETET','P0R0OM','P-R+OM',
     & 'P+R-OM','OMOM  ','R0ETET','R0R0ET','R+R-ET','P0OMOM','OMETET',
     & 'R0R0R0','R+R0R-','ETSRET','OMR0R0','OMR+R-','OMOMET','OMOMR0',
     & 'OMOMOM',
     & ' P+PO ','P+POPO','P+P+P-','P+ET  ','P0R+  ','P+R0  ','ETSP+ ',
     & 'R+ET  ',' R0R+ ','POETR+','P+ETR0','POR+R-','P+R0R0','P-R+R+',
     & 'P+R-R+','R+OM  ','P+ETOM','ETSR+ ','POR+OM','P+R0OM','R+ETET',
     & 'R+R0ET','P+OMOM','R0R0R+','R+R+R-','ETSR+E','OMR+R0','OMOMR+',
     & 'P-PO  ','P-POPO','P-P-P+','P-ET  ','POR-  ','P-R0  ','ETSP- ',
     & 'R-ET  ','R-R0  ','POETR-','P-ETR0','POR-R0','P-R+R-','P-R0R0'/
      DATA ZKNAM6/'P+R-R-','R-OM  ','P-ETOM','ETSR- ','POR-OM','P-R0OM',
     & 'R-ETET','R-R0ET','P-OMOM','R0R0R-','R+R-R-','ETSR-E','OMR0R-',
     & 'OMOMR-', 'PAN-14','APN+14','NAN014','ANN014','PAKO  ','LPI+  ',
     & 'SI+OM','LAMRO+','SI0RO+','SI+RO0','SI+ETA','SI0PI+','SI+PI0',
     & 'APETA ','AN=P+ ','AN-PO ','ANOPO ','APRHOO','ANRHO-','ANETA ',
     & 'AN-P+ ','AN0PO ','AN+P- ','APRHO+','ANRHO0',
     & 'KONPIO','KOPPI-','K+NPI-','AKOPPO','AKONP+','K-PPI+',
     & 9*'BLANK'/
*=                                               end*block.zk      *
      END
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
*-- Author :
c
c+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

*$ CREATE BLKDT3.FOR
*COPY BLKDT3
*
*=== blkdt3 ===========================================================*
*==                                                                    *
      BLOCK DATA BLKD43
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C      INCLUDE '(DBLPRC)'
C      INCLUDE '(DIMPAR)'
C      INCLUDE '(IOUNIT)'
* * * reaction channel cross section data                              *
C      INCLUDE '(REAC)'

*$ CREATE REAC.ADD
*COPY REAC
*
*=== reac =============================================================*
*
*----------------------------------------------------------------------*
*                                                                      *
*     Created on 10 december 1991  by    Alfredo Ferrari & Paola Sala  *
*                                                   Infn - Milan       *
*                                                                      *
*     Last change on 10-dec-91     by    Alfredo Ferrari               *
*                                                                      *
*     This is the original common reac of Hadrin                       *
*                                                                      *
*----------------------------------------------------------------------*
*
      COMMON /DREAC/ UMO   ( 296), PLABF ( 296), SIIN  ( 296),
     +              WK    (5184), NRK  (2,268), NURE  (30,2)

      DIMENSION
     & UMOPI(92), UMOKC(68), UMOP(39), UMON(63), UMOK0(34),
     & PLAPI(92), PLAKC(68), PLAP(39), PLAN(63), PLAK0(34),
     & SPIKP1(315), SPIKPU(278), SPIKPV(372),
     & SPIKPW(278), SPIKPX(372), SPIKP4(315),
     & SPIKP5(187), SPIKP6(289),
     & SKMPEL(102), SPIKP7(289), SKMNEL(68), SPIKP8(187),
     & SPIKP9(143), SPIKP0(169), SPKPV(143),
     & SAPPEL(105), SPIKPE(399), SAPNEL(84), SPIKPZ(273),
     & SANPEL(84) , SPIKPF(273),
     & SPKP15(187), SPKP16(272),
     & NRKPI(164), NRKKC(132), NRKP(70), NRKN(116), NRKK0(54),
     & NURELN(60)
*
       DIMENSION NRKLIN(532)
       EQUIVALENCE (NRK(1,1), NRKLIN(1))
       EQUIVALENCE (   UMO(  1),  UMOPI(1)), (   UMO( 93),  UMOKC(1))
       EQUIVALENCE (   UMO(161),   UMOP(1)), (   UMO(200),   UMON(1))
       EQUIVALENCE (   UMO(263),  UMOK0(1))
       EQUIVALENCE ( PLABF(  1),  PLAPI(1)), ( PLABF( 93),  PLAKC(1))
       EQUIVALENCE ( PLABF(161),   PLAP(1)), ( PLABF(200),   PLAN(1))
       EQUIVALENCE ( PLABF(263),  PLAK0(1))
       EQUIVALENCE (   WK(   1), SPIKP1(1)), (   WK( 316), SPIKPU(1))
       EQUIVALENCE (   WK( 594), SPIKPV(1)), (   WK( 966), SPIKPW(1))
       EQUIVALENCE (   WK(1244), SPIKPX(1)), (   WK(1616), SPIKP4(1))
       EQUIVALENCE (   WK(1931), SPIKP5(1)), (   WK(2118), SPIKP6(1))
       EQUIVALENCE (   WK(2407), SKMPEL(1)), (   WK(2509), SPIKP7(1))
       EQUIVALENCE (   WK(2798), SKMNEL(1)), (   WK(2866), SPIKP8(1))
       EQUIVALENCE (   WK(3053), SPIKP9(1)), (   WK(3196), SPIKP0(1))
       EQUIVALENCE (   WK(3365),  SPKPV(1)), (   WK(3508), SAPPEL(1))
       EQUIVALENCE (   WK(3613), SPIKPE(1)), (   WK(4012), SAPNEL(1))
       EQUIVALENCE (   WK(4096), SPIKPZ(1)), (   WK(4369), SANPEL(1))
       EQUIVALENCE (   WK(4453), SPIKPF(1)), (   WK(4726), SPKP15(1))
       EQUIVALENCE (   WK(4913), SPKP16(1))
       EQUIVALENCE (NRK(1,1), NRKLIN(1))
       EQUIVALENCE (NRKLIN(   1), NRKPI(1)), (NRKLIN( 165), NRKKC(1))
       EQUIVALENCE (NRKLIN( 297),  NRKP(1)), (NRKLIN( 367),  NRKN(1))
       EQUIVALENCE (NRKLIN( 483), NRKK0(1))
       EQUIVALENCE (NURE(1,1), NURELN(1))
*
**** pi- p data                                                        *
**** pi+ n data                                                        *
      DATA PLAPI / 0.D0, .3D0, .5D0, .6D0, .7D0, .8D0, .9D0, .95D0,1.D0,
     & 1.15D0, 1.3D0, 1.5D0, 1.6D0, 1.8D0, 2.D0, 2.3D0, 2.5D0, 2.8D0,
     & 3.D0, 3.5D0, 4.D0, 0.D0, .285D0, .4D0, .45D0, .5D0, .6D0, .7D0,
     & .75D0, .8D0, .85D0, .9D0, 1.D0, 1.15D0, 1.3D0, 1.5D0, 1.6D0,
     & 1.8D0, 2.D0, 2.3D0, 2.5D0, 2.8D0, 3.D0, 3.5D0, 4.D0, 4.5D0, 0.D0,
     & .285D0, .4D0, .45D0, .5D0, .6D0, .7D0, .75D0, .8D0, .85D0, .9D0,
     & 1.D0, 1.15D0, 1.3D0, 1.5D0, 1.6D0, 1.8D0, 2.D0, 2.3D0, 2.5D0,
     & 2.8D0, 3.D0, 3.5D0, 4.D0, 4.5D0, 0.D0, .3D0, .5D0, .6D0, .7D0,
     & .8D0, .9D0, .95D0, 1.D0, 1.15D0, 1.3D0, 1.5D0, 1.6D0, 1.8D0,
     & 2.D0, 2.3D0, 2.5D0, 2.8D0, 3.D0, 3.5D0, 4.D0 /
      DATA PLAKC /
     &   0.D0,  .58D0,   .8D0, 1.01D0, 1.23D0, 1.45D0, 1.68D0, 1.94D0,
     & 2.18D0, 2.42D0, 2.68D0, 2.96D0, 3.24D0,
     & 3.51D0, 3.84D0, 4.16D0, 4.49D0,
     &   0.D0,  .58D0,   .8D0, 1.01D0, 1.23D0, 1.45D0, 1.68D0, 1.94D0,
     & 2.18D0, 2.42D0, 2.68D0, 2.96D0, 3.24D0,
     & 3.51D0, 3.84D0, 4.16D0, 4.49D0,
     &   0.D0,  .58D0,   .8D0, 1.01D0, 1.23D0, 1.45D0, 1.68D0, 1.94D0,
     & 2.18D0, 2.42D0, 2.68D0, 2.96D0, 3.24D0,
     & 3.51D0, 3.84D0, 4.16D0, 4.49D0,
     &   0.D0,  .58D0,   .8D0, 1.01D0, 1.23D0, 1.45D0, 1.68D0, 1.94D0,
     & 2.18D0, 2.42D0, 2.68D0, 2.96D0, 3.24D0,
     & 3.51D0, 3.84D0, 4.16D0, 4.49D0/
      DATA PLAK0 /
     &   0.D0,  .58D0,   .8D0, 1.01D0, 1.23D0, 1.45D0, 1.68D0, 1.94D0,
     & 2.18D0, 2.42D0, 2.68D0, 2.96D0, 3.24D0,
     & 3.51D0, 3.84D0, 4.16D0, 4.49D0,
     &   0.D0,  .58D0,   .8D0, 1.01D0, 1.23D0, 1.45D0, 1.68D0, 1.94D0,
     & 2.18D0, 2.42D0, 2.68D0, 2.96D0, 3.24D0,
     & 3.51D0, 3.84D0, 4.16D0, 4.49D0/
*                 pp   pn   np   nn                                    *
      DATA PLAP /
     &   0.D0, 1.06D0, 1.34D0, 1.63D0, 1.92D0, 2.2D0, 2.5D0,2.8D0,3.1D0,
     & 3.43D0, 3.75D0, 4.07D0, 4.43D0,
     &   0.D0, 1.06D0, 1.34D0, 1.63D0, 1.92D0, 2.2D0, 2.5D0,2.8D0,3.1D0,
     & 3.43D0, 3.75D0, 4.07D0, 4.43D0,
     &   0.D0, 1.06D0, 1.34D0, 1.63D0, 1.92D0, 2.2D0, 2.5D0,2.8D0,3.1D0,
     & 3.43D0, 3.75D0, 4.07D0, 4.43D0 /
*    app   apn   anp   ann                                             *
      DATA PLAN /
     &  0.D0,   1.D-3,   .1D0,   .2D0,   .3D0,  .4D0,  .5D0, .6D0,
     & .74D0,  1.06D0, 1.34D0, 1.63D0, 1.92D0, 2.2D0, 2.5D0,2.8D0,3.1D0,
     & 3.43D0, 3.75D0, 4.07D0, 4.43D0,
     &  0.D0,   1.D-3,   .1D0,   .2D0,   .3D0,  .4D0,  .5D0, .6D0,
     & .74D0,  1.06D0, 1.34D0, 1.63D0, 1.92D0, 2.2D0, 2.5D0,2.8D0,3.1D0,
     & 3.43D0, 3.75D0, 4.07D0, 4.43D0,
     &  0.D0,   1.D-3,   .1D0,   .2D0,   .3D0,  .4D0,  .5D0, .6D0,
     & .74D0,  1.06D0, 1.34D0, 1.63D0, 1.92D0, 2.2D0, 2.5D0,2.8D0,3.1D0,
     & 3.43D0, 3.75D0, 4.07D0, 4.43D0  /
      DATA SIIN / 296*0.D0 /
      DATA UMOPI/ 1.08D0,1.233D0,1.302D0,1.369D0,1.496D0,
     & 1.557D0,1.615D0,1.6435D0,
     & 1.672D0,1.753D0,1.831D0,1.930D0,1.978D0,2.071D0,2.159D0,
     & 2.286D0,2.366D0,2.482D0,2.56D0,
     & 2.735D0,2.90D0,
     &             1.08D0,1.222D0,1.302D0,1.3365D0,1.369D0,1.434D0,
     & 1.496D0,1.527D0,1.557D0,
     & 1.586D0,1.615D0,1.672D0,1.753D0,1.831D0,1.930D0,1.978D0,
     & 2.071D0,2.159D0,2.286D0,2.366D0,
     & 2.482D0,2.560D0,2.735D0,2.90D0,3.06D0,
     &             1.08D0,1.222D0,1.302D0,1.3365D0,1.369D0,1.434D0,
     & 1.496D0,1.527D0,1.557D0,
     & 1.586D0,1.615D0,1.672D0,1.753D0,1.831D0,1.930D0,1.978D0,
     & 2.071D0,2.159D0,2.286D0,2.366D0,
     & 2.482D0,2.560D0,2.735D0,2.90D0,3.06D0,
     &                   1.08D0,1.233D0,1.302D0,1.369D0,1.496D0,
     & 1.557D0,1.615D0,1.6435D0,
     & 1.672D0,1.753D0,1.831D0,1.930D0,1.978D0,2.071D0,2.159D0,
     & 2.286D0,2.366D0,2.482D0,2.56D0,
     &  2.735D0, 2.90D0/
      DATA UMOKC/ 1.44D0,
     &  1.598D0,1.7D0,1.8D0,1.9D0,2.0D0,2.1D0,2.2D0,2.3D0,2.4D0,2.5D0,
     & 2.6D0,2.7D0,2.8D0,2.9D0,3.0D0,
     & 3.1D0,1.44D0,
     &  1.598D0,1.7D0,1.8D0,1.9D0,2.0D0,2.1D0,2.2D0,2.3D0,2.4D0,2.5D0,
     & 2.6D0,2.7D0,2.8D0,2.9D0,3.0D0,
     & 3.1D0,1.44D0,
     &  1.598D0,1.7D0,1.8D0,1.9D0,2.0D0,2.1D0,2.2D0,2.3D0,2.4D0,2.5D0,
     & 2.6D0,2.7D0,2.8D0,2.9D0,3.0D0,
     & 3.1D0,1.44D0,
     &  1.598D0,1.7D0,1.8D0,1.9D0,2.0D0,2.1D0,2.2D0,2.3D0,2.4D0,2.5D0,
     & 2.6D0,2.7D0,2.8D0,2.9D0,3.0D0,
     &  3.1D0/
      DATA UMOK0/ 1.44D0,
     &  1.598D0,1.7D0,1.8D0,1.9D0,2.0D0,2.1D0,2.2D0,2.3D0,2.4D0,2.5D0,
     & 2.6D0,2.7D0,2.8D0,2.9D0,3.0D0,
     & 3.1D0,1.44D0,
     &  1.598D0,1.7D0,1.8D0,1.9D0,2.0D0,2.1D0,2.2D0,2.3D0,2.4D0,2.5D0,
     & 2.6D0,2.7D0,2.8D0,2.9D0,3.0D0,
     &  3.1D0/
*                 pp   pn   np   nn                                    *
      DATA UMOP/
     & 1.88D0,2.102D0,2.2D0,2.3D0,2.4D0,2.5D0,2.6D0,2.7D0,2.8D0,2.9D0,
     & 3.D0,3.1D0,3.2D0,
     & 1.88D0,2.102D0,2.2D0,2.3D0,2.4D0,2.5D0,2.6D0,2.7D0,2.8D0,2.9D0,
     & 3.D0,3.1D0,3.2D0,
     & 1.88D0,2.102D0,2.2D0,2.3D0,2.4D0,2.5D0,2.6D0,2.7D0,2.8D0,2.9D0,
     & 3.D0,3.1D0,3.2D0/
*    app   apn   anp   ann                                             *
      DATA UMON /
     & 1.877D0,1.87701D0,1.879D0,1.887D0,1.9D0,1.917D0,1.938D0,1.962D0,
     & 2.D0,2.102D0,2.2D0,2.3D0,2.4D0,2.5D0,2.6D0,2.7D0,2.8D0,2.9D0,
     & 3.D0,3.1D0,3.2D0,
     & 1.877D0,1.87701D0,1.879D0,1.887D0,1.9D0,1.917D0,1.938D0,1.962D0,
     & 2.D0,2.102D0,2.2D0,2.3D0,2.4D0,2.5D0,2.6D0,2.7D0,2.8D0,2.9D0,
     & 3.D0,3.1D0,3.2D0,
     & 1.877D0,1.87701D0,1.879D0,1.887D0,1.9D0,1.917D0,1.938D0,1.962D0,
     & 2.D0,2.102D0,2.2D0,2.3D0,2.4D0,2.5D0,2.6D0,2.7D0,2.8D0,2.9D0,
     &  3.D0,3.1D0,3.2D0/
**** reaction channel state particles                                  *
      DATA NRKPI / 13, 1, 15, 21, 81, 0, 13, 54, 23, 53, 13, 63, 13, 58,
     & 23, 57, 13, 65, 1, 32, 53, 31, 54, 32, 53, 33, 53, 35, 63, 32,
     & 13, 8, 23, 1, 17, 15, 21, 24, 22, 15, 82, 0, 61, 0, 13, 55, 23,
     & 54, 14, 53, 13, 64, 23, 63, 13, 59, 23, 58, 14, 57, 13, 66, 23,
     & 65, 1, 31, 8, 32, 1, 33, 1, 35, 54, 31, 55, 32, 54, 33, 53, 34,
     & 54, 35, 14, 1, 23, 8, 17, 24, 20, 15, 22, 24, 83, 0, 62, 0, 14,
     & 54, 23, 55, 13, 56, 14, 63, 23, 64, 14, 58, 23, 59, 13, 60, 14,
     & 65, 23, 66, 8, 31, 1, 34, 8, 33, 8, 35, 55, 31, 54, 34, 55, 33,
     & 56, 32, 55, 35, 14, 8, 24, 20, 84, 0, 14, 55, 23, 56, 14, 64, 14,
     & 59, 23, 60, 14, 66, 8, 34, 56, 31, 55, 34, 56, 33, 56, 35, 64,34/
      DATA NRKKC/ 15, 1, 89, 0, 24, 53, 15, 54, 1, 36, 1, 40, 1, 44, 36,
     & 63, 15, 63, 45, 53, 44, 54, 15, 8, 24, 1, 91, 0, 24, 54, 15, 55,
     & 8, 36, 1, 37, 8, 40, 1, 41, 8, 44, 1, 45, 36, 64, 37, 63, 15, 64,
     & 24, 63, 45, 54, 44, 55, 16, 1, 25, 8, 17, 23, 21, 14, 20,
     & 13, 22, 23, 90, 0, 38, 1, 39, 8, 16, 54, 25, 55, 1, 42, 8, 43,
     & 16, 63, 25, 64, 39, 64, 38, 63, 46, 54, 47, 55, 8, 47, 1, 46, 52,
     & 0, 51, 0, 16, 8, 17, 14, 20, 23, 22, 14, 92, 0, 8, 38, 16, 55,
     & 25, 56, 8, 42, 16, 64, 38, 64, 46, 55, 47, 56, 8, 46, 94, 0 /
*                                                                      *
*   k0 p   k0 n   ak0 p   ak/ n                                        *
*                                                                      *
      DATA NRKK0 / 24, 8, 106, 0, 15, 56, 24, 55, 37, 8, 41, 8, 45, 8,
     & 37, 64, 24, 64, 44, 56, 45, 55, 25, 1, 17, 13,   22, 13, 21, 23,
     & 107, 0, 39, 1, 25, 54, 16, 53, 43, 1, 25, 63, 39, 63, 47, 54, 46,
     & 53, 47, 1, 103, 0, 93, 0/
*   pp  pn   np   nn                                                   *
      DATA NRKP / 1, 1, 85, 0, 8, 53, 1, 54, 1, 63, 8, 57, 1, 58, 2*54,
     & 53, 55, 63, 54, 64, 53, 1, 8, 86, 0, 8, 54, 1, 55, 8, 63, 1, 64,
     & 8, 58, 1, 59, 64, 54, 63, 55, 54, 55, 53, 56, 77, 0, 2*8, 95, 0,
     & 8, 55, 1, 56, 8, 64, 8, 59, 1, 60, 2*55, 54, 56, 64, 55, 63, 56 /
*     app   apn   anp   ann                                            *
      DATA NRKN/ 1, 2, 17, 18, 15, 16, 8, 9, 13, 14, 99, 0, 87, 0, 1,
     & 68, 8, 69, 2, 54, 9, 55, 102, 0, 2, 63, 9, 64, 1, 75, 8, 76, 53,
     & 67, 54, 68, 55, 69, 56, 70, 63, 68, 64, 69, 75, 54, 76, 55, 2, 8,
     & 18, 20, 16, 24, 14, 23, 101, 0, 88, 0, 2, 55, 9, 56, 1, 67, 8,
     & 68, 2, 64, 8, 75, 2, 59, 8, 72, 68, 55, 67, 54, 69, 56, 1, 9, 18,
     & 21, 15, 25, 13, 23, 100, 0, 96, 0, 2, 53, 9, 54, 1, 69, 8, 70, 1,
     & 76, 9, 63, 1, 73, 9, 58, 55, 70, 53, 68, 54, 69 /
**** channel cross section                                             *
      DATA SPIKP1/ 0.D0, 300.D0, 40.D0, 20.D0, 13.D0,8.5D0,8.D0, 9.5D0,
     & 12.D0,14.D0,15.5D0,20.D0,17.D0,13.D0,10.D0,9.D0,8.5D0,8.D0,7.8D0,
     & 7.3D0, 6.7D0, 9*0.D0,.23D0,.35D0,.7D0,.52D0,.4D0,.3D0,.2D0,.15D0,
     & .13D0, .11D0, .09D0, .07D0, 0.D0, .033D0,.8D0,1.35D0,1.35D0,.5D0,
     & 15*0.D0, 3*0.D0,.00D0,0.80D0,2.2D0,3.6D0,4.6D0,4.7D0,3.5D0,2.4D0,
     &1.8D0,1.4D0,.75D0,.47D0,.25D0,.13D0,.08D0,6*0.D0,0.D0,1.2D0,3.3D0,
     & 5.4D0,6.9D0,7.3D0,5.3D0,3.6D0,2.7D0,2.2D0,1.1D0,.73D0,.4D0,.22D0,
     & .12D0,9*0.D0,.0D0,0.D0,2.0D0,4.4D0,6.8D0,9.9D0,7.9D0,6.0D0,3.8D0,
     &2.5D0,2.D0,1.4D0,1.D0,.6D0,.35D0,10*0.D0,.25D0,.55D0,.75D0,1.25D0,
     & 1.9D0,2.D0,1.8D0,1.5D0,1.25D0,1.D0,.8D0,6*0.D0,4*0.D0,.4D0,.85D0,
     & 1.1D0, 1.85D0, 2.8D0, 3.D0,2.7D0,2.2D0,1.85D0,1.5D0,1.2D0,6*0.D0,
     & 6*0.D0, .5D0, 1.2D0, 1.7D0, 3.4D0, 5.2D0, 6.4D0, 6.1D0, 5.6D0,
     & 5.2D0, 6*0.D0, 2*0.D0, .0D0, 1.D0, 3.3D0, 5.2D0, 4.45D0, 3.6D0,
     & 2.75D0, 1.9D0, 1.65D0, 1.3D0, .95D0, .6D0, .45D0, 6*0.D0, 3*0.D0,
     & .0D0, .45D0, 1.4D0, 1.5D0, 1.1D0, .85D0, .5D0, .3D0, .2D0, .15D0,
     & 8*0.D0, 5*0.D0, .0D0, .0D0, .6D0, .8D0, .95D0, .8D0, .7D0, .6D0,
     & .5D0, .4D0, 6*0.D0, 5*0.D0, .0D0, .00D0, .85D0, 1.2D0, 1.4D0,
     & 1.2D0, 1.05D0, .9D0, .7D0, .55D0, 6*0.D0, 5*0.D0, .0D0, .00D0,
     & 1.D0, 1.5D0, 3.5D0, 4.15D0, 3.7D0, 2.7D0, 2.3D0, 1.75D0, 6*0.D0,
     & 10*0.D0, .5D0, 2.0D0, 3.3D0, 5.4D0, 7.D0 /
**** pi+ n data                                                        *
      DATA SPIKPU/   0.D0, 25.D0, 13.D0,  11.D0, 10.5D0, 14.D0,  20.D0,
     & 20.D0, 16.D0, 14.D0, 19.D0, 28.D0, 17.5D0, 13.5D0, 12.D0, 10.5D0,
     & 10.D0, 10.D0, 9.5D0,  9.D0, 8.D0, 7.5D0, 7.D0, 6.5D0, 6.D0, 0.D0,
     & 48.D0, 19.D0, 15.D0, 11.5D0, 10.D0, 8.D0, 6.5D0,   5.5D0,  4.8D0,
     & 4.2D0, 7.5D0, 3.4D0,  2.5D0, 2.5D0, 2.1D0, 1.4D0,   1.D0,   .8D0,
     &  .6D0, .46D0,  .3D0, .2D0, .15D0, .13D0, 11*0.D0,  .95D0,  .65D0,
     & .48D0, .35D0,  .2D0, .18D0, .17D0, .16D0,  .15D0,   .1D0,  .09D0,
     & .065D0, .05D0, .04D0, 12*0.D0, .2D0, .25D0, .25D0,  .2D0,   .1D0,
     & .08D0, .06D0, .045D0,   .03D0, .02D0, .01D0,      .005D0, .003D0,
     & 12*0.D0, .3D0, .24D0,   .18D0, .15D0, .13D0,  .12D0, .11D0, .1D0,
     & .09D0,  .08D0, .05D0,   .04D0, .03D0,  0.D0, 0.16D0, .7D0, 1.3D0,
     & 3.1D0,  4.5D0,  2.D0, 18*0.D0, 3*.0D0,  0.D0, 0.D0, 4.0D0, 11.D0,
     & 11.4D0, 10.3D0, 7.5D0, 6.8D0, 4.75D0, 2.5D0,  1.5D0, .9D0, .55D0,
     &  .35D0, 13*0.D0, .1D0, .34D0, .5D0, .8D0, 1.1D0,   2.25D0, 3.3D0,
     & 2.3D0, 1.6D0, .95D0, .45D0, .28D0, .15D0, 10*0.D0, 2*0.D0, .17D0,
     & .64D0,  1.D0, 1.5D0, 2.1D0, 4.25D0, 6.2D0,  4.4D0,   3.D0, 1.8D0,
     &  .9D0, .53D0, .28D0,      10*0.D0, 2*0.D0,  .25D0,  .82D0,
     & 1.3D0, 1.9D0, 2.8D0, 5.5D0 , 8.D0,  5.7D0, 3.9D0, 2.35D0, 1.15D0,
     & .69D0, .37D0, 10*0.D0,     7*0.D0,   .0D0, .34D0,  1.5D0, 3.47D0,
     & 5.87D0, 6.23D0, 4.27D0, 2.6D0, 1.D0, .6D0,  .3D0,  .15D0, 6*0.D0/
*
      DATA SPIKPV/ 7*0.D0, .00D0, .16D0, .75D0, 1.73D0, 2.93D0, 3.12D0,
     & 2.13D0, 1.3D0, .5D0, .3D0, .15D0, .08D0, 6*0.D0, 10*0.D0, .2D0,
     & .6D0, .92D0, 2.4D0, 4.9D0, 6.25D0, 5.25D0, 3.5D0, 2.15D0, 1.4D0,
     & 1.D0, .7D0, 13*0.D0, .13D0, .4D0, .62D0, 1.6D0, 3.27D0, 4.17D0,
     & 3.5D0, 2.33D0, 1.43D0, .93D0, .66D0, .47D0, 13*0.D0, .07D0, .2D0,
     & .31D0, .8D0, 1.63D0, 2.08D0, 1.75D0, 1.17D0, .72D0, .47D0, .34D0,
     & .23D0, 17*0.D0, .33D0, 1.D0, 1.8D0, 2.67D0, 5.33D0, 6.D0, 5.53D0,
     & 5.D0, 17*0.D0, .17D0, .5D0, .9D0, 1.83D0, 2.67D0, 3.0D0, 2.77D0,
     & 2.5D0, 3*0.D0, 3*0.D0, 1.D0, 3.3D0, 2.8D0, 2.5D0, 2.3D0, 1.8D0,
     & 1.5D0, 1.1D0, .8D0, .7D0, .55D0, .3D0, 10*0.D0, 9*0.D0, .1D0,
     & .4D0, 1.D0, 1.4D0, 2.2D0, 2.5D0, 2.2D0, 1.65D0, 1.35D0, 1.1D0,
     & .8D0, .6D0, .4D0, 12*0.D0, .15D0, .6D0, 1.5D0, 2.1D0, 3.3D0,
     & 3.8D0, 3.3D0, 2.45D0, 2.05D0, 1.65D0, 1.2D0, .9D0, .6D0, 3*0.D0,
     & 9*0.D0, .10D0, .2D0, .5D0, .7D0, 1.3D0, 1.55D0, 1.9D0, 1.8D0,
     & 1.55D0, 1.35D0, 1.15D0, .95D0, .7D0, 13*0.D0, .2D0, .5D0, .7D0,
     & 1.3D0, 1.55D0, 1.9D0, 1.8D0, 1.55D0, 1.35D0, 1.15D0, .95D0, .7D0,
     & 17*0.D0, .2D0, .5D0, .85D0, 2.D0, 2.15D0, 2.05D0, 1.75D0, 1.D0,
     & 17*0.D0, .13D0, .33D0, .57D0, 1.33D0, 1.43D0, 1.36D0, 1.17D0,
     & .67D0, 17*0.D0, .07D0, .17D0, .28D0, .67D0, .72D0, .69D0, .58D0,
     & .33D0,17*0.D0,.4D0, .7D0, 1.D0, 1.6D0, 1.8D0, 2.3D0,1.9D0,1.7D0 /
**** pi- p data                                                        *
      DATA SPIKPW/ 0.D0, 25.D0, 13.D0, 11.D0, 10.5D0, 14.D0, 2*20.D0,
     & 16.D0, 14.D0, 19.D0, 28.D0, 17.5D0, 13.5D0, 12.D0, 10.5D0,
     & 2*10.D0, 9.5D0, 9.D0, 8.D0, 7.5D0, 7.D0, 6.5D0, 6.D0, 0.D0,
     & 48.D0, 19.D0, 15.D0, 11.5D0, 10.D0, 8.D0, 6.5D0, 5.5D0, 4.8D0,
     & 4.2D0, 7.5D0, 3.4D0, 2*2.5D0, 2.1D0, 1.4D0, 1.D0, .8D0, .6D0,
     & .46D0, .3D0, .2D0, .15D0, .13D0, 11*0.D0, .95D0, .65D0, .48D0,
     & .35D0, .2D0, .18D0, .17D0, .16D0, .15D0, .1D0, .09D0, .065D0,
     & .05D0, .04D0, 12*0.D0, .2D0, 2*.25D0, .2D0, .1D0, .08D0, .06D0,
     & .045D0, .03D0, .02D0, .01D0, .005D0, .003D0, 12*0.D0, .3D0,
     & .24D0, .18D0, .15D0, .13D0, .12D0, .11D0, .1D0, .09D0, .08D0,
     & .05D0, .04D0, .03D0, 0.D0, 0.16D0, .7D0, 1.3D0, 3.1D0, 4.5D0,
     & 2.D0, 23*0.D0, 4.0D0, 11.D0, 11.4D0, 10.3D0, 7.5D0, 6.8D0,
     & 4.75D0, 2.5D0, 1.5D0, .9D0, .55D0, .35D0, 13*0.D0, .1D0, .34D0,
     & .5D0, .8D0, 1.1D0, 2.25D0, 3.3D0, 2.3D0, 1.6D0, .95D0, .45D0,
     & .28D0, .15D0, 12*0.D0, .17D0, .64D0, 1.D0, 1.5D0, 2.1D0, 4.25D0,
     & 6.2D0, 4.4D0, 3.D0, 1.8D0, .9D0, .53D0, .28D0, 12*0.D0, .25D0,
     & .82D0, 1.3D0, 1.9D0, 2.8D0, 5.5D0, 8.D0, 5.7D0, 3.9D0, 2.35D0,
     & 1.15D0, .69D0, .37D0, 18*0.D0, .34D0, 1.5D0, 3.47D0, 5.87D0,
     & 6.23D0, 4.27D0, 2.6D0, 1.D0, .6D0, .3D0, .15D0, 6*0.D0/
*
      DATA SPIKPX/ 8*0.D0, .16D0, .75D0, 1.73D0, 2.93D0, 3.12D0,
     & 2.13D0, 1.3D0, .5D0, .3D0, .15D0, .08D0, 16*0.D0, .2D0, .6D0,
     & .92D0, 2.4D0, 4.9D0, 6.25D0, 5.25D0, 3.5D0, 2.15D0, 1.4D0, 1.D0,
     & .7D0, 13*0.D0, .13D0, .4D0, .62D0, 1.6D0, 3.27D0, 4.17D0, 3.5D0,
     & 2.33D0, 1.43D0, .93D0, .66D0, .47D0, 13*0.D0, .07D0, .2D0, .31D0,
     & .8D0, 1.63D0, 2.08D0, 1.75D0, 1.17D0, .72D0, .47D0, .34D0, .23D0,
     & 17*0.D0, .33D0, 1.D0, 1.8D0, 2.67D0, 5.33D0, 6.D0, 5.53D0, 5.D0,
     & 17*0.D0, .17D0, .5D0, .9D0, 1.83D0, 2.67D0, 3.0D0, 2.77D0, 2.5D0,
     & 6*0.D0, 1.D0, 3.3D0, 2.8D0, 2.5D0, 2.3D0, 1.8D0, 1.5D0, 1.1D0,
     & .8D0, .7D0, .55D0, .3D0, 19*0.D0, .1D0, .4D0, 1.D0, 1.4D0, 2.2D0,
     & 2.5D0, 2.2D0, 1.65D0, 1.35D0, 1.1D0, .8D0, .6D0, .4D0, 12*0.D0,
     & .15D0, .6D0, 1.5D0, 2.1D0, 3.3D0, 3.8D0, 3.3D0, 2.45D0, 2.05D0,
     & 1.65D0, 1.2D0, .9D0, .6D0, 12*0.D0, .10D0, .2D0, .5D0, .7D0,
     & 1.3D0, 1.55D0, 1.9D0, 1.8D0, 1.55D0, 1.35D0, 1.15D0, .95D0, .7D0,
     & 13*0.D0, .2D0, .5D0, .7D0, 1.3D0, 1.55D0, 1.9D0, 1.8D0, 1.55D0,
     & 1.35D0, 1.15D0, .95D0, .7D0, 17*0.D0, .2D0, .5D0, .85D0, 2.D0,
     & 2.15D0, 2.05D0, 1.75D0, 1.D0, 17*0.D0, .13D0, .33D0, .57D0,
     & 1.33D0, 1.43D0, 1.36D0, 1.17D0, .67D0, 17*0.D0, .07D0, .17D0,
     & .28D0, .67D0, .72D0, .69D0, .58D0, .33D0, 17*0.D0, .4D0, .7D0,
     & 1.D0, 1.6D0, 1.8D0, 2.3D0, 1.9D0, 1.7D0 /
**** pi- n data                                                        *
      DATA SPIKP4 / 0.D0, 300.D0, 40.D0, 20.D0, 13.D0, 8.5D0, 8.D0,
     & 9.5D0, 12.D0, 14.D0, 15.5D0, 20.D0, 17.D0, 13.D0, 10.D0, 9.D0,
     & 8.5D0, 8.D0, 7.8D0, 7.3D0, 6.7D0, 9*0.D0, .23D0, .35D0, .7D0,
     & .52D0, .4D0, .3D0, .2D0, .15D0, .13D0, .11D0, .09D0, .07D0, 0.D0,
     & .033D0, .8D0, 2*1.35D0, .5D0, 19*0.D0, 0.8D0, 2.2D0, 3.6D0,
     & 4.6D0, 4.7D0, 3.5D0, 2.4D0, 1.8D0, 1.4D0, .75D0, .47D0, .25D0,
     & .13D0, .08D0, 7*0.D0, 1.2D0, 3.3D0, 5.4D0, 6.9D0, 7.3D0, 5.3D0,
     & 3.6D0, 2.7D0, 2.2D0, 1.1D0, .73D0, .4D0, .22D0, .12D0, 11*0.D0,
     & 2.0D0, 4.4D0, 6.8D0, 9.9D0, 7.9D0, 6.0D0, 3.8D0, 2.5D0, 2.D0,
     & 1.4D0, 1.D0, .6D0, .35D0, 10*0.D0, .25D0, .55D0, .75D0, 1.25D0,
     & 1.9D0, 2.D0, 1.8D0, 1.5D0, 1.25D0, 1.D0, .8D0, 10*0.D0, .4D0,
     & .85D0, 1.1D0, 1.85D0, 2.8D0, 3.D0, 2.7D0, 2.2D0, 1.85D0, 1.5D0,
     & 1.2D0, 12*0.D0, .5D0, 1.2D0, 1.7D0, 3.4D0, 5.2D0, 6.4D0, 6.1D0,
     & 5.6D0, 5.2D0, 9*0.D0, 1.D0, 3.3D0, 5.2D0, 4.45D0, 3.6D0, 2.75D0,
     & 1.9D0, 1.65D0, 1.3D0, .95D0, .6D0, .45D0, 10*0.D0, .45D0, 1.4D0,
     & 1.5D0, 1.1D0, .85D0, .5D0, .3D0, .2D0, .15D0, 15*0.D0, .6D0,
     & .8D0, .95D0, .8D0, .7D0, .6D0, .5D0, .4D0, 13*0.D0, .85D0, 1.2D0,
     & 1.4D0, 1.2D0, 1.05D0, .9D0, .7D0, .55D0, 13*0.D0, 1.D0, 1.5D0,
     & 3.5D0, 4.15D0, 3.7D0, 2.7D0, 2.3D0, 1.75D0, 16*0.D0, .5D0, 2.0D0,
     & 3.3D0, 5.4D0, 7.D0 /
**** k+  p data                                                        *
      DATA SPIKP5/ 0.D0, 20.D0, 14.D0, 12.D0, 11.5D0, 10.D0, 8.D0,
     & 7.D0, 6.D0, 5.5D0, 5.3D0, 5.D0, 4.5D0, 4.4D0, 3.8D0, 3.D0, 2.8D0,
     & 0.D0, .5D0, 1.15D0, 2.D0, 1.3D0, .8D0, .45D0, 13*0.D0, 0.9D0,
     & 2.5D0, 3.D0, 2.5D0, 2.3D0, 2.D0, 1.7D0, 1.5D0, 1.2D0, .9D0, .6D0,
     & .45D0, .21D0, .2D0, 3*0.D0, .9D0, 2.5D0, 3.D0, 2.5D0, 2.3D0,
     & 2.D0, 1.7D0, 1.5D0, 1.2D0, .9D0, .6D0, .45D0, .21D0, .2D0,
     & 4*0.D0, 1.D0, 2.1D0, 2.6D0, 2.3D0, 2.1D0, 1.8D0, 1.7D0, 1.4D0,
     & 1.2D0, 1.05D0, .9D0, .66D0, .5D0, 7*0.D0, .3D0, 2*1.D0, .9D0,
     & .7D0, .4D0, .3D0, .2D0, 11*0.D0, .1D0, 1.D0, 2.2D0, 3.5D0, 4.2D0,
     & 4.55D0, 4.85D0, 4.9D0, 10*0.D0, .2D0, .7D0, 1.6D0, 2.5D0, 2.2D0,
     & 1.71D0, 1.6D0, 6*0.D0, 1.4D0, 3.8D0, 5.D0, 4.7D0, 4.4D0, 4.D0,
     & 3.5D0, 2.85D0, 2.35D0, 2.01D0, 1.8D0, 12*0.D0, .1D0, .8D0,2.05D0,
     & 3.31D0, 3.5D0, 12*0.D0, .034D0, .2D0, .75D0, 1.04D0, 1.24D0 /
**** k+  n data                                                        *
      DATA SPIKP6/ 0.D0, 6.D0, 11.D0, 13.D0, 6.D0, 5.D0, 3.D0, 2.2D0,
     & 1.5D0, 1.2D0, 1.D0, .7D0, .6D0, .5D0, .45D0, .35D0, .3D0, 0.D0,
     & 6.D0, 11.D0, 13.D0, 6.D0, 5.D0, 3.D0, 2.2D0, 1.5D0, 1.2D0, 1.D0,
     & .7D0, .6D0, .5D0, .45D0, .35D0, .3D0, 0.D0, .5D0, 1.3D0, 2.8D0,
     & 2.3D0, 1.6D0, .9D0, 13*0.D0, 0.9D0, 2.5D0, 3.D0, 2.5D0, 2.3D0,
     & 2.D0, 1.7D0, 1.5D0,1.2D0,.9D0,.6D0,.45D0,.21D0,.2D0,3*0.D0,0.9D0,
     & 2.5D0, 3.D0, 2.5D0, 2.3D0,2.D0,1.7D0,1.5D0,1.2D0,.9D0,.6D0,.45D0,
     & .21D0, .2D0,4*0.D0,1.D0,2.1D0,2.6D0,2.3D0,2.D0,1.8D0,1.7D0,1.4D0,
     & 1.2D0,1.15D0,.9D0,.66D0,.5D0,4*0.D0,1.D0,2.1D0,2.6D0,2.3D0,2.1D0,
     & 1.8D0,1.7D0,1.4D0,1.2D0, 1.15D0, .9D0, .66D0, .5D0, 7*0.D0, .3D0,
     & 2*1.D0, .9D0, .7D0, .4D0, .35D0, .2D0, 9*0.D0, .3D0, 2*1.D0,.9D0,
     & .7D0, .4D0, .35D0, .2D0, 11*0.D0, .1D0, 1.D0, 2.4D0,3.5D0,4.25D0,
     & 4.55D0, 4.85D0, 4.9D0, 9*0.D0, .1D0, 1.D0, 2.4D0, 3.5D0, 4.25D0,
     & 4.55D0, 4.85D0, 4.9D0, 10*0.D0, .2D0, .7D0, 1.6D0, 2.5D0, 2.2D0,
     & 1.71D0, 1.6D0, 10*0.D0, .2D0, .7D0, 1.6D0, 2.5D0, 2.2D0, 1.71D0,
     & 1.6D0, 6*0.D0, 1.4D0, 3.8D0, 5.D0, 4.7D0,4.4D0,4.D0,3.5D0,2.85D0,
     & 2.35D0, 2.01D0, 1.8D0, 6*0.D0, 1.4D0,3.8D0,5.D0,4.7D0,4.4D0,4.D0,
     & 3.5D0,2.85D0,2.35D0,2.01D0,1.8D0,12*0.D0,.1D0,.8D0,2.05D0,3.31D0,
     & 3.5D0, 12*0.D0, .034D0,.2D0,.75D0,1.04D0,1.24D0 /
**** k-  p data                                                        *
      DATA SKMPEL/ 0.D0, 35.D0, 22.D0, 25.D0, 17.D0, 9.D0, 9.5D0, 8.D0,
     &     7.D0, 6.5D0, 6.1D0, 5.D0, 4.8D0, 4.6D0, 4.45D0, 4.3D0, 4.2D0,
     &    0.D0, 8.D0, 3.5D0, 8.D0, 3.D0, 1.9D0, 1.7D0, 1.D0, .9D0, .8D0,
     &    .75D0, .5D0, .42D0, .38D0, .34D0, .25D0, .2D0,
     &    0.D0, 3.D0, 3.2D0, 3.5D0, 1.5D0, 1.4D0, 1.1D0, .6D0, .5D0,
     &    .35D0, .28D0, .25D0, .18D0, .12D0, .1D0, .08D0, .04D0,
     &    0.D0, 8.5D0, 2.4D0, 1.7D0, 1.3D0, 1.3D0, 1.1D0, .5D0,
     &    .4D0, .4D0, .35D0, .3D0, .28D0, .2D0, .16D0, .13D0, .11D0,
     &    0.D0, 7.D0, 4.8D0, 1.4D0, 1.9D0, .9D0, .4D0, .2D0, .13D0,
     &    .1D0, .08D0, .06D0, .04D0, .02D0, .015D0, .01D0, .01D0,
     &    0.D0, 5.5D0, 1.D0, .8D0, .75D0, .32D0, .2D0, .1D0, .09D0,
     &    .08D0, .065D0, .05D0, .04D0, .022D0, .017D0, 2*.01D0/
      DATA SPIKP7 / 0.D0, .56D0, 1.46D0, 3.16D0, 2.01D0, 1.28D0, .74D0,
     & 14*0.D0, 1.13D0, 2.61D0, 2.91D0, 2.58D0, 2.35D0, 2.02D0,
     & 1.91D0, 1.57D0, 1.35D0, 1.29D0, 1.01D0, .74D0, .65D0, 4*0.D0,
     & 1.13D0, 2.61D0, 2.91D0, 2.58D0, 2.35D0, 2.02D0, 1.91D0, 1.57D0,
     & 1.35D0, 1.29D0, 1.01D0, .74D0, .65D0,  3*0.D0, 1.0D0, 3.03D0,
     & 3.36D0, 2.8D0, 2.58D0, 2.24D0, 1.91D0, 1.68D0, 1.35D0, 1.01D0,
     & .67D0, .5D0, .24D0, .23D0, 3*0.D0, 1.0D0, 3.03D0, 3.36D0, 2.8D0,
     & 2.58D0, 2.24D0, 1.91D0, 1.68D0, 1.35D0, 1.01D0, .67D0, .5D0,
     & .24D0, .23D0, 7*0.D0, .34D0, 1.12D0, 1.12D0, 1.01D0, .78D0,
     & .45D0, .39D0, .22D0, .07D0, 0.D0, 7*0.D0, .34D0, 1.12D0, 1.12D0,
     & 1.01D0, .78D0, .45D0, .39D0, .22D0, .07D0, 0.D0, 6*0.D0, 1.71D0,
     & 4.26D0, 5.6D0, 5.57D0, 4.93D0, 4.48D0, 3.92D0, 3.19D0, 2.63D0,
     & 2.25D0, 2.D0, 6*0.D0, 1.71D0, 4.26D0, 5.6D0, 5.57D0, 4.93D0,
     & 4.48D0, 3.92D0, 3.19D0, 2.63D0, 2.25D0, 2.D0, 10*0.D0, .22D0,
     & .8D0, .75D0, 1.D0, 1.3D0, 1.5D0, 1.3D0, 10*0.D0, .22D0, .8D0,
     & .75D0, 1.D0, 1.3D0, 1.5D0, 1.3D0, 13*0.D0, .1D0, .3D0, .7D0,1.D0,
     & 13*0.D0, .1D0, .3D0, .7D0, 1.D0, 9*0.D0, .11D0, 1.72D0, 2.69D0,
     & 3.92D0, 4.76D0, 5.10D0, 5.44D0, 5.3D0, 9*0.D0, .11D0, 1.72D0,
     & 2.69D0, 3.92D0, 4.76D0, 5.1D0, 5.44D0, 5.3D0, 5*0.D0,9.2D0,4.7D0,
     & 1.9D0, 10*0.D0, 2.5D0, 15.D0, 21.5D0, 15.3D0, 3.D0, 1.5D0,
     & 10*0.D0/
***** k- n data                                                        *
      DATA SKMNEL/0.D0, 4.D0, 9.5D0, 20.D0, 13.D0, 9.5D0, 6.D0, 4.4D0,
     &        3.D0, 2.4D0, 2.D0, 1.4D0, 1.2D0, 1.D0, .9D0, .7D0, .6D0,
     &        0.D0, 4.5D0, 6.D0, 5.D0, 2.5D0, 2.D0, 1.7D0, 2.1D0,
     &        1.9D0, .9D0, .5D0, .3D0, .24D0, .2D0, .18D0, .1D0, .09D0,
     &        0.D0, 1.8D0, 2.D0, 1.1D0, .9D0, .5D0, .5D0, .4D0, .4D0,
     &        .2D0, .1D0, .06D0, .05D0, .04D0, .03D0, .02D0, .02D0,
     &        0.D0, 1.5D0, 2.D0, .9D0, 1.1D0, .4D0, .6D0, .7D0, .65D0,
     &       .3D0, .17D0, .1D0, .08D0, .07D0, .06D0, .04D0, .03D0/
      DATA SPIKP8/0.D0, .56D0, 1.29D0, 2.26D0, 1.01D0, .64D0, .37D0,
     &  14*0.D0, 1.13D0, 2.61D0, 2.91D0, 2.58D0, 2.35D0, 2.02D0,
     &  1.91D0, 1.57D0, 1.35D0, 1.29D0, 1.01D0, .74D0, .65D0,
     &  3*0.D0, 1.D0, 3.03D0, 3.36D0, 2.8D0, 2.58D0, 2.24D0,
     &  1.91D0, 1.68D0, 1.35D0, 1.01D0, .67D0, .5D0, .24D0, .23D0,
     &  3*0.D0, 1.D0, 3.03D0, 3.36D0, 2.8D0, 2.58D0, 2.24D0,
     &  1.91D0, 1.68D0, 1.35D0, 1.01D0, .67D0, .5D0, .24D0, .23D0,
     &  7*0.D0, .34D0, 1.12D0, 1.12D0, 1.01D0, .78D0, .45D0,
     &  .39D0, .22D0, .07D0, 0.D0,
     &  6*0.D0, 1.71D0, 4.26D0, 5.6D0, 5.57D0, 4.93D0,
     &  4.48D0, 3.92D0, 3.19D0, 2.63D0, 2.25D0, 2.D0,
     &  10*0.D0, .22D0, .8D0, .75D0, 1.D0, 1.3D0, 1.5D0, 1.3D0,
     &  13*0.D0, .1D0, .3D0, .7D0, 1.D0,
     &  13*0.D0, .1D0, .3D0, .7D0, 1.D0,
     &  9*0.D0, .11D0, 1.72D0, 2.69D0, 3.92D0, 4.76D0,
     &  5.10D0, 5.44D0, 5.3D0,
     &  4*0.D0, 0.00D0, 9.2D0, 4.7D0, 1.9D0, 9*0.D0/
*****  p p data                                                        *
      DATA SPIKP9/ 0.D0, 24.D0, 25.D0, 27.D0, 23.D0, 21.D0, 20.D0,
     &              19.D0, 17.D0, 15.5D0, 14.D0, 13.5D0, 13.D0,
     &              0.D0, 3.6D0, 1.7D0, 10*0.D0,
     &              .0D0, 0.D0, 8.7D0, 17.7D0, 18.8D0, 15.9D0,
     &              11.7D0, 8.D0, 6.D0, 5.3D0, 4.5D0, 3.9D0, 3.5D0,
     &              .0D0, .0D0, 2.8D0, 5.8D0, 6.2D0, 5.1D0, 3.8D0,
     &              2.7D0, 2.1D0, 1.8D0, 1.5D0, 1.3D0, 1.1D0,
     &              5*0.D0, 4.6D0, 10.2D0, 15.1D0,
     &              16.9D0, 16.5D0, 11.D0, 5.5D0, 3.5D0,
     &              10*0.D0, 4.3D0, 7.6D0, 9.D0,
     &              10*0.D0, 1.7D0, 2.6D0, 3.D0,
     &              6*0.D0, .3D0, .6D0, 1.D0, 1.6D0, 1.3D0, .8D0, .6D0,
     &              6*0.D0, .7D0, 1.2D0, 1.8D0, 2.5D0, 1.8D0, 1.3D0,
     &              1.2D0, 10*0.D0, .6D0, 1.4D0, 1.7D0,
     &              10*0.D0, 1.9D0, 4.1D0, 5.2D0/
*****  p n data                                                        *
      DATA SPIKP0/ 0.D0, 24.D0, 25.D0, 27.D0, 23.D0, 21.D0, 20.D0,
     &              19.D0, 17.D0, 15.5D0, 14.D0, 13.5D0, 13.D0,
     &              0.D0, 1.8D0, .2D0,  12*0.D0,
     &              3.2D0, 6.05D0, 9.9D0, 5.1D0,
     &              3.8D0, 2.7D0, 1.9D0, 1.5D0, 1.4D0, 1.3D0, 1.1D0,
     &              2*.0D0, 3.2D0, 6.05D0, 9.9D0, 5.1D0,
     &              3.8D0, 2.7D0, 1.9D0, 1.5D0, 1.4D0, 1.3D0, 1.1D0,
     &              5*0.D0, 4.6D0, 10.2D0, 15.1D0,
     &              16.4D0, 15.2D0, 11.D0, 5.4D0, 3.5D0,
     &              5*0.D0, 4.6D0, 10.2D0, 15.1D0,
     &              16.4D0, 15.2D0, 11.D0, 5.4D0, 3.5D0,
     &              10*0.D0, .7D0, 5.1D0, 8.D0,
     &              10*0.D0, .7D0, 5.1D0, 8.D0,
     &              10*.0D0, .3D0, 2.8D0, 4.7D0,
     &              10*.0D0, .3D0, 2.8D0, 4.7D0,
     &              7*0.D0, 1.2D0, 2.5D0, 3.5D0, 6.D0, 5.3D0, 2.9D0,
     &              7*0.D0, 1.7D0, 3.6D0, 5.4D0, 9.D0, 7.6D0, 4.2D0,
     &              5*0.D0, 7.7D0, 6.1D0, 2.9D0, 5*0.D0/
*   nn - data                                                          *
*                                                                      *
      DATA SPKP V/ 0.D0, 24.D0, 25.D0, 27.D0, 23.D0, 21.D0, 20.D0,
     &              19.D0, 17.D0, 15.5D0, 14.D0, 13.5D0, 13.D0,
     &              0.D0, 3.6D0, 1.7D0, 12*0.D0,
     &              8.7D0, 17.7D0, 18.8D0, 15.9D0,
     &              11.7D0, 8.D0, 6.D0, 5.3D0, 4.5D0, 3.9D0, 3.5D0,
     &              .0D0, .0D0, 2.8D0, 5.8D0, 6.2D0, 5.1D0, 3.8D0,
     &              2.7D0, 2.1D0, 1.8D0, 1.5D0, 1.3D0, 1.1D0,
     &              5*0.D0, 4.6D0, 10.2D0, 15.1D0, 16.9D0, 16.5D0,
     &              11.D0, 5.5D0, 3.5D0,
     &              10*0.D0, 4.3D0, 7.6D0, 9.D0,
     &              10*0.D0, 1.7D0, 2.6D0, 3.D0,
     &              6*0.D0, .3D0, .6D0, 1.D0, 1.6D0, 1.3D0, .8D0, .6D0,
     &              6*0.D0, .7D0, 1.2D0, 1.8D0, 2.5D0, 1.8D0, 1.3D0,
     &              1.2D0, 10*0.D0, .6D0, 1.4D0, 1.7D0,
     &              10*0.D0, 1.9D0, 4.1D0, 5.2D0/
****************   ap - p - data                                       *
      DATA SAPPEL/ 0.D0,  176.D0, 160.D0, 105.D0, 75.D0, 68.D0, 65.D0,
     &  50.D0,  50.D0, 43.D0, 42.D0, 40.5D0, 35.D0, 30.D0, 28.D0,
     &  25.D0,  22.D0, 21.D0, 20.D0, 18.D0, 17.D0,  11*0.D0,
     &  .05D0,  .15D0, .18D0, .2D0, .2D0, .3D0, .4D0, .6D0, .7D0, .85D0,
     &  0.D0,  1.D0, .9D0, .46D0, .3D0, .23D0, .18D0, .16D0, .14D0,
     &  .1D0,  .08D0, .05D0, .02D0, .015D0, 4*.011D0, 3*.005D0,
     &  0.D0,  55.D0, 50.D0, 25.D0, 15.D0, 15.D0, 14.D0, 12.D0,
     &  10.D0,  7.D0, 6.D0, 4.D0, 3.3D0, 2.8D0, 2.4D0, 2.D0, 1.8D0,
     &  1.55D0,  1.3D0, .95D0, .75D0,
     &  0.D0,  3.3D0, 3.D0, 1.5D0, 1.D0, .7D0, .4D0, .35D0, .4D0,
     &  .25D0,  .18D0, .08D0, .04D0, .03D0, .023D0, .016D0, .014D0,
     & .01D0,  .008D0, .006D0, .005D0/
      DATA SPIKPE/0.D0, 215.D0, 193.D0, 170.D0, 148.D0, 113.D0, 97.D0,
     & 84.D0, 78.D0, 68.D0, 64.D0, 61.D0, 46.D0, 36.D0, 31.3D0, 28.5D0,
     & 25.7D0, 22.6D0, 21.4D0, 20.7D0, 19.9D0,
     & 9*0.D0, 2.D0, 2.5D0, .2D0, 19*0.D0, .3D0, 1.4D0, 2.2D0, 1.2D0,
     & 1.1D0, 1.D0, .8D0, .6D0, .5D0, .4D0, .3D0, 10*0.D0, .3D0, 1.4D0,
     & 2.2D0, 1.2D0, 1.1D0, 1.D0, .8D0, .6D0, .5D0, .4D0, .3D0, 10*0.D0,
     & .3D0, 1.4D0, 2.2D0, 1.2D0, 1.1D0, 1.D0, .8D0, .6D0, .5D0, .4D0,
     & .3D0, 10*0.D0, .3D0, 1.4D0, 2.2D0, 1.2D0, 1.1D0, 1.D0, .8D0,
     & .6D0, .5D0, .4D0, .3D0, 9*0.D0, .6D0, 2.5D0, 5.D0, 5.2D0, 5.1D0,
     & 5.4D0, 5.8D0, 2.8D0, 2.1D0, 1.8D0, 1.6D0, 1.2D0, 13*0.D0, 1.3D0,
     & 1.5D0, 2.D0, 2.5D0, 2.5D0, 2.3D0, 1.8D0, 1.4D0, 13*0.D0, 1.3D0,
     & 1.5D0, 2.D0, 2.5D0, 2.5D0, 2.3D0, 1.8D0, 1.4D0, 13*0.D0, 1.3D0,
     & 1.5D0, 2.D0, 2.5D0, 2.5D0, 2.3D0, 1.8D0, 1.4D0, 13*0.D0, 1.3D0,
     & 1.5D0, 2.D0, 2.5D0, 2.5D0, 2.3D0, 1.8D0, 1.4D0, 14*0.D0, .2D0,
     & .5D0, 1.1D0, 1.6D0, 1.4D0, 1.1D0, .9D0, 14*0.D0, .2D0, .5D0,
     & 1.1D0, 1.6D0, 1.4D0, 1.1D0, .9D0, 14*0.D0, .2D0, .5D0, 1.1D0,
     & 1.6D0, 1.4D0, 1.1D0, .9D0, 14*0.D0, .2D0, .5D0, 1.1D0, 1.6D0,
     & 1.4D0, 1.1D0, .9D0, 17*0.D0, .3D0, 1.6D0, 2.6D0, 3.6D0, 17*0.D0,
     & .3D0, 1.6D0, 2.6D0, 3.6D0, 17*0.D0, .3D0, 1.6D0, 2.6D0,
     & 3.6D0, 17*0.D0, .3D0, 1.6D0, 2.6D0, 3.6D0 /
****************   ap - n - data                                       *
      DATA SAPNEL/
     & 0.D0,  176.D0, 160.D0, 105.D0, 75.D0,  68.D0, 65.D0,
     & 50.D0, 50.D0,  43.D0,  42.D0,  40.5D0, 35.D0, 30.D0,  28.D0,
     & 25.D0, 22.D0,  21.D0,  20.D0,  18.D0,  17.D0, 11*0.D0,
     & .05D0, .15D0, .18D0,  .2D0,    .2D0,  .3D0,  .4D0,   .6D0,  .7D0,
     & .85D0,  0.D0,  1.D0,  .9D0,    .46D0, .3D0,  .23D0, .18D0, .16D0,
     & .14D0,  .1D0, .08D0, .05D0,    .02D0, .015D0, 4*.011D0, 3*.005D0,
     & 0.D0,  3.3D0,  3.D0, 1.5D0,     1.D0, .7D0,  .4D0,  .35D0, .4D0,
     & .25D0, .18D0, .08D0, .04D0,    .03D0, .023D0, .016D0, .014D0,
     & .01D0, .008D0, .006D0, .005D0 /
       DATA SPIKPZ/ 0.D0, 215.D0, 193.D0, 170.D0, 148.D0, 113.D0, 97.D0,
     &  84.D0, 78.D0, 68.D0, 64.D0, 61.D0, 46.D0, 36.D0, 31.3D0, 28.5D0,
     & 25.7D0, 22.6D0, 21.4D0, 20.7D0, 19.9D0, 9*0.D0, 2.4D0, .2D0,
     & 20*0.D0, 1.8D0, 2.8D0, 3.6D0, 2.3D0, 1.8D0, 1.5D0, 1.3D0, 1.D0,
     & .7D0, .5D0, .3D0, 10*0.D0, 1.8D0, 2.8D0, 3.6D0, 2.3D0, 1.8D0,
     & 1.5D0, 1.3D0, 1.D0, .7D0, .5D0, .3D0, 10*0.D0, 1.8D0, 2.8D0,
     & 3.6D0, 2.3D0, 1.8D0, 1.5D0, 1.3D0, 1.D0, .7D0, .5D0, .3D0,
     & 10*0.D0, 1.8D0, 2.8D0, 3.6D0, 2.3D0, 1.8D0, 1.5D0, 1.3D0, 1.D0,
     & .7D0, .5D0, .3D0, 13*0.D0, 5.2D0, 8.7D0, 11.4D0, 14.D0, 11.9D0,
     & 7.6D0, 6.D0, 5.D0, 13*0.D0, 5.2D0, 8.7D0, 11.4D0, 14.D0, 11.9D0,
     & 7.6D0, 6.D0, 5.D0, 18*0.D0, 1.D0, 4.9D0, 8.5D0, 18*0.D0, 1.D0,
     & 4.9D0, 8.5D0,  15*0.D0, 1.9D0, 2.3D0, 4.D0, 6.5D0, 5.2D0, 3.4D0,
     & 15*0.D0, 1.9D0, 2.3D0, 4.D0, 6.5D0, 5.2D0, 3.4D0, 15*0.D0, 1.9D0,
     & 2.3D0, 4.D0, 6.5D0, 5.2D0, 3.4D0 /
*                                                                      *
*                                                                      *
****************   an - p - data                                       *
*                                                                      *
      DATA SANPEL/
     & 0.D0,  176.D0, 160.D0, 105.D0, 75.D0, 68.D0, 65.D0, 50.D0,
     & 50.D0, 43.D0,  42.D0,  40.5D0, 35.D0, 30.D0, 28.D0,
     & 25.D0, 22.D0,  21.D0,  20.D0,  18.D0, 17.D0, 11*0.D0, .05D0,
     & .15D0, .18D0,   .2D0,   .2D0,   .3D0,  .4D0, .6D0,   .7D0, .85D0,
     & 0.D0,   1.D0,   .9D0,  .46D0,  .3D0,  .23D0, .18D0, .16D0, .14D0,
     & .1D0,  .08D0,  .05D0,  .02D0, .015D0, 4*.011D0, 3*.005D0,
     & 0.D0,  3.3D0,  3.D0, 1.5D0, 1.D0, .7D0, .4D0, .35D0, .4D0, .25D0,
     & .18D0, .08D0, .04D0, .03D0, .023D0, .016D0, .014D0,
     & .01D0, .008D0, .006D0, .005D0 /
      DATA SPIKPF/ 0.D0, 215.D0, 193.D0, 170.D0, 148.D0, 113.D0, 97.D0,
     & 84.D0, 78.D0, 68.D0, 64.D0, 61.D0, 46.D0, 36.D0, 31.3D0, 28.5D0,
     & 25.7D0, 22.6D0, 21.4D0, 20.7D0, 19.9D0, 9*0.D0, 2.4D0, .2D0,
     & 20*0.D0, 1.8D0, 2.8D0, 3.6D0, 2.3D0, 1.8D0, 1.5D0, 1.3D0, 1.D0,
     & .7D0, .5D0, .3D0, 10*0.D0, 1.8D0, 2.8D0, 3.6D0, 2.3D0, 1.8D0,
     & 1.5D0, 1.3D0, 1.D0, .7D0, .5D0, .3D0, 10*0.D0, 1.8D0, 2.8D0,
     & 3.6D0, 2.3D0, 1.8D0, 1.5D0, 1.3D0, 1.D0, .7D0, .5D0, .3D0,
     & 10*0.D0, 1.8D0, 2.8D0, 3.6D0, 2.3D0, 1.8D0, 1.5D0, 1.3D0, 1.D0,
     & .7D0, .5D0, .3D0, 13*0.D0, 5.2D0, 8.7D0, 11.4D0, 14.D0, 11.9D0,
     & 7.6D0, 6.D0, 5.D0, 13*0.D0, 5.2D0, 8.7D0, 11.4D0, 14.D0, 11.9D0,
     & 7.6D0, 6.D0, 5.D0, 18*0.D0, 1.D0, 4.9D0, 8.5D0, 18*0.D0, 1.D0,
     & 4.9D0, 8.5D0, 15*0.D0, 1.9D0, 2.3D0, 4.D0, 6.5D0, 5.2D0, 3.4D0,
     & 15*0.D0, 1.9D0, 2.3D0, 4.D0, 6.5D0, 5.2D0, 3.4D0, 15*0.D0, 1.9D0,
     & 2.3D0, 4.D0, 6.5D0, 5.2D0, 3.4D0 /
****  ko - n - data                                                    *
      DATA SPKP15/0.D0, 20.D0, 14.D0, 12.D0, 11.5D0, 10.D0, 8.D0, 7.D0,
     &      6.D0, 5.5D0, 5.3D0, 5.D0, 4.5D0, 4.4D0, 3.8D0, 3.D0, 2.8D0,
     &      0.D0, .5D0, 1.15D0, 2.D0, 1.3D0, .8D0, .45D0, 10*0.D0,
     &    3*0.D0, 0.9D0, 2.5D0, 3.D0, 2.5D0, 2.3D0, 2.D0, 1.7D0,
     &     1.5D0, 1.2D0, .9D0, .6D0, .45D0, .21D0, .2D0,
     &    3*0.D0, 0.9D0, 2.5D0, 3.D0, 2.5D0, 2.3D0, 2.D0, 1.7D0,
     &     1.5D0, 1.2D0, .9D0, .6D0, .45D0, .21D0, .2D0,
     &    4*0.D0, 1.D0, 2.1D0, 2.6D0, 2.3D0, 2.1D0, 1.8D0, 1.7D0,
     &     1.4D0, 1.2D0, 1.05D0, .9D0, .66D0,  .5D0,
     &    7*0.D0, .3D0, 1.D0, 1.D0, .9D0, .7D0, .4D0, .30D0, .2D0,
     &   11*0.D0, .1D0, 1.D0, 2.2D0, 3.5D0, 4.20D0, 4.55D0,
     &    4.85D0, 4.9D0,
     &   10*0.D0, .2D0, .7D0, 1.6D0, 2.5D0, 2.2D0, 1.71D0, 1.6D0,
     &    6*0.D0, 1.4D0, 3.8D0, 5.D0, 4.7D0, 4.4D0, 4.D0, 3.5D0,
     &    2.85D0, 2.35D0, 2.01D0, 1.8D0,
     &   12*0.D0, .1D0, .8D0, 2.05D0, 3.31D0, 3.5D0,
     &   12*0.D0, .034D0, .20D0, .75D0, 1.04D0, 1.24D0  /
**** ako - p - data                                                    *
      DATA SPKP16/ 0.D0, 4.D0, 9.5D0, 20.D0, 13.D0, 9.5D0, 6.D0, 4.4D0,
     & 3.D0, 2.4D0, 2.D0, 1.4D0, 1.2D0, 1.D0, .9D0, .7D0, .6D0, 0.D0,
     & 4.5D0, 6.D0, 5.D0, 2.5D0, 2.D0, 1.7D0, 2.1D0, 1.9D0, .9D0, .5D0,
     & .3D0, .24D0, .2D0, .18D0, .1D0, .09D0, 0.D0, 1.8D0, 2.D0, 1.1D0,
     & .9D0, .5D0, .5D0, .4D0, .4D0, .2D0, .1D0, .06D0, .05D0, .04D0,
     & .03D0, .02D0, .02D0, 0.D0, 1.5D0, 2.D0, .9D0, 1.1D0, .4D0, .6D0,
     & .7D0, .65D0, .3D0, .17D0, .1D0, .08D0, .07D0, .06D0, .04D0,
     & .03D0, 0.D0, .56D0, 1.29D0, 2.26D0, 1.01D0, .64D0, .37D0,
     & 14*0.D0, 1.13D0, 2.61D0, 2.91D0, 2.58D0, 2.35D0, 2.02D0, 1.91D0,
     & 1.57D0, 1.35D0, 1.29D0, 1.01D0, .74D0, .65D0, 3*0.D0, 1.0D0,
     & 3.03D0, 3.36D0, 2.8D0, 2.58D0, 2.24D0, 1.91D0, 1.68D0, 1.35D0,
     & 1.01D0, .67D0, .5D0, .24D0, .23D0, 3*0.D0, 1.0D0, 3.03D0, 3.36D0,
     & 2.8D0, 2.58D0, 2.24D0, 1.91D0, 1.68D0, 1.35D0, 1.01D0, .67D0,
     & .5D0, .24D0, .23D0, 7*0.D0, .34D0, 1.12D0, 1.12D0, 1.01D0, .78D0,
     & .45D0, .39D0, .22D0, .07D0, 7*0.D0, 1.71D0, 4.26D0, 5.6D0,5.57D0,
     & 4.93D0, 4.48D0, 3.92D0, 3.19D0, 2.63D0, 2.25D0, 2.D0, 10*0.D0,
     & .22D0, .8D0, .75D0, 1.D0, 1.3D0, 1.5D0, 1.3D0, 13*0.D0, .1D0,
     & .3D0, .7D0, 1.D0, 13*0.D0, .1D0, .3D0, .7D0, 1.D0, 9*0.D0, .11D0,
     & 1.72D0, 2.69D0, 3.92D0, 4.76D0, 5.10D0, 5.44D0, 5.3D0, 5*0.D0,
     & 9.2D0, 4.7D0, 1.9D0, 9*0.D0, .0D0,2.5D0,15.D0,
     & 21.5D0, 15.3D0, 3.D0, 1.5D0, 10*0.D0 /
      DATA NURELN/9, 12, 5*0, 10, 14, 3*0, 1, 3, 5, 7, 6*0, 2, 6, 16,
     & 5*0, 10, 13, 5*0, 11, 12, 3*0, 2, 4, 6, 8, 6*0, 3, 15, 7, 5*0 /
*=                                               end*block.blkdt3      *
      END

C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
      BLOCK DATA REACCH
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C*** REACTION CHANNEL CROSS SECTION DATA
C     INTEGER * 2
C    *                            NRKPI,NRKKC,NRKK0,NRKP,NRKN
C    *          ,NURE
      COMMON /DREACC/
     *UMOPI(  92),UMOKC(  68),UMOP( 39),UMON( 63),UMOK0( 34),
     *PLAPI(  92),PLAKC(  68),PLAP( 39),PLAN( 63),PLAK0( 34),
     *SIIN(296),
     *SPIKP1( 315),SPIKP U(278),SPIKP V(372),
     *SPIKP W(278),SPIKP X(372),SPIKP 4(315),
     *SPIKP 5(187),SPIKP 6(306),
     *S KMPEL(102),SPIKP 7(289),S KMNEL( 68),SPIKP 8(187),
     *SPIKP 9(143),SPIKP 0(169),SPKP V(143),
     *S APPEL(105),SPIKP E(399),S APNEL( 84),SPIKP Z(273),
     *S ANPEL( 84),SPIKP F(273),
     *SPKP15(187),SPKP16(255),
     *NRKPI( 164),NRKKC( 134),NRKP( 70),NRKN( 116),NRKK0( 52),
     *NURE(60)
C111111111111111111111111111111111111111111111111111111111111111111
*
**** pi- p data                                                        *
**** pi+ n data                                                        *
      DATA PLAPI / 0.D0, .3D0, .5D0, .6D0, .7D0, .8D0, .9D0, .95D0,1.D0,
     & 1.15D0, 1.3D0, 1.5D0, 1.6D0, 1.8D0, 2.D0, 2.3D0, 2.5D0, 2.8D0,
     & 3.D0, 3.5D0, 4.D0, 0.D0, .285D0, .4D0, .45D0, .5D0, .6D0, .7D0,
     & .75D0, .8D0, .85D0, .9D0, 1.D0, 1.15D0, 1.3D0, 1.5D0, 1.6D0,
     & 1.8D0, 2.D0, 2.3D0, 2.5D0, 2.8D0, 3.D0, 3.5D0, 4.D0, 4.5D0, 0.D0,
     & .285D0, .4D0, .45D0, .5D0, .6D0, .7D0, .75D0, .8D0, .85D0, .9D0,
     & 1.D0, 1.15D0, 1.3D0, 1.5D0, 1.6D0, 1.8D0, 2.D0, 2.3D0, 2.5D0,
     & 2.8D0, 3.D0, 3.5D0, 4.D0, 4.5D0, 0.D0, .3D0, .5D0, .6D0, .7D0,
     & .8D0, .9D0, .95D0, 1.D0, 1.15D0, 1.3D0, 1.5D0, 1.6D0, 1.8D0,
     & 2.D0, 2.3D0, 2.5D0, 2.8D0, 3.D0, 3.5D0, 4.D0 /
      DATA PLAKC /
     &   0.D0,  .58D0,   .8D0, 1.01D0, 1.23D0, 1.45D0, 1.68D0, 1.94D0,
     & 2.18D0, 2.42D0, 2.68D0, 2.96D0, 3.24D0,
     & 3.51D0, 3.84D0, 4.16D0, 4.49D0,
     &   0.D0,  .58D0,   .8D0, 1.01D0, 1.23D0, 1.45D0, 1.68D0, 1.94D0,
     & 2.18D0, 2.42D0, 2.68D0, 2.96D0, 3.24D0,
     & 3.51D0, 3.84D0, 4.16D0, 4.49D0,
     &   0.D0,  .58D0,   .8D0, 1.01D0, 1.23D0, 1.45D0, 1.68D0, 1.94D0,
     & 2.18D0, 2.42D0, 2.68D0, 2.96D0, 3.24D0,
     & 3.51D0, 3.84D0, 4.16D0, 4.49D0,
     &   0.D0,  .58D0,   .8D0, 1.01D0, 1.23D0, 1.45D0, 1.68D0, 1.94D0,
     & 2.18D0, 2.42D0, 2.68D0, 2.96D0, 3.24D0,
     & 3.51D0, 3.84D0, 4.16D0, 4.49D0/
      DATA PLAK0 /
     &   0.D0,  .58D0,   .8D0, 1.01D0, 1.23D0, 1.45D0, 1.68D0, 1.94D0,
     & 2.18D0, 2.42D0, 2.68D0, 2.96D0, 3.24D0,
     & 3.51D0, 3.84D0, 4.16D0, 4.49D0,
     &   0.D0,  .58D0,   .8D0, 1.01D0, 1.23D0, 1.45D0, 1.68D0, 1.94D0,
     & 2.18D0, 2.42D0, 2.68D0, 2.96D0, 3.24D0,
     & 3.51D0, 3.84D0, 4.16D0, 4.49D0/
*                 pp   pn   np   nn                                    *
      DATA PLAP /
     &   0.D0, 1.06D0, 1.34D0, 1.63D0, 1.92D0, 2.2D0, 2.5D0,2.8D0,3.1D0,
     & 3.43D0, 3.75D0, 4.07D0, 4.43D0,
     &   0.D0, 1.06D0, 1.34D0, 1.63D0, 1.92D0, 2.2D0, 2.5D0,2.8D0,3.1D0,
     & 3.43D0, 3.75D0, 4.07D0, 4.43D0,
     &   0.D0, 1.06D0, 1.34D0, 1.63D0, 1.92D0, 2.2D0, 2.5D0,2.8D0,3.1D0,
     & 3.43D0, 3.75D0, 4.07D0, 4.43D0 /
*    app   apn   anp   ann                                             *
      DATA PLAN /
     &  0.D0,   1.D-3,   .1D0,   .2D0,   .3D0,  .4D0,  .5D0, .6D0,
     & .74D0,  1.06D0, 1.34D0, 1.63D0, 1.92D0, 2.2D0, 2.5D0,2.8D0,3.1D0,
     & 3.43D0, 3.75D0, 4.07D0, 4.43D0,
     &  0.D0,   1.D-3,   .1D0,   .2D0,   .3D0,  .4D0,  .5D0, .6D0,
     & .74D0,  1.06D0, 1.34D0, 1.63D0, 1.92D0, 2.2D0, 2.5D0,2.8D0,3.1D0,
     & 3.43D0, 3.75D0, 4.07D0, 4.43D0,
     &  0.D0,   1.D-3,   .1D0,   .2D0,   .3D0,  .4D0,  .5D0, .6D0,
     & .74D0,  1.06D0, 1.34D0, 1.63D0, 1.92D0, 2.2D0, 2.5D0,2.8D0,3.1D0,
     & 3.43D0, 3.75D0, 4.07D0, 4.43D0  /
      DATA SIIN / 296*0.D0 /
      DATA UMOPI/ 1.08D0,1.233D0,1.302D0,1.369D0,1.496D0,
     & 1.557D0,1.615D0,1.6435D0,
     & 1.672D0,1.753D0,1.831D0,1.930D0,1.978D0,2.071D0,2.159D0,
     & 2.286D0,2.366D0,2.482D0,2.56D0,
     & 2.735D0,2.90D0,
     &             1.08D0,1.222D0,1.302D0,1.3365D0,1.369D0,1.434D0,
     & 1.496D0,1.527D0,1.557D0,
     & 1.586D0,1.615D0,1.672D0,1.753D0,1.831D0,1.930D0,1.978D0,
     & 2.071D0,2.159D0,2.286D0,2.366D0,
     & 2.482D0,2.560D0,2.735D0,2.90D0,3.06D0,
     &             1.08D0,1.222D0,1.302D0,1.3365D0,1.369D0,1.434D0,
     & 1.496D0,1.527D0,1.557D0,
     & 1.586D0,1.615D0,1.672D0,1.753D0,1.831D0,1.930D0,1.978D0,
     & 2.071D0,2.159D0,2.286D0,2.366D0,
     & 2.482D0,2.560D0,2.735D0,2.90D0,3.06D0,
     &                   1.08D0,1.233D0,1.302D0,1.369D0,1.496D0,
     & 1.557D0,1.615D0,1.6435D0,
     & 1.672D0,1.753D0,1.831D0,1.930D0,1.978D0,2.071D0,2.159D0,
     & 2.286D0,2.366D0,2.482D0,2.56D0,
     &  2.735D0, 2.90D0/
      DATA UMOKC/ 1.44D0,
     &  1.598D0,1.7D0,1.8D0,1.9D0,2.0D0,2.1D0,2.2D0,2.3D0,2.4D0,2.5D0,
     & 2.6D0,2.7D0,2.8D0,2.9D0,3.0D0,
     & 3.1D0,1.44D0,
     &  1.598D0,1.7D0,1.8D0,1.9D0,2.0D0,2.1D0,2.2D0,2.3D0,2.4D0,2.5D0,
     & 2.6D0,2.7D0,2.8D0,2.9D0,3.0D0,
     & 3.1D0,1.44D0,
     &  1.598D0,1.7D0,1.8D0,1.9D0,2.0D0,2.1D0,2.2D0,2.3D0,2.4D0,2.5D0,
     & 2.6D0,2.7D0,2.8D0,2.9D0,3.0D0,
     & 3.1D0,1.44D0,
     &  1.598D0,1.7D0,1.8D0,1.9D0,2.0D0,2.1D0,2.2D0,2.3D0,2.4D0,2.5D0,
     & 2.6D0,2.7D0,2.8D0,2.9D0,3.0D0,
     &  3.1D0/
      DATA UMOK0/ 1.44D0,
     &  1.598D0,1.7D0,1.8D0,1.9D0,2.0D0,2.1D0,2.2D0,2.3D0,2.4D0,2.5D0,
     & 2.6D0,2.7D0,2.8D0,2.9D0,3.0D0,
     & 3.1D0,1.44D0,
     &  1.598D0,1.7D0,1.8D0,1.9D0,2.0D0,2.1D0,2.2D0,2.3D0,2.4D0,2.5D0,
     & 2.6D0,2.7D0,2.8D0,2.9D0,3.0D0,
     &  3.1D0/
*                 pp   pn   np   nn                                    *
      DATA UMOP/
     & 1.88D0,2.102D0,2.2D0,2.3D0,2.4D0,2.5D0,2.6D0,2.7D0,2.8D0,2.9D0,
     & 3.D0,3.1D0,3.2D0,
     & 1.88D0,2.102D0,2.2D0,2.3D0,2.4D0,2.5D0,2.6D0,2.7D0,2.8D0,2.9D0,
     & 3.D0,3.1D0,3.2D0,
     & 1.88D0,2.102D0,2.2D0,2.3D0,2.4D0,2.5D0,2.6D0,2.7D0,2.8D0,2.9D0,
     & 3.D0,3.1D0,3.2D0/
*    app   apn   anp   ann                                             *
      DATA UMON /
     & 1.877D0,1.87701D0,1.879D0,1.887D0,1.9D0,1.917D0,1.938D0,1.962D0,
     & 2.D0,2.102D0,2.2D0,2.3D0,2.4D0,2.5D0,2.6D0,2.7D0,2.8D0,2.9D0,
     & 3.D0,3.1D0,3.2D0,
     & 1.877D0,1.87701D0,1.879D0,1.887D0,1.9D0,1.917D0,1.938D0,1.962D0,
     & 2.D0,2.102D0,2.2D0,2.3D0,2.4D0,2.5D0,2.6D0,2.7D0,2.8D0,2.9D0,
     & 3.D0,3.1D0,3.2D0,
     & 1.877D0,1.87701D0,1.879D0,1.887D0,1.9D0,1.917D0,1.938D0,1.962D0,
     & 2.D0,2.102D0,2.2D0,2.3D0,2.4D0,2.5D0,2.6D0,2.7D0,2.8D0,2.9D0,
     &  3.D0,3.1D0,3.2D0/

C111111111111111111111111111111111111111111111111111111111111111111
C111111111111111111111111111111111111111111111111111111111111111111
C*** REACTION CAHNNEL STATE PARTICLES
      DATA NRK PI/
     *13,1,15,21,81,0,
     *13,54,23,53,13,63,13,58,23,57,13,65,1,32,53,31,54,32,53,33,53,35,
     *63,32,
     *13,8,23,1,17,15,21,24,22,15,82,0,
     *61,0,13,55,23,54,14,53,13,64,
     *23,63,13,59,23,58,14,57,13,66,23,65,1,31,8,32,1,33,1,35,54,31,55,
     *32,54,33,53,34,54,35,
     *14,1,23,8,17,24,20,15,22,24,83,0,
     *62,0,14,54,23,55,13,56,14,63,
     *23,64,14,58,23,59,13,60,14,65,23,66,8,31,1,34,8,33,8,35,55,31,54,
     *34,55,33,56,32,55,35,
     *14,8,24,20,84,0,
     *14,55,23,56,14,64,14,59,23,60,14,66,8,34,56,31,55,34,56,33,56,35,
     *64,34
     F/
      DATA NRK KC/
     *15,1,89,0,
     *24,53,15,54,1,36,1,40,1,44,36,63,15,63,45,53,44,54,
     *15,8,24,1,91,0,
     *24,54,15,55,8,36,1,37,8,40,1,41,8,44,1,45,36,64,37,63,15,64,24,63,
     *45,54,44,55,93,0,
     *16,1,25,8,  17,23,21,14,  20,13,22,23,  90,0,
     *38,1,39,8,16,54,25,55,1,42,8,43,16,63,25,64,39,64,38,63,46,54,
     *47,55,8,47,1,46,52,0,51,0,
     *16,8,17,14,20,23,22,14,92,0,
     *8,38,16,55,25,56,8,42,16,64,38,64,46,55,47,56,8,46,94,0
     */
C
C   K0 P   K0 N   AK0 P   AK/ N
C
      DATA NRK K0/
     *24,8,
     *106,0,15,56,24,55,37,8,41,8,45,8,37,64,24,64,44,56,45,55,
     *25,1,17,13,  22,13,21,23,
     *107,0,39,1,25,54,16,53,43,1,25,63,39,63,47,54,46,53,47,1,103,0/
C   PP  PN   NP   NN
      DATA NRK P/1,1,85,0,
     F8,53,1,54,1,63,8,57,1,58,54,54,53,55,63,54,64,53,
     *1,8,86,0,
     F8,54,1,55,8,63,1,64,8,58,1,59,64,54,63,55,54,55,53,56,77,0,
     *8,8,
     *95,0,8,55,1,56,8,64,8,59,1,60,55,55,54,56,64,55,63,56/
C     APP   APN   ANP   ANN
      DATA NRK N/ 1,2,17,18,15,16,8,9,13,14,99,0,87,0, 1,68,8,69,2,54,9,
     +55,102,0, 2,63,9,64,1,75,8,76,53,67,54,68, 55,69,56,70,63,68,64,
     +69,75,54,76,55, 2,8,18,20, 16,24,14,23, 101,0,88,0, 2,55,9,56,1,
     +67,8,68,2,64,8,75,2,59,8,72,68,55,67,54,69,56, 1,9,18,21,15,25,13,
     +23,100,0, 96,0,2,53,9,54,1,69,8,70,1,76,9,63,1,73,9,58,55,70,53,
     +68,54,69/
C222222222222222222222222222222222222222222222222222222222222222222222 
**** channel cross section                                             *
      DATA SPIKP1/ 0.D0, 300.D0, 40.D0, 20.D0, 13.D0,8.5D0,8.D0, 9.5D0,
     & 12.D0,14.D0,15.5D0,20.D0,17.D0,13.D0,10.D0,9.D0,8.5D0,8.D0,7.8D0,
     & 7.3D0, 6.7D0, 9*0.D0,.23D0,.35D0,.7D0,.52D0,.4D0,.3D0,.2D0,.15D0,
     & .13D0, .11D0, .09D0, .07D0, 0.D0, .033D0,.8D0,1.35D0,1.35D0,.5D0,
     & 15*0.D0, 3*0.D0,.00D0,0.80D0,2.2D0,3.6D0,4.6D0,4.7D0,3.5D0,2.4D0,
     &1.8D0,1.4D0,.75D0,.47D0,.25D0,.13D0,.08D0,6*0.D0,0.D0,1.2D0,3.3D0,
     & 5.4D0,6.9D0,7.3D0,5.3D0,3.6D0,2.7D0,2.2D0,1.1D0,.73D0,.4D0,.22D0,
     & .12D0,9*0.D0,.0D0,0.D0,2.0D0,4.4D0,6.8D0,9.9D0,7.9D0,6.0D0,3.8D0,
     &2.5D0,2.D0,1.4D0,1.D0,.6D0,.35D0,10*0.D0,.25D0,.55D0,.75D0,1.25D0,
     & 1.9D0,2.D0,1.8D0,1.5D0,1.25D0,1.D0,.8D0,6*0.D0,4*0.D0,.4D0,.85D0,
     & 1.1D0, 1.85D0, 2.8D0, 3.D0,2.7D0,2.2D0,1.85D0,1.5D0,1.2D0,6*0.D0,
     & 6*0.D0, .5D0, 1.2D0, 1.7D0, 3.4D0, 5.2D0, 6.4D0, 6.1D0, 5.6D0,
     & 5.2D0, 6*0.D0, 2*0.D0, .0D0, 1.D0, 3.3D0, 5.2D0, 4.45D0, 3.6D0,
     & 2.75D0, 1.9D0, 1.65D0, 1.3D0, .95D0, .6D0, .45D0, 6*0.D0, 3*0.D0,
     & .0D0, .45D0, 1.4D0, 1.5D0, 1.1D0, .85D0, .5D0, .3D0, .2D0, .15D0,
     & 8*0.D0, 5*0.D0, .0D0, .0D0, .6D0, .8D0, .95D0, .8D0, .7D0, .6D0,
     & .5D0, .4D0, 6*0.D0, 5*0.D0, .0D0, .00D0, .85D0, 1.2D0, 1.4D0,
     & 1.2D0, 1.05D0, .9D0, .7D0, .55D0, 6*0.D0, 5*0.D0, .0D0, .00D0,
     & 1.D0, 1.5D0, 3.5D0, 4.15D0, 3.7D0, 2.7D0, 2.3D0, 1.75D0, 6*0.D0,
     & 10*0.D0, .5D0, 2.0D0, 3.3D0, 5.4D0, 7.D0 /
**** pi+ n data                                                        *
      DATA SPIKPU/   0.D0, 25.D0, 13.D0,  11.D0, 10.5D0, 14.D0,  20.D0,
     & 20.D0, 16.D0, 14.D0, 19.D0, 28.D0, 17.5D0, 13.5D0, 12.D0, 10.5D0,
     & 10.D0, 10.D0, 9.5D0,  9.D0, 8.D0, 7.5D0, 7.D0, 6.5D0, 6.D0, 0.D0,
     & 48.D0, 19.D0, 15.D0, 11.5D0, 10.D0, 8.D0, 6.5D0,   5.5D0,  4.8D0,
     & 4.2D0, 7.5D0, 3.4D0,  2.5D0, 2.5D0, 2.1D0, 1.4D0,   1.D0,   .8D0,
     &  .6D0, .46D0,  .3D0, .2D0, .15D0, .13D0, 11*0.D0,  .95D0,  .65D0,
     & .48D0, .35D0,  .2D0, .18D0, .17D0, .16D0,  .15D0,   .1D0,  .09D0,
     & .065D0, .05D0, .04D0, 12*0.D0, .2D0, .25D0, .25D0,  .2D0,   .1D0,
     & .08D0, .06D0, .045D0,   .03D0, .02D0, .01D0,      .005D0, .003D0,
     & 12*0.D0, .3D0, .24D0,   .18D0, .15D0, .13D0,  .12D0, .11D0, .1D0,
     & .09D0,  .08D0, .05D0,   .04D0, .03D0,  0.D0, 0.16D0, .7D0, 1.3D0,
     & 3.1D0,  4.5D0,  2.D0, 18*0.D0, 3*.0D0,  0.D0, 0.D0, 4.0D0, 11.D0,
     & 11.4D0, 10.3D0, 7.5D0, 6.8D0, 4.75D0, 2.5D0,  1.5D0, .9D0, .55D0,
     &  .35D0, 13*0.D0, .1D0, .34D0, .5D0, .8D0, 1.1D0,   2.25D0, 3.3D0,
     & 2.3D0, 1.6D0, .95D0, .45D0, .28D0, .15D0, 10*0.D0, 2*0.D0, .17D0,
     & .64D0,  1.D0, 1.5D0, 2.1D0, 4.25D0, 6.2D0,  4.4D0,   3.D0, 1.8D0,
     &  .9D0, .53D0, .28D0,      10*0.D0, 2*0.D0,  .25D0,  .82D0,
     & 1.3D0, 1.9D0, 2.8D0, 5.5D0 , 8.D0,  5.7D0, 3.9D0, 2.35D0, 1.15D0,
     & .69D0, .37D0, 10*0.D0,     7*0.D0,   .0D0, .34D0,  1.5D0, 3.47D0,
     & 5.87D0, 6.23D0, 4.27D0, 2.6D0, 1.D0, .6D0,  .3D0,  .15D0, 6*0.D0/
*
      DATA SPIKPV/ 7*0.D0, .00D0, .16D0, .75D0, 1.73D0, 2.93D0, 3.12D0,
     & 2.13D0, 1.3D0, .5D0, .3D0, .15D0, .08D0, 6*0.D0, 10*0.D0, .2D0,
     & .6D0, .92D0, 2.4D0, 4.9D0, 6.25D0, 5.25D0, 3.5D0, 2.15D0, 1.4D0,
     & 1.D0, .7D0, 13*0.D0, .13D0, .4D0, .62D0, 1.6D0, 3.27D0, 4.17D0,
     & 3.5D0, 2.33D0, 1.43D0, .93D0, .66D0, .47D0, 13*0.D0, .07D0, .2D0,
     & .31D0, .8D0, 1.63D0, 2.08D0, 1.75D0, 1.17D0, .72D0, .47D0, .34D0,
     & .23D0, 17*0.D0, .33D0, 1.D0, 1.8D0, 2.67D0, 5.33D0, 6.D0, 5.53D0,
     & 5.D0, 17*0.D0, .17D0, .5D0, .9D0, 1.83D0, 2.67D0, 3.0D0, 2.77D0,
     & 2.5D0, 3*0.D0, 3*0.D0, 1.D0, 3.3D0, 2.8D0, 2.5D0, 2.3D0, 1.8D0,
     & 1.5D0, 1.1D0, .8D0, .7D0, .55D0, .3D0, 10*0.D0, 9*0.D0, .1D0,
     & .4D0, 1.D0, 1.4D0, 2.2D0, 2.5D0, 2.2D0, 1.65D0, 1.35D0, 1.1D0,
     & .8D0, .6D0, .4D0, 12*0.D0, .15D0, .6D0, 1.5D0, 2.1D0, 3.3D0,
     & 3.8D0, 3.3D0, 2.45D0, 2.05D0, 1.65D0, 1.2D0, .9D0, .6D0, 3*0.D0,
     & 9*0.D0, .10D0, .2D0, .5D0, .7D0, 1.3D0, 1.55D0, 1.9D0, 1.8D0,
     & 1.55D0, 1.35D0, 1.15D0, .95D0, .7D0, 13*0.D0, .2D0, .5D0, .7D0,
     & 1.3D0, 1.55D0, 1.9D0, 1.8D0, 1.55D0, 1.35D0, 1.15D0, .95D0, .7D0,
     & 17*0.D0, .2D0, .5D0, .85D0, 2.D0, 2.15D0, 2.05D0, 1.75D0, 1.D0,
     & 17*0.D0, .13D0, .33D0, .57D0, 1.33D0, 1.43D0, 1.36D0, 1.17D0,
     & .67D0, 17*0.D0, .07D0, .17D0, .28D0, .67D0, .72D0, .69D0, .58D0,
     & .33D0,17*0.D0,.4D0, .7D0, 1.D0, 1.6D0, 1.8D0, 2.3D0,1.9D0,1.7D0 /
**** pi- p data                                                        *
      DATA SPIKPW/ 0.D0, 25.D0, 13.D0, 11.D0, 10.5D0, 14.D0, 2*20.D0,
     & 16.D0, 14.D0, 19.D0, 28.D0, 17.5D0, 13.5D0, 12.D0, 10.5D0,
     & 2*10.D0, 9.5D0, 9.D0, 8.D0, 7.5D0, 7.D0, 6.5D0, 6.D0, 0.D0,
     & 48.D0, 19.D0, 15.D0, 11.5D0, 10.D0, 8.D0, 6.5D0, 5.5D0, 4.8D0,
     & 4.2D0, 7.5D0, 3.4D0, 2*2.5D0, 2.1D0, 1.4D0, 1.D0, .8D0, .6D0,
     & .46D0, .3D0, .2D0, .15D0, .13D0, 11*0.D0, .95D0, .65D0, .48D0,
     & .35D0, .2D0, .18D0, .17D0, .16D0, .15D0, .1D0, .09D0, .065D0,
     & .05D0, .04D0, 12*0.D0, .2D0, 2*.25D0, .2D0, .1D0, .08D0, .06D0,
     & .045D0, .03D0, .02D0, .01D0, .005D0, .003D0, 12*0.D0, .3D0,
     & .24D0, .18D0, .15D0, .13D0, .12D0, .11D0, .1D0, .09D0, .08D0,
     & .05D0, .04D0, .03D0, 0.D0, 0.16D0, .7D0, 1.3D0, 3.1D0, 4.5D0,
     & 2.D0, 23*0.D0, 4.0D0, 11.D0, 11.4D0, 10.3D0, 7.5D0, 6.8D0,
     & 4.75D0, 2.5D0, 1.5D0, .9D0, .55D0, .35D0, 13*0.D0, .1D0, .34D0,
     & .5D0, .8D0, 1.1D0, 2.25D0, 3.3D0, 2.3D0, 1.6D0, .95D0, .45D0,
     & .28D0, .15D0, 12*0.D0, .17D0, .64D0, 1.D0, 1.5D0, 2.1D0, 4.25D0,
     & 6.2D0, 4.4D0, 3.D0, 1.8D0, .9D0, .53D0, .28D0, 12*0.D0, .25D0,
     & .82D0, 1.3D0, 1.9D0, 2.8D0, 5.5D0, 8.D0, 5.7D0, 3.9D0, 2.35D0,
     & 1.15D0, .69D0, .37D0, 18*0.D0, .34D0, 1.5D0, 3.47D0, 5.87D0,
     & 6.23D0, 4.27D0, 2.6D0, 1.D0, .6D0, .3D0, .15D0, 6*0.D0/
*
      DATA SPIKPX/ 8*0.D0, .16D0, .75D0, 1.73D0, 2.93D0, 3.12D0,
     & 2.13D0, 1.3D0, .5D0, .3D0, .15D0, .08D0, 16*0.D0, .2D0, .6D0,
     & .92D0, 2.4D0, 4.9D0, 6.25D0, 5.25D0, 3.5D0, 2.15D0, 1.4D0, 1.D0,
     & .7D0, 13*0.D0, .13D0, .4D0, .62D0, 1.6D0, 3.27D0, 4.17D0, 3.5D0,
     & 2.33D0, 1.43D0, .93D0, .66D0, .47D0, 13*0.D0, .07D0, .2D0, .31D0,
     & .8D0, 1.63D0, 2.08D0, 1.75D0, 1.17D0, .72D0, .47D0, .34D0, .23D0,
     & 17*0.D0, .33D0, 1.D0, 1.8D0, 2.67D0, 5.33D0, 6.D0, 5.53D0, 5.D0,
     & 17*0.D0, .17D0, .5D0, .9D0, 1.83D0, 2.67D0, 3.0D0, 2.77D0, 2.5D0,
     & 6*0.D0, 1.D0, 3.3D0, 2.8D0, 2.5D0, 2.3D0, 1.8D0, 1.5D0, 1.1D0,
     & .8D0, .7D0, .55D0, .3D0, 19*0.D0, .1D0, .4D0, 1.D0, 1.4D0, 2.2D0,
     & 2.5D0, 2.2D0, 1.65D0, 1.35D0, 1.1D0, .8D0, .6D0, .4D0, 12*0.D0,
     & .15D0, .6D0, 1.5D0, 2.1D0, 3.3D0, 3.8D0, 3.3D0, 2.45D0, 2.05D0,
     & 1.65D0, 1.2D0, .9D0, .6D0, 12*0.D0, .10D0, .2D0, .5D0, .7D0,
     & 1.3D0, 1.55D0, 1.9D0, 1.8D0, 1.55D0, 1.35D0, 1.15D0, .95D0, .7D0,
     & 13*0.D0, .2D0, .5D0, .7D0, 1.3D0, 1.55D0, 1.9D0, 1.8D0, 1.55D0,
     & 1.35D0, 1.15D0, .95D0, .7D0, 17*0.D0, .2D0, .5D0, .85D0, 2.D0,
     & 2.15D0, 2.05D0, 1.75D0, 1.D0, 17*0.D0, .13D0, .33D0, .57D0,
     & 1.33D0, 1.43D0, 1.36D0, 1.17D0, .67D0, 17*0.D0, .07D0, .17D0,
     & .28D0, .67D0, .72D0, .69D0, .58D0, .33D0, 17*0.D0, .4D0, .7D0,
     & 1.D0, 1.6D0, 1.8D0, 2.3D0, 1.9D0, 1.7D0 /
**** pi- n data                                                        *
      DATA SPIKP4 / 0.D0, 300.D0, 40.D0, 20.D0, 13.D0, 8.5D0, 8.D0,
     & 9.5D0, 12.D0, 14.D0, 15.5D0, 20.D0, 17.D0, 13.D0, 10.D0, 9.D0,
     & 8.5D0, 8.D0, 7.8D0, 7.3D0, 6.7D0, 9*0.D0, .23D0, .35D0, .7D0,
     & .52D0, .4D0, .3D0, .2D0, .15D0, .13D0, .11D0, .09D0, .07D0, 0.D0,
     & .033D0, .8D0, 2*1.35D0, .5D0, 19*0.D0, 0.8D0, 2.2D0, 3.6D0,
     & 4.6D0, 4.7D0, 3.5D0, 2.4D0, 1.8D0, 1.4D0, .75D0, .47D0, .25D0,
     & .13D0, .08D0, 7*0.D0, 1.2D0, 3.3D0, 5.4D0, 6.9D0, 7.3D0, 5.3D0,
     & 3.6D0, 2.7D0, 2.2D0, 1.1D0, .73D0, .4D0, .22D0, .12D0, 11*0.D0,
     & 2.0D0, 4.4D0, 6.8D0, 9.9D0, 7.9D0, 6.0D0, 3.8D0, 2.5D0, 2.D0,
     & 1.4D0, 1.D0, .6D0, .35D0, 10*0.D0, .25D0, .55D0, .75D0, 1.25D0,
     & 1.9D0, 2.D0, 1.8D0, 1.5D0, 1.25D0, 1.D0, .8D0, 10*0.D0, .4D0,
     & .85D0, 1.1D0, 1.85D0, 2.8D0, 3.D0, 2.7D0, 2.2D0, 1.85D0, 1.5D0,
     & 1.2D0, 12*0.D0, .5D0, 1.2D0, 1.7D0, 3.4D0, 5.2D0, 6.4D0, 6.1D0,
     & 5.6D0, 5.2D0, 9*0.D0, 1.D0, 3.3D0, 5.2D0, 4.45D0, 3.6D0, 2.75D0,
     & 1.9D0, 1.65D0, 1.3D0, .95D0, .6D0, .45D0, 10*0.D0, .45D0, 1.4D0,
     & 1.5D0, 1.1D0, .85D0, .5D0, .3D0, .2D0, .15D0, 15*0.D0, .6D0,
     & .8D0, .95D0, .8D0, .7D0, .6D0, .5D0, .4D0, 13*0.D0, .85D0, 1.2D0,
     & 1.4D0, 1.2D0, 1.05D0, .9D0, .7D0, .55D0, 13*0.D0, 1.D0, 1.5D0,
     & 3.5D0, 4.15D0, 3.7D0, 2.7D0, 2.3D0, 1.75D0, 16*0.D0, .5D0, 2.0D0,
     & 3.3D0, 5.4D0, 7.D0 /
**** k+  p data                                                        *
      DATA SPIKP5/ 0.D0, 20.D0, 14.D0, 12.D0, 11.5D0, 10.D0, 8.D0,
     & 7.D0, 6.D0, 5.5D0, 5.3D0, 5.D0, 4.5D0, 4.4D0, 3.8D0, 3.D0, 2.8D0,
     & 0.D0, .5D0, 1.15D0, 2.D0, 1.3D0, .8D0, .45D0, 13*0.D0, 0.9D0,
     & 2.5D0, 3.D0, 2.5D0, 2.3D0, 2.D0, 1.7D0, 1.5D0, 1.2D0, .9D0, .6D0,
     & .45D0, .21D0, .2D0, 3*0.D0, .9D0, 2.5D0, 3.D0, 2.5D0, 2.3D0,
     & 2.D0, 1.7D0, 1.5D0, 1.2D0, .9D0, .6D0, .45D0, .21D0, .2D0,
     & 4*0.D0, 1.D0, 2.1D0, 2.6D0, 2.3D0, 2.1D0, 1.8D0, 1.7D0, 1.4D0,
     & 1.2D0, 1.05D0, .9D0, .66D0, .5D0, 7*0.D0, .3D0, 2*1.D0, .9D0,
     & .7D0, .4D0, .3D0, .2D0, 11*0.D0, .1D0, 1.D0, 2.2D0, 3.5D0, 4.2D0,
     & 4.55D0, 4.85D0, 4.9D0, 10*0.D0, .2D0, .7D0, 1.6D0, 2.5D0, 2.2D0,
     & 1.71D0, 1.6D0, 6*0.D0, 1.4D0, 3.8D0, 5.D0, 4.7D0, 4.4D0, 4.D0,
     & 3.5D0, 2.85D0, 2.35D0, 2.01D0, 1.8D0, 12*0.D0, .1D0, .8D0,2.05D0,
     & 3.31D0, 3.5D0, 12*0.D0, .034D0, .2D0, .75D0, 1.04D0, 1.24D0 /
 
C222222222222222222222222222222222222222222222222222222222222222222222 
C2222222222222222222222222222222222222222222222222222222222222222222222 
 
 
 
C**** K+ N DATA
      DATA S PIKP6/ 0.,6.,11.,13.,6.,5.,3.,2.2,1.5,1.2,1.,.7,.6,.5,.45,.
     +35,.3, 0.,6.,11.,13.,6.,5.,3.,2.2,1.5,1.2,1.,.7,.6,.5,.45,.35,.3,
     +0.,.5,1.3,2.8,2.3,1.6,.9,10*0., 3*0.,0.9,2.5,3.,2.5,2.3,2.,1.7,
     +1.5,1.2,.9,.6,.45,.21,.2, 3*0.,0.9,2.5,3.,2.5,2.3,2.,1.7,1.5,1.2,.
     +9,.6,.45,.21,.2, 4*0.,1.0,2.1,2.6,2.3,2.0,1.8,1.7,1.4,1.2,1.15,.9,
     +.66, .5, 4*0.,1.0,2.1,2.6,2.3,2.1,1.8,1.7,1.4,1.2,1.15,.9,.66, .5,
     +7*0.,.3,1.,1.,.9,.7,.4,.35,.2,.00,0., 7*0.,.3,1.,1.,.9,.7,.4,.35,.
     +2,.00,0., 9*0.,.1,1.,2.4,3.5,4.25,4.55,4.85,4.9, 9*0.,.1,1.,2.4,
     +3.5,4.25,4.55,4.85,4.9, 10*0.,.2,.7,1.6,2.5,2.2,1.71,1.6, 10*0.,.
     +2,.7,1.6,2.5,2.2,1.71,1.6, 6*0.,1.4,3.8,5.,4.7,4.4,4.,3.5,2.85,
     +2.35,2.01,1.8, 6*0.,1.4,3.8,5.,4.7,4.4,4.,3.5,2.85,2.35,2.01,1.8,
     +12*0.,.1,.8,2.05,3.31,3.5, 12*0.,.034,.20,.75,1.04,1.24, .0,2.5,
     +15.,21.5,15.3,3.,1.5,10*0./
 
C333333333333333333333333333333333333333333333333333333333333333333333

**** k-  p data                                                        *
      DATA SKMPEL/ 0.D0, 35.D0, 22.D0, 25.D0, 17.D0, 9.D0, 9.5D0, 8.D0,
     &     7.D0, 6.5D0, 6.1D0, 5.D0, 4.8D0, 4.6D0, 4.45D0, 4.3D0, 4.2D0,
     &    0.D0, 8.D0, 3.5D0, 8.D0, 3.D0, 1.9D0, 1.7D0, 1.D0, .9D0, .8D0,
     &    .75D0, .5D0, .42D0, .38D0, .34D0, .25D0, .2D0,
     &    0.D0, 3.D0, 3.2D0, 3.5D0, 1.5D0, 1.4D0, 1.1D0, .6D0, .5D0,
     &    .35D0, .28D0, .25D0, .18D0, .12D0, .1D0, .08D0, .04D0,
     &    0.D0, 8.5D0, 2.4D0, 1.7D0, 1.3D0, 1.3D0, 1.1D0, .5D0,
     &    .4D0, .4D0, .35D0, .3D0, .28D0, .2D0, .16D0, .13D0, .11D0,
     &    0.D0, 7.D0, 4.8D0, 1.4D0, 1.9D0, .9D0, .4D0, .2D0, .13D0,
     &    .1D0, .08D0, .06D0, .04D0, .02D0, .015D0, .01D0, .01D0,
     &    0.D0, 5.5D0, 1.D0, .8D0, .75D0, .32D0, .2D0, .1D0, .09D0,
     &    .08D0, .065D0, .05D0, .04D0, .022D0, .017D0, 2*.01D0/
      DATA SPIKP7 / 0.D0, .56D0, 1.46D0, 3.16D0, 2.01D0, 1.28D0, .74D0,
     & 14*0.D0, 1.13D0, 2.61D0, 2.91D0, 2.58D0, 2.35D0, 2.02D0,
     & 1.91D0, 1.57D0, 1.35D0, 1.29D0, 1.01D0, .74D0, .65D0, 4*0.D0,
     & 1.13D0, 2.61D0, 2.91D0, 2.58D0, 2.35D0, 2.02D0, 1.91D0, 1.57D0,
     & 1.35D0, 1.29D0, 1.01D0, .74D0, .65D0,  3*0.D0, 1.0D0, 3.03D0,
     & 3.36D0, 2.8D0, 2.58D0, 2.24D0, 1.91D0, 1.68D0, 1.35D0, 1.01D0,
     & .67D0, .5D0, .24D0, .23D0, 3*0.D0, 1.0D0, 3.03D0, 3.36D0, 2.8D0,
     & 2.58D0, 2.24D0, 1.91D0, 1.68D0, 1.35D0, 1.01D0, .67D0, .5D0,
     & .24D0, .23D0, 7*0.D0, .34D0, 1.12D0, 1.12D0, 1.01D0, .78D0,
     & .45D0, .39D0, .22D0, .07D0, 0.D0, 7*0.D0, .34D0, 1.12D0, 1.12D0,
     & 1.01D0, .78D0, .45D0, .39D0, .22D0, .07D0, 0.D0, 6*0.D0, 1.71D0,
     & 4.26D0, 5.6D0, 5.57D0, 4.93D0, 4.48D0, 3.92D0, 3.19D0, 2.63D0,
     & 2.25D0, 2.D0, 6*0.D0, 1.71D0, 4.26D0, 5.6D0, 5.57D0, 4.93D0,
     & 4.48D0, 3.92D0, 3.19D0, 2.63D0, 2.25D0, 2.D0, 10*0.D0, .22D0,
     & .8D0, .75D0, 1.D0, 1.3D0, 1.5D0, 1.3D0, 10*0.D0, .22D0, .8D0,
     & .75D0, 1.D0, 1.3D0, 1.5D0, 1.3D0, 13*0.D0, .1D0, .3D0, .7D0,1.D0,
     & 13*0.D0, .1D0, .3D0, .7D0, 1.D0, 9*0.D0, .11D0, 1.72D0, 2.69D0,
     & 3.92D0, 4.76D0, 5.10D0, 5.44D0, 5.3D0, 9*0.D0, .11D0, 1.72D0,
     & 2.69D0, 3.92D0, 4.76D0, 5.1D0, 5.44D0, 5.3D0, 5*0.D0,9.2D0,4.7D0,
     & 1.9D0, 10*0.D0, 2.5D0, 15.D0, 21.5D0, 15.3D0, 3.D0, 1.5D0,
     & 10*0.D0/
C333333333333333333333333333333333333333333333333333333333333333333333 
C3333333333333333333333333333333333333333333333333333333333333333333333
 
 
 
 
C**** K- N DATA
      DATA SKMNEL/
     *0.,4.,9.5,20.,13.,9.5,6.,4.4,3.,2.4,2.,1.4,1.2,1.,.9,.7,.6,
     *0.,4.5,6.,5.,2.5,2.,1.7,2.1,1.9,.9,.5,.3,.24,.2,.18,.1,.09,
     *0.,1.8,2.,1.1,.9,.5,.5,.4,.4,.2,.1,.06,.05,.04,.03,.02,.02,
     *0.,1.5,2.,.9,1.1,.4,.6,.7,.65,.3,.17,.1,.08,.07,.06,.04,.03/
      DATA S PIKP8/ 0.,.56,1.29,2.26,1.01,.64,.37,10*0., 4*0.,1.13,2.61,
     +2.91,2.58,2.35,2.02,1.91,1.57,1.35,1.29,1.01,.74, .65, 3*0.,1.00,
     +3.03,3.36,2.8,2.58,2.24,1.91,1.68,1.35,1.01,.67,.5,.24, .23, 3*0.,
     +1.00,3.03,3.36,2.8,2.58,2.24,1.91,1.68,1.35,1.01,.67,.5,.24, .23,
     +7*0.,.34,1.12,1.12,1.01,.78,.45,.39,.22,.07,0., 6*0.,1.71,4.26,
     +5.6,5.57,4.93,4.48,3.92,3.19,2.63,2.25,2., 10*0.,.22,.8,.75,1.,
     +1.3,1.5,1.3, 13*0.,.1,.3,.7,1., 13*0.,.1,.3,.7,1., 9*0.,.11,1.72,
     +2.69,3.92,4.76,5.10,5.44,5.3, 4*0.,0.00,9.2,4.7,1.9,9*0. /
 
 
 
 
 
 
 
 
C****  P P DATA
      DATA S PIKP9/ 0.,24.,25.,27.,23.,21.,20.,19.,17.,15.5,14.,13.5,
     +13., 0.,3.6,1.7, 10*0., .0,0.0,8.7,17.7,18.8,15.9,11.7,8.,6.,5.3,
     +4.5,3.9,3.5, .0,.0,2.8,5.8,6.2,5.1,3.8,2.7,2.1,1.8,1.5,1.3,1.1, 4
     +*0.,0.0,4.6,10.2,15.1,16.9,16.5,11.,5.5,3.5, 10*0.,4.3,7.6,9., 10
     +*0.,1.7,2.6,3., 6*0.,.3,.6,1.,1.6,1.3,.8,.6, 6*0.,.7,1.2,1.8,2.5,
     +1.8,1.3,1.2, 10*0.,.6,1.4,1.7, 10*0.,1.9,4.1,5.2/
 
 
C444444444444444444444444444444444444444444444444444444444444444444444
*****  p n data                                                        *
      DATA SPIKP0/ 0.D0, 24.D0, 25.D0, 27.D0, 23.D0, 21.D0, 20.D0,
     &              19.D0, 17.D0, 15.5D0, 14.D0, 13.5D0, 13.D0,
     &              0.D0, 1.8D0, .2D0,  12*0.D0,
     &              3.2D0, 6.05D0, 9.9D0, 5.1D0,
     &              3.8D0, 2.7D0, 1.9D0, 1.5D0, 1.4D0, 1.3D0, 1.1D0,
     &              2*.0D0, 3.2D0, 6.05D0, 9.9D0, 5.1D0,
     &              3.8D0, 2.7D0, 1.9D0, 1.5D0, 1.4D0, 1.3D0, 1.1D0,
     &              5*0.D0, 4.6D0, 10.2D0, 15.1D0,
     &              16.4D0, 15.2D0, 11.D0, 5.4D0, 3.5D0,
     &              5*0.D0, 4.6D0, 10.2D0, 15.1D0,
     &              16.4D0, 15.2D0, 11.D0, 5.4D0, 3.5D0,
     &              10*0.D0, .7D0, 5.1D0, 8.D0,
     &              10*0.D0, .7D0, 5.1D0, 8.D0,
     &              10*.0D0, .3D0, 2.8D0, 4.7D0,
     &              10*.0D0, .3D0, 2.8D0, 4.7D0,
     &              7*0.D0, 1.2D0, 2.5D0, 3.5D0, 6.D0, 5.3D0, 2.9D0,
     &              7*0.D0, 1.7D0, 3.6D0, 5.4D0, 9.D0, 7.6D0, 4.2D0,
     &              5*0.D0, 7.7D0, 6.1D0, 2.9D0, 5*0.D0/
*   nn - data                                                          *
*                                                                      *
      DATA SPKP V/ 0.D0, 24.D0, 25.D0, 27.D0, 23.D0, 21.D0, 20.D0,
     &              19.D0, 17.D0, 15.5D0, 14.D0, 13.5D0, 13.D0,
     &              0.D0, 3.6D0, 1.7D0, 12*0.D0,
     &              8.7D0, 17.7D0, 18.8D0, 15.9D0,
     &              11.7D0, 8.D0, 6.D0, 5.3D0, 4.5D0, 3.9D0, 3.5D0,
     &              .0D0, .0D0, 2.8D0, 5.8D0, 6.2D0, 5.1D0, 3.8D0,
     &              2.7D0, 2.1D0, 1.8D0, 1.5D0, 1.3D0, 1.1D0,
     &              5*0.D0, 4.6D0, 10.2D0, 15.1D0, 16.9D0, 16.5D0,
     &              11.D0, 5.5D0, 3.5D0,
     &              10*0.D0, 4.3D0, 7.6D0, 9.D0,
     &              10*0.D0, 1.7D0, 2.6D0, 3.D0,
     &              6*0.D0, .3D0, .6D0, 1.D0, 1.6D0, 1.3D0, .8D0, .6D0,
     &              6*0.D0, .7D0, 1.2D0, 1.8D0, 2.5D0, 1.8D0, 1.3D0,
     &              1.2D0, 10*0.D0, .6D0, 1.4D0, 1.7D0,
     &              10*0.D0, 1.9D0, 4.1D0, 5.2D0/
****************   ap - p - data                                       *
      DATA SAPPEL/ 0.D0,  176.D0, 160.D0, 105.D0, 75.D0, 68.D0, 65.D0,
     &  50.D0,  50.D0, 43.D0, 42.D0, 40.5D0, 35.D0, 30.D0, 28.D0,
     &  25.D0,  22.D0, 21.D0, 20.D0, 18.D0, 17.D0,  11*0.D0,
     &  .05D0,  .15D0, .18D0, .2D0, .2D0, .3D0, .4D0, .6D0, .7D0, .85D0,
     &  0.D0,  1.D0, .9D0, .46D0, .3D0, .23D0, .18D0, .16D0, .14D0,
     &  .1D0,  .08D0, .05D0, .02D0, .015D0, 4*.011D0, 3*.005D0,
     &  0.D0,  55.D0, 50.D0, 25.D0, 15.D0, 15.D0, 14.D0, 12.D0,
     &  10.D0,  7.D0, 6.D0, 4.D0, 3.3D0, 2.8D0, 2.4D0, 2.D0, 1.8D0,
     &  1.55D0,  1.3D0, .95D0, .75D0,
     &  0.D0,  3.3D0, 3.D0, 1.5D0, 1.D0, .7D0, .4D0, .35D0, .4D0,
     &  .25D0,  .18D0, .08D0, .04D0, .03D0, .023D0, .016D0, .014D0,
     & .01D0,  .008D0, .006D0, .005D0/
      DATA SPIKPE/0.D0, 215.D0, 193.D0, 170.D0, 148.D0, 113.D0, 97.D0,
     & 84.D0, 78.D0, 68.D0, 64.D0, 61.D0, 46.D0, 36.D0, 31.3D0, 28.5D0,
     & 25.7D0, 22.6D0, 21.4D0, 20.7D0, 19.9D0,
     & 9*0.D0, 2.D0, 2.5D0, .2D0, 19*0.D0, .3D0, 1.4D0, 2.2D0, 1.2D0,
     & 1.1D0, 1.D0, .8D0, .6D0, .5D0, .4D0, .3D0, 10*0.D0, .3D0, 1.4D0,
     & 2.2D0, 1.2D0, 1.1D0, 1.D0, .8D0, .6D0, .5D0, .4D0, .3D0, 10*0.D0,
     & .3D0, 1.4D0, 2.2D0, 1.2D0, 1.1D0, 1.D0, .8D0, .6D0, .5D0, .4D0,
     & .3D0, 10*0.D0, .3D0, 1.4D0, 2.2D0, 1.2D0, 1.1D0, 1.D0, .8D0,
     & .6D0, .5D0, .4D0, .3D0, 9*0.D0, .6D0, 2.5D0, 5.D0, 5.2D0, 5.1D0,
     & 5.4D0, 5.8D0, 2.8D0, 2.1D0, 1.8D0, 1.6D0, 1.2D0, 13*0.D0, 1.3D0,
     & 1.5D0, 2.D0, 2.5D0, 2.5D0, 2.3D0, 1.8D0, 1.4D0, 13*0.D0, 1.3D0,
     & 1.5D0, 2.D0, 2.5D0, 2.5D0, 2.3D0, 1.8D0, 1.4D0, 13*0.D0, 1.3D0,
     & 1.5D0, 2.D0, 2.5D0, 2.5D0, 2.3D0, 1.8D0, 1.4D0, 13*0.D0, 1.3D0,
     & 1.5D0, 2.D0, 2.5D0, 2.5D0, 2.3D0, 1.8D0, 1.4D0, 14*0.D0, .2D0,
     & .5D0, 1.1D0, 1.6D0, 1.4D0, 1.1D0, .9D0, 14*0.D0, .2D0, .5D0,
     & 1.1D0, 1.6D0, 1.4D0, 1.1D0, .9D0, 14*0.D0, .2D0, .5D0, 1.1D0,
     & 1.6D0, 1.4D0, 1.1D0, .9D0, 14*0.D0, .2D0, .5D0, 1.1D0, 1.6D0,
     & 1.4D0, 1.1D0, .9D0, 17*0.D0, .3D0, 1.6D0, 2.6D0, 3.6D0, 17*0.D0,
     & .3D0, 1.6D0, 2.6D0, 3.6D0, 17*0.D0, .3D0, 1.6D0, 2.6D0,
     & 3.6D0, 17*0.D0, .3D0, 1.6D0, 2.6D0, 3.6D0 /
****************   ap - n - data                                       *
      DATA SAPNEL/
     & 0.D0,  176.D0, 160.D0, 105.D0, 75.D0,  68.D0, 65.D0,
     & 50.D0, 50.D0,  43.D0,  42.D0,  40.5D0, 35.D0, 30.D0,  28.D0,
     & 25.D0, 22.D0,  21.D0,  20.D0,  18.D0,  17.D0, 11*0.D0,
     & .05D0, .15D0, .18D0,  .2D0,    .2D0,  .3D0,  .4D0,   .6D0,  .7D0,
     & .85D0,  0.D0,  1.D0,  .9D0,    .46D0, .3D0,  .23D0, .18D0, .16D0,
     & .14D0,  .1D0, .08D0, .05D0,    .02D0, .015D0, 4*.011D0, 3*.005D0,
     & 0.D0,  3.3D0,  3.D0, 1.5D0,     1.D0, .7D0,  .4D0,  .35D0, .4D0,
     & .25D0, .18D0, .08D0, .04D0,    .03D0, .023D0, .016D0, .014D0,
     & .01D0, .008D0, .006D0, .005D0 /
       DATA SPIKPZ/ 0.D0, 215.D0, 193.D0, 170.D0, 148.D0, 113.D0, 97.D0,
     &  84.D0, 78.D0, 68.D0, 64.D0, 61.D0, 46.D0, 36.D0, 31.3D0, 28.5D0,
     & 25.7D0, 22.6D0, 21.4D0, 20.7D0, 19.9D0, 9*0.D0, 2.4D0, .2D0,
     & 20*0.D0, 1.8D0, 2.8D0, 3.6D0, 2.3D0, 1.8D0, 1.5D0, 1.3D0, 1.D0,
     & .7D0, .5D0, .3D0, 10*0.D0, 1.8D0, 2.8D0, 3.6D0, 2.3D0, 1.8D0,
     & 1.5D0, 1.3D0, 1.D0, .7D0, .5D0, .3D0, 10*0.D0, 1.8D0, 2.8D0,
     & 3.6D0, 2.3D0, 1.8D0, 1.5D0, 1.3D0, 1.D0, .7D0, .5D0, .3D0,
     & 10*0.D0, 1.8D0, 2.8D0, 3.6D0, 2.3D0, 1.8D0, 1.5D0, 1.3D0, 1.D0,
     & .7D0, .5D0, .3D0, 13*0.D0, 5.2D0, 8.7D0, 11.4D0, 14.D0, 11.9D0,
     & 7.6D0, 6.D0, 5.D0, 13*0.D0, 5.2D0, 8.7D0, 11.4D0, 14.D0, 11.9D0,
     & 7.6D0, 6.D0, 5.D0, 18*0.D0, 1.D0, 4.9D0, 8.5D0, 18*0.D0, 1.D0,
     & 4.9D0, 8.5D0,  15*0.D0, 1.9D0, 2.3D0, 4.D0, 6.5D0, 5.2D0, 3.4D0,
     & 15*0.D0, 1.9D0, 2.3D0, 4.D0, 6.5D0, 5.2D0, 3.4D0, 15*0.D0, 1.9D0,
     & 2.3D0, 4.D0, 6.5D0, 5.2D0, 3.4D0 /
*                                                                      *
*                                                                      *
****************   an - p - data                                       *
*                                                                      *
      DATA SANPEL/
     & 0.D0,  176.D0, 160.D0, 105.D0, 75.D0, 68.D0, 65.D0, 50.D0,
     & 50.D0, 43.D0,  42.D0,  40.5D0, 35.D0, 30.D0, 28.D0,
     & 25.D0, 22.D0,  21.D0,  20.D0,  18.D0, 17.D0, 11*0.D0, .05D0,
     & .15D0, .18D0,   .2D0,   .2D0,   .3D0,  .4D0, .6D0,   .7D0, .85D0,
     & 0.D0,   1.D0,   .9D0,  .46D0,  .3D0,  .23D0, .18D0, .16D0, .14D0,
     & .1D0,  .08D0,  .05D0,  .02D0, .015D0, 4*.011D0, 3*.005D0,
     & 0.D0,  3.3D0,  3.D0, 1.5D0, 1.D0, .7D0, .4D0, .35D0, .4D0, .25D0,
     & .18D0, .08D0, .04D0, .03D0, .023D0, .016D0, .014D0,
     & .01D0, .008D0, .006D0, .005D0 /
      DATA SPIKPF/ 0.D0, 215.D0, 193.D0, 170.D0, 148.D0, 113.D0, 97.D0,
     & 84.D0, 78.D0, 68.D0, 64.D0, 61.D0, 46.D0, 36.D0, 31.3D0, 28.5D0,
     & 25.7D0, 22.6D0, 21.4D0, 20.7D0, 19.9D0, 9*0.D0, 2.4D0, .2D0,
     & 20*0.D0, 1.8D0, 2.8D0, 3.6D0, 2.3D0, 1.8D0, 1.5D0, 1.3D0, 1.D0,
     & .7D0, .5D0, .3D0, 10*0.D0, 1.8D0, 2.8D0, 3.6D0, 2.3D0, 1.8D0,
     & 1.5D0, 1.3D0, 1.D0, .7D0, .5D0, .3D0, 10*0.D0, 1.8D0, 2.8D0,
     & 3.6D0, 2.3D0, 1.8D0, 1.5D0, 1.3D0, 1.D0, .7D0, .5D0, .3D0,
     & 10*0.D0, 1.8D0, 2.8D0, 3.6D0, 2.3D0, 1.8D0, 1.5D0, 1.3D0, 1.D0,
     & .7D0, .5D0, .3D0, 13*0.D0, 5.2D0, 8.7D0, 11.4D0, 14.D0, 11.9D0,
     & 7.6D0, 6.D0, 5.D0, 13*0.D0, 5.2D0, 8.7D0, 11.4D0, 14.D0, 11.9D0,
     & 7.6D0, 6.D0, 5.D0, 18*0.D0, 1.D0, 4.9D0, 8.5D0, 18*0.D0, 1.D0,
     & 4.9D0, 8.5D0, 15*0.D0, 1.9D0, 2.3D0, 4.D0, 6.5D0, 5.2D0, 3.4D0,
     & 15*0.D0, 1.9D0, 2.3D0, 4.D0, 6.5D0, 5.2D0, 3.4D0, 15*0.D0, 1.9D0,
     & 2.3D0, 4.D0, 6.5D0, 5.2D0, 3.4D0 /
****  ko - n - data                                                    *
      DATA SPKP15/0.D0, 20.D0, 14.D0, 12.D0, 11.5D0, 10.D0, 8.D0, 7.D0,
     &      6.D0, 5.5D0, 5.3D0, 5.D0, 4.5D0, 4.4D0, 3.8D0, 3.D0, 2.8D0,
     &      0.D0, .5D0, 1.15D0, 2.D0, 1.3D0, .8D0, .45D0, 10*0.D0,
     &    3*0.D0, 0.9D0, 2.5D0, 3.D0, 2.5D0, 2.3D0, 2.D0, 1.7D0,
     &     1.5D0, 1.2D0, .9D0, .6D0, .45D0, .21D0, .2D0,
     &    3*0.D0, 0.9D0, 2.5D0, 3.D0, 2.5D0, 2.3D0, 2.D0, 1.7D0,
     &     1.5D0, 1.2D0, .9D0, .6D0, .45D0, .21D0, .2D0,
     &    4*0.D0, 1.D0, 2.1D0, 2.6D0, 2.3D0, 2.1D0, 1.8D0, 1.7D0,
     &     1.4D0, 1.2D0, 1.05D0, .9D0, .66D0,  .5D0,
     &    7*0.D0, .3D0, 1.D0, 1.D0, .9D0, .7D0, .4D0, .30D0, .2D0,
     &   11*0.D0, .1D0, 1.D0, 2.2D0, 3.5D0, 4.20D0, 4.55D0,
     &    4.85D0, 4.9D0,
     &   10*0.D0, .2D0, .7D0, 1.6D0, 2.5D0, 2.2D0, 1.71D0, 1.6D0,
     &    6*0.D0, 1.4D0, 3.8D0, 5.D0, 4.7D0, 4.4D0, 4.D0, 3.5D0,
     &    2.85D0, 2.35D0, 2.01D0, 1.8D0,
     &   12*0.D0, .1D0, .8D0, 2.05D0, 3.31D0, 3.5D0,
     &   12*0.D0, .034D0, .20D0, .75D0, 1.04D0, 1.24D0  /

C444444444444444444444444444444444444444444444444444444444444444444444 
C44444444444444444444444444444444444444444444444444444444444444444
C*** AKO - P - DATA
      DATA SPKP16/
     *0.,4.,9.5,20.,13.,9.5,6.,4.4,3.,2.4,2.,1.4,1.2,1.,.9,.7,.6,
     *0.,4.5,6.,5.,2.5,2.,1.7,2.1,1.9,.9,.5,.3,.24,.2,.18,.1,.09,
     *0.,1.8,2.,1.1,.9,.5,.5,.4,.4,.2,.1,.06,.05,.04,.03,.02,.02,
     *0.,1.5,2.,.9,1.1,.4,.6,.7,.65,.3,.17,.1,.08,.07,.06,.04,.03,
     *0.,.56,1.29,2.26,1.01,.64,.37,10*0.,
     *4*0.,1.13,2.61,2.91,2.58,2.35,2.02,1.91,1.57,1.35,1.29,1.01,.74,
     *.65,
     *3*0.,1.00,3.03,3.36,2.8,2.58,2.24,1.91,1.68,1.35,1.01,.67,.5,.24,
     *.23,
     *3*0.,1.00,3.03,3.36,2.8,2.58,2.24,1.91,1.68,1.35,1.01,.67,.5,.24,
     *.23,
     *7*0.,.34,1.12,1.12,1.01,.78,.45,.39,.22,.07,0.,
     *6*0.,1.71,4.26,5.6,5.57,4.93,4.48,3.92,3.19,2.63,2.25,2.,
     *10*0.,.22,.8,.75,1.,1.3,1.5,1.3,
     *13*0.,.1,.3,.7,1.,    13*0.,.1,.3,.7,1.,
     *9*0.,.11,1.72,2.69,3.92,4.76,5.10,5.44,5.3,
     *4*0.,0.00,9.2,4.7,1.9,9*0.
     */
      DATA NURE/9,12,5*0,10,14,3*0,1,3,5,7,6*0,2,6,16,5*0,
     *10,13,5*0,11,12,3*0,2,4,6,8,6*0,3,15,7,5*0/
      END
**sr 19-11-95: DNUPRE removed
*-- Author :
C
C*******************************************************************
C
      SUBROUTINE TSAMCS(KPROJ,EKIN,CST)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C
C  HJM 24/10/88
C
C                 SAMPLING OF COS(THETA)
C                 FOR NUCLEON-PROTON ELASTIC SCATTERING
C                 ACCORDING TO HETKFA2/BERTINI PARAMETRIZATION
C
C-------------------------------------------------------------  ------
C
      DIMENSION DCLIN(195),DCHN(143),DCHNA(36),DCHNB(60)
      DIMENSION PDCI(60),PDCH(55)
C
C--------------------------------------------------------------------
C
      DATA (DCLIN(I),I=1,80) /
C***     DCLN ARRAY
     *     5.000D-01,  1.000D+00,  0.000D+00,  1.000D+00,  0.000D+00,
     *     4.993D-01,  9.881D-01,  5.963D-02,  9.851D-01,  5.945D-02,
     *     4.936D-01,  8.955D-01,  5.224D-01,  8.727D-01,  5.091D-01,
     *     4.889D-01,  8.228D-01,  8.859D-01,  7.871D-01,  8.518D-01,
     *     4.874D-01,  7.580D-01,  1.210D+00,  7.207D-01,  1.117D+00,
     *     4.912D-01,  6.969D-01,  1.516D+00,  6.728D-01,  1.309D+00,
     *     5.075D-01,  6.471D-01,  1.765D+00,  6.667D-01,  1.333D+00,
     *     5.383D-01,  6.054D-01,  1.973D+00,  7.059D-01,  1.176D+00,
     *     5.397D-01,  5.990D-01,  2.005D+00,  7.023D-01,  1.191D+00,
     *     5.336D-01,  6.083D-01,  1.958D+00,  6.959D-01,  1.216D+00,
     *     5.317D-01,  6.075D-01,  1.962D+00,  6.897D-01,  1.241D+00,
     *     5.300D-01,  6.016D-01,  1.992D+00,  6.786D-01,  1.286D+00,
     *     5.281D-01,  6.063D-01,  1.969D+00,  6.786D-01,  1.286D+00,
     *     5.280D-01,  5.960D-01,  2.020D+00,  6.667D-01,  1.333D+00,
     *     5.273D-01,  5.920D-01,  2.040D+00,  6.604D-01,  1.358D+00,
     *     5.273D-01,  5.862D-01,  2.069D+00,  6.538D-01,  1.385D+00/
      DATA (DCLIN(I),I=81,160) /
C***     DCIN ARRAY
     *     5.223D-01,  5.980D-01,  2.814D+00,  6.538D-01,  1.385D+00,
     *     5.202D-01,  5.969D-01,  2.822D+00,  6.471D-01,  1.412D+00,
     *     5.183D-01,  5.881D-01,  2.883D+00,  6.327D-01,  1.469D+00,
     *     5.159D-01,  5.866D-01,  2.894D+00,  6.250D-01,  1.500D+00,
     *     5.133D-01,  5.850D-01,  2.905D+00,  6.170D-01,  1.532D+00,
     *     5.106D-01,  5.833D-01,  2.917D+00,  6.087D-01,  1.565D+00,
     *     5.084D-01,  5.801D-01,  2.939D+00,  6.000D-01,  1.600D+00,
     *     5.063D-01,  5.763D-01,  2.966D+00,  5.909D-01,  1.636D+00,
     *     5.036D-01,  5.730D-01,  2.989D+00,  5.814D-01,  1.674D+00,
     *     5.014D-01,  5.683D-01,  3.022D+00,  5.714D-01,  1.714D+00,
     *     4.986D-01,  5.641D-01,  3.051D+00,  5.610D-01,  1.756D+00,
     *     4.964D-01,  5.580D-01,  3.094D+00,  5.500D-01,  1.800D+00,
     *     4.936D-01,  5.573D-01,  3.099D+00,  5.431D-01,  1.827D+00,
     *     4.909D-01,  5.509D-01,  3.144D+00,  5.313D-01,  1.875D+00,
     *     4.885D-01,  5.512D-01,  3.142D+00,  5.263D-01,  1.895D+00,
     *     4.857D-01,  5.437D-01,  3.194D+00,  5.135D-01,  1.946D+00/
      DATA (DCLIN(I),I=161,195) /
     *     4.830D-01,  5.353D-01,  3.253D+00,  5.000D-01,  2.000D+00,
     *     4.801D-01,  5.323D-01,  3.274D+00,  4.915D-01,  2.034D+00,
     *     4.770D-01,  5.228D-01,  3.341D+00,  4.767D-01,  2.093D+00,
     *     4.738D-01,  5.156D-01,  3.391D+00,  4.643D-01,  2.143D+00,
     *     4.701D-01,  5.010D-01,  3.493D+00,  4.444D-01,  2.222D+00,
     *     4.672D-01,  4.990D-01,  3.507D+00,  4.375D-01,  2.250D+00,
     *     4.634D-01,  4.856D-01,  3.601D+00,  4.194D-01,  2.323D+00/
C
      DATA PDCI /
     *     4.400D+02,  1.896D-01,  1.931D-01,  1.982D-01,  1.015D-01,
     *     1.029D-01,  4.180D-02,  4.228D-02,  4.282D-02,  4.350D-02,
     *     2.204D-02,  2.236D-02,  5.900D+02,  1.433D-01,  1.555D-01,
     *     1.774D-01,  1.000D-01,  1.128D-01,  5.132D-02,  5.600D-02,
     *     6.158D-02,  6.796D-02,  3.660D-02,  3.820D-02,  6.500D+02,
     *     1.192D-01,  1.334D-01,  1.620D-01,  9.527D-02,  1.141D-01,
     *     5.283D-02,  5.952D-02,  6.765D-02,  7.878D-02,  4.796D-02,
     *     6.957D-02,  8.000D+02,  4.872D-02,  6.694D-02,  1.152D-01,
     *     9.348D-02,  1.368D-01,  6.912D-02,  7.953D-02,  9.577D-02,
     *     1.222D-01,  7.755D-02,  9.525D-02,  1.000D+03,  3.997D-02,
     *     5.456D-02,  9.804D-02,  8.084D-02,  1.208D-01,  6.520D-02,
     *     8.233D-02,  1.084D-01,  1.474D-01,  9.328D-02,  1.093D-01/
C
      DATA PDCH /
     *     1.000D+03,  9.453D-02,  9.804D-02,  8.084D-02,  1.208D-01,
     *     6.520D-02,  8.233D-02,  1.084D-01,  1.474D-01,  9.328D-02,
     *     1.093D-01,  1.400D+03,  1.072D-01,  7.450D-02,  6.645D-02,
     *     1.136D-01,  6.750D-02,  8.580D-02,  1.110D-01,  1.530D-01,
     *     1.010D-01,  1.350D-01,  2.170D+03,  4.004D-02,  3.013D-02,
     *     2.664D-02,  5.511D-02,  4.240D-02,  7.660D-02,  1.364D-01,
     *     2.300D-01,  1.670D-01,  2.010D-01,  2.900D+03,  1.870D-02,
     *     1.804D-02,  1.320D-02,  2.970D-02,  2.860D-02,  5.160D-02,
     *     1.020D-01,  2.400D-01,  2.250D-01,  3.370D-01,  4.400D+03,
     *     1.196D-03,  8.784D-03,  1.517D-02,  2.874D-02,  2.488D-02,
     *     4.464D-02,  8.330D-02,  2.008D-01,  2.360D-01,  3.567D-01/
C
      DATA (DCHN(I),I=1,90) /
     *     4.770D-01,  4.750D-01,  4.715D-01,  4.685D-01,  4.650D-01,
     *     4.610D-01,  4.570D-01,  4.550D-01,  4.500D-01,  4.450D-01,
     *     4.405D-01,  4.350D-01,  4.300D-01,  4.250D-01,  4.200D-01,
     *     4.130D-01,  4.060D-01,  4.000D-01,  3.915D-01,  3.840D-01,
     *     3.760D-01,  3.675D-01,  3.580D-01,  3.500D-01,  3.400D-01,
     *     3.300D-01,  3.200D-01,  3.100D-01,  3.000D-01,  2.900D-01,
     *     2.800D-01,  2.700D-01,  2.600D-01,  2.500D-01,  2.400D-01,
     *     2.315D-01,  2.240D-01,  2.150D-01,  2.060D-01,  2.000D-01,
     *     1.915D-01,  1.850D-01,  1.780D-01,  1.720D-01,  1.660D-01,
     *     1.600D-01,  1.550D-01,  1.500D-01,  1.450D-01,  1.400D-01,
     *     1.360D-01,  1.320D-01,  1.280D-01,  1.250D-01,  1.210D-01,
     *     1.180D-01,  1.150D-01,  1.120D-01,  1.100D-01,  1.070D-01,
     *     1.050D-01,  1.030D-01,  1.010D-01,  9.900D-02,  9.700D-02,
     *     9.550D-02,  9.480D-02,  9.400D-02,  9.200D-02,  9.150D-02,
     *     9.100D-02,  9.000D-02,  8.990D-02,  8.900D-02,  8.850D-02,
     *     8.750D-02,  8.700D-02,  8.650D-02,  8.550D-02,  8.500D-02,
     *     8.499D-02,  8.450D-02,  8.350D-02,  8.300D-02,  8.250D-02,
     *     8.150D-02,  8.100D-02,  8.030D-02,  8.000D-02,  7.990D-02/
      DATA (DCHN(I),I=91,143) /
     *     7.980D-02,  7.950D-02,  7.900D-02,  7.860D-02,  7.800D-02,
     *     7.750D-02,  7.650D-02,  7.620D-02,  7.600D-02,  7.550D-02,
     *     7.530D-02,  7.500D-02,  7.499D-02,  7.498D-02,  7.480D-02,
     *     7.450D-02,  7.400D-02,  7.350D-02,  7.300D-02,  7.250D-02,
     *     7.230D-02,  7.200D-02,  7.100D-02,  7.050D-02,  7.020D-02,
     *     7.000D-02,  6.999D-02,  6.995D-02,  6.993D-02,  6.991D-02,
     *     6.990D-02,  6.870D-02,  6.850D-02,  6.800D-02,  6.780D-02,
     *     6.750D-02,  6.700D-02,  6.650D-02,  6.630D-02,  6.600D-02,
     *     6.550D-02,  6.525D-02,  6.510D-02,  6.500D-02,  6.499D-02,
     *     6.498D-02,  6.496D-02,  6.494D-02,  6.493D-02,  6.490D-02,
     *     6.488D-02,  6.485D-02,  6.480D-02/
C
      DATA DCHNA /
     *     6.300D+02,  7.810D-02,  1.421D-01,  1.979D-01,  2.479D-01,
     *     3.360D-01,  5.400D-01,  7.236D-01,  1.000D+00,  1.540D+03,
     *     2.225D-01,  3.950D-01,  5.279D-01,  6.298D-01,  7.718D-01,
     *     9.405D-01,  9.835D-01,  1.000D+00,  2.560D+03,  2.625D-01,
     *     4.550D-01,  5.963D-01,  7.020D-01,  8.380D-01,  9.603D-01,
     *     9.903D-01,  1.000D+00,  3.520D+03,  4.250D-01,  6.875D-01,
     *     8.363D-01,  9.163D-01,  9.828D-01,  1.000D+00,  1.000D+00,
     *     1.000D+00/
C
      DATA DCHNB /
     *     6.300D+02,  3.800D-02,  7.164D-02,  1.275D-01,  2.171D-01,
     *     3.227D-01,  4.091D-01,  5.051D-01,  6.061D-01,  7.074D-01,
     *     8.434D-01,  1.000D+00,  2.040D+03,  1.200D-01,  2.115D-01,
     *     3.395D-01,  5.295D-01,  7.251D-01,  8.511D-01,  9.487D-01,
     *     9.987D-01,  1.000D+00,  1.000D+00,  1.000D+00,  2.200D+03,
     *     1.344D-01,  2.324D-01,  3.754D-01,  5.674D-01,  7.624D-01,
     *     8.896D-01,  9.808D-01,  1.000D+00,  1.000D+00,  1.000D+00,
     *     1.000D+00,  2.850D+03,  2.330D-01,  4.130D-01,  6.610D-01,
     *     9.010D-01,  9.970D-01,  1.000D+00,  1.000D+00,  1.000D+00,
     *     1.000D+00,  1.000D+00,  1.000D+00,  3.500D+03,  3.300D-01,
     *     5.450D-01,  7.950D-01,  1.000D+00,  1.000D+00,  1.000D+00,
     *     1.000D+00,  1.000D+00,  1.000D+00,  1.000D+00,  1.000D+00/
C
C---------------------------------------------------------------
      CST=1D0
C
C*                      IS THE KINETIC ENERGY GREATER THAN LIMIT ?
C
      IF (EKIN.GT.3.5D0) RETURN
C
      IF(KPROJ.EQ.8) GOTO 101
      IF(KPROJ.EQ.1) GOTO 102
C*                                             INVALID REACTION
      WRITE(6,'(A,I5/A)')
     &        ' INVALID PARTICLE TYPE IN DNUPRE - KPROJ=',KPROJ,
     &        ' COS(THETA) = 1D0 RETURNED'
      RETURN
C-------------------------------- NP ELASTIC SCATTERING----------
101   CONTINUE
      IF (EKIN.GT.0.740D0)GOTO 1000
      IF (EKIN.LT.0.300D0)THEN
C                                 EKIN .LT. 300 MEV
         IDAT=1
      ELSE
C                                 300 MEV < EKIN < 740 MEV
         IDAT=6
      END IF
C
      ENER=EKIN
      IE=ABS(ENER/0.020D0)
      UNIV=(ENER-FLOAT(IE)*0.020D0)/0.020D0
C                                            FORWARD/BACKWARD DECISION
      K=IDAT+5*IE
      BWFW=(DCLIN(K+5)-DCLIN(K))*UNIV + DCLIN(K)
      IF (RNDM(V).LT.BWFW)THEN
         VALUE2=-1D0
         K=K+1
      ELSE
         VALUE2=1D0
         K=K+3
      END IF
C
      COEF=(DCLIN(K+5)-DCLIN(K))*UNIV + DCLIN(K)
      RND=RNDM(V)
C
      IF(RND.LT.COEF)THEN
         CST=RNDM(V)
         CST=CST*VALUE2
      ELSE
         R1=RNDM(V)
         R2=RNDM(V)
         R3=RNDM(V)
         R4=RNDM(V)
C
         IF(VALUE2.GT.0.0)THEN
            CST=MAX(R1,R2,R3,R4)
            GOTO 1500
         ELSE
            R5=RNDM(V)
C
            IF (IDAT.EQ.1)THEN
               CST=-MAX(R1,R2,R3,R4,R5)
            ELSE
               R6=RNDM(V)
               R7=RNDM(V)
               CST=-MAX(R1,R2,R3,R4,R5,R6,R7)
            END IF
C
         END IF
C
      END IF
C
      GOTO 1500
C
C********                                EKIN  .GT.  0.74 GEV
C
1000  ENER=EKIN - 0.66
C     IE=ABS(ENER/0.02)
      IE=ENER/0.02
      EMEV=EKIN*1D3
C
      UNIV=(ENER-FLOAT(IE)*0.020D0)/0.020D0
      K=IE
      BWFW=(DCHN(K+1)-DCHN(K))*UNIV + DCHN(K)
      RND=RNDM(V)
C                                        FORWARD NEUTRON
      IF (RND.GE.BWFW)THEN
         DO 1200 K=10,36,9
           IF (DCHNA(K).GT.EMEV) THEN
              UNIVE=(EMEV-DCHNA(K-9))/(DCHNA(K)-DCHNA(K-9))
              UNIV=RNDM(V)
              DO 1100 I=1,8
                 II=K+I
                 P=(DCHNA(II)-DCHNA(II-9))*UNIVE + DCHNA(II-9)
C
                 IF (P.GT.UNIV)THEN
                    UNIV=RNDM(V)
                    FLTI=FLOAT(I)-UNIV
                    GOTO(290,290,290,290,330,340,350,360) I
                 END IF
 1100         CONTINUE
           END IF
 1200    CONTINUE
C
      ELSE
C                                        BACKWARD NEUTRON
         DO 1400 K=13,60,12
            IF (DCHNB(K).GT.EMEV) THEN
               UNIVE=(EMEV-DCHNB(K-12))/(DCHNB(K)-DCHNB(K-12))
               UNIV=RNDM(V)
               DO 1300 I=1,11
                 II=K+I
                 P=(DCHNB(II)-DCHNB(II-12))*UNIVE + DCHNB(II-12)
C
                 IF (P.GT.UNIV)THEN
                   UNIV=RNDM(V)
                   FLTI=FLOAT(I)-UNIV
                   GOTO(120,120,140,150,160,160,180,190,200,210,220) I
                 END IF
 1300          CONTINUE
            END IF
 1400    CONTINUE
      END IF
C
120   CST=1.0D-2*FLTI-1.0D0
      GOTO 1500
140   CST=2.0D-2*UNIV-0.98D0
      GOTO 1500
150   CST=4.0D-2*UNIV-0.96D0
      GOTO 1500
160   CST=6.0D-2*FLTI-1.16D0
      GOTO 1500
180   CST=8.0D-2*UNIV-0.80D0
      GOTO 1500
190   CST=1.0D-1*UNIV-0.72D0
      GOTO 1500
200   CST=1.2D-1*UNIV-0.62D0
      GOTO 1500
210   CST=2.0D-1*UNIV-0.50D0
      GOTO 1500
220   CST=3.0D-1*(UNIV-1.0D0)
      GOTO 1500
C
290   CST=1.0D0-2.5d-2*FLTI
      GOTO 1500
330   CST=0.85D0+0.5D-1*UNIV
      GOTO 1500
340   CST=0.70D0+1.5D-1*UNIV
      GOTO 1500
350   CST=0.50D0+2.0D-1*UNIV
      GOTO 1500
360   CST=0.50D0*UNIV
C
1500  RETURN
C
C-----------------------------------  PP ELASTIC SCATTERING -------
C
 102  CONTINUE
      EMEV=EKIN*1D3
C
      IF (EKIN.LE.0.500D0) THEN
         RND=RNDM(V)
         CST=2.0D0*RND-1.0D0
         RETURN
C
      ELSEIF (EKIN.LT.1.0D0) THEN
         DO 2200 K=13,60,12
            IF (PDCI(K).GT.EMEV) THEN
               UNIVE=(EMEV-PDCI(K-12))/(PDCI(K)-PDCI(K-12))
               UNIV=RNDM(V)
               SUM=0
               DO 2100 I=1,11
                 II=K+I
                 SUM=SUM + (PDCI(II)-PDCI(II-12))*UNIVE + PDCI(II-12)
C
                 IF (UNIV.LT.SUM)THEN
                   UNIV=RNDM(V)
                   FLTI=FLOAT(I)-UNIV
                   GOTO(55,55,55,60,60,65,65,65,65,70,70) I
                 END IF
 2100          CONTINUE
            END IF
 2200    CONTINUE
      ELSE
         DO 2400 K=12,55,11
            IF (PDCH(K).GT.EMEV) THEN
              UNIVE=(EMEV-PDCH(K-11))/(PDCH(K)-PDCH(K-11))
              UNIV=RNDM(V)
              SUM=0.0
              DO 2300 I=1,10
                II=K+I
                SUM=SUM + (PDCH(II)-PDCH(II-11))*UNIVE + PDCH(II-11)
C
                IF (UNIV.LT.SUM)THEN
                  UNIV=RNDM(V)
                  FLTI=UNIV+FLOAT(I)
                  GOTO(50,55,60,60,65,65,65,65,70,70) I
                END IF
 2300         CONTINUE
            END IF
 2400    CONTINUE
      END IF
C
50    CST=0.4D0*UNIV
      GOTO 2500
55    CST=0.2D0*FLTI
      GOTO 2500
60    CST=0.3D0+0.1D0*FLTI
      GOTO 2500
65    CST=0.6D0+0.04D0*FLTI
      GOTO 2500
70    CST=0.78D0+0.02D0*FLTI
C
2500  CONTINUE
      IF (RNDM(V).GT.0.5D0) CST=-CST
C
      RETURN
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
c/* *************************************************************
c/*    27/10/89
c/*    TEST OF CROSS SECTION routines
C      actually applied in dtunuc90:
c/*            SHPTOT (called from SHMAKI)
c/*            SIHNIN, SIHNEL (called from FOZOKL)
c/* *************************************************************
C
      SUBROUTINE SIGTES
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C
*KEEP,PANAME.
C------------------
C
C     /PANAME/ CONTAINS PARTICLE NAMES
C        BTYPE  = LITERAL NAME OF THE PARTICLE
C
      CHARACTER*8 BTYPE
      COMMON /PANAME/ BTYPE(30)
*KEEP,DPAR.
C     /DPAR/   CONTAINS PARTICLE PROPERTIES
C        ANAME  = LITERAL NAME OF THE PARTICLE
C        AAM    = PARTICLE MASS IN GEV
C        GA     = DECAY WIDTH
C        TAU    = LIFE TIME OF INSTABLE PARTICLES
C        IICH   = ELECTRIC CHARGE OF THE PARTICLE
C        IIBAR  = BARYON NUMBER
C        K1,K1  = BIGIN AND END OF DECAY CHANNELS OF PARTICLE
C
      CHARACTER*8  ANAME
      COMMON /DPAR/ ANAME(210),AAM(210),GA(210),TAU(210),IICH(210),
     +IIBAR(210),K1(210),K2(210)
C------------------
*KEND.
      PARAMETER (NPA=45,IPMAX=16)
      DIMENSION KPROJ(IPMAX)
      DIMENSION P(NPA),EK(NPA),PL(180)
      DIMENSION SIGMA(NPA,4)
      DATA P /0.13, 0.19, 0.25, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1.0,
     +1.1, 1.2, 1.3, 1.4, 1.5, 2.0, 3.0, 4.0, 5.0, 6.0, 10.0, 20., 50.,
     +100., 200., 400., 1000., 5000., 10000.,
     +20000.,50000.,100000.,200000.,500000.,1000000.,2000000.,
     +5000000.,10000000.,20000000.,50000000.,100000000.,
     +200000000.,500000000.,1000000000./
      DATA KPROJ / 1, 8, 13, 14, 15, 16, 24, 25, 2, 9, 17, 18, 20, 21,
     +22, 23/
C********************************************************************
      WRITE(6,'(1H1)')
      WRITE(6,'(2A)') ' TEST OF CROSS SECTIONS ROUTINES APPLIED:',
     +' SHPTOT, SIHNIN, SIHNEL(SIGEL)'
      WRITE(6,'(A,5X,A)') ' PRINTED FOR EACH MOMENTUM/KINETIC ENERGY:',
     +' SIHNEL , SIHNIN / (SIHNEL+SIHNIN), SHPTOT'
 
C                                   LOOP OVER PROJECTILES
C     AA=1.0
      DO 50 IPR=1,IPMAX
        KPRO=KPROJ(IPR)
        DO 20 IE=1,NPA
          EK(IE)=SQRT(P(IE)**2+AAM(KPRO)**2) - AAM(KPRO)
C         CALL SIGEL(KPRO,AA,P(IE),SIEL1,ZLEL)
          CALL SIHNEL(KPRO,1,P(IE),SIEL)
C         CALL NIZL(KPRO,AA,P(IE),SIIN1,ZLIN)
          CALL SIHNIN(KPRO,1,P(IE),SIIN)
          SIGMA(IE,2)=SIIN
          SIGMA(IE,1)=SIEL
          SIGMA(IE,4)=SIIN + SIEL
          SIGMA(IE,3)=DSHPTO(KPRO,P(IE))
          DO 10 IM=0,3
            IIE=IM*NPA +IE
            PL(IIE)=LOG10(P(IE))
   10     CONTINUE
   20   CONTINUE
C
        WRITE(6,'(1H1,A,I3,2A)') ' PROJECTILE IPRO=', KPRO, '   - ',
     +  BTYPE(KPRO)
        WRITE(6,'(//A/2A/)')
     +  ' TABLE OF CROSS SECTION VALUES VERSUS PLAB / EKIN:',
     +  ' PLAB, EKIN  /  SIG(EL), SIG(INEL)  /',
     +  '  SIG(TOT)-USED,SIG(EL)+SIG(INEL) - TEST PRINT'
C
        DO 30 IE=1,NPA
          WRITE(6,1000) P(IE),EK(IE), (SIGMA(IE,IS),IS=1,4)
   30   CONTINUE
C
        DO 40 IM=1,3
          DO 40 IE=1,NPA
            SIGMA(IE,IM)=LOG10(SIGMA(IE,IM))
   40   CONTINUE
        WRITE(6,'(///A//)')
     +  ' DOUBLE-LOG PLOT OF SIGMA(EL/INEL/TOT/SUM EL+INEL) VS PLAB'
        NPOI=4*NPA
        CALL PLOT(PL,SIGMA,NPOI,4,NPA,-1.0D0,0.2D0,0.0D0,0.050D0)
C
   50 CONTINUE
C*****************
 1000 FORMAT(2(1PE10.2),5X,4(1PE12.3))
C
      END
      SUBROUTINE TIMDAT
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      character*8 datum
      character*11 zeit
*     CALL GETDAT(IYEAR,IMONTH,IDAY)
*     CALL GETTIM(IHOUR,IMINUT,ISECND,IHSCND)
*     WRITE(6,'(A)') ' YEAR, MONTH,DAY        '
*     WRITE(6,'(1X,3I4)')IYEAR,IMONTH,IDAY
*     WRITE(6,'(A)') ' HOUR, MINUTE,SECOND,...'
*     WRITE(6,'(1X,4I4)')IHOUR,IMINUT,ISECND,IHSCND
C     call date(datum)
C     call time(zeit)
C     WRITE(6,'(4A)') ' YEAR / MONTH / DAY  : ',datum,' time: ',zeit
      RETURN
      END
*CMZ :  1.00/00 25/11/91  16.46.51  by  H.-J. Mhring
*-- Author :
C===========================================================
C#######################################################################
C    THIS IS A PACKAGE CONTAINING A RANDOM NUMBER GENERATOR AND
C    SERVICE ROUTINES.
C    THE ALGORITHM IS FROM
C      'TOWARD A UNVERSAL RANDOM NUMBER GENERATOR'
C      G.MARSAGLIA, A.ZAMAN ;  FLORIDA STATE UNIV. PREPRINT FSU-SCRI-87-
C    IMPLEMENTATION BY K. HAHN  DEC. 88,
C    THIS GENERATOR SHOULD NOT DEPEND ON THE HARD WARE ( IF A REAL HAS
C    AT LEAST 24 SIGNIFICANT BITS IN INTERNAL REPRESENTATION ),
C    THE PERIOD IS ABOUT 2**144,
C    TIME FOR ONE CALL AT IBM-XT IS ABOUT 0.7 MILLISECONDS,
C    THE PACKAGE CONTAINS
C      FUNCTION RNDM(I)                     : GENERATOR
C      SUBROUTINE RNDMST(NA1,NA2,NA3,NB4)   : INITIALIZATION
C      SUBROUTINE RNDMIN(U,C,CD,CM,I,J)     : PUT SEED TO GENERATOR
C      SUBROUTINE RNDMOU(U,C,CD,CM,I,J)     : TAKE SEED FROM GENERATOR
C      SUBROUTINE RNDMTE(IO)                : TEST OF GENERATOR
C---
C    FUNCTION RNDM(I)
C       GIVES UNIFORMLY DISTRIBUTED RANDOM NUMBERS  IN 0..1)
C       I  - DUMMY VARIABLE, NOT USED
C    SUBROUTINE RNDMST(NA1,NA2,NA3,NB1)
C       INITIALIZES THE GENERATOR, MUST BE CALLED BEFORE USING RNDM
C       NA1,NA2,NA3,NB1  - VALUES FOR INITIALIZING THE GENERATOR
C                          NA? MUST BE IN 1..178 AND NOT ALL 1
C                          12,34,56  ARE THE STANDARD VALUES
C                          NB1 MUST BE IN 1..168
C                          78  IS THE STANDARD VALUE
C    SUBROUTINE RNDMIN(U,C,CD,CM,I,J)
C       PUTS SEED TO GENERATOR ( BRINGS GENERATOR IN THE SAME STATUS
C       AS AFTER THE LAST RNDMOU CALL )
C       U(97),C,CD,CM,I,J  - SEED VALUES AS TAKEN FROM RNDMOU
C    SUBROUTINE RNDMOU(U,C,CD,CM,I,J)
C       TAKES SEED FROM GENERATOR
C       U(97),C,CD,CM,I,J  - SEED VALUES
C    SUBROUTINE RNDMTE(IO)
C       TEST OF THE GENERATOR
C       IO     - DEFINES OUTPUT
C                  = 0  OUTPUT ONLY IF AN ERROR IS DETECTED
C                  = 1  OUTPUT INDEPENDEND ON AN ERROR
C       RNDMTE USES RNDMIN AND RNDMOU TO BRING GENERATOR TO SAME STATUS
C       AS BEFORE CALL OF RNDMTE
C#######################################################################
C===========================================================
C     DOUBLE PRECISION FUNCTION RNDM(VDUMMY)
C     IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C     COMMON /RANDOO/ U(97),C,CD,CM,I,J
C     RNDM = U(I)-U(J)
C     IF ( RNDM.LT.0.0D0 ) RNDM = RNDM+1.0D0
C     U(I) = RNDM
C     I    = I-1
C     IF ( I.EQ.0 ) I = 97
C     J    = J-1
C     IF ( J.EQ.0 ) J = 97
C     C    = C-CD
C     IF ( C.LT.0.0D0 ) C = C+CM
C     RNDM = RNDM-C
C     IF ( RNDM.LT.0.0D0 ) RNDM = RNDM+1.0D0
C     RETURN
C     END
*-- Author :
C===========================================================
      SUBROUTINE RNDMST(NA1,NA2,NA3,NB1)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      COMMON /RANDOO/ U(97),C,CD,CM,I,J
      MA1 = NA1
      MA2 = NA2
      MA3 = NA3
      MB1 = NB1
      I   = 97
      J   = 33
      DO 20 II2 = 1,97
        S = 0
        T = 0.5D0
        DO 10 II1 = 1,24
          MAT  = MOD(MOD(MA1*MA2,179)*MA3,179)
          MA1  = MA2
          MA2  = MA3
          MA3  = MAT
          MB1  = MOD(53*MB1+1,169)
          IF ( MOD(MB1*MAT,64).GE.32 ) S = S+T
   10   T = 0.5*T
   20 U(II2) = S
      C  =   362436.D0/16777216.D0
      CD =  7654321.D0/16777216.D0
      CM = 16777213.D0/16777216.D0
      RETURN
      END
*-- Author :
C==========================================================
      SUBROUTINE RNDMIN(UIN,CIN,CDIN,CMIN,IIN,JIN)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION UIN(97)
      COMMON /RANDOO/ U(97),C,CD,CM,I,J
      DO 10 KKK = 1,97
   10 U(KKK) = UIN(KKK)
      C  = CIN
      CD = CDIN
      CM = CMIN
      I  = IIN
      J  = JIN
      RETURN
      END
*-- Author :
C==========================================================
      SUBROUTINE RNDMOU(UOUT,COUT,CDOUT,CMOUT,IOUT,JOUT)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION UOUT(97)
      COMMON /RANDOO/ U(97),C,CD,CM,I,J
      DO 10 KKK = 1,97
   10 UOUT(KKK) = U(KKK)
      COUT  = C
      CDOUT = CD
      CMOUT = CM
      IOUT  = I
      JOUT  = J
      RETURN
      END
*-- Author :
C==========================================================
      SUBROUTINE RNDMTE(IO)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION UU(97),U(6),X(6),D(6)
      DATA U / 6533892.D0, 14220222.D0, 7275067.D0, 6172232.D0,
     +8354498.D0, 10633180.D0/
      CALL RNDMOU(UU,CC,CCD,CCM,II,JJ)
      CALL RNDMST(12,34,56,78)
      DO 10 II1 = 1,20000
   10 XX = RNDM(V)
      SD        = 0
      DO 20 II2 = 1,6
        X(II2)  = 4096.D0*(4096.D0*RNDM(V))
        D(II2)  = X(II2)-U(II2)
   20 SD = SD+D(II2)
      CALL RNDMIN(UU,CC,CCD,CCM,II,JJ)
C     IF ( IO.EQ. 1.OR. SD.NE.0. 0) WRITE(6,500) (U(I),X(I),D(I),I=1,6)
      RETURN
C==END OF RANDOM GENERATOR PACKAGE==========================
  500 FORMAT('  === TEST OF THE RANDOM-GENERATOR ===',/,
     +'    EXPECTED VALUE    CALCULATED VALUE     DIFFERENCE',/, 6(F17.
     +1,F20.1,F15.3,/), '  === END OF TEST ;',
     +'  GENERATOR HAS THE SAME STATUS AS BEFORE CALLING RNDMTE')
      END
*-- Author :
C   03/10/89 910141255  MEMBER NAME  KKEVT    (KK89.S)      F77
      SUBROUTINE RANNORR(X,Y)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C     X UND Y SIND GAUSSVERTEILTE ZUFALLSZAHLEN
      CALL DSFECF(SFE,CFE)
      A=SQRT(-2.D0*LOG(RNDM(V)))
      X=A*SFE
      Y=A*CFE
      RETURN
      END
*-- Author :
****************************************************** PLOT**********
*
      SUBROUTINE PLOT (X,Y,N,M,MM,XO,DX,YO,DY)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
*
*     initial version
*     J. Ranft, (FORTRAN-Programmierung,J.R.,Teubner, Leipzig, 72)
*     This is a subroutine of fluka to plot Y across the page
*     as a function of X down the page. Up to 37 curves can be
*     plotted in the same picture with different plotting characters.
*     Output of first 10 overprinted characters addad by FB 88
*  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
*
*     Input Variables:
*        X   = array containing the values of X
*        Y   = array containing the values of Y
*        N   = number of values in X and in Y
*              can exceed the fixed number of lines
*        M   = number of different curves X,Y are containing
*        MM  = number of points in each curve i.e. N=M*MM
*        XO  = smallest value of X to be plotted
*        DX  = increment of X between subsequent lines
*        YO  = smallest value of Y to be plotted
*        DY  = increment of Y between subsequent character spaces
*
*        other variables used inside:
*        XX  = numbers along the X-coordinate axis
*        YY  = numbers along the Y-coordinate axis
*        LL  = ten lines temporary storage for the plot
*        L   = character set used to plot different curves
*        LOV = memorizes overprinted symbols
*              the first 10 overprinted symbols are printed on
*              the end of the line to avoid ambiguities
*              (added by FB as considered quite helpful)
*
*********************************************************************
*
      DIMENSION XX(61),YY(61),LL(101,10)
      DIMENSION X(N),Y(N),L(40),LOV(40,10)
      DATA  L/
     11H*,1H2,1H3,1H4,1H5,1H6,1H7,1H8,1H9,1HZ,
     21H+,1HA,1HO,1HB,1HC,1HD,1HE,1HF,1HG,1HH,
     31HI,1HJ,1HK,1HL,1HM,1HN,1HO,1HP,1HQ,1HR,
     41HS,1HT,1HU,1HV,1HW,1HX,1HY,1H1,1H-,1H  /
*
*
      MN=51
      AMN=MN
      DO 10 I=1,MN
        AI=I-1
   10 XX(I)=XO+AI*DX
      DO 20 I=1,11
        AI=I-1
   20 YY(I)=YO+10.*AI*DY
      WRITE(6, 500) (YY(I),I=1,11)
      MMN=MN-1
*
*
      DO 90 JJ=1,MMN,10
        JJJ=JJ-1
        DO 30 I=1,101
          DO 30 J=1,10
   30   LL(I,J)=L(40)
        DO 40 I=1,101
   40   LL(I,1)=L(39)
        DO 50 I=1,101,10
          DO 50 J=1,10
   50   LL(I,J)=L(38)
        DO 60 I=1,40
          DO 60 J=1,10
   60   LOV(I,J)=L(40)
*
*
        DO 70 I=1,M
          DO 70 J=1,MM
            II=J+(I-1)*MM
            AIX=(X(II)-(XO-DX/2.))/DX+1.
            AIY=(Y(II)-(YO-DY/2.))/DY+1.
            AIX=AIX-FLOAT(JJJ)
*           changed Sept.88 by FB to avoid INTEGER OVERFLOW
            IF( AIX .GT. 1.D0.AND. AIX .LT. 11.D0.AND. AIY .GT. 1.D0.AND
     +      . AIY .LT. 102.D0) THEN
              IX=AIX
              IY=AIY
              IF( IX.GT. 0.AND. IX.LE. 10.AND. IY.GT. 0.AND. IY.LE. 101)
     +        THEN
                IF(LL(IY,IX).NE.L(38).AND.LL(IY,IX).NE.L(39)) LOV(I,IX)
     +          =LL(IY,IX)
                LL(IY,IX)=L(I)
              ENDIF
            ENDIF
   70   CONTINUE
*
*
        DO 80 I=1,10
          II=I+JJJ
          III=II+1
          WRITE(6,510) XX(II),XX(III) , (LL(J,I),J=1,101) , (LOV(J,I),J
     +    =1,10)
   80   CONTINUE
   90 CONTINUE
*
*
      WRITE(6, 520)
      WRITE(6, 500) (YY(I),I=1,11)
      RETURN
*
  500 FORMAT(11X,11(1PE10.2),11HOVERPRINTED)
  510 FORMAT(1X,2(1PE10.2),101A1,1H ,10A1)
  520 FORMAT(20X,10('1---------'),'1')
      END
*-- Author :
C
C++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      DOUBLE PRECISION FUNCTION DBETAR(GAM,ETA)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C
C********************************************************************
C
C     RANDOM NUMBER GENERATION FROM BETA
C     DISTRIBUTION IN REGION  0.LE.X.LE.1.
C     F(X) = X**(GAM-1.)*(1.-X)**(ETA-1)*GAMM(ETA+GAM) / (GAMM(GAM
C                                                        *GAMM(ETA))
C
C********************************************************************
C
      Y = DGAMRN(1.D0,GAM)
      Z = DGAMRN(1.D0,ETA)
      DBETAR = Y/(Y+Z)
      RETURN
      END
*-- Author :
      DOUBLE PRECISION FUNCTION DGAMRN(ALAM,ETA)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C
C********************************************************************
C
C     RANDOM NUMBER SELECTION FROM GAMMA DISTRIBUTION
C     F(X) = ALAM**ETA*X**(ETA-1)*EXP(-ALAM*X) / GAM(ETA)
C
C********************************************************************
C
      NCOU=0
      N = ETA
      F = ETA - N
      IF(F.EQ.0.D0)                                            GO TO 20
   10 R = RNDM(R)
      NCOU=NCOU+1
      IF (NCOU.GE.11)                                          GO TO 20
      IF(R.LT.F/(F+2.71828D0))                                 GO TO 30
      YYY=LOG(RNDM(Y)+1.0D-9)/F
      IF(ABS(YYY).GT.50.0D0)                                   GO TO 20
      Y = EXP(YYY)
      IF(LOG(RNDM(R)+1.0D-9).GT.-Y)                            GO TO 10
                                                               GO TO 40
   20 Y = 0
                                                               GO TO 50
   30 Y = 1.-LOG(RNDM(Y)+1.0D-9)
      IF(RNDM(R).GT.Y**(F-1.D0))                               GO TO 10
   40 IF(N.EQ.0)                                               GO TO 70
   50 Z = 1
      DO 60 I = 1,N
   60 Z = Z*RNDM(Z)
      Y = Y-LOG(Z+1.0D-9)
   70 DGAMRN = Y/ALAM
      RETURN
      END
*-- Author :
C*****************************************************************
      DOUBLE PRECISION FUNCTION BETREJ(GAM,ETA,XMIN,XMAX)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IF (XMIN.GE.XMAX)THEN
        WRITE (6,500)XMIN,XMAX
        STOP
      ENDIF
   10 CONTINUE
      XX=XMIN+(XMAX-XMIN)*RNDM(V)
      BETMAX=XMIN**(GAM-1.)*(1.-XMIN)**(ETA-1.)
      YY=BETMAX*RNDM(W)
      BETXX=XX**(GAM-1.)*(1.-XX)**(ETA-1.)
      IF(YY.GT.BETXX)                                           GO TO 10
      BETREJ=XX
      RETURN
  500 FORMAT(' XMIN<XMAX IN BETREJ STOP ',2F10.5)
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      FUNCTION MCIHAD(MCIND)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C*** CALCULATION OF THE PARTICLE INDEX ACCORDING TO THE PDG PROPOSAL.
C    MCIHAD PARTICLE NUMBER AS IN DECAY, BAMJET, HADEVT, FLUKA ETC.
C    MCIND  PDG PARTICLE NUMBER
      INTEGER HAMCIN
      COMMON /HAMCIN/ HAMCIN(410)
      IH=0
      MCIHAD=0
      IF((MCIND.EQ.0).OR.(MCIND.GT.70000))RETURN
      DO 10 I=1,410
        IH=I
        IF (HAMCIN(I).EQ.MCIND)                                 GO TO 20
   10 CONTINUE
   20 CONTINUE
      MCIHAD=IH
      RETURN
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      FUNCTION MPDGHA(MCIND)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C*** CALCULATION OF THE PARTICLE INDEX ACCORDING TO THE PDG PROPOSAL.
C    MCIND  PARTICLE NUMBER AS IN DECAY, BAMJET, HADEVT, FLUKA ETC.
C    MPDGHA PDG PARTICLE NUMBER
      INTEGER HAMCIN
      COMMON /HAMCIN/ HAMCIN(410)
      MPDGHA=HAMCIN(MCIND)
      RETURN
      END
*-- Author :
C---------------------------------
      BLOCK DATA RADINI
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      INTEGER HAMCIN
      COMMON /RHAMCIN/ HAMCIN(200)
      DATA HAMCIN/
     *2212,-2212,-11,11,12,   -12,22,2112,-2112,-13,
     *13,130,211,-211,321,   -321,3122,-3122,310,3112,
     *3222,3212,111,311,-311,   0,0,0,0,0,
     *221,213,113,-213,223,   323,313,-323,-313,99999,
     *99999,99999,99999,30323,30313,   -30323,-30313,3224,3214,3114,
     *3216,3218,2224,2214,2114,   1114,12224,12214,12114,11114,
     *12212,12112,22212,22112,99999,99999,-2224,-2214,-2114,-1114,
     *10*99999,
     *10*99999,
     *4*99999,331,333,3322,3312,-3222,-3212,
     *-3112,-3322,-3312,3224,3214,3114,3324,3314,3334,-3114,
     *-3214,-3224,-3324,-3314,-3334,421,411,-411,-421,431,
     *-431,441,8*99999,
     *6*99999,4122,4232,4132,4222,
     *4212,4112,6*99999,-4122,-4232,
     *-4132,-4222,-4212,-4112,6*99999,
     *40*99999/
      END


C**********************************************************************
      BLOCK DATA HADINI
C**********************************************************************
C
C     conversion table BAMJET --> PDG
C
C**********************************************************************
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
C  translation table version filled up by r.e. 25.01.94
      COMMON /HAMCIN/ IAMCIN(410)
C
      DATA IAMCIN /
     &2212,-2212,11,-11,12,              -12,22,2112,-2112,-13,
     &13,130,211,-211,321,               -321,3122,-3122,310,3112,
     &3222,3212,111,311,-311,            0,0,0,0,0,
     &221,213,113,-213,223,              323,313,-323,-313,10323,
     &10313,-10323,-10313,30323,30313,   -30323,-30313,3224,3214,3114,
     &3216,3218,2224,2214,2114,          1114,12224,12214,12114,11114,
     &12212,12112,22212,22112,32124,     31214,-2224,-2214,-2114,-1114,
     &-12224,-12214,-12114,-11114,-2124, -1214,4*99999,
     &5*99999,                           5*99999,
     &4*99999,331,                       333,3322,3312,-3222,-3212,
     &-3112,-3322,-3312,3224,3214,       3114,3324,3314,3334,-3224,
     &-3214,-3114,-3324,-3314,-3334,     421,411,-411,-421,431,
     &-431,441,423,413,-413,             -423,433,-433,20443,443,
     &-15,15,16,-16,14,                  -14,4122,4232,4132,4222,
     & 4212,4112,4322,4312,4332,          4422,4412,4432,-4122,-4232,
     & -4132,-4222,-4212,-4112,-4322,     -4312,-4332,-4422,-4412,-4432,
     & 4224,4214,4114,4324,4314,          4334,4424,4414,4434,4444,
     & -4224,-4214,-4114,-4324,-4314,     -4334,-4424,-4414,-4434,-4444,
     &5*99999 , 20211,20111,-20211,99999,20321,
     &-20321,20311,-20311,7*99999 ,
     &7*99999,12212,12112,99999,
     &115 ,215 ,-215 ,225 ,315 ,-315 ,325 ,-325 ,335 ,415 ,
     &-415 ,425 ,-425 ,435 ,-435 ,445 ,511 ,-511 ,513 ,-513 ,
     &515 ,-515 ,521 ,-521 ,523 ,-523 ,525 ,-525 ,531 ,-531 ,
     &533 ,-533 ,535 ,-535 ,551 ,553 ,555 ,661 ,663 ,665 ,
     &5112,-5112,5114,-5114,5122,-5122,5132,-5132,5212,-5212,
     &5214 ,-5214,5222,-5222,5224,-5224,5232,-5232,5312,-5312,
     &5314 ,-5314,5322,-5322,5324,-5324,5332,-5332,5334,-5334,
     &10111 ,10113,10211,-10211,10213,-10213,10221,10223,
     &10311,-10311,
     & 10321,-10321,10331,10333,10411,-10411,10413,-10413,
     &10421,-10421,
     & 10423,-10423,10431,-10431,10433,10433,10411,10443,
     &10511,-10511,
     & 10513,-10513,10521,-10521,10523,-10523,10531,-10531,
     &10533,-10533,
     & 10551,10553,10661,10663,20113,20213,-20213,20223,
     &20313,-20313,
     & 20323,-20323,20333,20413,-20413,20423,-20423,20433,
     &-20433,20443,
     & 20513,-20513,20523,-20523,20533,-20533,20553,20663,
     *99999,99999,
     &40*99999 ,
     &1,-1,2,-2,3,-3,4,-4,5,-5,
     &6,-6,21,23,24,-24,25,99999,99999,99999/
C
      END
C
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      FUNCTION MCHAD(ITDTU)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C*** CALCULATION OF THE PARTICLE INDEX TO BE USED FOR HADRIN
C                                        IN SECONDARY COLLISIONS
C    ITDTU  PARTICLE NUMBER AS IN DECAY, BAMJET, HADEVT, FLUKA ETC.
C    MCHAD  PARTICLE NUMBER TO BE USED IN HADRIN
      DIMENSION ITRANS(210)
      DATA ITRANS / 1, 2, -1, -1, -1, -1, -1, 8, 9, -1, -1, 24, 13, 14,
     +15, 16, 8, 9, 25, 8, 1, 8, 23, 24, 25, -1, -1, -1, -1, -1, 23, 13,
     +23, 14, 23, 15, 24, 16, 25, 15, 24, 16, 25, 15, 24, 16, 25, 1, 8,
     +8, 8, 1, 1, 1, 8, 8, 1, 1, 8, 8, 1, 8, 1, 8, 1, 8, 2, 2, 9, 9, 2,
     +2, 9, 9, 2, 9, 1, 13, 23, 14, 1, 1, 8, 8, 1, 1, 23, 14, 1, 8, 1,
     +8, 1, 8, 23, 23, 8, 8, 2, 9, 9, 9, 9, 1, 8, 8, 8, 8, 8, 2, 9, 9,
     +9, 9, 9, 85*- 1,7*-1,1,8,-1/
C
      MCHAD=ITRANS(ITDTU)
      RETURN
      END
*-- Author :
C
C++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE  DTRANS(XO,YO,ZO,CDE,SDE,SFE,CFE,X,Y,Z)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C  NEW TRANS VERSION OCTOBER 1987  J.RANFT
C  ROTATION OF COORDINATE FRAME (1) DE RORATION AROUND Y AXIS
C                               (2) FE ROTATION AROUND Z AXIS
      X= CDE*CFE*XO-SFE*YO+SDE*CFE*ZO
      Y= CDE*SFE*XO+CFE*YO+SDE*SFE*ZO
      Z=-SDE    *XO       +CDE    *ZO
      RETURN
      END
*-- Author :
C
C++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C     SUBROUTINE DALTRA(GA,BGX,BGY,BGZ,PCX,PCY,PCZ,EC,P,PX,PY,PZ,E)
C     IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C*** ARBITRARY LORENTZ T\RANSFORM
C     HUGE=1.D15
C     EP=PCX*BGX+PCY*BGY+PCZ*BGZ
C     PE=EP/(GA+1.)+EC
C     PX=PC X+BG X*PE
C     PY=PC Y+BG Y*PE
C     PZ=PC Z+BG Z*PE
C     PX=MIN(HUGE,MAX(-HUGE,P X))
C     PY=MIN(HUGE,MAX(-HUGE,P Y))
C     PZ=MIN(HUGE,MAX(-HUGE,P Z))
C     P=SQRT(PX*PX+PY*PY+PZ*PZ)
C     E=GA*EC+EP
C     RETURN
C     END
*===daltra=============================================================*
*
      SUBROUTINE DALTRA(GA,BGX,BGY,BGZ,PCX,PCY,PCZ,EC,P,PX,PY,PZ,E)
 
************************************************************************
* Arbitrary Lorentz-transformation.                                    *
* Adopted from the original by S. Roesler. This version dated 15.01.95 *
************************************************************************
 
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      PARAMETER (HUGE=1.0D50,ONE=1.0D0)
 
      EP = PCX*BGX+PCY*BGY+PCZ*BGZ
      PE = EP/(GA+ONE)+EC
      PX = PCX+BGX*PE
      PY = PCY+BGY*PE
      PZ = PCZ+BGZ*PE
      PX = MIN(HUGE,MAX(-HUGE,PX))
      PY = MIN(HUGE,MAX(-HUGE,PY))
      PZ = MIN(HUGE,MAX(-HUGE,PZ))
      P  = SQRT(PX*PX+PY*PY+PZ*PZ)
      E  = GA*EC+EP
 
      RETURN
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE FALTRA(GA,BGA,CX,CY,CZ,COD,COF,SIF,PC,EC,P,PX,PY,PZ,E)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      BGX=BGA*CX
      BGY=BGA*CY
      BGZ=BGA*CZ
      COD2=COD*COD
      IF (COD2.GT.0.999999D0) COD2=0.999999D0
      SID=SQRT(1.-COD2)*PC
      PCX=SID*COF
      PCY=SID*SIF
      PCZ=COD*PC
      EP=PCX*BGX+PCY*BGY+PCZ*BGZ
      PE=EP/(GA+1.)+EC
      PX=PCX+BGX*PE
      PY=PCY+BGY*PE
      PZ=PCZ+BGZ*PE
      P=SQRT(PX*PX+PY*PY+PZ*PZ)
      PM=1./P
      PX=PX*PM
      PY=PY*PM
      PZ=PZ*PM
      E=GA*EC+EP
      RETURN
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE DPOLI(CS,SI)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      U=RNDM(V)
      CS=RNDM(VV)
      IF (U.LT.0.5D0) CS=-CS
      SI=SQRT(1.-CS*CS+1.D-10)
      RETURN
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE DFERMI(GPART)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION G(3)
      DO 10 I=1,3
        G(I)=RNDM(G(I))
   10 CONTINUE
C
C      FIND LARGEST OF 3 RANDOM NUMBERS
C
      IF (G(3).LT.G(2))                                         GO TO 40
      IF (G(3).LT.G(1))                                         GO TO 30
      GPART=G(3)
   20 RETURN
   30 GPART=G(1)
                                                                GO TO 20
   40 IF (G(2).LT.G(1))                                         GO TO 30
      GPART=G(2)
                                                                GO TO 20
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C--------------------------------------------------------------
C
C                             GQUAD.FOR
C
C----------------------------------------------------------------
      DOUBLE PRECISION FUNCTION GQUAD(F,AX,BX,NX)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C     N-POINT GAUSSIAN QUADRATURE OF FUNCTION F OVER INTERVAL (AX,BX).
C
      EXTERNAL F
      COMMON /GQCOM/A(273),X(273),KTAB(96)
C
      CALL D106BD
C-----TEST N
      N=NX
      ALPHA=0.5*(BX+AX)
      BETA=0.5*(BX-AX)
      IF(N.LT.1)                                                GO TO 50
      IF(N.NE.1)                                                GO TO 10
      GQUAD=(BX-AX)*F(ALPHA)
      RETURN
C
   10 IF(N.LE.16)                                               GO TO 20
      IF(N.EQ.20)                                               GO TO 20
      IF(N.EQ.24)                                               GO TO 20
      IF(N.EQ.32)                                               GO TO 20
      IF(N.EQ.40)                                               GO TO 20
      IF(N.EQ.48)                                               GO TO 20
      IF(N.EQ.64)                                               GO TO 20
      IF(N.EQ.80)                                               GO TO 20
      IF(N.EQ.96)                                               GO TO 20
                                                                GO TO 50
C
C----- SET K EQUAL TO INITIAL SUBSCRIPT AND INTEGRATE
   20 K=KTAB(N)
      M=N/2
      SUM=0.0
      JMAX=K-1+M
C
      DO 30 J=K,JMAX
        DELTA=BETA*X(J)
        SUM=SUM+A(J)*(F(ALPHA+DELTA)+F(ALPHA-DELTA))
   30 CONTINUE
C
      IF(N-M-M.EQ.0)                                            GO TO 40
      JMID=K+M
      SUM=SUM+A(JMID)*F(ALPHA)
   40 GQUAD=BETA*SUM
      RETURN
C
   50 GQUAD=0.0
      ZN=N
      WRITE(6, 500)ZN
      RETURN
C
  500 FORMAT( 42H GQUAD ... N HAS THE NON-PERMISSIBLE VALUE ,E11. 3)
      END
*-- Author :
      SUBROUTINE GSET(AX,BX,NX,Z,W)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C     N-POINT GAUSS ZEROS AND WEIGHTS FOR THE INTERVAL (AX,BX) ARE
C           STORED IN  ARRAYS Z AND W RESPECTIVELY.
C
      COMMON /GQCOM/A(273),X(273),KTAB(96)
      DIMENSION Z(192),W(192)
C
      CALL D106BD
C-----TEST N
      N=NX
      ALPHA=0.5*(BX+AX)
      BETA=0.5*(BX-AX)
      IF(N.LT.1)                                                GO TO 40
      IF(N.NE.1)                                                GO TO 10
      Z(1)=ALPHA
      W(1)=BX-AX
      RETURN
C
   10 IF(N.LE.16)                                               GO TO 20
      IF(N.EQ.20)                                               GO TO 20
      IF(N.EQ.24)                                               GO TO 20
      IF(N.EQ.32)                                               GO TO 20
      IF(N.EQ.40)                                               GO TO 20
      IF(N.EQ.48)                                               GO TO 20
      IF(N.EQ.64)                                               GO TO 20
      IF(N.EQ.80)                                               GO TO 20
      IF(N.EQ.96)                                               GO TO 20
                                                                GO TO 40
C
C----- SET K EQUAL TO INITIAL SUBSCRIPT AND STORE RESULTS
   20 K=KTAB(N)
      M=N/2
C
      DO 30 J=1,M
        JTAB=K-1+J
        WTEMP=BETA*A(JTAB)
        DELTA=BETA*X(JTAB)
        Z(J)=ALPHA-DELTA
        W(J)=WTEMP
        JP=N+1-J
        Z(JP)=ALPHA+DELTA
        W(JP)=WTEMP
   30 CONTINUE
C
      IF((N-M-M).EQ.0) RETURN
      Z(M+1)=ALPHA
      JMID=K+M
      W(M+1)=BETA*A(JMID)
      RETURN
C
   40 ZN=N
      WRITE(6, 500)ZN
      RETURN
C
  500 FORMAT( 41H GSET ... N HAS THE NON-PERMISSIBLE VALUE ,E11. 3)
      END
*-- Author :
      SUBROUTINE D106BD
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      COMMON /GQCOM/ B(273),Y(273),LTAB(96)
      DIMENSION      A(273),X(273),KTAB(96)
C
C-----TABLE OF INITIAL SUBSCRIPTS FOR N=2(1)16(4)96
      DATA KTAB(2)/1/
      DATA KTAB(3)/2/
      DATA KTAB(4)/4/
      DATA KTAB(5)/6/
      DATA KTAB(6)/9/
      DATA KTAB(7)/12/
      DATA KTAB(8)/16/
      DATA KTAB(9)/20/
      DATA KTAB(10)/25/
      DATA KTAB(11)/30/
      DATA KTAB(12)/36/
      DATA KTAB(13)/42/
      DATA KTAB(14)/49/
      DATA KTAB(15)/56/
      DATA KTAB(16)/64/
      DATA KTAB(20)/72/
      DATA KTAB(24)/82/
      DATA KTAB(28)/82/
      DATA KTAB(32)/94/
      DATA KTAB(36)/94/
      DATA KTAB(40)/110/
      DATA KTAB(44)/110/
      DATA KTAB(48)/130/
      DATA KTAB(52)/130/
      DATA KTAB(56)/130/
      DATA KTAB(60)/130/
      DATA KTAB(64)/154/
      DATA KTAB(68)/154/
      DATA KTAB(72)/154/
      DATA KTAB(76)/154/
      DATA KTAB(80)/186/
      DATA KTAB(84)/186/
      DATA KTAB(88)/186/
      DATA KTAB(92)/186/
      DATA KTAB(96)/226/
C
C-----TABLE OF ABSCISSAE (X) AND WEIGHTS (A) FOR INTERVAL (-1,+1).
C
C-----N=2
      DATA X(1)/0.577350269189626  /, A(1)/1.000000000000000  /
C-----N=3
      DATA X(2)/0.774596669241483  /, A(2)/0.555555555555556  /
      DATA X(3)/0.000000000000000  /, A(3)/0.888888888888889  /
C-----N=4
      DATA X(4)/0.861136311594053  /, A(4)/0.347854845137454  /
      DATA X(5)/0.339981043584856  /, A(5)/0.652145154862546  /
C-----N=5
      DATA X(6)/0.906179845938664  /, A(6)/0.236926885056189  /
      DATA X(7)/0.538469310105683  /, A(7)/0.478628670499366  /
      DATA X(8)/0.000000000000000  /, A(8)/0.568888888888889  /
C-----N=6
      DATA X(9)/0.932469514203152  /, A(9)/0.171324492379170  /
      DATA X(10)/0.661209386466265 /, A(10)/0.360761573048139 /
      DATA X(11)/0.238619186083197 /, A(11)/0.467913934572691 /
C-----N=7
      DATA X(12)/0.949107912342759 /, A(12)/0.129484966168870 /
      DATA X(13)/0.741531185599394 /, A(13)/0.279705391489277 /
      DATA X(14)/0.405845151377397 /, A(14)/0.381830050505119 /
      DATA X(15)/0.000000000000000 /, A(15)/0.417959183673469 /
C-----N=8
      DATA X(16)/0.960289856497536 /, A(16)/0.101228536290376 /
      DATA X(17)/0.796666477413627 /, A(17)/0.222381034453374 /
      DATA X(18)/0.525532409916329 /, A(18)/0.313706645877887 /
      DATA X(19)/0.183434642495650 /, A(19)/0.362683783378362 /
C-----N=9
      DATA X(20)/0.968160239507626 /, A(20)/0.081274388361574 /
      DATA X(21)/0.836031107326636 /, A(21)/0.180648160694857 /
      DATA X(22)/0.613371432700590 /, A(22)/0.260610696402935 /
      DATA X(23)/0.324253423403809 /, A(23)/0.312347077040003 /
      DATA X(24)/0.000000000000000 /, A(24)/0.330239355001260 /
C-----N=10
      DATA X(25)/0.973906528517172 /, A(25)/0.066671344308688 /
      DATA X(26)/0.865063366688985 /, A(26)/0.149451349150581 /
      DATA X(27)/0.679409568299024 /, A(27)/0.219086362515982 /
      DATA X(28)/0.433395394129247 /, A(28)/0.269266719309996 /
      DATA X(29)/0.148874338981631 /, A(29)/0.295524224714753 /
C-----N=11
      DATA X(30)/0.978228658146057 /, A(30)/0.055668567116174 /
      DATA X(31)/0.887062599768095 /, A(31)/0.125580369464905 /
      DATA X(32)/0.730152005574049 /, A(32)/0.186290210927734 /
      DATA X(33)/0.519096129206812 /, A(33)/0.233193764591990 /
      DATA X(34)/0.269543155952345 /, A(34)/0.262804544510247 /
      DATA X(35)/0.000000000000000 /, A(35)/0.272925086777901 /
C-----N=12
      DATA X(36)/0.981560634246719 /, A(36)/0.047175336386512 /
      DATA X(37)/0.904117256370475 /, A(37)/0.106939325995318 /
      DATA X(38)/0.769902674194305 /, A(38)/0.160078328543346 /
      DATA X(39)/0.587317954286617 /, A(39)/0.203167426723066 /
      DATA X(40)/0.367831498998180 /, A(40)/0.233492536538355 /
      DATA X(41)/0.125233408511469 /, A(41)/0.249147045813403 /
C-----N=13
      DATA X(42)/0.984183054718588 /, A(42)/0.040484004765316 /
      DATA X(43)/0.917598399222978 /, A(43)/0.092121499837728 /
      DATA X(44)/0.801578090733310 /, A(44)/0.138873510219787 /
      DATA X(45)/0.642349339440340 /, A(45)/0.178145980761946 /
      DATA X(46)/0.448492751036447 /, A(46)/0.207816047536889 /
      DATA X(47)/0.230458315955135 /, A(47)/0.226283180262897 /
      DATA X(48)/0.000000000000000 /, A(48)/0.232551553230874 /
C-----N=14
      DATA X(49)/0.986283808696812 /, A(49)/0.035119460331752 /
      DATA X(50)/0.928434883663574 /, A(50)/0.080158087159760 /
      DATA X(51)/0.827201315069765 /, A(51)/0.121518570687903 /
      DATA X(52)/0.687292904811685 /, A(52)/0.157203167158194 /
      DATA X(53)/0.515248636358154 /, A(53)/0.185538397477938 /
      DATA X(54)/0.319112368927890 /, A(54)/0.205198463721296 /
      DATA X(55)/0.108054948707344 /, A(55)/0.215263853463158 /
C-----N=15
      DATA X(56)/0.987992518020485 /, A(56)/0.030753241996117 /
      DATA X(57)/0.937273392400706 /, A(57)/0.070366047488108 /
      DATA X(58)/0.848206583410427 /, A(58)/0.107159220467172 /
      DATA X(59)/0.724417731360170 /, A(59)/0.139570677926154 /
      DATA X(60)/0.570972172608539 /, A(60)/0.166269205816994 /
      DATA X(61)/0.394151347077563 /, A(61)/0.186161000015562 /
      DATA X(62)/0.201194093997435 /, A(62)/0.198431485327111 /
      DATA X(63)/0.000000000000000 /, A(63)/0.202578241925561 /
C-----N=16
      DATA X(64)/0.989400934991650 /, A(64)/0.027152459411754 /
      DATA X(65)/0.944575023073233 /, A(65)/0.062253523938648 /
      DATA X(66)/0.865631202387832 /, A(66)/0.095158511682493 /
      DATA X(67)/0.755404408355003 /, A(67)/0.124628971255534 /
      DATA X(68)/0.617876244402644 /, A(68)/0.149595988816577 /
      DATA X(69)/0.458016777657227 /, A(69)/0.169156519395003 /
      DATA X(70)/0.281603550779259 /, A(70)/0.182603415044924 /
      DATA X(71)/0.095012509837637 /, A(71)/0.189450610455069 /
C-----N=20
      DATA X(72)/0.993128599185094 /, A(72)/0.017614007139152 /
      DATA X(73)/0.963971927277913 /, A(73)/0.040601429800386 /
      DATA X(74)/0.912234428251325 /, A(74)/0.062672048334109 /
      DATA X(75)/0.839116971822218 /, A(75)/0.083276741576704 /
      DATA X(76)/0.746331906460150 /, A(76)/0.101930119817240 /
      DATA X(77)/0.636053680726515 /, A(77)/0.118194531961518 /
      DATA X(78)/0.510867001950827 /, A(78)/0.131688638449176 /
      DATA X(79)/0.373706088715419 /, A(79)/0.142096109318382 /
      DATA X(80)/0.227785851141645 /, A(80)/0.149172986472603 /
      DATA X(81)/0.076526521133497 /, A(81)/0.152753387130725 /
C-----N=24
      DATA X(82)/0.995187219997021 /, A(82)/0.012341229799987 /
      DATA X(83)/0.974728555971309 /, A(83)/0.028531388628933 /
      DATA X(84)/0.938274552002732 /, A(84)/0.044277438817419 /
      DATA X(85)/0.886415527004401 /, A(85)/0.059298584915436 /
      DATA X(86)/0.820001985973902 /, A(86)/0.073346481411080 /
      DATA X(87)/0.740124191578554 /, A(87)/0.086190161531953 /
      DATA X(88)/0.648093651936975 /, A(88)/0.097618652104113 /
      DATA X(89)/0.545421471388839 /, A(89)/0.107444270115965 /
      DATA X(90)/0.433793507626045 /, A(90)/0.115505668053725 /
      DATA X(91)/0.315042679696163 /, A(91)/0.121670472927803 /
      DATA X(92)/0.191118867473616 /, A(92)/0.125837456346828 /
      DATA X(93)/0.064056892862605 /, A(93)/0.127938195346752 /
C-----N=32
      DATA X(94)/0.997263861849481 /, A(94)/0.007018610009470 /
      DATA X(95)/0.985611511545268 /, A(95)/0.016274394730905 /
      DATA X(96)/0.964762255587506 /, A(96)/0.025392065309262 /
      DATA X(97)/0.934906075937739 /, A(97)/0.034273862913021 /
      DATA X(98)/0.896321155766052 /, A(98)/0.042835898022226 /
      DATA X(99)/0.849367613732569 /, A(99)/0.050998059262376 /
      DATA X(100)/0.794483795967942/, A(100)/0.058684093478535/
      DATA X(101)/0.732182118740289/, A(101)/0.065822222776361/
      DATA X(102)/0.663044266930215/, A(102)/0.072345794108848/
      DATA X(103)/0.587715757240762/, A(103)/0.078193895787070/
      DATA X(104)/0.506899908932229/, A(104)/0.083311924226946/
      DATA X(105)/0.421351276130635/, A(105)/0.087652093004403/
      DATA X(106)/0.331868602282127/, A(106)/0.091173878695763/
      DATA X(107)/0.239287362252137/, A(107)/0.093844399080804/
      DATA X(108)/0.144471961582796/, A(108)/0.095638720079274/
      DATA X(109)/0.048307665687738/, A(109)/0.096540088514727/
C-----N=40
      DATA X(110)/0.998237709710559/, A(110)/0.004521277098533/
      DATA X(111)/0.990726238699457/, A(111)/0.010498284531152/
      DATA X(112)/0.977259949983774/, A(112)/0.016421058381907/
      DATA X(113)/0.957916819213791/, A(113)/0.022245849194166/
      DATA X(114)/0.932812808278676/, A(114)/0.027937006980023/
      DATA X(115)/0.902098806968874/, A(115)/0.033460195282547/
      DATA X(116)/0.865959503212259/, A(116)/0.038782167974472/
      DATA X(117)/0.824612230833311/, A(117)/0.043870908185673/
      DATA X(118)/0.778305651426519/, A(118)/0.048695807635072/
      DATA X(119)/0.727318255189927/, A(119)/0.053227846983936/
      DATA X(120)/0.671956684614179/, A(120)/0.057439769099391/
      DATA X(121)/0.612553889667980/, A(121)/0.061306242492928/
      DATA X(122)/0.549467125095128/, A(122)/0.064804013456601/
      DATA X(123)/0.483075801686178/, A(123)/0.067912045815233/
      DATA X(124)/0.413779204371605/, A(124)/0.070611647391286/
      DATA X(125)/0.341994090825758/, A(125)/0.072886582395804/
      DATA X(126)/0.268152185007253/, A(126)/0.074723169057968/
      DATA X(127)/0.192697580701371/, A(127)/0.076110361900626/
      DATA X(128)/0.116084070675255/, A(128)/0.077039818164247/
      DATA X(129)/0.038772417506050/, A(129)/0.077505947978424/
C-----N=48
      DATA X(130)/0.998771007252426/, A(130)/0.003153346052305/
      DATA X(131)/0.993530172266350/, A(131)/0.007327553901276/
      DATA X(132)/0.984124583722826/, A(132)/0.011477234579234/
      DATA X(133)/0.970591592546247/, A(133)/0.015579315722943/
      DATA X(134)/0.952987703160430/, A(134)/0.019616160457355/
      DATA X(135)/0.931386690706554/, A(135)/0.023570760839324/
      DATA X(136)/0.905879136715569/, A(136)/0.027426509708356/
      DATA X(137)/0.876572020274247/, A(137)/0.031167227832798/
      DATA X(138)/0.843588261624393/, A(138)/0.034777222564770/
      DATA X(139)/0.807066204029442/, A(139)/0.038241351065830/
      DATA X(140)/0.767159032515740/, A(140)/0.041545082943464/
      DATA X(141)/0.724034130923814/, A(141)/0.044674560856694/
      DATA X(142)/0.677872379632663/, A(142)/0.047616658492490/
      DATA X(143)/0.628867396776513/, A(143)/0.050359035553854/
      DATA X(144)/0.577224726083972/, A(144)/0.052890189485193/
      DATA X(145)/0.523160974722233/, A(145)/0.055199503699984/
      DATA X(146)/0.466902904750958/, A(146)/0.057277292100403/
      DATA X(147)/0.408686481990716/, A(147)/0.059114839698395/
      DATA X(148)/0.348755886292160/, A(148)/0.060704439165893/
      DATA X(149)/0.287362487355455/, A(149)/0.062039423159892/
      DATA X(150)/0.224763790394689/, A(150)/0.063114192286254/
      DATA X(151)/0.161222356068891/, A(151)/0.063924238584648/
      DATA X(152)/0.097004699209462/, A(152)/0.064466164435950/
      DATA X(153)/0.032380170962869/, A(153)/0.064737696812683/
C-----N=64
      DATA X(154)/0.999305041735772/, A(154)/0.001783280721696/
      DATA X(155)/0.996340116771955/, A(155)/0.004147033260562/
      DATA X(156)/0.991013371476744/, A(156)/0.006504457968978/
      DATA X(157)/0.983336253884625/, A(157)/0.008846759826363/
      DATA X(158)/0.973326827789910/, A(158)/0.011168139460131/
      DATA X(159)/0.961008799652053/, A(159)/0.013463047896718/
      DATA X(160)/0.946411374858402/, A(160)/0.015726030476024/
      DATA X(161)/0.929569172131939/, A(161)/0.017951715775697/
      DATA X(162)/0.910522137078502/, A(162)/0.020134823153530/
      DATA X(163)/0.889315445995114/, A(163)/0.022270173808383/
      DATA X(164)/0.865999398154092/, A(164)/0.024352702568710/
      DATA X(165)/0.840629296252580/, A(165)/0.026377469715054/
      DATA X(166)/0.813265315122797/, A(166)/0.028339672614259/
      DATA X(167)/0.783972358943341/, A(167)/0.030234657072402/
      DATA X(168)/0.752819907260531/, A(168)/0.032057928354851/
      DATA X(169)/0.719881850171610/, A(169)/0.033805161837141/
      DATA X(170)/0.685236313054233/, A(170)/0.035472213256882/
      DATA X(171)/0.648965471254657/, A(171)/0.037055128540240/
      DATA X(172)/0.611155355172393/, A(172)/0.038550153178615/
      DATA X(173)/0.571895646202634/, A(173)/0.039953741132720/
      DATA X(174)/0.531279464019894/, A(174)/0.041262563242623/
      DATA X(175)/0.489403145707052/, A(175)/0.042473515123653/
      DATA X(176)/0.446366017253464/, A(176)/0.043583724529323/
      DATA X(177)/0.402270157963991/, A(177)/0.044590558163756/
      DATA X(178)/0.357220158337668/, A(178)/0.045491627927418/
      DATA X(179)/0.311322871990210/, A(179)/0.046284796581314/
      DATA X(180)/0.264687162208767/, A(180)/0.046968182816210/
      DATA X(181)/0.217423643740007/, A(181)/0.047540165714830/
      DATA X(182)/0.169644420423992/, A(182)/0.047999388596458/
      DATA X(183)/0.121462819296120/, A(183)/0.048344762234802/
      DATA X(184)/0.072993121787799/, A(184)/0.048575467441503/
      DATA X(185)/0.024350292663424/, A(185)/0.048690957009139/
C-----N=80
      DATA X(186)/0.999553822651630/, A(186)/0.001144950003186/
      DATA X(187)/0.997649864398237/, A(187)/0.002663533589512/
      DATA X(188)/0.994227540965688/, A(188)/0.004180313124694/
      DATA X(189)/0.989291302499755/, A(189)/0.005690922451403/
      DATA X(190)/0.982848572738629/, A(190)/0.007192904768117/
      DATA X(191)/0.974909140585727/, A(191)/0.008683945269260/
      DATA X(192)/0.965485089043799/, A(192)/0.010161766041103/
      DATA X(193)/0.954590766343634/, A(193)/0.011624114120797/
      DATA X(194)/0.942242761309872/, A(194)/0.013068761592401/
      DATA X(195)/0.928459877172445/, A(195)/0.014493508040509/
      DATA X(196)/0.913263102571757/, A(196)/0.015896183583725/
      DATA X(197)/0.896675579438770/, A(197)/0.017274652056269/
      DATA X(198)/0.878722567678213/, A(198)/0.018626814208299/
      DATA X(199)/0.859431406663111/, A(199)/0.019950610878141/
      DATA X(200)/0.838831473580255/, A(200)/0.021244026115782/
      DATA X(201)/0.816954138681463/, A(201)/0.022505090246332/
      DATA X(202)/0.793832717504605/, A(202)/0.023731882865930/
      DATA X(203)/0.769502420135041/, A(203)/0.024922535764115/
      DATA X(204)/0.744000297583597/, A(204)/0.026075235767565/
      DATA X(205)/0.717365185362099/, A(205)/0.027188227500486/
      DATA X(206)/0.689637644342027/, A(206)/0.028259816057276/
      DATA X(207)/0.660859898986119/, A(207)/0.029288369583267/
      DATA X(208)/0.631075773046871/, A(208)/0.030272321759557/
      DATA X(209)/0.600330622829751/, A(209)/0.031210174188114/
      DATA X(210)/0.568671268122709/, A(210)/0.032100498673487/
      DATA X(211)/0.536145920897131/, A(211)/0.032941939397645/
      DATA X(212)/0.502804111888784/, A(212)/0.033733214984611/
      DATA X(213)/0.468696615170544/, A(213)/0.034473120451753/
      DATA X(214)/0.433875370831756/, A(214)/0.035160529044747/
      DATA X(215)/0.398393405881969/, A(215)/0.035794393953416/
      DATA X(216)/0.362304753499487/, A(216)/0.036373749905835/
      DATA X(217)/0.325664370747701/, A(217)/0.036897714638276/
      DATA X(218)/0.288528054884511/, A(218)/0.037365490238730/
      DATA X(219)/0.250952358392272/, A(219)/0.037776364362001/
      DATA X(220)/0.212994502857666/, A(220)/0.038129711314477/
      DATA X(221)/0.174712291832646/, A(221)/0.038424993006959/
      DATA X(222)/0.136164022809143/, A(222)/0.038661759774076/
      DATA X(223)/0.097408398441584/, A(223)/0.038839651059051/
      DATA X(224)/0.058504437152420/, A(224)/0.038958395962769/
      DATA X(225)/0.019511383256793/, A(225)/0.039017813656306/
C-----N=96
      DATA X(226)/0.999689503883230/, A(226)/0.000796792065552/
      DATA X(227)/0.998364375863181/, A(227)/0.001853960788946/
      DATA X(228)/0.995981842987209/, A(228)/0.002910731817934/
      DATA X(229)/0.992543900323762/, A(229)/0.003964554338444/
      DATA X(230)/0.988054126329623/, A(230)/0.005014202742927/
      DATA X(231)/0.982517263563014/, A(231)/0.006058545504235/
      DATA X(232)/0.975939174585136/, A(232)/0.007096470791153/
      DATA X(233)/0.968326828463264/, A(233)/0.008126876925698/
      DATA X(234)/0.959688291448742/, A(234)/0.009148671230783/
      DATA X(235)/0.950032717784437/, A(235)/0.010160770535008/
      DATA X(236)/0.939370339752755/, A(236)/0.011162102099838/
      DATA X(237)/0.927712456722308/, A(237)/0.012151604671088/
      DATA X(238)/0.915071423120898/, A(238)/0.013128229566961/
      DATA X(239)/0.901460635315852/, A(239)/0.014090941772314/
      DATA X(240)/0.886894517402420/, A(240)/0.015038721026994/
      DATA X(241)/0.871388505909296/, A(241)/0.015970562902562/
      DATA X(242)/0.854959033434601/, A(242)/0.016885479864245/
      DATA X(243)/0.837623511228187/, A(243)/0.017782502316045/
      DATA X(244)/0.819400310737931/, A(244)/0.018660679627411/
      DATA X(245)/0.800308744139140/, A(245)/0.019519081140145/
      DATA X(246)/0.780369043867433/, A(246)/0.020356797154333/
      DATA X(247)/0.759602341176647/, A(247)/0.021172939892191/
      DATA X(248)/0.738030643744400/, A(248)/0.021966644438744/
      DATA X(249)/0.715676812348967/, A(249)/0.022737069658329/
      DATA X(250)/0.692564536642171/, A(250)/0.023483399085926/
      DATA X(251)/0.668718310043916/, A(251)/0.024204841792364/
      DATA X(252)/0.644163403784967/, A(252)/0.024900633222483/
      DATA X(253)/0.618925840125468/, A(253)/0.025570036005349/
      DATA X(254)/0.593032364777572/, A(254)/0.026212340735672/
      DATA X(255)/0.566510418561397/, A(255)/0.026826866725591/
      DATA X(256)/0.539388108324357/, A(256)/0.027412962726029/
      DATA X(257)/0.511694177154667/, A(257)/0.027970007616848/
      DATA X(258)/0.483457973920596/, A(258)/0.028497411065085/
      DATA X(259)/0.454709422167743/, A(259)/0.028994614150555/
      DATA X(260)/0.425478988407300/, A(260)/0.029461089958167/
      DATA X(261)/0.395797649828908/, A(261)/0.029896344136328/
      DATA X(262)/0.365696861472313/, A(262)/0.030299915420827/
      DATA X(263)/0.335208522892625/, A(263)/0.030671376123669/
      DATA X(264)/0.304364944354496/, A(264)/0.031010332586313/
      DATA X(265)/0.273198812591049/, A(265)/0.031316425596861/
      DATA X(266)/0.241743156163840/, A(266)/0.031589330770727/
      DATA X(267)/0.210031310460567/, A(267)/0.031828758894411/
      DATA X(268)/0.178096882367618/, A(268)/0.032034456231992/
      DATA X(269)/0.145973714654896/, A(269)/0.032206204794030/
      DATA X(270)/0.113695850110665/, A(270)/0.032343822568575/
      DATA X(271)/0.081297495464425/, A(271)/0.032447163714064/
      DATA X(272)/0.048812985136049/, A(272)/0.032516118713868/
      DATA X(273)/0.016276744849602/, A(273)/0.032550614492363/
      DATA IBD/0/
      IF(IBD.NE.0) RETURN
      IBD=1
      DO 10 I=1,273
        B(I) = A(I)
   10 Y(I) = X(I)
      DO 20 I=1,96
   20 LTAB(I) = KTAB(I)
      RETURN
      END
*-- Author :
C*********************************************************************
      DOUBLE PRECISION FUNCTION SAMSQX(X1,X2)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
C                       SAMPLING FROM F(X)=1/X**0.5 BETWEEN X1 AND X2
      R=RNDM(V)
      SAMSQX=(R*SQRT(X2)+(1.D0-R)*SQRT(X1))**2
      RETURN
      END
C*********************************************************************
      DOUBLE PRECISION FUNCTION SAMPEY(X1,X2)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DATA ISAMPE/1/
C                             SAMPLING FROM F(X)=1/X BETWEEN X1 AND X2
        R=RNDM(V)
        AL1=LOG(X1)
        AL2=LOG(X2)
        SAMPEY=EXP((1.-R)*AL1+R*AL2)
      RETURN
      END
C*********************************************************************
      DOUBLE PRECISION FUNCTION SAMPEX(X1,X2)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DATA ISAMPE/1/
      SAVE
C                             SAMPLING FROM F(X)=1/X BETWEEN X1 AND X2
      IF(ISAMPE.EQ.0)THEN
        R=RNDM(V)
        AL1=LOG(X1)
        AL2=LOG(X2)
        SAMPEX=EXP((1.-R)*AL1+R*AL2)
      ELSEIF(ISAMPE.EQ.1)THEN
	SAMPEX=SAMSQX(X1,X2)
      ENDIF
      RETURN
      END
C*********************************************************************
      DOUBLE PRECISION FUNCTION SAMPXB(X1,X2,B)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C      Sampling x values between x1 and x2 from
C      f(x)=1./SQRT(X**2+B**2)
C
      A1=LOG(X1+SQRT(X1**2+B**2))
      A2=LOG(X2+SQRT(X2**2+B**2))
      AN=A2-A1
      A=AN*RNDM(V)+A1
      BB=EXP(A)
      SAMPXB=(BB**2-B**2)/(2.*BB)
      RETURN
      END
C
      SUBROUTINE SORTI(A,N)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION A(N)
      M=N
   10 CONTINUE
      M=N-1
      IF(M.LE.0) RETURN
      L=0
      DO 20 I=1,M
        J=I+1
        IF (A(I).LE.A(J))                                   GO TO 20
        B=A(I)
        A(I)=A(J)
        A(J)=B
        L=1
   20 CONTINUE
      IF(L.EQ.1)                                           GO TO 10
      RETURN
      END
*$ CREATE RM48.FOR
*COPY RM48
      SUBROUTINE RM488(RVEC,LENV)
C     Double-precision version of
C Universal random number generator proposed by Marsaglia and Zaman
C in report FSU-SCRI-87-50
C        based on RANMAR, modified by F. James, to generate vectors
C        of pseudorandom numbers RVEC of length LENV, where the numbers
C        in RVEC are numbers with at least 48-bit mantissas.
C   Input and output entry points: RM48IN, RM48UT.
C!!! ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C!!!  Calling sequences for RM48:                                    ++
C!!!      CALL RM48 (RVEC, LEN)     returns a vector RVEC of LEN     ++
C!!!                   64-bit random floating point numbers between  ++
C!!!                   zero and one.                                 ++
C!!!      CALL RM48IN(I1,N1,N2)   initializes the generator from one ++
C!!!                   64-bit integer I1, and number counts N1,N2    ++
C!!!                  (for initializing, set N1=N2=0, but to restart ++
C!!!                    a previously generated sequence, use values  ++
C!!!                    output by RM48UT)                            ++
C!!!      CALL RM48UT(I1,N1,N2)   outputs the value of the original  ++
C!!!                  seed and the two number counts, to be used     ++
C!!!                  for restarting by initializing to I1 and       ++
C!!!                  skipping N2*100000000+N1 numbers.              ++
C!!! ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C for 32-bit machines, use IMPLICIT DOUBLE PRECISION
C     INCLUDE '(DBLPRC)'
*$ CREATE DBLPRC.ADD
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      PARAMETER ( KALGNM = 2 )
      PARAMETER ( ANGLGB = 5.0D-16 )
      PARAMETER ( ANGLSQ = 2.5D-31 )
      PARAMETER ( AXCSSV = 0.2D+16 )
      PARAMETER ( ANDRFL = 1.0D-38 )
      PARAMETER ( AVRFLW = 1.0D+38 )
      PARAMETER ( AINFNT = 1.0D+30 )
      PARAMETER ( AZRZRZ = 1.0D-30 )
      PARAMETER ( EINFNT = +69.07755278982137 D+00 )
      PARAMETER ( EZRZRZ = -69.07755278982137 D+00 )
      PARAMETER ( ONEMNS = 0.999999999999999  D+00 )
      PARAMETER ( ONEPLS = 1.000000000000001  D+00 )
      PARAMETER ( CSNNRM = 2.0D-15 )
      PARAMETER ( DMXTRN = 1.0D+08 )
      PARAMETER ( ZERZER = 0.D+00 )
      PARAMETER ( ONEONE = 1.D+00 )
      PARAMETER ( TWOTWO = 2.D+00 )
      PARAMETER ( THRTHR = 3.D+00 )
      PARAMETER ( FOUFOU = 4.D+00 )
      PARAMETER ( FIVFIV = 5.D+00 )
      PARAMETER ( SIXSIX = 6.D+00 )
      PARAMETER ( SEVSEV = 7.D+00 )
      PARAMETER ( EIGEIG = 8.D+00 )
      PARAMETER ( ANINEN = 9.D+00 )
      PARAMETER ( TENTEN = 10.D+00 )
      PARAMETER ( HLFHLF = 0.5D+00 )
      PARAMETER ( ONETHI = ONEONE / THRTHR )
      PARAMETER ( TWOTHI = TWOTWO / THRTHR )
      PARAMETER ( ONEFOU = ONEONE / FOUFOU )
      PARAMETER ( THRTWO = THRTHR / TWOTWO )
      PARAMETER ( PIPIPI = 3.141592653589793238462643383279D+00 )
      PARAMETER ( TWOPIP = 6.283185307179586476925286766559D+00 )
      PARAMETER ( PIP5O2 = 7.853981633974483096156608458199D+00 )
      PARAMETER ( PIPISQ = 9.869604401089358618834490999876D+00 )
      PARAMETER ( PIHALF = 1.570796326794896619231321691640D+00 )
      PARAMETER ( ERFA00 = 0.886226925452758013649083741671D+00 )
      PARAMETER ( ENEPER = 2.718281828459045235360287471353D+00 )
      PARAMETER ( SQRENT = 1.648721270700128146848650787814D+00 )
      PARAMETER ( SQRSIX = 2.449489742783178098197284074706D+00 )
      PARAMETER ( SQRSEV = 2.645751311064590590501615753639D+00 )
      PARAMETER ( SQRT12 = 3.464101615137754587054892683012D+00 )
      PARAMETER ( CLIGHT = 2.99792458         D+10 )
      PARAMETER ( AVOGAD = 6.0221367          D+23 )
      PARAMETER ( BOLTZM = 1.380658           D-23 )
      PARAMETER ( AMELGR = 9.1093897          D-28 )
      PARAMETER ( PLCKBR = 1.05457266         D-27 )
      PARAMETER ( ELCCGS = 4.8032068          D-10 )
      PARAMETER ( ELCMKS = 1.60217733         D-19 )
      PARAMETER ( AMUGRM = 1.6605402          D-24 )
      PARAMETER ( AMMUMU = 0.113428913        D+00 )
      PARAMETER ( AMPRMU = 1.007276470        D+00 )
      PARAMETER ( AMNEMU = 1.008664904        D+00 )
      PARAMETER ( ALPFSC = 7.2973530791728595 D-03 )
      PARAMETER ( FSCTO2 = 5.3251361962113614 D-05 )
      PARAMETER ( FSCTO3 = 3.8859399018437826 D-07 )
      PARAMETER ( FSCTO4 = 2.8357075508200407 D-09 )
      PARAMETER ( PLABRC = 0.197327053        D+00 )
      PARAMETER ( AMELCT = 0.51099906         D-03 )
      PARAMETER ( AMUGEV = 0.93149432         D+00 )
      PARAMETER ( AMMUON = 0.105658389        D+00 )
      PARAMETER ( AMPRTN = 0.93827231         D+00 )
      PARAMETER ( AMNTRN = 0.93956563         D+00 )
      PARAMETER ( AMDEUT = 1.87561339         D+00 )
      PARAMETER ( COUGFM = ELCCGS * ELCCGS / ELCMKS * 1.D-07 * 1.D+13
     &                   * 1.D-09 )
      PARAMETER ( RCLSEL = 2.8179409183694872 D-13 )
      PARAMETER ( BLTZMN = 8.617385           D-14 )
      PARAMETER ( GEVMEV = 1.0                D+03 )
      PARAMETER ( EMVGEV = 1.0                D-03 )
      PARAMETER ( ALGVMV = 6.90775527898214   D+00 )
      PARAMETER ( RADDEG = 180.D+00 / PIPIPI )
      PARAMETER ( DEGRAD = PIPIPI / 180.D+00 )
      LOGICAL LGBIAS, LGBANA
      COMMON / GLOBAL / LGBIAS, LGBANA
C     INCLUDE '(DIMPAR)'
*$ CREATE DIMPAR.ADD
      PARAMETER ( MXXRGN = 5000 )
      PARAMETER ( MXXMDF = 56   )
      PARAMETER ( MXXMDE = 50   )
      PARAMETER ( MFSTCK = 1000 )
      PARAMETER ( MESTCK = 100  )
      PARAMETER ( NALLWP = 39   )
      PARAMETER ( MPDPDX = 8    )
      PARAMETER ( ICOMAX = 180  )
      PARAMETER ( NSTBIS = 304  )
      PARAMETER ( IDMAXP = 210  )
      PARAMETER ( IDMXDC = 620  )
      PARAMETER ( MKBMX1 = 1    )
      PARAMETER ( MKBMX2 = 1    )
C     INCLUDE '(IOUNIT)'
*$ CREATE IOUNIT.ADD
      PARAMETER ( LUNIN  = 5  )
      PARAMETER ( LUNOUT = 6  )
      PARAMETER ( LUNERR = 15 )
      PARAMETER ( LUNBER = 14 )
      PARAMETER ( LUNECH = 8  )
      PARAMETER ( LUNFLU = 13 )
      PARAMETER ( LUNGEO = 16 )
      PARAMETER ( LUNPGS = 12 )
      PARAMETER ( LUNRAN = 2  )
      PARAMETER ( LUNXSC = 9  )
      PARAMETER ( LUNDET = 17 )
      PARAMETER ( LUNRAY = 10 )
      PARAMETER ( LUNRDB = 1  )
*
*     IMPLICIT DOUBLE PRECISION (A-H,O-Z)
*
      DIMENSION RVEC(*)
      COMMON/R48ST1/U(97),C,I97,J97
      PARAMETER (MODCNS=1000000000)
      SAVE CD, CM, TWOM24,  ZERO, ONE, NTOT, NTOT2, IJKL
      DATA NTOT,NTOT2,IJKL/-1,0,0/
C
      IF (NTOT .GE. 0)  GO TO 50
C
C        Default initialization. User has called RM48 without RM48IN.
      IJKL = 54217137
      NTOT = 0
      NTOT2 = 0
      KALLED = 0
      GO TO 1
C
      ENTRY      RM48IN(IJKLIN, NTOTIN,NTOT2N)
C         Initializing routine for RM48, may be called before
C         generating pseudorandom numbers with RM48.   The input
C         values should be in the ranges:  0<=IJKLIN<=900 OOO OOO
C                                          0<=NTOTIN<=999 999 999
C                                          0<=NTOT2N<<999 999 999!
C To get the standard values in Marsaglia's paper, IJKLIN=54217137
C                                            NTOTIN,NTOT2N=0
      IJKL = IJKLIN
      NTOT = MAX(NTOTIN,0)
      NTOT2= MAX(NTOT2N,0)
      KALLED = 1
C          always come here to initialize
    1 CONTINUE
      IJ = IJKL/30082
      KL = IJKL - 30082*IJ
      I = MOD(IJ/177, 177) + 2
      J = MOD(IJ, 177)     + 2
      K = MOD(KL/169, 178) + 1
      L = MOD(KL, 169)
      WRITE(LUNOUT,'(A,I10,2X,2I10)')
     & ' RM48 INITIALIZED:',IJKL,NTOT,NTOT2
CCC      PRINT '(A,4I10)', '   I,J,K,L= ',I,J,K,L
      ONE = 1.D+00
      HALF = 0.5D+00
      ZERO = 0.D+00
      DO 2 II= 1, 97
      S = 0.D+00
      T = HALF
      DO 3 JJ= 1, 48
         M = MOD(MOD(I*J,179)*K, 179)
         I = J
         J = K
         K = M
         L = MOD(53*L+1, 169)
         IF (MOD(L*M,64) .GE. 32)  S = S+T
    3    T = HALF*T
    2 U(II) = S
      TWOM24 = ONE
      DO 4 I24= 1, 24
    4 TWOM24 = HALF*TWOM24
      C  =   362436.D+00*TWOM24
      CD =  7654321.D+00*TWOM24
      CM = 16777213.D+00*TWOM24
      I97 = 97
      J97 = 33
C       Complete initialization by skipping
C            (NTOT2*MODCNS + NTOT) random numbers
      DO 45 LOOP2= 1, NTOT2+1
      NOW = MODCNS
      IF (LOOP2 .EQ. NTOT2+1)  NOW=NTOT
      IF (NOW .GT. 0)  THEN
      WRITE(LUNOUT,'(A,I15)') ' RM48IN SKIPPING OVER ',NOW
          DO 40 IDUM = 1, NTOT
          UNI = U(I97)-U(J97)
          IF (UNI .LT. ZERO)  UNI=UNI+ONE
          U(I97) = UNI
          I97 = I97-1
          IF (I97 .EQ. 0)  I97=97
          J97 = J97-1
          IF (J97 .EQ. 0)  J97=97
          C = C - CD
          IF (C .LT. ZERO)  C=C+CM
   40     CONTINUE
      ENDIF
   45 CONTINUE
      IF (KALLED .EQ. 1)  RETURN
C
C          Normal entry to generate LENV random numbers
   50 CONTINUE
      DO 100 IVEC= 1, LENV
      UNI = U(I97)-U(J97)
      IF (UNI .LT. ZERO)  UNI=UNI+ONE
      U(I97) = UNI
      I97 = I97-1
      IF (I97 .EQ. 0)  I97=97
      J97 = J97-1
      IF (J97 .EQ. 0)  J97=97
      C = C - CD
      IF (C .LT. ZERO)  C=C+CM
      UNI = UNI-C
      IF (UNI .LT. ZERO) UNI=UNI+ONE
      RVEC(IVEC) = UNI
CC             Replace exact zeros by uniform distr. *2**-24
C         IF (UNI .EQ. 0.)  THEN
C         ZUNI = TWOM24*U(2)
CC             An exact zero here is very unlikely, but let's be safe.
C         IF (ZUNI .EQ. 0.) ZUNI= TWOM24*TWOM24
C         RVEC(IVEC) = ZUNI
C         ENDIF
  100 CONTINUE
      NTOT = NTOT + LENV
         IF (NTOT .GE. MODCNS)  THEN
         NTOT2 = NTOT2 + 1
         NTOT = NTOT - MODCNS
         ENDIF
      RETURN
C           Entry to output current status
      ENTRY RM48UT(IJKLUT,NTOTUT,NTOT2T)
      IJKLUT = IJKL
      NTOTUT = NTOT
      NTOT2T = NTOT2
      RETURN
C
      ENTRY      RM48WR(IOSEED)
C         Output routine for RM48, without skipping numbers
      WRITE (IOSEED,'(2Z8)') NTOT,NTOT2
      WRITE (IOSEED,'(2Z8,Z16)') I97,J97,C
      WRITE (IOSEED,'(24(4Z16,/),Z16)') U
      RETURN
C
      ENTRY      RM48RD(IOSEED)
C         Initializing routine for RM48, without skipping numbers
      READ (IOSEED,'(2Z8)') NTOT,NTOT2
      READ (IOSEED,'(2Z8,Z16)') I97,J97,C
      READ (IOSEED,'(24(4Z16,/),Z16)') U
      CLOSE (UNIT=IOSEED)
      IJKL = 54217137
      IJ = IJKL/30082
      KL = IJKL - 30082*IJ
      I = MOD(IJ/177, 177) + 2
      J = MOD(IJ, 177)     + 2
      K = MOD(KL/169, 178) + 1
      L = MOD(KL, 169)
      WRITE (LUNOUT,'(A,I10,2X,2I10)')
     &  ' RM48 INITIALIZED:',IJKL,NTOT,NTOT2
CCC      PRINT '(A,4I10)', '   I,J,K,L= ',I,J,K,L
      ONE  = 1.D+00
      HALF = 0.5D+00
      ZERO = 0.D+00
      TWOM24 = ONE
      DO 400 I24= 1, 24
  400 TWOM24 = HALF*TWOM24
      CD =  7654321.D+00*TWOM24
      CM = 16777213.D+00*TWOM24
      RETURN
      END
 
*$ CREATE RNDM.FOR
*COPY RNDM
*
*===  rndm  ===========================================================*
*
      DOUBLE PRECISION FUNCTION RNDMM(RDUMMY)
 
C     INCLUDE '(DBLPRC)'
*$ CREATE DBLPRC.ADD
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      PARAMETER ( KALGNM = 2 )
      PARAMETER ( ANGLGB = 5.0D-16 )
      PARAMETER ( ANGLSQ = 2.5D-31 )
      PARAMETER ( AXCSSV = 0.2D+16 )
      PARAMETER ( ANDRFL = 1.0D-38 )
      PARAMETER ( AVRFLW = 1.0D+38 )
      PARAMETER ( AINFNT = 1.0D+30 )
      PARAMETER ( AZRZRZ = 1.0D-30 )
      PARAMETER ( EINFNT = +69.07755278982137 D+00 )
      PARAMETER ( EZRZRZ = -69.07755278982137 D+00 )
      PARAMETER ( ONEMNS = 0.999999999999999  D+00 )
      PARAMETER ( ONEPLS = 1.000000000000001  D+00 )
      PARAMETER ( CSNNRM = 2.0D-15 )
      PARAMETER ( DMXTRN = 1.0D+08 )
      PARAMETER ( ZERZER = 0.D+00 )
      PARAMETER ( ONEONE = 1.D+00 )
      PARAMETER ( TWOTWO = 2.D+00 )
      PARAMETER ( THRTHR = 3.D+00 )
      PARAMETER ( FOUFOU = 4.D+00 )
      PARAMETER ( FIVFIV = 5.D+00 )
      PARAMETER ( SIXSIX = 6.D+00 )
      PARAMETER ( SEVSEV = 7.D+00 )
      PARAMETER ( EIGEIG = 8.D+00 )
      PARAMETER ( ANINEN = 9.D+00 )
      PARAMETER ( TENTEN = 10.D+00 )
      PARAMETER ( HLFHLF = 0.5D+00 )
      PARAMETER ( ONETHI = ONEONE / THRTHR )
      PARAMETER ( TWOTHI = TWOTWO / THRTHR )
      PARAMETER ( ONEFOU = ONEONE / FOUFOU )
      PARAMETER ( THRTWO = THRTHR / TWOTWO )
      PARAMETER ( PIPIPI = 3.141592653589793238462643383279D+00 )
      PARAMETER ( TWOPIP = 6.283185307179586476925286766559D+00 )
      PARAMETER ( PIP5O2 = 7.853981633974483096156608458199D+00 )
      PARAMETER ( PIPISQ = 9.869604401089358618834490999876D+00 )
      PARAMETER ( PIHALF = 1.570796326794896619231321691640D+00 )
      PARAMETER ( ERFA00 = 0.886226925452758013649083741671D+00 )
      PARAMETER ( ENEPER = 2.718281828459045235360287471353D+00 )
      PARAMETER ( SQRENT = 1.648721270700128146848650787814D+00 )
      PARAMETER ( SQRSIX = 2.449489742783178098197284074706D+00 )
      PARAMETER ( SQRSEV = 2.645751311064590590501615753639D+00 )
      PARAMETER ( SQRT12 = 3.464101615137754587054892683012D+00 )
      PARAMETER ( CLIGHT = 2.99792458         D+10 )
      PARAMETER ( AVOGAD = 6.0221367          D+23 )
      PARAMETER ( BOLTZM = 1.380658           D-23 )
      PARAMETER ( AMELGR = 9.1093897          D-28 )
      PARAMETER ( PLCKBR = 1.05457266         D-27 )
      PARAMETER ( ELCCGS = 4.8032068          D-10 )
      PARAMETER ( ELCMKS = 1.60217733         D-19 )
      PARAMETER ( AMUGRM = 1.6605402          D-24 )
      PARAMETER ( AMMUMU = 0.113428913        D+00 )
      PARAMETER ( AMPRMU = 1.007276470        D+00 )
      PARAMETER ( AMNEMU = 1.008664904        D+00 )
      PARAMETER ( ALPFSC = 7.2973530791728595 D-03 )
      PARAMETER ( FSCTO2 = 5.3251361962113614 D-05 )
      PARAMETER ( FSCTO3 = 3.8859399018437826 D-07 )
      PARAMETER ( FSCTO4 = 2.8357075508200407 D-09 )
      PARAMETER ( PLABRC = 0.197327053        D+00 )
      PARAMETER ( AMELCT = 0.51099906         D-03 )
      PARAMETER ( AMUGEV = 0.93149432         D+00 )
      PARAMETER ( AMMUON = 0.105658389        D+00 )
      PARAMETER ( AMPRTN = 0.93827231         D+00 )
      PARAMETER ( AMNTRN = 0.93956563         D+00 )
      PARAMETER ( AMDEUT = 1.87561339         D+00 )
      PARAMETER ( COUGFM = ELCCGS * ELCCGS / ELCMKS * 1.D-07 * 1.D+13
     &                   * 1.D-09 )
      PARAMETER ( RCLSEL = 2.8179409183694872 D-13 )
      PARAMETER ( BLTZMN = 8.617385           D-14 )
      PARAMETER ( GEVMEV = 1.0                D+03 )
      PARAMETER ( EMVGEV = 1.0                D-03 )
      PARAMETER ( ALGVMV = 6.90775527898214   D+00 )
      PARAMETER ( RADDEG = 180.D+00 / PIPIPI )
      PARAMETER ( DEGRAD = PIPIPI / 180.D+00 )
      LOGICAL LGBIAS, LGBANA
      COMMON / GLOBAL / LGBIAS, LGBANA
C     INCLUDE '(DIMPAR)'
*$ CREATE DIMPAR.ADD
      PARAMETER ( MXXRGN = 5000 )
      PARAMETER ( MXXMDF = 56   )
      PARAMETER ( MXXMDE = 50   )
      PARAMETER ( MFSTCK = 1000 )
      PARAMETER ( MESTCK = 100  )
      PARAMETER ( NALLWP = 39   )
      PARAMETER ( MPDPDX = 8    )
      PARAMETER ( ICOMAX = 180  )
      PARAMETER ( NSTBIS = 304  )
      PARAMETER ( IDMAXP = 210  )
      PARAMETER ( IDMXDC = 620  )
      PARAMETER ( MKBMX1 = 1    )
      PARAMETER ( MKBMX2 = 1    )
C     INCLUDE '(IOUNIT)'
*$ CREATE IOUNIT.ADD
      PARAMETER ( LUNIN  = 5  )
      PARAMETER ( LUNOUT = 6  )
      PARAMETER ( LUNERR = 15 )
      PARAMETER ( LUNBER = 14 )
      PARAMETER ( LUNECH = 8  )
      PARAMETER ( LUNFLU = 13 )
      PARAMETER ( LUNGEO = 16 )
      PARAMETER ( LUNPGS = 12 )
      PARAMETER ( LUNRAN = 2  )
      PARAMETER ( LUNXSC = 9  )
      PARAMETER ( LUNDET = 17 )
      PARAMETER ( LUNRAY = 10 )
      PARAMETER ( LUNRDB = 1  )
*
*----------------------------------------------------------------------*
*                                                                      *
*     This routine merely acts as an interface to F.James RM48 gen.    *
*                                                                      *
*     Created on 03  april  1992   by    Alfredo Ferrari & Paola Sala  *
*                                                   Infn - Milan       *
*                                                                      *
*     Last change on 16-sep-93     by    Alfredo Ferrari               *
*                                                                      *
*                                                                      *
*----------------------------------------------------------------------*
*
      DIMENSION RNDNUM (2)
      CALL RM48 ( RNDNUM, 1 )
CDH   RNDM = RNDNUM (1)
      RNDMM = RNDNUM (1)
      RETURN
      ENTRY RD2IN (ISEED1,ISEED2)
*  The following card just to avoid warning messages on the HP compiler
      RD2IN  = PIPIPI
      CALL RM48IN (54217137,ISEED1,ISEED2)
      RETURN
      ENTRY RD2OUT(ISEED1,ISEED2)
*  The following card just to avoid warning messages on the HP compiler
      RD2OUT = PIPIPI
      CALL RM48UT (IDUMMY,ISEED1,ISEED2)
*=== End of function rndm =============================================*
      RETURN
      END
 
C-------------------------------------------------------------
C                    was dpmlund.f
C-------------------------------------------------------------
C     SUBROUTINE TESLUN
C     IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C     SAVE
C     COMMON /DPRIN/  IPRI,IPEV,IPPA,IPCO,INIT,IPHKK,ITOPD,IPAUPR
C     COMMON/POPCOR/PDB,AJSDEF
C     COMMON/HARLUN/IHARLU,QLUN
C     COMMON /HARLUN/ QLUN,IHARLU
C--------------------------------------------------
C                       IHARLU=0  soft jets fragmenting
C                       IHARLU=1  hard jets fragmenting
C                                 with final state evolution
C                                 in JETSET
C                       QLUN = Mass of hard partons at end of
C                              chain
C-----------------------------------------------------------
C     AJSDEF=0.
C     PDB=0.5
C     IPRI=2
c     CALL LUNDIN
C     IHARLU=0
C     QLUN=0.
C     IF(IPRI.GE.2) WRITE(6,111)QLUN
c 111 FORMAT(' QLUN= ',F10.2)
C     CALL BAMLUN(IHAD,1,7,0,0,25.,3,IREJ)
C     IF(IPRI.GE.2) WRITE(6,111)QLUN
C     CALL BAMLUN(IHAD,2,8,0,0,25.,3,IREJ)
C     IF(IPRI.GE.2) WRITE(6,111)QLUN
C     CALL BAMLUN(IHAD,3,9,0,0,25.,3,IREJ)
C     IHARLU=1
C     QLUN=8.
C     IF(IPRI.GE.2) WRITE(6,111)QLUN
C     CALL BAMLUN(IHAD,1,7,0,0,25.,3,IREJ)
C     IF(IPRI.GE.2) WRITE(6,111)QLUN
C     CALL BAMLUN(IHAD,2,8,0,0,25.,3,IREJ)
C     IF(IPRI.GE.2) WRITE(6,111)QLUN
C     CALL BAMLUN(IHAD,3,9,0,0,25.,3,IREJ)
c     QLUN=6.
C     IF(IPRI.GE.2) WRITE(6,111)QLUN
C     CALL BAMLUN(IHAD,1,7,0,0,25.,3,IREJ)
C     IF(IPRI.GE.2) WRITE(6,111)QLUN
C     CALL BAMLUN(IHAD,2,8,0,0,25.,3,IREJ)
C     IF(IPRI.GE.2) WRITE(6,111)QLUN
C 
C     CALL BAMLUN(IHAD,2,8,0,0,25.,3,IREJ)
C     IF(IPRI.GE.2) WRITE(6,111)QLUN
C     CALL BAMLUN(IHAD,3,9,0,0,25.,3,IREJ)
C     QLUN=2.
C     IF(IPRI.GE.2) WRITE(6,111)QLUN
C     CALL BAMLUN(IHAD,1,7,0,0,25.,3,IREJ)
C     IF(IPRI.GE.2) WRITE(6,111)QLUN
C     CALL BAMLUN(IHAD,2,8,0,0,25.,3,IREJ)
C     IF(IPRI.GE.2) WRITE(6,111)QLUN
C     CALL BAMLUN(IHAD,3,9,0,0,25.,3,IREJ)
C     IPRI=0
C     IHARLU=0
C     QLUN=0.
C     RETURN
C     END
      SUBROUTINE LUNDIN
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      INTEGER PYCOMP
C
C     INITIALIZATION FOR JETSET-7.3 CALL IN DTUNUC 1.04 (J.R. 6/93)
C
      COMMON/PYJETS/N,NPAD,K(4000,5),P(4000,5),V(4000,5)
      COMMON/PYDAT1/MSTU(200),PARU(200),MSTJ(200),PARJ(200)
      COMMON/PYDAT2/KCHG(500,4),PMAS(500,4),PARF(2000),VCKM(4,4)
      COMMON/PYDAT3/MDCY(500,3),MDME(4000,2),BRAT(4000),KFDP(4000,5)
      COMMON/POPCOR/PDB,AJSDEF
      COMMON/PROMU/IPROMU
      COMMON/IFRAGM/IFRAG
C     COMMON/HARLUN/IHARLU,QLUN
      COMMON /HARLUN/ QLUN,IHARLU
      DATA IPROMM/0/
C--------------------------------------------------
C                       IHARLU=0  soft jets fragmenting
C                       IHARLU=1  hard jets fragmenting
C                                 with final state evolution
C                                 in JEYTSET
C                       QLUN = Mass of hard partons at end of
C                              chain
C-----------------------------------------------------------
C                                defaults for parton showering
C                                QCD type branchings
      MSTJ(41)=1
C                                coherent branching, angular
C                                ordering
      MSTJ(42)=2
      MSTJ(43)=4
      MSTJ(44)=2
C                                 only u,d,s,c quarks
      MSTJ(45)=4
      MSTJ(46)=0
C                                  no lowest order corrections
      MSTJ(47)=0
      MSTJ(48)=0
      MSTJ(49)=0
C                                  Lambda in running alpha(s)
      PARJ(81)=0.40D0
C                                  M(min) cut-off
      PARJ(82)=1.D0
      PARJ(83)=1.D0
C------------------------------------------------------------------
      IHARLU=0
      QLUN=0.D0
C-----------------------------------------------------------------
      IF(IPROMU.NE.0)IPROMM=IPROMU
CDH   ipromu is set to 1 within corsika/dpmjin
CDH   IPROMM=1
C----------------------------------------------------------------
C        if AJSDEF=1 set default values for all jetset parameters
      IF(AJSDEF.EQ.1.D0) GO TO 100
C----------------------------------------------------------------
C                           switch off popcorn fragmentation
C                            MSTJ(12) default 2 : popcorn allowed
      IF(PDB.EQ.0.D0)MSTJ(12)=1 
C                           TEST proton x distribution 19.11.97
      MSTJ(12)=3
      PARJ(19)=0.1
C----------------------------------------------------------------
C                           MODIFY POPCORM mechanism
C                           PARJ(5), default:0.5
      IF(PDB.GT.0.D0)PARJ(5)=PDB
C
C----------------------------------------------------------------
C
C                   DEFINE Lund parameters
C                       IFRAG=1  
C
C----------------------------------------------------------------
C
      IF(IFRAG.EQ.1)THEN   
C                 Probability for meson with spin 1 (d=0.5) 
      PARJ(11)=0.6D0
C----------------------------------------------------------------
C                           Lund b-parameter (default=0.9)
      PARJ(42)=0.5D0
C----------------------------------------------------------------
C                           Lund a-parameter (default=0.5)
      PARJ(41)=0.2D0 
C----------------------------------------------------------------
C                d=1 Lund Fragmentation 2: F-F fragmentation   
C     MSTJ(11)=1
C                           F.-F. c-parameter (default=0.77)
C     PARJ(51)=0.99
C     PARJ(52)=0.99
C     PARJ(53)=0.99
C----------------------------------------------------------------
C                           Lund sigma parameter in pt distribution
C                                             (default=0.35)
      PARJ(21)=0.42D0
C----------------------------------------------------------------
C        Some of these parmeters are changed in BAMLUN
C!!!!!!!!

C----------------------------------------------------------------
C                           Diquark supression (default 0.1)
      PARJ(1)=0.07D0
C     PARJ(1)=0.06D0
C----------------------------------------------------------------
C                           STRANGENESS supression (default 0.3)
C     PARJ(2)=0.27D0
C                                        6.1.95
      PARJ(2)=0.25D0
C----------------------------------------------------------------
C                          Extra supression of strange diquarks
C                           Default 0.4
C     PARJ(3)=0.4D0
C                                        6.1.95
      PARJ(3)=0.3D0
C     PARJ(3)=0.5D0
C----------------------------------------------------------------
C                          Extra supression of Strangeness in
C                          B-M-B Situation (defaults 0.5)
C     PARJ(6)=0.75D0
C     PARJ(7)=0.75D0
C                                        6.1.95
      PARJ(6)=0.50D0
      PARJ(7)=0.50D0
C     PARJ(6)=0.75D0
C     PARJ(7)=0.75D0
C----------------------------------------------------------------
C
C----------------------------------------------------------------
C
C                   DEFINE Lund parameters
C                       IFRAG=10 
C                low energy tests 
C
C----------------------------------------------------------------
      ELSEIF(IFRAG.EQ.10)THEN
C                 Probability for meson with spin 1 (d=0.5) 
      PARJ(11)=0.6D0
C----------------------------------------------------------------
C                           Lund b-parameter (default=0.9)
      PARJ(42)=0.5
C----------------------------------------------------------------
C                           Lund a-parameter (default=0.5)
C     PARJ(41)=0.51
C                                      14.3.95 like 1
      PARJ(41)=0.20D0
C----------------------------------------------------------------
C                d=1 Lund Fragmentation 2: F-F fragmentation   
C     MSTJ(11)=1
C                           F.-F. c-parameter (default=0.77)
C     PARJ(51)=0.99
C     PARJ(52)=0.99
C     PARJ(53)=0.99
C----------------------------------------------------------------
C                           Lund sigma parameter in pt distribution
C                                             (default=0.35)
      PARJ(21)=0.42D0
C----------------------------------------------------------------
C        Some of these parmeters are changed in BAMLUN
C!!!!!!!!

C----------------------------------------------------------------
C                           Diquark supression (default 0.1)
      PARJ(1)=0.07D0
C----------------------------------------------------------------
C                           STRANGENESS supression (default 0.3)
C     PARJ(2)=0.27D0
C                                        6.1.95
      PARJ(2)=0.25D0
C----------------------------------------------------------------
C                          Extra supression of strange diquarks
C                           Default 0.4
C     PARJ(3)=0.4D0
C                                        6.1.95
      PARJ(3)=0.3D0
C----------------------------------------------------------------
C                          Extra supression of Strangeness in
C                          B-M-B Situation (defaults 0.5)
C     PARJ(6)=0.75D0
C     PARJ(7)=0.75D0
C                                        6.1.95
      PARJ(6)=0.50D0
      PARJ(7)=0.50D0
C----------------------------------------------------------------
C
C----------------------------------------------------------------
C----------------------------------------------------------------
      ENDIF
C----------------------------------------------------------------
  100 CONTINUE
      WRITE (6,2355)PDB,AJSDEF,MSTJ(12),PARJ(42),PARJ(21)
 2355 FORMAT( ' LUNDIN initialization PDB,AJSDEF= ',2F10.3/
     + ' MSTJ(12) popcorn default=2  : ',I10/
     + ' PARJ(42 )Lund b,default=0.9 : ',F10.3/
     + ' PARJ(21) sigma in pt distr,default=0.35 : ',F10.3)
C----------------------------------------------------------------
C                           Prevent particles dacaying
C                 KOS
      KC=PYCOMP(310)
      MDCY(KC,1)=0
C                 PIO
      KC=PYCOMP(111)
      MDCY(KC,1)=0
C                 LAMBDA
      KC=PYCOMP(3122)
      MDCY(KC,1)=0
C                 ALAMBDA
      KC=PYCOMP(-3122)
      MDCY(KC,1)=0
C                 SIG+
      KC=PYCOMP(3222)
      MDCY(KC,1)=0
C                 ASIG+
      KC=PYCOMP(-3222)
      MDCY(KC,1)=0
C                 SIG-
      KC=PYCOMP(3112)
      MDCY(KC,1)=0
C                 ASIG-
      KC=PYCOMP(-3112)
      MDCY(KC,1)=0
C                 SIG0
C     KC=PYCOMP(3212)
C     MDCY(KC,1)=0
C                 ASIG0
C     KC=PYCOMP(-3212)
C     MDCY(KC,1)=0
C                 TET0
      KC=PYCOMP(3322)
      MDCY(KC,1)=0
C                 ATET0
      KC=PYCOMP(-3322)
      MDCY(KC,1)=0
C                 TET-
      KC=PYCOMP(3312)
      MDCY(KC,1)=0
C                 ATET-
      KC=PYCOMP(-3312)
      MDCY(KC,1)=0
C                 OMEGA-
      KC=PYCOMP(3334)
      MDCY(KC,1)=0
C                 AOMEGA-
      KC=PYCOMP(-3334)
      MDCY(KC,1)=0
C                 TAU
CDH   the tau particles cannot be treated in CORSIKA
c     KC=PYCOMP(15)
c     MDCY(KC,1)=0
C
C               HAVE CHARMED MESONS DECAYING for IPROMM=1
C
*     IF(IPROMM.EQ.1)GO TO 199
      IF(IPROMU.EQ.1)GO TO 201
*     IF(IPROMM.EQ.1)GO TO 201
C                 D+
      KC=PYCOMP(411)
      MDCY(KC,1)=0
C                 D-
      KC=PYCOMP(-411)
      MDCY(KC,1)=0
C                 D0
      KC=PYCOMP(421)
      MDCY(KC,1)=0
C                 A-D0
      KC=PYCOMP(-421)
      MDCY(KC,1)=0
C                 DS+
      KC=PYCOMP(431)
      MDCY(KC,1)=0
C                 A-DS+
      KC=PYCOMP(-431)
      MDCY(KC,1)=0
C                ETAC 
      KC=PYCOMP(441)
      MDCY(KC,1)=0
  199 CONTINUE
C                LAMBDAC+ 
      KC=PYCOMP(4122)
      MDCY(KC,1)=0
C                A-LAMBDAC+ 
      KC=PYCOMP(-4122)
      MDCY(KC,1)=0
C                SIGMAC++ 
      KC=PYCOMP(4222)
      MDCY(KC,1)=0
C                SIGMAC+ 
      KC=PYCOMP(4212)
      MDCY(KC,1)=0
C                SIGMAC0 
      KC=PYCOMP(4112)
      MDCY(KC,1)=0
C                A-SIGMAC++ 
      KC=PYCOMP(-4222)
      MDCY(KC,1)=0
C                A-SIGMAC+ 
      KC=PYCOMP(-4212)
      MDCY(KC,1)=0
C                A-SIGMAC0 
      KC=PYCOMP(-4112)
      MDCY(KC,1)=0
C                KSIC+ 
      KC=PYCOMP(4232)
      MDCY(KC,1)=0
C                KSIC0 
      KC=PYCOMP(4132)
      MDCY(KC,1)=0
C                A-KSIC+ 
      KC=PYCOMP(-4232)
      MDCY(KC,1)=0
C                A-KSIC0 
      KC=PYCOMP(-4132)
      MDCY(KC,1)=0
 201  CONTINUE
      RETURN
      END
      SUBROUTINE BAMLUN(IHAD,KFA1,KFA2,KFA3,KFA4,AEO,IOPT,IREJ)
C
C     IOPT = 3  q -- aq Jet
C     IOPT = 4  q -- qq Jet
C     IOPT = 5  qq -- aqaq Jet
C     IOPT = 10 q -- q -- q Jet Capella-Kopeliovich
C
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
C
C     INTERFACE FOR JETSET-7.3 CALL IN DTUNUC 1.04 (J.R. 6/93)
C
      COMMON/PYJETS/N,NPAD,K(4000,5),P(4000,5),V(4000,5)
      COMMON/PYDAT1/MSTU(200),PARU(200),MSTJ(200),PARJ(200)
      COMMON/PYDAT2/KCHG(500,4),PMAS(500,4),PARF(2000),VCKM(4,4)
      CHARACTER*8 ANF
      PARAMETER (NFIMAX=249)
      COMMON /DFINPA/ ANF(NFIMAX),PXF(NFIMAX),PYF(NFIMAX),PZF(NFIMAX),
     +HEF(NFIMAX),AMF(NFIMAX), ICHF(NFIMAX),IBARF(NFIMAX),NREF(NFIMAX)
      COMMON /DFINPZ/IORMO(NFIMAX),IDAUG1(NFIMAX),IDAUG2(NFIMAX),
     * ISTATH(NFIMAX)
*KEEP,DPRIN.
      COMMON /DPRIN/  IPRI,IPEV,IPPA,IPCO,INIT,IPHKK,ITOPD,IPAUPR
      CHARACTER*8 ANAME
      COMMON/DPAR/ANAME(210),AM(210),GA(210),TAU(210),ICH(210),
     *IBAR(210),K1(210),K2(210)
      COMMON/DIFFRA/ISINGD,IDIFTP,IOUDIF,IFLAGD
      COMMON/CAPKOP/XXX1,XXX3
      DIMENSION NBAMLU(10)
      DIMENSION KORIII(4000)
      COMMON/PROMU/IPROMU
      COMMON/POPCOR/PDB,AJSDEF
      COMMON/IFRAGM/IFRAG
C     COMMON/HARLUN/IHARLU,QLUN
      COMMON /HARLUN/ QLUN,IHARLU
      COMMON /NNCMS/ GAMCM,BGCM,UMO,PCM,EPROJ,PPROJ
      COMMON /JSPART/PXP(1000),PYP(1000),PZP(1000),HEP(1000),NNNP
C--------------------------------------------------
C                       IHARLU=0  soft jets fragmenting
C                       IHARLU=1  hard jets fragmenting
C                                 with final state evolution
C                                 in JEYTSET
C                       QLUN = Mass of hard partons at end of
C                              chain
C-----------------------------------------------------------
      DIMENSION IJOIN(3)
      COMMON /JNI/JNI
      DATA IJOIN/1,2,3/
      DATA IPROMM/0/
      DATA NBAMLU /2,1,3,4,5,6,-2,-1,-3,-4/
      DATA ICOUN/0/
      DATA IWARN/0/
      DATA NBAML/0/
      IF(IPROMU.NE.0)IPROMM=IPROMU
C
C---------------------------------------------------------
C
C               Change Lund parameters depending on energy
C
C---------------------------------------------------------
C
C
C----------------------------------------------------------------
C
C                   DEFINE Lund parameters
C                       IFRAG=1  
C
C----------------------------------------------------------------
C
      IF(IFRAG.EQ.1)THEN   
C--------------------------------------------------------------
C--------------------------------------------------------------
C                                Test LUND default 2.2.99
C--------------------------------------------------------------
C--------------------------------------------------------------
      IF(AEO.LE.15.D0)THEN
C                           Lund b-parameter (default=0.9)
C                     2.2.99
C       PARJ(42)=1.55D0
C                    22.4.99
        PARJ(42)=1.20D0
C                           Lund a-parameter (default=0.5)
C                     2.2.99
c       PARJ(41)=0.14D0
C                    22.4.99
        PARJ(41)=0.30D0
C                           Lund sigma parameter in pt distribution
C                                             (default=0.35)
         PARJ(21)=0.35D0
         PARJ(23)=0.2D0
         PARJ(24)=2.D0
      ELSEIF(AEO.GE.30.D0)THEN
C                           Lund b-parameter (default=0.9)
C                     2.2.99
        PARJ(42)=1.1D0
C                           Lund a-parameter (default=0.5)
C                     2.2.99
        PARJ(41)=0.40D0
C                           Lund sigma parameter in pt distribution
C                                             (default=0.35)
         PARJ(21)=0.38D0
         PARJ(23)=0.2D0
         PARJ(24)=2.D0
      ELSE
        AINTER=(AEO-15.D0)/15.D0
C                           Lund b-parameter (default=0.9)
C                     2.2.99    (das war wohl falsch)
C       PARJ(42)=1.15D0-AINTER*0.45D0
C                    22.4.99
        PARJ(42)=1.20D0-AINTER*0.10D0
C                           Lund a-parameter (default=0.5)
C                     2.2.99
C       PARJ(41)=0.14D0+AINTER*0.15D0 
C                    22.4.99
        PARJ(41)=0.30D0+AINTER*0.10D0 
C                           Lund sigma parameter in pt distribution
C                                             (default=0.35)
         PARJ(21)=0.35D0+AINTER*0.03D0
         PARJ(23)=0.2D0
         PARJ(24)=2.D0
      ENDIF
C                 Probability for meson with spin 1 (d=0.5) 
	PARJ(11)=0.4D0
C                Extra supression for spin 3/2 baryons (d=1.)
	PARJ(18)=0.3D0
C                Extra supression for eta production (d=1.)
C                     taken out since no effect on eta production 5.3.97
C	PARJ(25)=1.3D0
C
C
C----------------------------------------------------------------
C
C                   DEFINE Lund parameters
C                       IFRAG=10  
C                 Low energy test
C
C----------------------------------------------------------------
      ELSEIF(IFRAG.EQ.10)THEN
        IF(AEO.LT.4.D0)THEN
C                          Supress S=3/2 Baryons at low energy
C          PARJ(18)=0.D0
C                           Lund b-parameter (default=0.9)
           IF(PPROJ.LE.30.D0)THEN
             PARJ(42)= 0.6D0
           ELSEIF(PPROJ.GE.100.D0)THEN
             PARJ(42)= 6.D0
           ELSE
             DUPAR=(PPROJ-30.D0)/70.D0
             PARJ(42)=0.6D0+DUPAR*5.4D0
           ENDIF
C                           Popcorn
           MSTJ(12)=2
           PARJ(5)=PDB
C                           Lund sigma parameter in pt distribution
C                                             (default=0.35)
           PARJ(21)=0.65D0
           PARJ(23)=0.2D0
           PARJ(24)=2.D0
C                                     extension 16.12--------------------
        ELSEIF(AEO.LT.7.D0)THEN
C                                    4--7  GeV
           AINTER=-(AEO- 7.D0)/3.D0
C                           Lund b-parameter (default=0.9)
           IF(PPROJ.LE.30.D0)THEN
             DD42=0.25D0
           ELSEIF(PPROJ.GE.100.D0)THEN
             DD42=5.65D0
           ELSE
             DUPAR=(PPROJ-30.D0)/70.D0
             DD42=0.25D0+DUPAR*5.4D0
           ENDIF
           PARJ(42)=0.35D0+AINTER*DD42
C                           Lund sigma parameter in pt distribution
C                                             (default=0.35)
           PARJ(21)=0.65D0
           PARJ(23)=0.2D0
           PARJ(24)=2.D0
C                           Popcorn
           MSTJ(12)=2
           PARJ(5)=PDB
C                                     extension 16.12--------------------
      ELSEIF(AEO.LT.10.D0)THEN
C-----------------------------------end test-15.12-----------------------
C                               Test unsuccessful p-p multiplicities too low
C     IF(AEO.LT.10.D0)THEN
C                           Lund b-parameter (default=0.9)
C        PARJ(42)=6.0         before 4.2.94
C        PARJ(42)=0.5         before 21.3.94
         PARJ(42)=0.35D0
C                           Lund sigma parameter in pt distribution
C                                             (default=0.35)
         PARJ(21)=0.55D0
         PARJ(21)=0.65D0
         PARJ(23)=0.2D0
         PARJ(24)=2.D0
C                           Popcorn
           MSTJ(12)=2
           PARJ(5)=PDB
      ELSEIF(AEO.GE.30.D0)THEN
C                           Lund b-parameter (default=0.9)
C        PARJ(42)=1.1 D0      before 21.3.94 
         PARJ(42)=0.5D0
         PARJ(42)=0.35D0
C                           Lund sigma parameter in pt distribution
C                                             (default=0.35)
         PARJ(21)=0.42D0
         PARJ(21)=0.52D0
         PARJ(23)=0.2D0
         PARJ(24)=2.D0
C                           Popcorn
           MSTJ(12)=2
           PARJ(5)=PDB
      ELSE
         AINTER=-(AEO-30.D0)/20.D0
C                           Lund b-parameter (default=0.9)
C        PARJ(42)=1.4D0+AINTER*4.6D0     before 4.2.94
c        PARJ(42)=1.1D0-AINTER*0.6D0     before 21.3.94
         PARJ(42)=0.5D0-AINTER*0.15D0
         PARJ(42)=0.35D0-AINTER*0.00D0
C                           Lund sigma parameter in pt distribution
C                                             (default=0.35)
         PARJ(21)=0.42D0+AINTER*0.13D0
         PARJ(21)=0.52D0+AINTER*0.13D0
         PARJ(23)=0.2D0
         PARJ(24)=2.D0
C                           Popcorn
           MSTJ(12)=2
           PARJ(5)=PDB
      ENDIF
C
      ENDIF
C     IF(IOPT.EQ.5)THEN
C       PARJ(21)=0.46
C     ELSEIF(IOPT.EQ.3)THEN
C       PARJ(21)=0.46
C     ELSEIF(IOPT.EQ.4)THEN
C       PARJ(21)=0.46
C     ENDIF
C
C---------------------------------------------------------
C
C               Change Lund parameters depending on energy
C                           SINGLE DIFFRACTIVE EVENTS
C
C---------------------------------------------------------
C
      IF(IFLAGD.EQ.1)THEN
C                           Lund b-parameter (default=0.9)
           PARJ(42)=0.23D0
C                           Lund sigma parameter in pt distribution
C                                             (default=0.35)
           PARJ(21)=0.55D0
C        IF(AEO.LE.6.D0)THEN
C                           Lund b-parameter (default=0.9)
C   
C          PARJ(42)=0.15
C        ELSEIF(AEO.GE.30.D0)THEN
C                           Lund b-parameter (default=0.9)
C          PARJ(42)=0.4
C        ELSE
C          AINTER=-(AEO-30.)/24.
C                           Lund b-parameter (default=0.9)
C          PARJ(42)=0.4+AINTER*0.25
C        ENDIF 
C        IF(AEO.LE.6.D0)THEN
C                           Lund sigma parameter in pt distribution
C                                             (default=0.35)
C          PARJ(21)=0.85
C        ELSEIF(AEO.LE.10.D0)THEN
C          AINTER=-(AEO-7.)/4.
C                           Lund sigma parameter in pt distribution
C                                             (default=0.35)
C          PARJ(21)=0.55+AINTER*0.30
C        ELSEIF(AEO.GE.30.D0)THEN
C                           Lund sigma parameter in pt distribution
C                                             (default=0.35)
C          PARJ(21)=0.40
C        ELSE
C          AINTER=-(AEO-30.)/20.
C                           Lund sigma parameter in pt distribution
C                                             (default=0.35)
C          PARJ(21)=0.40+AINTER*0.15
C       ENDIF
      ENDIF
C
C--------------------------------------------------------
C
C--------------------------------------------------------
C
C       Check and modify flavors at chain ends depending on energy
C       and define Lund flavor parameters
C
C--------------------------------------------------------
C
C        IOPT = 3              Quark-Antiquark
C
C--------------------------------------------------------
C
  111 CONTINUE
      IF(IOPT.EQ.3)THEN
	IF((KFA1.LE.0.OR.KFA1.GT.10).OR.
     *     (KFA2.LE.0.OR.KFA2.GT.10))THEN
	  KFA11=KFA1
	  KFA22=KFA2
	  KFA1=1
	  KFA2=7
	  IWARN=IWARN+1
	  IF(IWARN.LE.-20)WRITE(6,*)
     *	  ' BAMLUN KFA1,KFA2:',KFA11,KFA22,
     *                            ' changed into :',KFA1,KFA2	  
	ENDIF
	IF(((KFA1.EQ.4.OR.KFA1.EQ.10).AND.
     *     (KFA2.EQ.4.OR.KFA2.EQ.10)).AND.AEO.LE.4.2D0)THEN
          KFA11=KFA1
          KFA22=KFA2
	  KFA1=1
	  IWARN=IWARN+1
	  IF(IWARN.LE.-20)WRITE(6,*)
     *	  ' BAMLUN KFA1,KFA2 at energy AEO:',KFA11,KFA22,AEO,
     *    ' changed into:',KFA1,KFA2
        ENDIF
	IF(((KFA1.EQ.4.OR.KFA1.EQ.10).OR.
     *     (KFA2.EQ.4.OR.KFA2.EQ.10)).AND.AEO.LE.2.5D0)THEN
          KFA11=KFA1
          KFA22=KFA2
	  KFA1=1
	  KFA2=7
	  IWARN=IWARN+1
	  IF(IWARN.LE.-20)WRITE(6,*)
     *	  ' BAMLUN KFA1,KFA2 at energy AEO:',KFA11,KFA22,AEO,
     *    ' changed into:',KFA1,KFA2
	ENDIF
	IF(((KFA1.EQ.3.OR.KFA1.EQ.9).AND.
     *     (KFA2.EQ.3.OR.KFA2.EQ.9)).AND.AEO.LE.1.5D0)THEN
          KFA11=KFA1
          KFA22=KFA2
	  KFA1=2
	  IWARN=IWARN+1
	  IF(IWARN.LE.-20)WRITE(6,*)
     *	  ' BAMLUN KFA1,KFA2 at energy AEO:',KFA11,KFA22,AEO,
     *    ' changed into:',KFA1,KFA2
        ENDIF
	IF(((KFA1.EQ.3.OR.KFA1.EQ.9).OR.
     *     (KFA2.EQ.3.OR.KFA2.EQ.9)).AND.AEO.LE.1.0D0)THEN
          KFA11=KFA1
          KFA22=KFA2
	  KFA1=2
	  KFA2=8
	  IWARN=IWARN+1
	  IF(IWARN.LE.-20)WRITE(6,*)
     *	  ' BAMLUN KFA1,KFA2 at energy AEO:',KFA11,KFA22,AEO,
     *    ' changed into:',KFA1,KFA2
	ENDIF
        IF(AEO.LT.0.8D0)THEN
          IREJ=1
	  NBAML=NBAML+1
          IF(NBAML.LT.-20)WRITE(6,*)' REJECTION IN BAMLUN '
          RETURN
        ENDIF
        IFLA1=NBAMLU(KFA1)
        IFLA2=NBAMLU(KFA2)
C
C--------------------------------------------------------
C
C            IOPT = 4          Quark-Diquark
C
C--------------------------------------------------------
C
      ELSEIF(IOPT.EQ.4)THEN
        IF(AEO.LT.1.5D0)THEN
          IREJ=1
	  NBAML=NBAML+1
          IF(NBAML.LT.-20)WRITE(6,*)' REJECTION IN BAMLUN '
          RETURN
        ENDIF
	IF((KFA1.LE.0.OR.KFA1.GT.10).OR.
     *     (KFA2.LE.0.OR.KFA2.GT.10).OR. 
     *     (KFA2.LE.0.OR.KFA3.GT.10))THEN
          KFA11=KFA1
          KFA22=KFA2
          KFA33=KFA3
	  KFA1=1
	  KFA2=2
	  KFA3=1
	  IWARN=IWARN+1
	  IF(IWARN.LE.-20)WRITE(6,*)
     *	  ' BAMLUN KFA1,KFA2,KFA3:',
     *	  KFA11,KFA22,
     *                 KFA33,' changed into :',KFA1,KFA2,KFA3	  
	ENDIF
        IF(((KFA1.EQ.4).OR.(KFA1.EQ.10).OR.
     *(KFA2.EQ.4).OR.(KFA2.EQ.10).OR.
     *(KFA3.EQ.4).OR.(KFA3.EQ.10)).AND.(AEO.LT.3.5D0))THEN
          KFA11=KFA1
          KFA22=KFA2
          KFA33=KFA3
          KFA1=1
          KFA2=1
          KFA3=2
	  IWARN=IWARN+1
	  IF(IWARN.LE.-10)WRITE(6,*)
     *	  ' BAMLUN KFA1,KFA2,KFA3 at energy AEO:',KFA11,KFA22,KFA33,AEO,
     *    ' changed into:',KFA1,KFA2,KFA3
        ENDIF
        IF(AEO.LT.1.25D0)THEN
          KFA11=KFA1
          KFA22=KFA2
          KFA33=KFA3
          KFA1=1
          KFA2=7
          KFA3=0
	  IWARN=IWARN+1
	  IF(IWARN.LE.-20)WRITE(6,*)
     *	  ' BAMLUN KFA1,KFA2,KFA3 at energy AEO:',KFA11,KFA22,KFA33,AEO,
     *    ' changed into:',KFA1,KFA2,KFA3
          IOPT=3
          GO TO 111
        ENDIF
        IFLA1=NBAMLU(KFA1)
        IFL2=NBAMLU(KFA2)
        IFL3=NBAMLU(KFA3)
        IF(ABS(IFL3).GT.ABS(IFL2))THEN
          IFL22=IFL2
          IFL2=IFL3
          IFL3=IFL22
        ENDIF
        IFLA2=1000*ABS(IFL2)+100*ABS(IFL3)
        IFLZ=3
        IF(ABS(IFL3).LT.ABS(IFL2).AND.RNDM(U).LE.0.25D0)IFLZ=1
        IFLA2=IFLA2+IFLZ
        IF(IFL2.LT.0)IFLA2=-IFLA2
C       IF(IFLA1.EQ.-1.AND.IFLA2.EQ.-3303)IPRI=2
C
C--------------------------------------------------------
C
C            IOPT = 5         DiQuark-AntiDiquark
C
C--------------------------------------------------------
C
      ELSEIF(IOPT.EQ.5)THEN
        IFL1=NBAMLU(KFA1)
        IFL2=NBAMLU(KFA2)
        IF(ABS(IFL2).GT.ABS(IFL1))THEN
          IFL11=IFL1
          IFL1=IFL2
          IFL2=IFL11
        ENDIF
        IFL3=NBAMLU(KFA3)
        IFL4=NBAMLU(KFA4)
        IF(ABS(IFL4).GT.ABS(IFL3))THEN
          IFL33=IFL3
          IFL3=IFL4
          IFL4=IFL33
        ENDIF
        IFLA1=1000*ABS(IFL1)+100*ABS(IFL2)
        IFLA2=1000*ABS(IFL3)+100*ABS(IFL4)
        IFLZ=3
        IF(ABS(IFL2).LT.ABS(IFL1).AND.RNDM(U).LE.0.25D0)IFLZ=1
        IFLA1=IFLA1+IFLZ
        IF(IFL1.LT.0)IFLA1=-IFLA1
        IFLZ=3
        IF(ABS(IFL4).LT.ABS(IFL3).AND.RNDM(U).LE.0.25D0)IFLZ=1
        IFLA2=IFLA2+IFLZ
        IF(IFL3.LT.0)IFLA2=-IFLA2
C
C--------------------------------------------------------
C
C            IOPT = 10        DiQuark-AntiDiquark
C
C--------------------------------------------------------
C
      ELSEIF(IOPT.EQ.10)THEN
        IFLA1=NBAMLU(KFA1)
        IFLA2=NBAMLU(KFA2)
        IFLA3=NBAMLU(KFA3)
      ENDIF
      IF(IPRI.GE.1)WRITE(6,*)IFLA1,IFLA2,AEO,IFLA3
C     WRITE(6,103)IFLA1,IFLA2,AEO,' BAMLUN'
  103 FORMAT(' BAMLUN',2I10,F10.2,I10)
C
C---------------------------------------------------------------------------
C
C               JETSET Call
C
C---------------------------------------------------------------------------
C
C--------------------------------------------------
C                       IHARLU=0  soft jets fragmenting
C                       IHARLU=1  hard jets fragmenting
C                                 with final state evolution
C                                 in JETSET
C                       QLUN = Mass of hard partons at end of
C                              chain
C-----------------------------------------------------------
C     CALL PY2ENT(0,IFLA1,IFLA2,AEO)
C----------------------------------------------------------
      IF(IOPT.EQ.10)THEN
	XX1=XXX1
	XX3=XXX3
	XX2=1.D0-XX1
	ICOU=0
 1234   CONTINUE
	ICOU=ICOU+1
	IF(ICOU.GE.100)THEN
 	  WRITE(6,*)" Stop in dpmlund IOPT=10"
	  STOP
        ENDIF
C                       Select sea q--aq pair
	CALL XSEAPA(AEO,XXXX,ISQ,ISAQ,XSQ,XSAQ,IREJ)
	WRITE(6,*)ISQ,ISAQ,XSQ,XSAQ,XX1
C	IF(XSQ+XSAQ.GE.XX1/2.D0)GO TO 1234
	IF(XSQ.GE.XX1/2.D0.OR.XSAQ.GE.XX3/2.D0)GO TO 1234
C	IF(XSQ.LE.XX2)GO TO 1234
	XX1=XX1-XSQ
	XX3=XX3-XSAQ
        IFLASQ=NBAMLU(ISQ)
        IFLASA=NBAMLU(ISAQ)

	IF(IFLA1.GT.0)THEN
C                      Form diquark out of IFLA2 and IFLASQ
          IF(ABS(IFLASQ).GT.ABS(IFLA2))THEN
            IFl11=IFLA2
            IFLA2=IFLASQ
            IFLASQ=IFL11
          ENDIF
          IFLAD=1000*ABS(IFLA2)+100*ABS(IFLASQ)
          IFLZ=3
          IF(ABS(IFLASQ).LT.ABS(IFLA2).AND.RNDM(U).LE.0.25D0)IFLZ=1
          IFLAD=IFLAD+IFLZ
        	WRITE(6,'(4I10)')IFLA1,IFLAD,IFLASA,IFLA3
	CALL PY4ENT(1,IFLA1,IFLAD,IFLASA,IFLA3,AEO,
     *	XX1,XX2+XSQ,XX3,0.D0,4.D0*XX1*XX3)
C    *	XX1,XX2+XSQ,XX3,4.D0*XX1*(XX2+XSQ),4.D0*XX1*XX3)
C     *	XX1,XX2+XSQ,XX3,(XX1-XX2-XSQ)**2,4.D0*XX1*XX3)
          IJOIN(1)=1 
	IJOIN(2)=3 
	CALL PYJOIN(2,IJOIN) 
        IJOIN(1)=2 
	IJOIN(2)=4 
	CALL PYJOIN(2,IJOIN) 
	CALL PYEXEC
	ELSEIF(IFLA1.LT.0)THEN
C                      Form anti-diquark out of IFLA2 and IFLASA
        IF(ABS(IFLASA).GT.ABS(IFLA2))THEN
          IFl11=IFLA2
          IFLA2=IFLASA
          IFLASA=IFL11
        ENDIF
        IFLAD=1000*ABS(IFLA2)+100*ABS(IFLASA)
        IFLZ=3
        IF(ABS(IFLASA).LT.ABS(IFLA2).AND.RNDM(U).LE.0.25D0)IFLZ=1
        IFLAD=IFLAD+IFLZ
        IF(IFLA2.LT.0)IFLAD=-IFLAD
	WRITE(6,'(4I10)')IFLA1,IFLAD,IFLASQ,IFLA3
	CALL PY4ENT(1,IFLA1,IFLAD,IFLASQ,IFLA3,AEO,
     *  XX1,XX2+XSAQ,XX3,0.D0,XX1*XX3)
        IJOIN(1)=1 
	IJOIN(2)=3 
	CALL PYJOIN(2,IJOIN) 
        IJOIN(1)=2 
	IJOIN(2)=4 
	CALL PYJOIN(2,IJOIN) 
	CALL PYEXEC
	ENDIF
      ELSE
        IF(IHARLU.EQ.0)THEN
          CALL PY2ENT(0,IFLA1,IFLA2,AEO)
          PXP(1)=0.
          PYP(1)=0.
          PZP(1)=AEO/2.D0
          HEP(1)=AEO/2.D0
          PXP(2)=0.D0
          PYP(2)=0.D0
          PZP(2)=AEO/2.D0
          HEP(2)=AEO/2.D0
          NNNP=2
        ELSEIF(IHARLU.EQ.1)THEN
          CALL PY2ENT(-1,IFLA1,IFLA2,AEO)
          CALL PYSHOW(1,2,QLUN)
          DO 201 I=1,N
            IF(K(I,1).EQ.3)THEN
              NNNP=NNNP+1
              IF(NNNP.LT.1000)THEN
              PXP(NNNP)=P(I,1)
              PYP(NNNP)=P(I,2)
              PZP(NNNP)=P(I,3)
              HEP(NNNP)=P(I,4)
              ENDIF
            ENDIF
  201     CONTINUE
          IF(IPRI.GE.2)CALL PYLIST(1)
          CALL PYEXEC
C         CALL PYLIST(1)
        ENDIF
      ENDIF
C                                     Force all particles wanted to decay
      DO 1111 IIII=1,N
        IF(K(IIII,1).EQ.4)K(IIII,1)=5
 1111 CONTINUE
      CALL PYEXEC
C
      IF(IPRI.GE.2)WRITE(6,*)' After PYEXEC'
      IF(IPRI.GE.2)CALL PYLIST(1)
C         CALL PYLIST(1)
C         IF(IPRI.GE.2)CALL PYLIST(1)
C
C---------------------------------------------------------------------------
C
C               Edit JETSET event
C
C---------------------------------------------------------------------------
C
      CALL PYEDIT(12)
      ICOUN=ICOUN+1
      IF(IPRI.GE.2)WRITE(6,*)' After PYEDIT'
C         CALL PYLIST(1)
      IF(IPRI.GE.2)CALL PYLIST(1)
C
C---------------------------------------------------------------------------
C
C               Move JETSET event into BAMJET COMMON
C
C---------------------------------------------------------------------------
C
      IHAD=0
C                      EXISTING PARTICLES
         IF(IPRI.GE.2) WRITE(6,*)' DPMJET COMMON  particles'
      IORII=0	  
      KORJJJ=0
      DO 101 I=1,N
        IF((K(I,1).EQ.11).AND.(K(I,2).EQ.92))THEN
	  IORII=999
	  KORII=I
C         KORJJJ is the first string	  
	  IF(KORJJJ.EQ.0)KORJJJ=I
	ENDIF  
        IF((K(I,1).EQ.11).AND.(K(I,2).EQ.91))THEN
	  IORII=999
	  KORII=I
C         KORJJJ is the first string	  
	  IF(KORJJJ.EQ.0)KORJJJ=I
	ENDIF  
C       KORIII(I) is the string from which particle I comes	
	KORIII(I)=KORII
C       IF(K(I,1).EQ.1) THEN
        IF(K(I,1).EQ.1.OR.K(I,1).EQ.11.OR.K(I,1).EQ.15)THEN
          IF(K(I,2).EQ.92) GO TO 101
          IF(K(I,2).EQ.91) GO TO 101
          IF(K(I,2).EQ.94) GO TO 101
          IF(ABS(K(I,2)).LE.6) GO TO 101
          IF(ABS(K(I,2)).GE.1000) THEN
	    KOO=ABS(K(I,2))
	    KAA=KOO/100
	    KLL=KOO-KAA*100
	    IF(KLL.EQ.1.OR.KLL.EQ.3)GO TO 101
	  ENDIF
          IHAD=IHAD+1
          IF(IHAD.GT.NFIMAX)THEN
            WRITE(6,1112)IHAD
 1112       FORMAT(' BAMLUN: IHAD.GT.NFIMAX INCREASE NFIMAX IHAD=',I10)
            GO TO 101 
          ENDIF
	  IF(K(I,3).EQ.KORIII(I))THEN
C           Hadrons from string
            IORMO(IHAD)=IORII
	  ELSE
C           Hadrons from decaying particle	  
	    IF(KORJJJ.EQ.KORIII(K(I,3)))THEN
              IORMO(IHAD)=K(I,3)-KORJJJ
	    ELSE
              IORMO(IHAD)=K(I,3)-KORJJJ-1
	    ENDIF  
	  ENDIF
          PXF(IHAD)=P(I,1)
          PYF(IHAD)=P(I,2)
          PZF(IHAD)=P(I,3)
          HEF(IHAD)=P(I,4)
          NREFB=MCIHAD(K(I,2))
	  AMASSS=PYMASS(K(I,2))
          IF(IPRI.GE.3)WRITE(6,'(4I10)')I,K(I,1),K(I,2),NREFB
          IF(NREFB.LT.1.OR.NREFB.GT.183)NREFB=4
          NREF(IHAD)=NREFB
          ANF(IHAD)=ANAME(NREFB)
C         AMF(IHAD)=AM(NREFB)
          AMF(IHAD)=AMASSS
C	  WRITE(6,*)' IHAD,AMF(IHAD),AMASSS ',IHAD,AMF(IHAD),AMASSS
          ICHF(IHAD)=ICH(NREFB)
          IBARF(IHAD)=IBAR(NREFB)
	  ISTATH(IHAD)=1
          IF(K(I,1).EQ.11.OR.K(I,1).EQ.15)THEN
	    IBARF(IHAD)=500
	    ISTATH(IHAD)=2
	  ENDIF  
C
C         IF(NREFB.EQ.31.OR.NREFB.EQ.95)THEN
C	  WRITE(6,*)'K(I,1),IBARF(IHAD),ISTATH(IHAD)',
C    *	  K(I,1),IBARF(IHAD),ISTATH(IHAD)
C	  WRITE(6,*)ICOUN,IHAD,K(I,2),NREFB,K(I,3),
C    *	  ISTATH(IHAD),IORMO(IHAD),ANF(IHAD),
C    *                PXF(IHAD),PYF(IHAD),
C    *                PZF(IHAD),HEF(IHAD),AMF(IHAD),' BAMLUN'
C         ENDIF
          IF(IPRI.GE.3)WRITE(6,*)ICOUN,IHAD,K(I,2),NREFB,K(I,3),
     *	  ISTATH(IHAD),IORMO(IHAD),ANF(IHAD),
     *                PXF(IHAD),PYF(IHAD),
     *                PZF(IHAD),HEF(IHAD),AMF(IHAD),' BAMLUN'
  102     FORMAT(' BAMLUN',2I5,5I10,A8,5E12.3)
C
        ENDIF
  101 CONTINUE
C                            DECAYED RESONAMCES TO BE PUT INTO EVENT RECORD
C                            NOTE: PARTICLES with IBARF=500 are decayed
      IF(JNI.NE.7)GO TO 777
      IF(JNI.NE.7)THEN
C         WRITE(6,*)' DPMJET COMMON decayed particles'
      IORII=0	  
      DO 105 I=1,N
        IF(K(I,1).EQ.11.AND.K(I,2).EQ.92)THEN
	  IORII=999
	  KORII=I
	ENDIF  
        IF(K(I,1).EQ.11.OR.K(I,1).EQ.15)THEN
          IF(K(I,2).EQ.92) GO TO 105
          IF(K(I,2).EQ.94) GO TO 105
          IF(ABS(K(I,2)).LE.6) GO TO 105
          IHAD=IHAD+1
          IF(IHAD.GT.NFIMAX)THEN
            WRITE(6,1112)IHAD
            GO TO 107 
          ENDIF
	  IF(K(I,3).EQ.KORII)THEN
C           Hadrons from string
            IORMO(IHAD)=IORII
	  ELSE
	    IORMO(IHAD)=K(I,3)-KORII
	  ENDIF
          PXF(IHAD)=P(I,1)
          PYF(IHAD)=P(I,2)
          PZF(IHAD)=P(I,3)
          HEF(IHAD)=P(I,4)
          NREFB=MCIHAD(K(I,2))
	  AMASSS=PYMASS(K(I,2))
          IF(IPRI.GE.3)WRITE(6,'(5I10)')I,K(I,1),K(I,2),K(I,3),NREFB
          IF(NREFB.LT.1.OR.NREFB.GT.183)NREFB=4
          NREF(IHAD)=NREFB
          ANF(IHAD)=ANAME(NREFB)
C         AMF(IHAD)=AM(NREFB)
          AMF(IHAD)=AMASSS
          ICHF(IHAD)=ICH(NREFB)
          IBARF(IHAD)=500
C
          IF(IPRI.GE.3)WRITE(6,102)ICOUN,IHAD,K(I,2),NREFB,K(I,3),
     *	  IORMO(IHAD),ANF(IHAD),
     *                PXF(IHAD),PYF(IHAD),
     *                PZF(IHAD),HEF(IHAD),AMF(IHAD)
C
        ENDIF
  105 CONTINUE
      ENDIF
  777 CONTINUE
  107 CONTINUE
C
C---------------------------------------------------------------------------
C
      IF(IFLA1.EQ.-1.AND.IFLA2.EQ.-3303)IPRI=0
      RETURN
      END
      SUBROUTINE XSEAPA(ECM,XXXX,IPSQ1,IPSAQ1,XPSQ1,XPSAQ1,IREJ)
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
*KEEP,DPRIN.
      COMMON /DPRIN/  IPRI,IPEV,IPPA,IPCO,INIT,IPHKK,ITOPD,IPAUPR
      COMMON /SEASU3/SEASQ
      SAVE
          IREJ=0
          IF(ECM.LT.20.D0)THEN
            XPTHRO=1.5D0*LOG10(ECM/200.D0)+3.5D0
          ELSEIF(ECM.GE.20.D0)THEN
            XPTHRO=5.0D0
          ENDIF
          XPTHR=1.5D0*XPTHRO/(ECM**1.5D0*14.D0)
C         XSTHR2=1.5D0*XPTHR2/(ECM**1.5D0*14.D0)
          IF(IPCO.GE.1)WRITE(6,*)' XSEAPA:XPTHR ',XPTHR
	  I=1
          AI=I-1
          XPTHRX=XPTHR-0.5D0*AI/ECM**2
          IF (XPTHRX.LT.4.D0/ECM**2)XPTHRX=4.D0/ECM**2
C---------------------------------------------------------------
C                              SPLIT GLUON INTO TWO SEA QUARKS
C                              FLAVORS OF SEA QUARKS
C         INCREASE s-quark fraction to acount for larger rejection
          SEASQQ=2.D0*SEASQ
          AI=I
          BI=I+I
          IPSQ1=1.+RNDM(AI)*(2.D0+SEASQQ)
          IPSAQ1=-IPSQ1
          IPSAQ1=6+IPSQ1
          IF(IPCO.GE.1)
     &    WRITE(6,*)' XSEAPA SEASQQ,IPSQ1,IPSAQ1',SEASQQ,IPSQ1,IPSAQ1
C                              X-FRAXTIONS OF SEA QUARKS
C------------------------------------------------------j.r.29.4.93
	          SOX1=0.3D0
              NCOU=0
  500         CONTINUE
              NCOU=NCOU+1
	      IF(IPSQ1.EQ.3)THEN
                IF(NCOU.GE.200)THEN
	 	  IREJ=3
	          RETURN
		ENDIF
              ELSE		
                IF(NCOU.GE.50)THEN
	          IREJ=1
	          RETURN
		ENDIF  
	      ENDIF
              XGLU1=SAMPEX(XPTHRX,SOX1)
              IF(IPCO.GE.1)WRITE(6,*)' XSEAPA: XGLU1,XPSQ1,XPSAQ1,ECM=',
     &           XGLU1,XPSQ1,XPSAQ1,ECM
C          Change J.R. 4.12.2000
          XPSQ1=(0.2D0+(0.36D0*RNDM(AI))**0.50D0)*XGLU1
          XPSAQ1=XGLU1-XPSQ1
          IF(IPSQ1.EQ.3)THEN
            IF (XPSQ1.LE.0.3D0/ECM)GO TO 500
            IF (XPSAQ1.LE.0.3D0/ECM)GO TO 500
          ENDIF
          IF(XPSAQ1.GE.XXXX)GO TO 500
	  RETURN
	  END
C------------------------------------------------------------
C             was dpmtcbsh.f
C------------------------------------------------------------
C
C     file with changes of r.e. 20.12.93 old file: d4tcbshm.fold
*-- Author :
C        PROGRAM SHMAKOV    11/1986
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C  THE PROGRAM SIMULATES THE STARS OF THE SECONDARY PARTICLES IN NUCLEUS
C  -NUCLEUS COLLISIONS AT HIGH ENERGIES. THE SIMULATION IS BASED ON
C  GLAUBER APPROACH. EACH STAR IS MADE UP AS THE SUM OVER THE ORDERED N-
C  N STARS. MESON PRODUCTION IS ONLY TAKEN INTO ACCOUNT.
C       LET'S DISCRIBE THE MAIN PARAMETERS OF THE PROGRAM IN FORM:
C  FIRST LIST OF THE PARAMETERS - MEANING - (BOUNDS); AND SO ON.
C  NA,NB - AMOUNT OF NUCLONS IN NUCLEI A AND B - (GT.1,LT.41,
C  PREFERENTIALLY NA LT. NB)
C  NCA,NCB - AMOUNT OF PROTONS IN THE NUCLEI
C  RA,RB - THE RADII TO USE INTO FORMULARS FOR THE NUCLEAR DENSITIES -(F
C  SIG,G,RO - THE PARAMETERS OF THE N-N ELASTIC AMPLITUDE,
C  AMLITUDE(B)=SIG*G*(1-I*RO)*EXP(-G*B**2)/2PI - (FM**2,FM**(-2) AND
C  DIMENSIONLESS ACCORDIANLY)
C  SE2 - QUADRATE OF THE TOTAL 4-MOMENTUM BOTH NUCLEI - (GEV**2,
C  GT. (NA+NB)**2,PREFERENTIALLY GT. 4*(NA+NB)**2)
C  TF01,TF02 - FERMI ENERGIES IN THE CENTERS OF THE NUCLEI - (GEV)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
      SUBROUTINE SHMAKI(NA,NCA,NB,NCB,RPROJ,RTARG,PPN)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
C*** SHMAKOV INITIALIZATION
*KEEP,DSHM.
      COMMON /DSHM/ RASH,RBSH,BMAX,BSTEP,SIGSH,ROSH,GSH,
     *              BSITE(0:1,200),NSTATB,NSITEB
      COMMON /DSHMS/ SIGSHS
*KEEP,RTAR.
      COMMON /RTAR/ RTARNU
*KEEP,NUCC.
      COMMON /NUCC/   IT,ITZ,IP,IPZ,IJPROJ,IBPROJ,IJTARG,IBTARG
*KEND.
      COMMON /ZENTRA/ ICENTR
      COMMON /SIGLA/SIGLAU
      COMMON /KGLAUB/JGLAUB
C--------------------------------------
      RNA=NA
      RNB=NB
      RASH=1.12D0*RNA**0.33D0
      RBSH=1.12D0*RNB**0.33D0
      IF(JGLAUB.EQ.1)THEN
        IF(NA.EQ.9)RASH=2.52D0
        IF(NA.EQ.10)RASH=2.45D0
        IF(NA.EQ.11)RASH=2.37D0
        IF(NA.EQ.12)RASH=2.45D0
        IF(NA.EQ.13)RASH=2.44D0
        IF(NA.EQ.14)RASH=2.55D0
        IF(NA.EQ.15)RASH=2.58D0
        IF(NA.EQ.16)RASH=2.71D0
        IF(NA.EQ.17)RASH=2.66D0
        IF(NA.EQ.18)RASH=2.71D0
        IF(NB.EQ.9)RBSH=2.52D0
        IF(NB.EQ.10)RBSH=2.45D0
        IF(NB.EQ.11)RBSH=2.37D0
        IF(NB.EQ.12)RBSH=2.45D0
        IF(NB.EQ.13)RBSH=2.44D0
        IF(NB.EQ.14)RBSH=2.55D0
        IF(NB.EQ.15)RBSH=2.58D0
        IF(NB.EQ.16)RBSH=2.71D0
        IF(NB.EQ.17)RBSH=2.66D0
        IF(NB.EQ.18)RBSH=2.71D0
      ENDIF
      WRITE(6,*)' SHMAKI: RASH, RBSH = ',RASH,RBSH
      RPROJ=RASH
      RTARG=RBSH
      RTARNU=RBSH
      NSTATB=2000
      IF((ICENTR.EQ.1).AND.(NA.GE.200).AND.(NB.GE.200))THEN
	NSTATB=1000
      ENDIF
      NSITEB=200
      WRITE(6, 1010)NSTATB,NSITEB
 1000 FORMAT(2I10)
 1010 FORMAT(' STATISTIC ON POINT ON B AND NUMBER OF POINTS',2I10)
C*** PARAMETERS IN NN-AMP.
      SIGSH=4.3
      PPNN=PPN
      WRITE(6,*)' SMAKI, PPN = ',PPN
      SIGSH=DSHPTO(IJPROJ,PPN)/10.D0
C     IF(NA.GT.0.D0)
C    *SIGSH=(DSHPTO(IJPROJ,PPNN)-SIGSDS(PPNN*2.D0))/10.D0
      IF(JGLAUB.EQ.2)THEN
        SIGSHS=(DSHPTO(IJPROJ,PPNN)-SIGSDS(PPNN*2.D0))/10.D0
      ELSEIF(JGLAUB.EQ.1)THEN
        SIGSHS=(DSHPTO(IJPROJ,PPNN))/10.D0
      ENDIF
      IF(IJPROJ.EQ.5)THEN
      SIGSHS=(DSHPTO(1,PPNN)-SIGSDS(PPNN*2.D0))/10.D0
      ENDIF
      SIGSH=SIGSHS
      GSH=1.6
      BSLOPE=10.D0
      SSS=2.*PPN
      ECM=SQRT(SSS)
      IF (IJPROJ.LE.12)BSLOPE=8.5D0*(1.D0+0.065D0*LOG(SSS))
      IF (IJPROJ.GT.12)BSLOPE=6.D0*(1.D0+0.065D0*LOG(SSS))
      GSH=1.D0/(2.D0*BSLOPE*0.038938D0)
      ROSH=-0.43D0
      IF (IJPROJ.LE.12)THEN
      IF(ECM.GT.3.0D0.AND.ECM.LE.50.D0) ROSH=-0.63D0+
     +                               0.175D0*LOG(ECM)
      IF(ECM.GT.50.) ROSH=0.1D0
      ENDIF
      IF (IJPROJ.GT.12) ROSH=0.01D0
      WRITE(6, 1030)SIGSH,ROSH,GSH,BSLOPE,ECM
 1020 FORMAT(3F10.5)
 1030 FORMAT(' PARAMETERS OF THE NN AMPLITUDE SIG,RO,G,BSLOPE,ECM ' /5
     +(1PE12.5))
      CALL TITLE(NA,NB,NCA,NCB)
      WRITE(6,*)' vor PREVIO(RA,RB,NSTB,BMAX,BSTEP,SIG,RO,G)',
     &RASH,RBSH,NSITEB,BMAX,BSTEP,SIGSH,ROSH,GSH
      CALL PREVIO(RASH,RBSH,NSITEB,BMAX,BSTEP,SIGSH,ROSH,GSH)
      WRITE(6,*)' SHMAKI: RASH, RBSH = ',RASH,RBSH
      CALL PROFB(BSTEP,NSTATB,NA,RASH,NB,RBSH,BSITE,NSITEB)
      WRITE(37,'(4I5,F15.2,E15.5,F15.2)')
     * NA,NCA,NB,NCB,SIGSH,PPN,SIGLAU
      RETURN
      END
      DOUBLE PRECISION FUNCTION SIGSDS(S)
C                  Approximate sigma_SD in p-p (mb)      
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      SIGSDS=4.D0+1.2D0*LOG10(S)
      RETURN
      END
*-- Author :
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
      SUBROUTINE SHMAKF(NA,NCA,NB,NCB)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
C***     SHMAKOV INITIALIZATION
C***     To be called for each material separately
C***     Input of Shmakov data from file:
C***           1) 'NUCLEUS'      IT, ITZ
C***           2) BMAX, BSTEP, RASH, RBSH
C***           3) BSITE (energy and projectile dependence)
C-----------------------
      CHARACTER*10 BNUC
*KEEP,DSHM.
      COMMON /DSHM/ RASH,RBSH,BMAX,BSTEP,SIGSH,ROSH,GSH,
     *              BSITE(0:1,200),NSTATB,NSITEB
      COMMON /DSHMS/ SIGSHS
*KEEP,RTAR.
      COMMON /RTAR/ RTARNU
*KEEP,NUCC.
      COMMON /NUCC/   IT,ITZ,IP,IPZ,IJPROJ,IBPROJ,IJTARG,IBTARG
*KEEP,DTUMAT.
      COMMON /DTUMAT/ BSITEN(200,24,50),BSITEM(200,24,50),
     +                RPROJJ(50),RTARGG(50),BSTEPP(50),BMAXX(50),
     +                NTAXX(50),NZTAXX(50),NPRXX(50),NZPRXX(50)
*KEEP,DAMP.
      COMPLEX*16 CA,CI
      COMMON /DAMP/   CA,CI,GA
*KEND.
      COMMON /KKMATU/KKMATO,KKMATA,IPOO,IPOA,IPZOO,IPZOA
     *,IBPROO,IBPROA,IREADO
      DIMENSION HELP(200)
      DATA MATNUM /0/
C--------------------------------------
      KKMATO=0
      IPOO=0
      IPZOO=0
      IBPROO=0
      IREADO=0
      REWIND 47
      MATNUM=MATNUM + 1
      IF(MATNUM.GT.50) THEN
      WRITE(6,'(2A,I3/A)')
     &  ' Too large number of materials requested for Glauber',
     &  ' initialization in SHMAKF / MATNUM=',MATNUM,
     &  ' execution stopped in SHMAKF'
      STOP
      ENDIF
      WRITE(6,'(A,I3,A)') ' Read Glauber data for material no.',MATNUM,
     &                    ' from unit 47'
C----------------------------------Read Glauber data----------------
      DO 72 I=1,100000
        READ(47,'(A10)',END=79) BNUC
        IF(BNUC.EQ.' NUCLEUS  ') THEN
          BACKSPACE 47
          READ(47,'(A10,4I10)') BNUC,NPRX,NZPRX,NTAX,NZTAX
          IF(NB.EQ.NTAX.AND.NCB.EQ.NZTAX.AND.NA.EQ.NPRX.
     &	  AND.NCA.EQ.NZPRX) THEN
          NTAXX(MATNUM)=NTAX
          NZTAXX(MATNUM)=NZTAX
	  NPRXX(MATNUM)=NPRX
	  NZPRXX(MATNUM)=NZPRX
        READ(47,'(4F10.5)') BMAXX(MATNUM),BSTEPP(MATNUM),
     &                        RPROJJ(MATNUM),RTARGG(MATNUM)
        DO 170 IE=1,24
            READ(47,'(5E16.8)') (BSITEN(IDA,IE,MATNUM),IDA=1,200)
 170      CONTINUE
          IF(NPRX.EQ.1)THEN
            DO 171 IE=1,24
              READ(47,'(5E16.8)') (BSITEM(IDA,IE,MATNUM),IDA=1,200)
 171        CONTINUE
          ENDIF
        GOTO 78
        ENDIF
      ENDIF
 72   CONTINUE
 79   CONTINUE
      WRITE(6,'(A)') ' GLAUBER DATA NOT FOUND'
      STOP
 
 78   CONTINUE
C     DO 80 I=1,200
C     HELP(I)=I*BSTEPP(MATNUM)
C     WRITE (6,1040) HELP(I),(BSITEN(I,IE,MATNUM),IE=1,24)
C1040   FORMAT (F10.4,10(1PE12.4)/10(1PE12.4))
C  80 CONTINUE
C-------------------------------------------------------------------
      RETURN
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE SHMAKO(NA,NB,B,INTT,INTA,INTB,JS,JT,PPN,KKMAT)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      PARAMETER(NAMX=248)
      PARAMETER (INTMX=2488,INTMD=252)
      DIMENSION JS(NAMX),JT(NAMX)
*KEEP,DPRIN.
      COMMON /DPRIN/  IPRI,IPEV,IPPA,IPCO,INIT,IPHKK,ITOPD,IPAUPR
*KEEP,NUCKOO.
      COMMON /NUCKOO/ PKOO(3,INTMX),TKOO(3,INTMX),PPOO(3,INTMX),
     +TPOO(3,INTMX)
*KEEP,DSHM.
      COMMON /DSHM/ RASH,RBSH,BMAX,BSTEP,SIGSH,ROSH,GSH,
     *              BSITE(0:1,200),NSTATB,NSITEB
      COMMON /DSHMS/ SIGSHS
*KEEP,NUCC.
      COMMON /NUCC/   IT,ITZ,IP,IPZ,IJPROJ,IBPROJ,IJTARG,IBTARG
*KEEP,INTMX.
*KEEP,SHMAKL.
C     INCLUDE (SHMAKL)
* NOTE: INTMX set via INCLUDE(INTMX)
      COMMON/SHMAKL/JSSH(INTMX),JTSH(INTMX),INTER1(INTMX),INTER2(INTMX)
*KEEP,DTUMAT.
      COMMON /DTUMAT/ BSITEN(200,24,50),BSITEM(200,24,50),
     +                RPROJJ(50),RTARGG(50),BSTEPP(50),BMAXX(50),
     +                NTAXX(50),NZTAXX(50),NPRXX(50),NZPRXX(50)
*KEEP,RTAR.
      COMMON /RTAR/ RTARNU
*KEEP,DAMP.
      COMPLEX*16 CA,CI
      COMMON /DAMP/   CA,CI,GA
*KEEP,RPTSHM.
      COMMON /RPTSHM/ RPROJ,RTARG,BIMPAC
*KEND.
      COMMON /KKMATU/KKMATO,KKMATA,IPOO,IPOA,IPZOO,IPZOA
     *,IBPROO,IBPROA,IREADO
      COMMON /KGLAUB/JGLAUB
C------------------------------------------
*---use predefined values for BSITE array and redefine necessary parameters
*---if initialization by SHMAKI (KKMAT=0) all information directly available
C     WRITE(6,*)' SHMAKO(NA,NB,B,INTT,INTA,INTB,JS,JT,PPN,KKMAT)',
C    * NA,NB,B,INTT,INTA,INTB,JS,JT,PPN,KKMAT
      KKMATA=KKMAT
      IPOA=IP
      IPZOA=IPZ
      IF(IP.GE.2)IJPROJ=1 
      IF(IP.GE.2)IBPROJ=1 
      IBPROA=IBPROJ
      IF(KKMAT.GT.0) THEN
      RASH=RPROJJ(KKMAT)
      RBSH=RTARGG(KKMAT)
      RPROJ=RASH
      RTARG=RBSH
      RTARNU=RBSH
      BMAX=BMAXX(KKMAT)
      BSTEP=BSTEPP(KKMAT)
C     SIGSH=DSHPTO(IJPROJ,PPN)/10.
C     IF(NA.GT.2.D0)
C    *SIGSH=(DSHPTO(IJPROJ,PPN)-SIGSDS(PPN*2.D0))/10.D0
      IF(JGLAUB.EQ.2)THEN
        SIGSHS=(DSHPTO(IJPROJ,PPN)-SIGSDS(PPN*2.D0))/10.D0
      ELSEIF(JGLAUB.EQ.1)THEN
        SIGSHS=(DSHPTO(IJPROJ,PPN))/10.D0
      ENDIF
      IF(IJPROJ.EQ.5)THEN
        SIGSHS=(DSHPTO(1,PPN)-SIGSDS(PPN*2.D0))/10.D0
      ENDIF
      SIGSH=SIGSHS
      BSLOPE=10.D0
      SSS=2.*PPN
      ECM=SQRT(SSS)
      IF (IJPROJ.LE.12)BSLOPE=8.5D0*(1.D0+0.065D0*LOG(SSS))
      IF (IJPROJ.GT.12)BSLOPE=6.D0*(1.D0+0.065D0*LOG(SSS))
*     GSH=1.6D0
      GSH=1.D0/(2.D0*BSLOPE*0.038938D0)
      ROSH=-0.43D0
      IF (IBPROJ.LE.12)THEN
        IF(ECM.GT.3.0D0.AND.ECM.LE.50.D0) ROSH=-0.63D0+
     +                                 0.175D0*LOG(ECM)
        IF(ECM.GT.50.D0) ROSH=0.1
      ENDIF
      IF (IJPROJ.GT.12) ROSH=0.01
      RCA=GSH*SIGSHS/6.2831854D0
      FCA=-GSH*SIGSHS*ROSH/6.2831854D0
      CA=CMPLX(RCA,FCA)
      GA=GSH
      IREAD=0
      WU10=SQRT(10.0)
      DO 73 IPO=1,24
        PPO=WU10**(IPO+1) + 10.
        IF(PPN.LE.PPO) THEN
          IREAD=IREAD + IPO - 1
          GOTO 74
        ENDIF
 73     CONTINUE
 74     CONTINUE
        IF(IREAD.LE.0)IREAD=1
        IF(IREAD.GE.25)IREAD=24
C       old (before 10/98 IF, which might be correct for HEMAS interface
C       INTER_DPM calling DPMEVT calling KKINC (to be checked)
C       IF (KKMAT.NE.KKMATO.AND.IP.NE.IPOO.AND.
C    *  IJPROJ.NE.IBPROO.AND.IPZ.NE.IPZOO )THEN
        IF ((KKMAT.NE.KKMATO).OR.(IP.NE.IPOO).OR.
     *  (IBPROJ.NE.IBPROO).OR.(IPZ.NE.IPZOO).OR.(IREAD.NE.IREADO) )THEN
          IF(IBPROJ.NE.0) THEN
            DO 75 II=1,200
              BSITE(1,II)=BSITEN(II,IREAD,KKMAT)
 75         CONTINUE
	    IBPROO=IBPROJ
C           ADDED 10/98
            KKMATO=KKMAT
            IREADO=IREAD
          ELSE
            DO 76 II=1,200
              BSITE(1,II)=BSITEM(II,IREAD,KKMAT)
 76         CONTINUE
	    IBPROO=IBPROJ
C           ADDED 10/98
            KKMATO=KKMAT
            IREADO=IREAD
          ENDIF
        ENDIF
      ENDIF
C     WRITE(6,'(A)')  ' SHMAKO - BEFORE DIAGR'
      IF(IPEV.GE.6) THEN
C     WRITE(6,'(A)')  ' SHMAKO - BEFORE DIAGR'
      IF(IPRI.GE.6) WRITE(6, 1030)SIGSH,ROSH,GSH,BSLOPE,ECM
C      WRITE(6, 1030)SIGSH,ROSH,GSH,BSLOPE,ECM
 1030 FORMAT(' PARAMETERS OF THE NN AMPLITUDE SIG,RO,G,BSLOPE,ECM ' /5
     +(1PE12.5))
      ENDIF
      CALL DIAGR(NA,NB,B,JS,JT,INTT,INTA,INTB)
C      WRITE(6,1000)NA,NB,B,INTT,INTA,INTB,JS(1),JT(1),
C    +              PKOO(1,1),TKOO(1,1)
      IF(IPEV.GE.6) WRITE(6,1000)NA,NB,B,INTT,INTA,INTB,JS(1),JT(1),
     +              PKOO(1,1),TKOO(1,1)
 1000 FORMAT(' NA,NB,B,INTT,INTA,INTB,JS(1),JT(1),PKOO(1,1),TKOO(1,1)
     + IN SHMAKO '/2I5,F10.4,5I6,2F10.3)
      RETURN
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE TITLE(NA,NB,NCA,NCB)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      WRITE(6,1000)NA,NCA,NB,NCB
 1000 FORMAT(//10X,39HGLAUBER S APPROACH IS USED TO SIMULATE ,
     +26HNUCLEUS-NUCLEUS COLLISIONS/ 24X,
     +40HTHE CALCULATION NAS BEEN CARRIED OUT FOR/
     +27H PROJECTED NUCLEI WITH A = ,I5,12H CHARGE A = ,I5/
     +24H TARGET NUCLEI WITH B = ,I5,12H CHARGE B = ,I5///)
      RETURN
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE CONUCL(X,N,R)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
C     -----------------------------------
      COMMON /KGLAUB/JGLAUB
      DIMENSION X(3,N),WD(4),RD(3)
C     LOGICAL ISTART
      COMMON /KAINIT/  UMODA,INICH1,INICH2,INICH3,INICH4,INICH5,
     *                 INICH6,INICH7,INICH8,INICH9,IRETUR,KAIS,INIPRI,
     *                 NUSEPT,MUSEPT,ISTART
      DOUBLE PRECISION UMODA
      INTEGER          INICH1,INICH2,INICH3,INICH4,INICH5,
     *                 INICH6,INICH7,INICH8,INICH9,IRETUR,KAIS,INIPRI,
     *                 NUSEPT,MUSEPT
      LOGICAL          ISTART
      DATA SQR2/1.414216D0/
      DATA PDIF/0.545D0/,R2MIN/0.16D0/
      DATA WD/0.D0,0.178D0,0.465D0,1.D0/
      DATA RD/2.09D0,0.935D0,0.697D0/
C     DATA RC12/1.6976D0/,WC12/0.4444444D0/
C     WRITE(6,*)' entry CONUCL'
C     DO IIII=1,2000
C        XXXX=RNDM(V)
C     ENDDO	 

      AAN=N
      IF (N.EQ.1)THEN
        GOTO 10
      ELSEIF (N.EQ.2)THEN
        GOTO 20
      ELSEIF (N.EQ.4) THEN
        GOTO 60
      ELSEIF (N.GE.12) THEN
        GOTO 110
      ELSE
        GO TO 110
      ENDIF
   10 CONTINUE
      X(1,1)=0
      X(2,1)=0
      X(3,1)=0
      RETURN
   20 CONTINUE
      EPS=RNDM(V)
C     EPS=PYR(K)
      DO 30 I=1,3
        IF ((EPS.GE.WD(I)).AND.(EPS.LE.WD(I+1)))                 GOTO 40
 
   30 CONTINUE
   40 CONTINUE
      DO 50 J=1,3
        CALL RANNORR(X1,X2)
        X(J,1)=RD(I)*X1
        X(J,2)=-X(J,1)
C	WRITE(6,*)'X(J,1),X(j,2)',X(J,1),X(J,2),J
   50 CONTINUE
      RETURN
   60 CONTINUE
C     WRITE(6,*)' 60 CONTINUE'
C     DO IIII=1,2000
C        XXXX=RNDM(V)
C     ENDDO	 
      SIGMA=R/SQR2
   70 CONTINUE
      ISTART=.TRUE.
      CALL RANNORR(X3,X4)
C     WRITE(6,*)'RANNOR:X3,X4',X3,X4
      DO 100 I=1,N
        CALL RANNORR(X1,X2)
C     WRITE(6,*)'RANNOR:X1,X2',X1,X2
C     DO IIII=1,2000
C        XXXX=RNDM(V)
C     ENDDO	 
        X(1,I)=SIGMA*X1
        X(2,I)=SIGMA*X2
C	WRITE(6,*)'X(1,I),X(2,I)',X(1,I),X(2,I),I
        IF (ISTART)                                              GOTO 80
 
        X(3,I)=SIGMA*X4
        CALL RANNORR(X3,X4)
C     WRITE(6,*)'RANNOR:X3,X4',X3,X4
C     DO IIII=1,2000
C        XXXX=RNDM(V)
C     ENDDO	 
                                                                 GOTO 90
   80   CONTINUE
        X(3,I)=SIGMA*X3
CWRITE(6,*)'X(3,I)',X(3,I),I
   90   CONTINUE
        ISTART=.NOT.ISTART
  100 CONTINUE
C     WRITE(6,*)' end CONUCL'
C     DO IIII=1,2000
C        XXXX=RNDM(V)
C     ENDDO	 
      RETURN
  110 CONTINUE
      RMAX=R+4.605*PDIF
      DO 140 I=1,N
  120   CONTINUE
        XXXXX=RNDM(V)
C       XXXXX=PYR(K)
        RAD=RMAX*XXXXX**0.3333333
C	WRITE(6,*)'xxxxx,rad',XXXXX,RAD
        CT=1.-2.*RNDM(V)
C       CT=1.-2.*PYR(K)
        FI=6.283185D0*RNDM(V)
C       FI=6.283185D0*PYR(K)
        ST=SQRT(1.-CT*CT)
        X(1,I)=RAD*ST*COS(FI)
        X(2,I)=RAD*ST*SIN(FI)
        X(3,I)=RAD*CT
C	WRITE(6,*)'RAD,ST,CT,FI,RMAX,R,PDIF',RAD,ST,CT,FI,RMAX,R,PDIF
C	WRITE(6,*)'X(1,I),X(2,I),X(3,I)',X(1,I),X(2,I),X(3,I),I
        RR=SQRT(X(1,I)**2+X(2,I)**2+X(3,I)**2)
        IF(JGLAUB.EQ.2)F=1./(1.+EXP((RR-R)/PDIF))
        IF(JGLAUB.EQ.1)THEN
	  IF(N.GE.11.OR.N.LE.18)THEN
	    RR0=R*R/(2.5D0-4.D0/AAN)
            F=(1.D0+(AAN-4.D0)*RR**2/(6.D0*RR0))*6.D0/(AAN-4.D0)
     *        *EXP(-RR**2/RR0+(AAN-10.D0)/(AAN-4.D0))
C           F=(1.D0+(AAN-4.D0)*RR**2/(6.D0*R0**2))
C    *        *EXP(-RR**2/R0**2)
C    PDIF=0.513
C           F=(1.D0-0.051D0*RR**2/R**2)/(1.+EXP((RR-R)/PDIF))
	  ELSEIF(N.GE.9.AND.N.LE.10)THEN
	    RR0=R*R/(2.5D0-4.D0/AAN)
            F=(1.D0+(AAN-4.D0)*RR**2/(6.D0*RR0))
     *        *EXP(-RR**2/RR0)
	  ELSE
            F=1./(1.+EXP((RR-R)/PDIF))
          ENDIF
        ENDIF
        IF (RNDM(V).GT.F)                                      GOTO 120
C       IF (PYR(K).GT.F)                                      GOTO 120
 
        IF (I.LT.2)                                            GOTO 140
 
        I1=I-1
        DO 130 I2=1,I1
          DIST2=(X(1,I)-X(1,I2))**2+(X(2,I)-X(2,I2))**2+(X(3,I)-X(3,I2))
     *    **2
          IF (DIST2.LE.R2MIN)                                   GOTO 120
 
  130   CONTINUE
  140 CONTINUE
C     WRITE(6,*)' end CONUCL'
C     DO IIII=1,2000
C        XXXX=RNDM(V)
C     ENDDO	 
      RETURN
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE MODB(BSITE,N,BSTEP,B)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
*KEEP,ZENTRA.
      COMMON /ZENTRA/ ICENTR
      COMMON /DSHM/ RASH,RBSH,BMAX,BSTAP,SIGSH,ROSH,GSH,
     *              BSITA(0:1,200),NSTATB,NSITEB
      COMMON /DSHMS/ SIGSHS
*KEND.
      DIMENSION BSITE(0:1,N)
      LOGICAL LEFT
C**** BSITE(1)=0. , BSITE(N)=1.
C
C                            Central collisions for lead-lead
C
C     WRITE(6,*)'RASH,RBSH,BMAX,BSTAP,SIGSH,ROSH,GSH,ICENTR,N',
C    *RASH,RBSH,BMAX,BSTAP,SIGSH,ROSH,GSH,ICENTR,N
      IF (ICENTR.EQ.1) THEN
        IF(RASH.EQ.RBSH)THEN
	IF(RASH.LE.15.D0)THEN
          BB=RNDM(V)*9.D0
          B=SQRT(BB)
          RETURN
        ELSEIF(RASH.GT.5.D0)THEN
          BB=RNDM(V)*30.D0
          B=SQRT(BB)
          RETURN
	ENDIF
        ELSEIF(RASH.LT.RBSH)THEN
          BB=RNDM(V)*(RBSH-RASH+3.D0)**2
          B=SQRT(BB)
          RETURN
        ELSEIF(RASH.GT.RBSH)THEN
          BB=RNDM(V)*(RASH-RBSH+3.D0)**2
          B=SQRT(BB)
          RETURN
        ENDIF
      ENDIF
C
      Y=RNDM(V)
      I0=1
      I2=N
   10 CONTINUE
      I1=(I0+I2)/2
      LEFT=((BSITE(1,I0)-Y)*(BSITE(1,I1)-Y)).LT.0.D0
      IF(LEFT)                                                  GO TO 20
      I0=I1
                                                                GO TO 30
   20 CONTINUE
      I2=I1
   30 CONTINUE
      IF(I2-I0-2)40,50,60
   40 CONTINUE
      I1=I2+1
      IF(I1.GT.N)I1=I0-1
                                                                GO TO 70
   50 CONTINUE
      I1=I0+1
                                                                GO TO 70
   60 CONTINUE
                                                                GO TO 10
   70 CONTINUE
      X0=(I0-1)*BSTEP
      X1=(I1-1)*BSTEP
      X2=(I2-1)*BSTEP
      Y0=BSITE(1,I0)
      Y1=BSITE(1,I1)
      Y2=BSITE(1,I2)
   80 CONTINUE
      B=X0*(Y-Y1)*(Y-Y2)/((Y0-Y1)*(Y0-Y2)+1.E-9)+ X1*(Y-Y0)*(Y-Y2)
     +/((Y1-Y0)*(Y1-Y2)+1.E-9)+ X2*(Y-Y0)*(Y-Y1)/((Y2-Y0)*(Y2-Y1)+1.E-9)
**sr 14.4.98
      B = B+0.5D0*BSTEP
      IF (B.LT.0.0D0) B = X1
      IF (B.GT.BMAX)  B = BMAX
**
 
      RETURN
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE DIAGR(NA,NB,B,JS,JT,INT,INTA,INTB)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
*---
*   -sample new impct parameter B
*   -sample nucleon configuration for projectile and target
*   -sample number of collisions  INT, INTA, INTB
*---
*KEEP,INTMX.
      PARAMETER (INTMX=2488,INTMD=252)
*KEEP,SHMAKL.
C     INCLUDE (SHMAKL)
* NOTE: INTMX set via INCLUDE(INTMX)
      COMMON/SHMAKL/JSSH(INTMX),JTSH(INTMX),INTER1(INTMX),INTER2(INTMX)
*KEEP,DPRIN.
      COMMON /DPRIN/  IPRI,IPEV,IPPA,IPCO,INIT,IPHKK,ITOPD,IPAUPR
*KEEP,DSHM.
      COMMON /DSHM/ RASH,RBSH,BMAX,BSTEP,SIGSH,ROSH,GSH,
     *              BSITE(0:1,200),NSTATB,NSITEB
      COMMON /DSHMS/ SIGSHS
*KEEP,NUCKOO.
      COMMON /NUCKOO/ PKOO(3,INTMX),TKOO(3,INTMX),PPOO(3,INTMX),
     +TPOO(3,INTMX)
*KEEP,DAMP.
C     COMPLEX*16 CA,CI
      DOUBLE COMPLEX CA,CI
      COMMON /DAMP/   CA,CI,GA
*KEND.
      COMMON /KKMATU/KKMATO,KKMATA,IPOO,IPOA,IPZOO,IPZOA
     *,IBPROO,IBPROA,IREADO
      COMMON /FLUCTU/IFLUCT
      COMMON /FLUARR/FLUSI(1000),FLUIX(1000),FLUIXX(1000)
      PARAMETER(NAMX=248)
      DIMENSION JS(NAMX),JT(NAMX)
C     COMPLEX*16 C
      DOUBLE COMPLEX C
      DATA ICNT/0/
      DATA INTCO/0/
C------------------------------
C     WRITE(6,*)' DIAGR(NA,NB,B,JS,JT,INT,INTA,INTB)',
C    *NA,NB,B,JS,JT,INT,INTA,INTB
**sr 14.4.98
      CALL MODB(BSITE,NSITEB,BSTEP,B)
C     WRITE(6,*)' after MODB'
      INTCO=0
**
      DO 10 I=1,NA
   10 JS(I)=0
      DO 20 I=1,NB
   20 JT(I)=0
C--------
   30 INT=0
      INTA=0
      INTB=0
      INTCO=INTCO+1
      IF(INTCO.GE.500)THEN
        INTCO=0
        CALL MODB(BSITE,NSITEB,BSTEP,B)
C     WRITE(6,*)' after MODB'
      ENDIF
C--------
C     IF (KKMATO.NE.KKMATA.AND.IPOO.NE.IPOA.AND.
C    *  IBPROO.NE.IBPROA.AND.IPZOO.NE.IPZOA )THEN
        CALL CONUCL(PKOO,NA,RASH)
C     WRITE(6,*)' after CONUCL'
        CALL SORTIN(PKOO,NA)
C     WRITE(6,*)' after SORTIN'
      DO IIII=1,500
         XXXX=RNDM(V)
      ENDDO	 
        CALL CONUCL(TKOO,NB,RBSH)
C     WRITE(6,*)' after CONUCL'
      DO IIII=1,500
         XXXX=RNDM(V)
      ENDDO	 
        CALL SORT(TKOO,NB)
C     WRITE(6,*)' after SORT'
        KKMATO=KKMATA
	IPOO=IPOA
	IPZOO=IPZOA
	IBPROO=IBPROA
C     ELSEIF (KKMATO.EQ.KKMATA.AND.IPOO.EQ.IPOA.AND.
C    *                              IPZOO.EQ.IPZOA)THEN
C       IF(MOD(ICNT,5).EQ.0) THEN
C         CALL CONUCL(PKOO,NA,RASH)
C         CALL SORTIN(PKOO,NA)
C         CALL CONUCL(TKOO,NB,RBSH)
C         CALL SORT(TKOO,NB)
C       ENDIF
C       ICNT=ICNT+1
C     ENDIF
C
C      WRITE (6,1000)ICNT,PKOO(1,1),TKOO(1,1)
      IF(IPEV.GE.6) WRITE (6,1000)ICNT,PKOO(1,1),TKOO(1,1)
 1000 FORMAT (' 111 FORM IN DIAGR ICNT,PKOO(1,1),TKOO(1,1) ',I6,2F10.3)
C--------
      DO 40 I=1,NA
        X1=B-PKOO(1,I)
        X2=-PKOO(2,I)
        IF(IFLUCT.EQ.0)THEN
          AFLUK=1.
        ELSEIF(IFLUCT.EQ.1)THEN
          IFUK=(RNDM(V)+0.001)*1000.
          AFLUK=FLUIXX(IFUK)
        ENDIF
C	WRITE(6,*)' before Do 40'
        DO 40 J=1,NB
          Q1=X1+TKOO(1,J )
          Q2=X2+TKOO(2,J )
          XY=GA*(Q1*Q1+Q2*Q2)
          IF(XY.GT.15.D0)                                    GO TO 40
          E=EXP(-XY)
          C=CI-CA*E*AFLUK
          AR=REAL(REAL(C))
          AI=IMAG(C)
          P=AR*AR+AI*AI
          IF(RNDM(V).LT.P)                                  GO TO 40
          INT=INT+1
          IF(INT.GT.INTMX)                                   GO TO 40
          JS(I)=JS(I)+1
          JT(J)=JT(J)+1
          INTER1(INT)=I
          INTER2(INT)=J
   40 CONTINUE
      DO 50 I=1,NA
        IF (JS(I).NE.0) INTA=INTA+1
   50 CONTINUE
      DO 60 J=1,NB
        IF (JT(J).NE.0) INTB=INTB+1
   60 CONTINUE
C       WRITE(6,'(A)')
C    +  ' DIAGR - AFTER 30 CONTINUE: ICNT, INT, B, NA,RA, NB,RB'
C     WRITE(6,'(I10,I5,1PE11.3,2(I5,1PE11.3))') ICNT, INT, B, NA,RASH,
C    +  NB,RBSH
      IF(IPEV.GE.6) THEN
        WRITE(6,'(A)')
     +  ' DIAGR - AFTER 30 CONTINUE: ICNT, INT, B, NA,RA, NB,RB'
      WRITE(6,'(I10,I5,1PE11.3,2(I5,1PE11.3))') ICNT, INT, B, NA,RASH,
     +  NB,RBSH
      ENDIF
      IF(INT.EQ.0)                                              GO TO 30
      RETURN
      END
C----------------------------------------------------------------
       SUBROUTINE FLUINI
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
C      INITIALIZE THE ARRAY FOR CROSS SECTION FLUCTUATIONS
C
      COMMON /FLUARR/ FLUSI(1000),FLUIX(1000),FLUIXX(1000)
      DX=0.003D0
      B=0.893D0
      N=6
      A=0.1
      OM=1.1
      FLUSU=0
      FLUSUU=0
      DO 1 I=1,1000
        X=I*DX
        FLUIX(I)=X
        FLUS=((X-B)/(OM*B))**N
        IF(FLUS.LE.20.)THEN
          FLUSI(I)=(X/B)*EXP(-((X-B)/(OM*B))**N)/(X/B+A)
        ELSE
          FLUSI(I)=0.
        ENDIF
        FLUSU=FLUSU+FLUSI(I)
    1 CONTINUE
      DO 2 I=1,1000
        FLUSUU=FLUSUU+FLUSI(I)/FLUSU
        FLUSI(I)=FLUSUU
    2 CONTINUE
      WRITE(6,3)
    3 FORMAT(' FLUCTUATIONS')
      CALL PLOT(FLUIX,FLUSI,1000,1,1000,0.D0,0.06D0,0.D0,0.01D0)
      DO 5 I=1,1000
        AF=I*0.001D0
        DO 6 J=1,1000
          IF(AF.LE.FLUSI(J))THEN
            FLUIXX(I)=FLUIX(J)
            GO TO 7
          ENDIF
    6   CONTINUE
    7   CONTINUE
    5 CONTINUE
      FLUIXX(1)=FLUIX(1)
      FLUIXX(1000)=FLUIX(1000)
      RETURN
      END
*-- Author :
C
C--------------------------------------------------------------------
C
C     FILE TECALBAM
C
C
C--------------------------------------------------------------------
c     SUBROUTINE TECALB
C     SUBROUTINE TECALBAM
C
C------------------------------------------------------------------
C
C               DTNTCBI.FOR
C
C------------------------------------------------------------------
C
      SUBROUTINE CALBAM(NNCH,I1,I2,IFB11,IFB22,IFB33,IFB44,
     *                  AMCH,NOBAM,IHAD)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
C
C--------------------------------------------------------------------
C    SAMPLING OF Q-AQ, Q-QQ, QQ-AQQ CHAINS
C       USING BAMJET(IHAD,IFB1,IFB2,IFB3,IFB4,AMCH,NOBAM)-----FOR NNCH=0
C       OR    PARJET(IHAD,ICH1=I1 OR I2)------FOR NNCH=-1 OR +1
C-------------------------------------------------------------------
C   IHAD  :  NUMBER OF PRODUCED PARTICLES
C   NNCH  :  CALL BAMJET FOR NNCH=0
C            CALL PARJET FOR NNCH=+1 ICH1=I1
C                        FOR NNCH=-1 ICH1=I2
C            jet not existing for NNCH=+/-99, i.e. IHAD=0
C   PRODUCED PARTICLES IN CHAIN REST FRAME ARE IN COMMON /FINPAR/
C   AMCH  :  INVARIANT MASS OF CHAIN (BAMJET)
C
C   NOBAM :  = 3  QUARK-ANTIQUARK JET   QUARK FLAVORS : IFB1,IFB2
C                 OR ANTIQUARK-QUARK JET                  IN ANY ORDER
C
C            = 4  QUARK-DIQUARK JET, FLAVORS : QU : IFB1, DIQU :IFB2,IFB
C                 OR ANTIQUARK-ANTIDIQUARK JET
C
C
C            = 5  DIQUARK-ANTIDIQUARK JET
C                 OR ANTIDIQUARK-DIQUARK JET
C                     FLAVORS :  DIQU : IFB1,IFB2, ANTIDIQU : IFB3,IFB4
C                                IN ANY ORDER
C
C            = 6  DIQUARK-QUARK JET, FLAVORS : DIQU  : IFB1,IFB2 QU: IFB
C                 OR ANTIDIQUARK-ANTIQUARK JET
C
C            = 10 q -- q -- q Jet Capella Kopeliovich 
C                or aq -- aq -- aq flavors IFB11,IFB22,IFB33
C
C   IFBI  : FLAVORS : 1,2,3,4 = U,D,S,C    7,8,9,10 = AU,AD,AS,AC
C
C   I1,I2 : NUMBER LABEL OF A HADRON CREATED BY PARJET
C
C   NORMALLY IN BAMJET THE QUARKS MOVE FORWARD  (POSITIVE Z-DIRECTION)
C                      THE QUARK FLAVORS ARE FIRST GIVEN
C   CALBAM ALLOWS EITHER THE QUARK OR ANTIQUARK (DIQU) TO MOVE FORWARD
C                      THE FORWARD GOING FLAVORS ARE GIVEN FIRST
C
C =====================================================================
*KEEP,DFINPA.
      CHARACTER*8 ANF
      PARAMETER (NFIMAX=249)
      COMMON /DFINPA/ ANF(NFIMAX),PXF(NFIMAX),PYF(NFIMAX),PZF(NFIMAX),
     +HEF(NFIMAX),AMF(NFIMAX), ICHF(NFIMAX),IBARF(NFIMAX),NREF(NFIMAX)
      COMMON /DFINPZ/IORMO(NFIMAX),IDAUG1(NFIMAX),IDAUG2(NFIMAX),
     * ISTATH(NFIMAX)
*KEEP,DPRIN.
      COMMON /DPRIN/  IPRI,IPEV,IPPA,IPCO,INIT,IPHKK,ITOPD,IPAUPR
      DATA ISYMM/0/
*KEND.
C---------------------
C     IPCO=6
C-------------------------------------------------------------------------------C  
C                       Symmetrize JETSET and BAMJET at small chain masses
C                       for NOBAM=4 or 6
C
C-------------------------------------------------------------------------------
      IF(NOBAM.EQ.4.AND.ISYMM.EQ.1)THEN
        IFB4=IFB44
        IF (AMCH.LT.3.D0)THEN
          RR=RNDM(V)
          IF (RR.LT.0.33333D0)THEN
            IFB1=IFB11
            IFB2=IFB22
            IFB3=IFB33
          ELSEIF (RR.GT.0.666666D0)THEN
            IFB1=IFB22
            IFB2=IFB11
            IFB3=IFB33
          ELSE
            IFB1=IFB33
            IFB2=IFB22
            IFB3=IFB11
          ENDIF
        ELSEIF(AMCH.GT.7.D0)THEN
          IFB1=IFB11
          IFB2=IFB22
          IFB3=IFB33
          IFB4=IFB44
        ELSE
          SSSS=(7.D0-AMCH)/4.D0
          RRR=RNDM(VV)
          IF(RRR.LT.1.D0-SSSS)THEN
            IFB1=IFB11
            IFB2=IFB22
            IFB3=IFB33
          ELSE
            RR=RNDM(V)
            IF (RR.LT.0.33333D0)THEN
              IFB1=IFB11
              IFB2=IFB22
              IFB3=IFB33
            ELSEIF (RR.GT.0.666666D0)THEN
              IFB1=IFB22
              IFB2=IFB11
              IFB3=IFB33
            ELSE
              IFB1=IFB33
              IFB2=IFB22
              IFB3=IFB11
            ENDIF
          ENDIF
        ENDIF
      ELSEIF(NOBAM.EQ.6.AND.ISYMM.EQ.1)THEN
        IFB4=IFB44
        IF (AMCH.LT.3.D0)THEN
          RR=RNDM(V)
          IF (RR.LT.0.33333D0)THEN
            IFB1=IFB11
            IFB2=IFB22
            IFB3=IFB33
          ELSEIF (RR.GT.0.666666D0)THEN
            IFB3=IFB22
            IFB1=IFB11
            IFB2=IFB33
          ELSE
            IFB3=IFB11
            IFB2=IFB22
            IFB1=IFB33
          ENDIF
        ELSEIF(AMCH.GT.7.D0)THEN
          IFB1=IFB11
          IFB2=IFB22
          IFB3=IFB33
          IFB4=IFB44
        ELSE
          SSSS=(7.D0-AMCH)/4.D0
          RRR=RNDM(VV)
          IF(RRR.LT.1.D0-SSSS)THEN
            IFB1=IFB11
            IFB2=IFB22
            IFB3=IFB33
          ELSE
            RR=RNDM(V)
            IF (RR.LT.0.33333D0)THEN
              IFB1=IFB11
              IFB2=IFB22
              IFB3=IFB33
            ELSEIF (RR.GT.0.666666D0)THEN
              IFB3=IFB22
              IFB1=IFB11
              IFB2=IFB33
            ELSE
              IFB1=IFB33
              IFB2=IFB22
              IFB3=IFB11
            ENDIF
          ENDIF
        ENDIF
      ELSE
        IFB1=IFB11
        IFB2=IFB22
        IFB3=IFB33
        IFB4=IFB44
      ENDIF
C------------------------------------------------------------------------------
      IF(IPCO.GE.6)THEN
        WRITE (6,1000)NNCH,I1,I2,IFB1,IFB2,IFB3,IFB4,AMCH,NOBAM,IHAD
 1000 FORMAT(' CALBAM:NNCH,I1,I2,IFB1,IFB2,IFB3,IFB4,AMCH,NOBAM,IHAD' /7
     +I5,F10.3,2I5)
      ENDIF
      IF(NOBAM.EQ.10)THEN
        CALL DBAMJE(IHAD,IFB1,IFB2,IFB3,IFB4,AMCH,NOBAM)
      ENDIF
      ITURN=0
      IF (NNCH) 10,30,20
   10 CONTINUE
      IF(NNCH.EQ.-99) THEN
        IHAD=0
        RETURN
      ENDIF
      ICH1=I1
                                                                GO TO 50
   20 CONTINUE
      IF(NNCH.EQ.99) THEN
        IHAD=0
        RETURN
      ENDIF
      ICH1=I2
                                                                GO TO 50
   30 CONTINUE
C***  ITURN=0                       HJM 24/01/91
      IF (IFB1.LE.6)                                            GO TO 40
      ITURN=1
      IF(NOBAM.EQ.3) CALL DBAMJE(IHAD,IFB2,IFB1,IFB3,IFB4,AMCH,NOBAM)
      IF(NOBAM.EQ.4)THEN
        ITURN=0
        CALL DBAMJE(IHAD,IFB1,IFB2,IFB3,IFB4,AMCH,NOBAM)
      END IF
      IF(NOBAM.EQ.6) CALL DBAMJE(IHAD,IFB3,IFB1,IFB2,IFB4,AMCH,4)
      IF(NOBAM.EQ.5)THEN
        CALL DBAMJE(IHAD,IFB3,IFB4,IFB1,IFB2,AMCH,NOBAM)
      ENDIF
                                                                GO TO 60
   40 CONTINUE
 
      IF (NOBAM.EQ.3.OR.NOBAM.EQ.4.OR.NOBAM.EQ.5) THEN
        CALL DBAMJE(IHAD,IFB1,IFB2,IFB3,IFB4,AMCH,NOBAM)
      ELSEIF(NOBAM.EQ.6)THEN
        ITURN=1
        CALL DBAMJE(IHAD,IFB3,IFB1,IFB2,IFB4,AMCH,4)
      END IF
                                                                GO TO 60
   50 CONTINUE
      CALL DPARJE(IHAD,ICH1)
   60 CONTINUE
C     CALL DECAY(IHAD,2)
   70 CONTINUE
C*** TURN CHAINS AROUND IF NESSESARY
      IF (ITURN.EQ.0)                                          GO TO 100
C*** TURN JET AROUND
      DO 80 I=1,IHAD
        PZF(I)=-PZF(I)
   80 CONTINUE
   90 CONTINUE
  100 CONTINUE
      IF (IPCO.GE.6)THEN
        DO 1244 I=1,IHAD
          WRITE(6,1245)I,PZF(I),HEF(I),ANF(I)
 1245     FORMAT(I5,2F10.4,A8)
 1244   CONTINUE
      ENDIF
      RETURN
      END
*-- Author :
C
C++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C
      SUBROUTINE DBAMJE(IHAD,KFA1,KFA2,KFA3,KFA4,AE0,IOPT)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
C*****IHAD=NUMBER OF FINAL HADRONS AND HADRON RESONANCES
C*****AE0=INITIAL ENERGY IN GEV
C*****KFA=INITIAL QUARK FLAVOUR
C*****KFD1,KFD2=FLAVOUR CONTENTS OF A INITIAL DIQUARK
C*****IOPT=1,2,3,4 MEANS: SINGLE QUARK JET,SINGLE DIQUARK JET,
C*****COMPLETE QUARK ANTIQUARK TWOJET EVENT,COMPLETE QUARK-DIQUARK TWO
C*****JET EVENT
C*****IOPT=10 q -- q -- q Jet Capella Kopeliovich (only jetset defined)
C*****COMMON/FINPAR/ CONTAINS THE MOMENTA,ENERGIES AND QUANTUM NUMBERS
C*****OF THE CREATED HADRONS
C*****IV IS THE ACTUAL VERTEX,IV=1,4,5,6,9,10 ARE MESON VERTIZES
C*****IV=2,3,7,8 ARE BARYON VERTIZES
C*****LA=1 MEANS CUT-OFF
C*****LL=0,1 MEANS QUARK JET,ANTIQUARK JET(DIQUARK JET,ANTIDIQUARK JET)
C*****COMMON/REMAIN/ CONTAINS REST JET ENERGY,MOMENTA AND QUANTUMNUMBERS
C------------------
*KEEP,DFINPA.
      CHARACTER*8 ANF
      PARAMETER (NFIMAX=249)
      COMMON /DFINPA/ ANF(NFIMAX),PXF(NFIMAX),PYF(NFIMAX),PZF(NFIMAX),
     +HEF(NFIMAX),AMF(NFIMAX), ICHF(NFIMAX),IBARF(NFIMAX),NREF(NFIMAX)
      COMMON /DFINPZ/IORMO(NFIMAX),IDAUG1(NFIMAX),IDAUG2(NFIMAX),
     * ISTATH(NFIMAX)
*KEEP,DINPDA.
      COMMON /DINPDA/ IMPS(6,6),IMVE(6,6),IB08(6,21),IB10(6,21), IA08
     +(6,21),IA10(6,21), A1,B1,B2,B3,LT,LE,BET,AS,B8,AME,DIQ,ISU
*KEND.
      CHARACTER*8 ANAME
      COMMON /DPAR/ ANAME(210),AM(210),GA(210),TAU(210),ICH(210), IBAR
     +(210),K1(210),K2(210)
      COMMON/DREMAI/ RPXR,RPYR,RPZR,RER,KR1R,KR2R
      COMMON /BAMCO/  NVDD
      COMMON/IFRAGM/IFRAG
      COMMON /DPRIN/  IPRI,IPEV,IPPA,IPCO,INIT,IPHKK,ITOPD,IPAUPR
*--------------------------- S.Roesler 5/27/93
      COMMON /DIFFRA/ ISINGD,IDIFTP,IOUDIF,IFLAGD
*
      DIMENSION RPX(100),RPY(100),RE(100)
      DIMENSION KFR1(100),KFR2(100),IV(100)
      PARAMETER (PIMASS=0.15D0)
C
      IF(IPCO.GE.6)LT=1
C-------------------------------------------------------------------
      IF (LT.EQ.1)WRITE(6, 1000)IHAD,KFA1,KFA2,KFA3,KFA4,AE0,IOPT
 1000 FORMAT (5I5,E12.4,I5,
     +      ' BAMJET,IHAD,KFA1,KFA2,KFA3,KFA4,AE0,IOPT')
C------------------------------------------------------------------
C
C                            JETSET-7.3 FRAGMENTATION j.r.6/93
C
      IF(IOPT.EQ.10)THEN
        IREJ=0
        CALL BAMLUN(IHAD,KFA1,KFA2,KFA3,KFA4,AE0,IOPT,IREJ)
        IF(IREJ.EQ.1)THEN
          RETURN
        ENDIF
        RETURN
      ENDIF
      IF(IFRAG.EQ.1.OR.IFRAG.EQ.2.OR.IFRAG.GE.10)THEN
        IREJ=0
        CALL BAMLUN(IHAD,KFA1,KFA2,KFA3,KFA4,AE0,IOPT,IREJ)
        IF(IREJ.EQ.1)THEN
          RETURN
        ENDIF
        RETURN
      ENDIF
C_________________________________________________________________
      AS=0.5
      B8=0.4
      A1=0.88
*-------------------------- S.Roesler 5/26/93
      B1=3.
      B2=3.
*
      B3=8.0
C     BET=9.5
      BET=12.0
      IF(NVDD.EQ.15) THEN
        A1=0.99
        B3=2.0
        BET=3.
      ENDIF
*-------------------------- S.Roesler 5/26/93
*                           diffractive chains
*
      IF(IFLAGD.EQ.1)THEN
         A1=0.88
         B1=6.
         B2=9.
         B3=4.0
      ENDIF
*
C
      ITRY = 0
   10 CONTINUE
C
C  avoid hang ups
      ITRY = ITRY+1
      IF(ITRY.GT.10000) THEN
        WRITE(6,'(/1X,A)') 'DBAMJE:ERROR: FRAGMENTATION IMPOSSIBLE'
        WRITE(6,'(1X,A,5I5,E12.3,I5)')
     &    'DBAMJE:IHAD,KFA1,KFA2,KFA3,KFA4,AE0,IOPT ',
     &    IHAD,KFA1,KFA2,KFA3,KFA4,AE0,IOPT
        STOP
      ENDIF
C
      DO 20 I=1,100
        KFR1(I)=0
        KFR2(I)=0
   20 CONTINUE
   30 CONTINUE
      IYY=0
      IHAD=0
      IT=0
      E0=AE0/2.
C  low mass asymmetric fragmentation (r.e. 12/93)
      IF(ITRY.GT.100) THEN
        IF(IOPT.EQ.3) THEN
          IF(KFA1.GT.(KFA2-6)) THEN
            E0=AE0-MAX(AE0*0.1,PIMASS)
          ELSE
            E0=MAX(AE0*0.1,PIMASS)
          ENDIF
        ENDIF
      ENDIF
C
      IF(IOPT.EQ.1.OR.IOPT.EQ.2) E0=AE0
      LL=0
      PGX=0.
      IF(KFA1.GT.6.AND.IOPT.EQ.1) LL=1
      IF(KFA1.LE.6.AND.IOPT.EQ.2) LL=1
      IF(KFA1.GT.6.AND.IOPT.EQ.4) LL=1
      PGY=0.
      PGZ=0.
      RPX0=0.
      RPY0=0.
      DO 130 I=1,100
        LA=0
        IT=IT+1
        J=IT-1
   40   CONTINUE
C*****CUT OFF TASK
C       CALL DABBRC(IT,LL,LA,LT,E0,PGX,PGY,PGZ,KFR1,KFR2,RE, KR1R,KR2R,
C    +  KR1L,KR2L,RPX,RPY,RPZ,RPXR,RPYR,RPZR,RPXL,RPYL,RPZL, RER,REL,IV,
C    +  B1,B2,KFA1,KFA2,KFA3,KFA4,IOPT,IYY)
        IF(LA.EQ.0)                                               GOTO60
        IT=IT-1
        IF(IOPT.EQ.3.AND.LL.EQ.0)                                GOTO 50
        IF(IOPT.EQ.4.AND.KFA1.LE.6.AND.LL.EQ.0)                  GOTO 50
        IF(IOPT.EQ.4.AND.KFA1.GT.6.AND.LL.EQ.1)                  GOTO 50
        IF(IOPT.EQ.5.AND.LL.EQ.0)                                GOTO 50
C  asymmetric fragmentation (r.e. 12/93)
        E0 = AE0/2.
                                                                GOTO 140
   50   CONTINUE
C  asymmetric fragmentation (r.e. 12/93)
        E0 = AE0-E0
C
        IYY=1
        LL=1
        IF(IOPT.EQ.4.AND.KFA1.GT.6) LL=0
        IAR=IT
                                                                 GOTO120
   60   CONTINUE
C*****CHOICE OF THE VERTEX
C       CALL DVERTE(IT,LT,LL,KFA1,E0,IV,AME,IOPT)
C*****CHOICE OF THE FLAVOUR
C       CALL DFLAVO(IT,LT,LL,E0,IV,RE,KFR1,KFR2,ISU,BET,KFA1,KFA2,KFA3,
C    +  KFA4,IOPT)
C*****CLASSIFICATION OF THEPARTICLES
C       CALL DHKLAS(IT,LT,LA,LL,KFR1,KFR2,KR1R,KR2R,KR1L,KR2L,IV,IMPS,
C    +  IMVE,IB08,IA08,IB10,IA10,AS,B8,KFA1,KFA2,KFA3,KFA4,IOPT)
        IF(IT.EQ.1)RX=E0
        IF(IT.GT.1)RX=RE(J)
        IF(AMF(IT).GT.RX)                                        GOTO 10
        IF(AMF(IT).LE.RX)                                        GOTO 70
        LA=1
                                                                  GOTO40
   70   CONTINUE
        IHAD=IHAD+1
        IF(LT.EQ.0)                                               GOTO80
        WRITE(6, 1070)IHAD
   80   CONTINUE
C*****CHOICE OF THE ENERGY
C       CALL DENERG(IT,IV,RE,HMA,HE,E0,A1)
C*****CHOICE OF THE MOMENTUM
C       CALL IMPULD(HE,HMA,HPS,HPX,HPY,HPZ,LT,LL,B3)
        IF(IT.GT.1)                                               GOTO90
        RPX(IT)=RPX0-HPX
        RPY(IT)=RPY0-HPY
                                                                 GOTO100
   90   RPX(IT)=RPX(J)-HPX
        RPY(IT)=RPY(J)-HPY
  100   CONTINUE
        IF (IOPT.EQ.1.AND.LL.EQ.1)HPZ=-HPZ
        IF(IOPT.EQ.2.AND.LL.EQ.1) HPZ=-HPZ
        IF(IOPT.EQ.4.AND.KFA1.GT.6) HPZ=-HPZ
        IF(IOPT.EQ.5) HPZ=-HPZ
        PGX=PGX+HPX
        PGY=PGY+HPY
        PGZ=PGZ+HPZ
        PXF(IT)=HPX
        PYF(IT)=HPY
        PZF(IT)=HPZ
        IF(LT.EQ.0)                                              GOTO110
        WRITE(6, 1010)PGX,PGY,PGZ
 1010 FORMAT(1H0,12HPGX,PGY,PGZ=,3F8.4)
  110   CONTINUE
  120   CONTINUE
  130 CONTINUE
  140 CONTINUE
      IF(IOPT.EQ.1.OR.IOPT.EQ.2)                                GOTO 150
C*****PUT THE RIGHT AND LEFT JET TOGETHER
C     CALL DVEREI(IT,LA,LT,RER,REL,RPXR,RPYR,RPZR,RPXL,RPYL,RPZL,
C    *KR1R,KR2R,KR1L,KR2L,IHAD,LL,KFR1,KFR2,IMPS,IMVE,IB08,IA08,
C    *IB10,IA10,B3,AS,B8,IAR,KFA1,KFA2,KFA3,KFA4,IOPT)
      IF(LA.EQ.3)                                                GOTO 10
      IF(LA.EQ.2)                                                GOTO 10
  150 CONTINUE
      IF(IOPT.EQ.3.OR.IOPT.EQ.4.OR.IOPT.EQ.5)                   GOTO 160
      IF(LL.EQ.0)                                               GOTO 160
      RPXR=RPXL
      RPYR=RPYL
      RPZR=RPZL
      RER=REL
      KR1R=KR1L
      KR2R=KR2L
  160 CONTINUE
      IF(LE.EQ.0)                                               GOTO 180
      WRITE(6, 1030)
      DO170 J=1,IT
        WRITE(6, 1020)NREF(J),ANF(J),AMF(J),ICHF(J),
     +  IBARF(J),PXF(J),PYF(J),
     +  PZF(J),HEF(J)
 1020 FORMAT(2X,I3,A6,F6.3,2I4,4F8.4)
 1030 FORMAT(2X,'NF,NAME,MASS,IQ,IB,PX,PY,PZ,E')
  170 CONTINUE
  180 CONTINUE
 1040 FORMAT(1H0,38HNUMBER OF EVENTS WITH PREST GT. EREST=,I4, /,
     +21HNUMBER OF ALL EVENTS=,I4)
 1050 FORMAT(1H0,'NUMBER OF EVENTS WITH ONLY ONE PARTICLE=',I4)
C*****TEST OF THE CONSERVATION LAWS
C      CALL TERHAL(IT,LE,KFA1,KFA2,IOPT)
      IF(LT.EQ.0)                                                GOTO190
      WRITE(6, 1060)IHAD
 1060 FORMAT(1H0,' MULTIPLIZITAET=',I3)
 1070 FORMAT(1H0,13HHADRONANZAHL=,I3)
  190 CONTINUE
C     IF (IHAD.EQ.2)THEN
C       DO 200 I=1,IHAD
C         PZF(I)=-PZF(I)
C 200   CONTINUE
C     ENDIF
C
      RETURN
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE INDEXD(KA,KB,IND)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      KP=KA*KB
      KS=KA+KB
      IF(KP.EQ.1)IND=1
      IF(KP.EQ.2)IND=2
      IF(KP.EQ.3)IND=3
      IF(KP.EQ.4.AND.KS.EQ.5)IND=4
      IF(KP.EQ.5)IND=5
      IF(KP.EQ.6.AND.KS.EQ.7)IND=6
      IF(KP.EQ.4.AND.KS.EQ.4)IND=7
      IF(KP.EQ.6.AND.KS.EQ.5)IND=8
      IF(KP.EQ.8)IND=9
      IF(KP.EQ.10)IND=10
      IF(KP.EQ.12.AND.KS.EQ.8)IND=11
      IF(KP.EQ.9)IND=12
      IF(KP.EQ.12.AND.KS.EQ.7)IND=13
      IF(KP.EQ.15)IND=14
      IF(KP.EQ.18)IND=15
      IF(KP.EQ.16)IND=16
      IF(KP.EQ.20)IND=17
      IF(KP.EQ.24)IND=18
      IF(KP.EQ.25)IND=19
      IF(KP.EQ.30)IND=20
      IF(KP.EQ.36)IND=21
      RETURN
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      DOUBLE PRECISION FUNCTION DBETA(X1,X2,BET)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      AX=0.0
      BETX1=BET*X1
      IF(BETX1.LT.70.) AX=-1./BET**2*(BETX1+1.)*EXP(-BETX1)
      AY=1./BET**2*(BET*X2+1.)*EXP(-BET*X2)
      DBETA=AX+AY
      RETURN
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE DDRELA(X,Y,Z,COTE,SITE,COPS,SIPS)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      X1=COPS*X-SIPS*COTE*Y+SIPS*SITE*Z
      X2=SIPS*X+COPS*COTE*Y-COPS*SITE*Z
      X3=SITE*Y+COTE*Z
      X=X1
      Y=X2
      Z=X3
      RETURN
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C      SUBROUTINE DPOLI(CS,SI)
C     IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C     SAVE
C      U=RNDM(V)
C     CS=RNDM(VV)
C     IF (U.LT.0.5) CS=-CS
C     SI=SQRT(1.-CS*CS+1.E-10)
C     RETURN
C     END
C     SUBROUTINE ALTRAF(GA,BGA,CX,CY,CZ,COD,COF,SIF,PC,EC,P,PX,PY,PZ,E)
C     IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C     SAVE
C     BGX=BGA*CX
C     BGY=BGA*CY
C     BGZ=BGA*CZ
C     COD2=COD*COD
C     IF (COD2.GT.0.999999) COD2=0.999999
C     SID=SQRT(1.-COD2)*PC
C     PCX=SID*COF
C     PCY=SID*SIF
C     PCZ=COD*PC
C     EP=PCX*BGX+PCY*BGY+PCZ*BGZ
C     PE=EP/(GA+1.)+EC
C     PX=PCX+BGX*PE
C     PY=PCY+BGY*PE
C     PZ=PCZ+BGZ*PE
C     P=SQRT(PX*PX+PY*PY+PZ*PZ)
C     PM=1./P
C     PX=PX*PM
C     PY=PY*PM
C     PZ=PZ*PM
C     E=GA*EC+EP
C     RETURN
C     END
C     SUBROUTINE ROTAT(PX,PY,PZ,PXN,PYN,PZN,COTE,SITE,COPS,SIPS)
C     IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C     SAVE
C     PXN=-PX*SIPS-PY*COTE*COPS+PZ*SITE*COPS
C     PYN=PX*COPS-PY*COTE*SIPS+PZ*SITE*SIPS
C     PZN=PY*SITE+PZ*COTE
C     RETURN
C     END
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
*=== threpd ===========================================================*
*
      SUBROUTINE DTHREP(UMO,ECM1,ECM2,ECM3,PCM1,PCM2,PCM3,COD1,COF1,
     &SIF1,COD2,COF2,SIF2,COD3,COF3,SIF3,AM1,AM2,AM3)
 
*$ CREATE DBLPRC.ADD
*COPY DBLPRC
*                                                                     *
*=== dblprc ==========================================================*
*                                                                     *
*---------------------------------------------------------------------*
*                                                                     *
*      Dblprc: included in any routine                                *
*                                                                     *
*  !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!  *
*  !!!! O N   M A C H I N E S   W H E R E   T H E   D O U B L E !!!!  *
*  !!!! P R E C I S I O N   I S   N O T   R E Q U I R E D  R E -!!!!  *
*  !!!! M O V E   T H E   D O U B L E   P R E C I S I O N       !!!!  *
*  !!!! S T A T E M E N T,  S E T   K A L G N M = 1   A N D     !!!!  *
*  !!!! C H A N G E   A L L   N U M E R I C A L   C O N S -     !!!!  *
*  !!!! T A N T S   T O   S I N G L E   P R E C I S I O N       !!!!  *
*  !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!  *
*                                                                     *
*         Kalgnm = real address alignment, 2 for double precision,    *
*                  1 for single precision                             *
*         Anglgb = this parameter should be set equal to the machine  *
*                  "zero" with respect to unit                        *
*         Anglsq = this parameter should be set equal to the square   *
*                  of Anglgb                                          *
*         Axcssv = this parameter should be set equal to the number   *
*                  for which unity is negligible for the machine      *
*                  accuracy                                           *
*         Andrfl = "underflow" of the machine for floating point      *
*                  operation                                          *
*         Avrflw = "overflow"  of the machine for floating point      *
*                  operation                                          *
*         Ainfnt = code "infinite"                                    *
*         Azrzrz = code "zero"                                        *
*         Einfnt = natural logarithm of the code "infinite"           *
*         Ezrzrz = natural logarithm of the code "zero"               *
*         Onemns = 1- of the machine, it is 1 - 2 x Anglgb            *
*         Onepls = 1+ of the machine, it is 1 + 2 x Anglgb            *
*         Csnnrm = maximum tolerable error on cosine normalization,   *
*                  u**2+v**2+w**2: assuming a typical anglgb relative *
*                  error on each component we would get 2xanglgb: use *
*                  4xanglgb to avoid too many normalizations          *
*         Dmxtrn = "infinite" distance for transport (cm)             *
*                                                                     *
*---------------------------------------------------------------------*
*                                                                     *
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      PARAMETER ( KALGNM = 2 )
      PARAMETER ( ANGLGB = 5.0D-16 )
      PARAMETER ( ANGLSQ = 2.5D-31 )
      PARAMETER ( AXCSSV = 0.2D+16 )
      PARAMETER ( ANDRFL = 1.0D-38 )
      PARAMETER ( AVRFLW = 1.0D+38 )
      PARAMETER ( AINFNT = 1.0D+30 )
      PARAMETER ( AZRZRZ = 1.0D-30 )
      PARAMETER ( EINFNT = +69.07755278982137 D+00 )
      PARAMETER ( EZRZRZ = -69.07755278982137 D+00 )
      PARAMETER ( ONEMNS = 0.999999999999999  D+00 )
      PARAMETER ( ONEPLS = 1.000000000000001  D+00 )
      PARAMETER ( CSNNRM = 2.0D-15 )
      PARAMETER ( DMXTRN = 1.0D+08 )
*
*======================================================================*
*======================================================================*
*=========                                                   ==========*
*=========    M A T H E M A T I C A L   C O N S T A N T S    ==========*
*=========                                                   ==========*
*======================================================================*
*======================================================================*
*                                                                      *
*   Numerical constants:                                               *
*                                                                      *
*         Zerzer = 0                                                   *
*         Oneone = 1                                                   *
*         Twotwo = 2                                                   *
*         Thrthr = 3                                                   *
*         Foufou = 4                                                   *
*         Fivfiv = 5                                                   *
*         Sixsix = 6                                                   *
*         Sevsev = 7                                                   *
*         Eigeig = 8                                                   *
*         Aninen = 9                                                   *
*         Tenten = 10                                                  *
*         Hlfhlf = 1/2                                                 *
*         Onethi = 1/3                                                 *
*         Twothi = 2/3                                                 *
*         Pipipi = Circumference / diameter                            *
*         Eneper = "e", base of natural logarithm                      *
*         Sqrent = square root of "e"                                  *
*                                                                      *
*----------------------------------------------------------------------*
*
      PARAMETER ( ZERZER = 0.D+00 )
      PARAMETER ( ONEONE = 1.D+00 )
      PARAMETER ( TWOTWO = 2.D+00 )
      PARAMETER ( THRTHR = 3.D+00 )
      PARAMETER ( FOUFOU = 4.D+00 )
      PARAMETER ( FIVFIV = 5.D+00 )
      PARAMETER ( SIXSIX = 6.D+00 )
      PARAMETER ( SEVSEV = 7.D+00 )
      PARAMETER ( EIGEIG = 8.D+00 )
      PARAMETER ( ANINEN = 9.D+00 )
      PARAMETER ( TENTEN = 10.D+00 )
      PARAMETER ( HLFHLF = 0.5D+00 )
      PARAMETER ( ONETHI = ONEONE / THRTHR )
      PARAMETER ( TWOTHI = TWOTWO / THRTHR )
      PARAMETER ( PIPIPI = 3.1415926535897932270 D+00 )
      PARAMETER ( ENEPER = 2.7182818284590452354 D+00 )
      PARAMETER ( SQRENT = 1.6487212707001281468 D+00 )
*
*======================================================================*
*======================================================================*
*=========                                                   ==========*
*=========       P H Y S I C A L   C O N S T A N T S         ==========*
*=========                                                   ==========*
*======================================================================*
*======================================================================*
*                                                                      *
*   Primary constants:                                                 *
*                                                                      *
*         Clight = speed of light in cm s-1                            *
*         Avogad = Avogadro number                                     *
*         Amelgr = electron mass (g)                                   *
*         Plckbr = reduced Planck constant (erg s)                     *
*         Elccgs = elementary charge (CGS unit)                        *
*         Elcmks = elementary charge (MKS unit)                        *
*         Amugrm = Atomic mass unit (g)                                *
*         Ammumu = Muon mass (amu)                                     *
*                                                                      *
*   Derived constants:                                                 *
*                                                                      *
*         Alpfsc = Fine structure constant  = e^2/(hbar c)             *
*         Amelct = Electron mass (GeV) = 10^-16Amelgr Clight^2 / Elcmks*
*         Amugev = Atomic mass unit (GeV) = 10^-16Amelgr Clight^2      *
*                                           / Elcmks                   *
*         Ammuon = Muon mass (GeV) = Ammumu * Amugev                   *
*         Fscto2 = (Fine structure constant)^2                         *
*         Fscto3 = (Fine structure constant)^3                         *
*         Fscto4 = (Fine structure constant)^4                         *
*         Plabrc = Reduced Planck constant times the light velocity    *
*                  expressed in GeV fm                                 *
*         Rclsel = Classical electron radius (cm) = e^2 / (m_e c^2)    *
*   Conversion constants:                                              *
*         GeVMeV = from GeV to MeV                                     *
*         eMVGeV = from MeV to GeV                                     *
*         Raddeg = from radians to degrees                             *
*         Degrad = from degrees to radians                             *
*                                                                      *
*----------------------------------------------------------------------*
*
      PARAMETER ( CLIGHT = 2.99792458         D+10 )
      PARAMETER ( AVOGAD = 6.0221367          D+23 )
      PARAMETER ( AMELGR = 9.1093897          D-28 )
      PARAMETER ( PLCKBR = 1.05457266         D-27 )
      PARAMETER ( ELCCGS = 4.8032068          D-10 )
      PARAMETER ( ELCMKS = 1.60217733         D-19 )
      PARAMETER ( AMUGRM = 1.6605402          D-24 )
      PARAMETER ( AMMUMU = 0.113428913        D+00 )
*     PARAMETER ( ALPFSC = 1.D+00 / 137.035989561D+00 )
*     PARAMETER ( FSCTO2 = ALPFSC * ALPFSC )
*     PARAMETER ( FSCTO3 = FSCTO2 * ALPFSC )
*     PARAMETER ( FSCTO4 = FSCTO3 * ALPFSC )
*    It is important to set the electron mass exactly with the same
*    rounding as in the mass tables, so use the explicit expression
*     PARAMETER ( AMELCT = 1.D-16 * AMELGR * CLIGHT * CLIGHT / ELCMKS )
*    It is important to set the amu mass exactly with the same
*    rounding as in the mass tables, so use the explicit expression
*     PARAMETER ( AMUGEV = 1.D-16 * AMUGRM * CLIGHT * CLIGHT / ELCMKS )
*    It is important to set the muon mass exactly with the same
*    rounding as in the mass tables, so use the explicit expression
*     PARAMETER ( AMMUON = AMMUMU * AMUGEV ELCMKS )
*     PARAMETER ( RCLSEL = ELCCGS * ELCCGS / CLIGHT / CLIGHT / AMELGR )
      PARAMETER ( ALPFSC = 7.2973530791728595 D-03 )
      PARAMETER ( FSCTO2 = 5.3251361962113614 D-05 )
      PARAMETER ( FSCTO3 = 3.8859399018437826 D-07 )
      PARAMETER ( FSCTO4 = 2.8357075508200407 D-09 )
      PARAMETER ( PLABRC = 0.197327053        D+00 )
      PARAMETER ( AMELCT = 0.51099906         D-03 )
      PARAMETER ( AMUGEV = 0.93149432         D+00 )
      PARAMETER ( AMMUON = 0.105658389        D+00 )
      PARAMETER ( RCLSEL = 2.8179409183694872 D-13 )
      PARAMETER ( GEVMEV = 1.0                D+03 )
      PARAMETER ( EMVGEV = 1.0                D-03 )
      PARAMETER ( RADDEG = 180.D+00 / PIPIPI )
      PARAMETER ( DEGRAD = PIPIPI / 180.D+00 )
 
*$ CREATE IOUNIT.ADD
*COPY IOUNIT
*                                                                     *
*=== iounit ==========================================================*
*                                                                     *
*---------------------------------------------------------------------*
*                                                                     *
*      Iounit: included in any routine                                *
*                                                                     *
*         lunin  = standard input unit                                *
*         lunout = standard output unit                               *
*         lunerr = standard error unit                                *
*         lunber = input file for bertini nuclear data                *
*         lunech = echo file for pegs dat                             *
*         lunflu = input file for photoelectric edges and X-ray fluo- *
*                  rescence data                                      *
*         lungeo = scratch file for combinatorial geometry            *
*         lunpgs = input file for pegs material data                  *
*         lunran = output file for the final random number seed       *
*         lunxsc = input file for low energy neutron cross sections   *
*         lunrdb = unit number for reading (extra) auxiliary external *
*                  files to be closed just after reading              *
*                                                                     *
*---------------------------------------------------------------------*
*                                                                     *
      PARAMETER ( LUNIN  = 5  )
      PARAMETER ( LUNOUT = 6  )
      PARAMETER ( LUNERR = 66 )
      PARAMETER ( LUNBER = 14 )
      PARAMETER ( LUNECH = 8  )
      PARAMETER ( LUNFLU = 86 )
      PARAMETER ( LUNGEO = 16 )
      PARAMETER ( LUNPGS = 12 )
      PARAMETER ( LUNRAN = 2  )
      PARAMETER ( LUNXSC = 81 )
      PARAMETER ( LUNRDB = 1  )
 
*$ CREATE DIMPAR.ADD
*COPY DIMPAR
*                                                                     *
*=== dimpar ==========================================================*
*                                                                     *
*---------------------------------------------------------------------*
*                                                                     *
*      DIMPAR: included in any routine                                *
*                                                                     *
*          Mxxrgn = maximum number of regions                         *
*          Mxxmdf = maximum number of media in Fluka                  *
*          Mxxmde = maximum number of media in Emf                    *
*          Mfstck = stack dimension in Fluka                          *
*          Mestck = stack dimension in Emf                            *
*          Nallwp = number of allowed particles                       *
*          Mpdpdx = number of particle types for which EM dE/dx pro-  *
*                   cesses (ion,pair,bremss) have to be computed      *
*          Icomax = maximum number of materials for compounds (equal  *
*                   to the sum of the number of materials for every   *
*                   compound )                                        *
*          Nstbis = number of stable isotopes recorded in common iso- *
*                   top                                               *
*          Idmaxp = number of particles/resonances defined in common  *
*                   part                                              *
*                                                                     *
*---------------------------------------------------------------------*
*                                                                     *
      PARAMETER ( MXXRGN = 500  )
      PARAMETER ( MXXMDF = 56   )
      PARAMETER ( MXXMDE = 50   )
      PARAMETER ( MFSTCK = 1000 )
      PARAMETER ( MESTCK = 100  )
      PARAMETER ( NALLWP = 39   )
      PARAMETER ( MPDPDX = 8    )
      PARAMETER ( ICOMAX = 180  )
      PARAMETER ( NSTBIS = 304  )
      PARAMETER ( IDMAXP = 210  )
*----------------------------------------------------------------------*
*  Threpd89: slight revision by A. Ferrari                             *
*  Last change on   11-oct-93   by    Alfredo Ferrari, INFN - Milan    *
*----------------------------------------------------------------------*
*
      DIMENSION F(5),XX(5)
C***THREE PARTICLE DECAY IN THE CM - SYSTEM
      COMMON /DGAMRE/ REDU,AMO,AMM(15 )
      COMMON/DDREI/UUMO,AAM1,AAM2,AAM3,S22,UMO2,
     *AM11,AM22,AM33,S2SUP,S2SAP(2)
C     COMMON/PRUNT/ISYS
      COMMON/PRITT/ISYS
ctp060123      SAVE EPS
      DATA EPS/AZRZRZ/
*
      UMOO=UMO+UMO
C***S1, S2, S3 ARE THE INVARIANT MASSES OF THE PARTICLES 1, 2, 3
C***J. VON NEUMANN - RANDOM - SELECTION OF S2
C***CALCULATION OF THE MAXIMUM OF THE S2 - DISTRIBUTION
      UUMO=UMO
      AAM1=AM1
      AAM2=AM2
      AAM3=AM3
      GU=(AM2+AM3)**2
      GO=(UMO-AM1)**2
*     UFAK=1.0000000000001D0
*     IF (GU.GT.GO) UFAK=0.9999999999999D0
      IF (GU.GT.GO) THEN
         UFAK=ONEMNS
      ELSE
         UFAK=ONEPLS
      END IF
      OFAK=2.D0-UFAK
      GU=GU*UFAK
      GO=GO*OFAK
      DS2=(GO-GU)/99.D0
      AM11=AM1*AM1
      AM22=AM2*AM2
      AM33=AM3*AM3
      UMO2=UMO*UMO
      RHO2=0.D0
      S22=GU
      DO 124 I=1,100
         S21=S22
         S22=GU+(I-1.D0)*DS2
         RHO1=RHO2
         RHO2=DXLAMB(S22,UMO2,AM11)*DXLAMB(S22,AM22,AM33)/
     *                                             (S22+EPS)
         IF(RHO2.LT.RHO1) GO TO 125
  124 CONTINUE
  125 S2SUP=(S22-S21)*.5D0+S21
      SUPRHO=DXLAMB(S2SUP,UMO2,AM11)*DXLAMB(S2SUP,AM22,AM33)/
     *                                           (S2SUP+EPS)
      SUPRHO=SUPRHO*1.05D0
      XO=S21-DS2
      IF (GU.LT.GO.AND.XO.LT.GU) XO=GU
      IF (GU.GT.GO.AND.XO.GT.GU) XO=GU
      XX(1)=XO
      XX(3)=S22
      X1=(XO+S22)*0.5D0
      XX(2)=X1
      F(3)=RHO2
      F(1)=DXLAMB(XO,UMO2,AM11)*DXLAMB(XO,AM22,AM33)/(XO+EPS)
      F(2)=DXLAMB(X1,UMO2,AM11)*DXLAMB(X1,AM22,AM33)/(X1+EPS)
      DO 126 I=1,16
         X4=(XX(1)+XX(2))*0.5D0
         X5=(XX(2)+XX(3))*0.5D0
         F(4)=DXLAMB(X4,UMO2,AM11)*DXLAMB(X4,AM22,AM33)/
     *                                               (X4+EPS)
         F(5)=DXLAMB(X5,UMO2,AM11)*DXLAMB(X5,AM22,AM33)/
     *                                               (X5+EPS)
         XX(4)=X4
         XX(5)=X5
         DO 128 II=1,5
            IA=II
            DO 128 III=IA,5
               IF (F (II).GE.F (III)) GO TO 128
               FH=F(II)
               F(II)=F(III)
               F(III)=FH
               FH=XX(II)
               XX(II)=XX(III)
               XX(III)=FH
128      CONTINUE
         SUPRHO=F(1)
         S2SUP=XX(1)
         DO 129 II=1,3
            IA=II
            DO 129 III=IA,3
               IF (XX(II).GE.XX(III)) GO TO 129
               FH=F(II)
               F(II)=F(III)
               F(III)=FH
               FH=XX(II)
               XX(II)=XX(III)
               XX(III)=FH
129      CONTINUE
126   CONTINUE
      AM23=(AM2+AM3)**2
      ITH=0
      REDU=2.D0
    1 CONTINUE
      ITH=ITH+1
      IF (ITH.GT.200) REDU=-9.D0
      IF (ITH.GT.200) GO TO 400
      C=RNDM(C)
*     S2=AM23+C*((UMO-AM1)**2-AM23)
      S2=AM23+C*(UMO-AM1-AM2-AM3)*(UMO-AM1+AM2+AM3)
      Y=RNDM(Y)
      Y=Y*SUPRHO
      RHO=DXLAMB(S2,UMO2,AM11)*DXLAMB(S2,AM22,AM33)/S2
      IF(Y.GT.RHO) GO TO 1
C***RANDOM SELECTION OF S3 AND CALCULATION OF S1
      S1=RNDM(S1)
      S1=S1*RHO+AM11+AM22-(S2-UMO2+AM11)*(S2+AM22-AM33)/(2.D0*S2)-
     &RHO*.5D0
      S3=UMO2+AM11+AM22+AM33-S1-S2
      ECM1=(UMO2+AM11-S2)/UMOO
      ECM2=(UMO2+AM22-S3)/UMOO
      ECM3=(UMO2+AM33-S1)/UMOO
      PCM1=SQRT((ECM1+AM1)*(ECM1-AM1))
      PCM2=SQRT((ECM2+AM2)*(ECM2-AM2))
      PCM3=SQRT((ECM3+AM3)*(ECM3-AM3))
      CALL DSFECF(SFE,CFE)
C***TH IS THE ANGLE BETWEEN PARTICLES 1 AND 2
C***TH1, TH2 ARE THE ANGLES BETWEEN PARTICLES 1, 2 AND THE DIRECTION OF
      PCM12 = PCM1 * PCM2
      IF ( PCM12 .LT. ANGLSQ ) GO TO 200
      COSTH=(ECM1*ECM2+0.5D+00*(AM11+AM22-S1))/PCM12
      GO TO 300
 200  CONTINUE
         UW=RNDM(UW)
         COSTH=(UW-0.5D+00)*2.D+00
 300  CONTINUE
*     IF(ABS(COSTH).GT.0.9999999999999999D0)
*    &COSTH=SIGN(0.9999999999999999D0,COSTH)
      IF(ABS(COSTH).GT.ONEONE)
     &COSTH=SIGN(ONEONE,COSTH)
      IF (REDU.LT.1.D+00) RETURN
      COSTH2=(PCM3*PCM3+PCM2*PCM2-PCM1*PCM1)/(2.D+00*PCM2*PCM3)
*     IF(ABS(COSTH2).GT.0.9999999999999999D0)
*    &COSTH2=SIGN(0.9999999999999999D0,COSTH2)
      IF(ABS(COSTH2).GT.ONEONE)
     &COSTH2=SIGN(ONEONE,COSTH2)
      SINTH2=SQRT((ONEONE-COSTH2)*(ONEONE+COSTH2))
      SINTH =SQRT((ONEONE-COSTH)*(ONEONE+COSTH))
      SINTH1=COSTH2*SINTH-COSTH*SINTH2
      COSTH1=COSTH*COSTH2+SINTH2*SINTH
C***RANDOM SELECTION OF THE SPHERICAL COORDINATES OF THE DIRECTION OF PA
C***CFE, SFE ARE COS AND SIN OF THE ROTATION ANGLE OF THE SYSTEM 1, 2 AR
C***THE DIRECTION OF PARTICLE 3
C***CALCULATION OF THE SPHERICAL COORDINATES OF PARTICLES 1, 2
      CX11=-COSTH1
      CY11=SINTH1*CFE
      CZ11=SINTH1*SFE
      CX22=-COSTH2
      CY22=-SINTH2*CFE
      CZ22=-SINTH2*SFE
      CALL DSFECF(SIF3,COF3)
      COD3=TWOTWO*RNDM(COD3)-ONEONE
      SID3=SQRT((1.D+00-COD3)*(1.D+00+COD3))
    2 FORMAT(5F20.15)
      COD1=CX11*COD3+CZ11*SID3
      CHLP=(ONEONE-COD1)*(ONEONE+COD1)
      IF(CHLP.LT.1.D-14)WRITE(ISYS,2)COD1,COF3,SID3,
     &CX11,CZ11
      SID1=SQRT(CHLP)
      COF1=(CX11*SID3*COF3-CY11*SIF3-CZ11*COD3*COF3)/SID1
      SIF1=(CX11*SID3*SIF3+CY11*COF3-CZ11*COD3*SIF3)/SID1
      COD2=CX22*COD3+CZ22*SID3
      SID2=SQRT((ONEONE-COD2)*(ONEONE+COD2))
      COF2=(CX22*SID3*COF3-CY22*SIF3-CZ22*COD3*COF3)/SID2
      SIF2=(CX22*SID3*SIF3+CY22*COF3-CZ22*COD3*SIF3)/SID2
 400  CONTINUE
* === Energy conservation check: === *
      EOCHCK = UMO - ECM1 - ECM2 - ECM3
*     SID1 = SQRT ( ( ONEONE - COD1 ) * ( ONEONE + COD1 ) )
*     SID2 = SQRT ( ( ONEONE - COD2 ) * ( ONEONE + COD2 ) )
*     SID3 = SQRT ( ( ONEONE - COD3 ) * ( ONEONE + COD3 ) )
      PZCHCK = PCM1 * COD1 + PCM2 * COD2 + PCM3 * COD3
      PXCHCK = PCM1 * COF1 * SID1 + PCM2 * COF2 * SID2
     &       + PCM3 * COF3 * SID3
      PYCHCK = PCM1 * SIF1 * SID1 + PCM2 * SIF2 * SID2
     &       + PCM3 * SIF3 * SID3
      EOCMPR = 1.D-12 * UMO
      IF ( ABS (EOCHCK) + ABS (PXCHCK) + ABS (PYCHCK) + ABS (PZCHCK)
     &     .GT. EOCMPR ) THEN
         WRITE(LUNERR,*)
     &   ' *** Threpd: energy/momentum conservation failure! ***',
     &   EOCHCK,PXCHCK,PYCHCK,PZCHCK
         WRITE(LUNERR,*)' *** SID1,SID2,SID3',SID1,SID2,SID3
      END IF
      RETURN
      END
*=== xlamb ============================================================*
*
      DOUBLE PRECISION FUNCTION DXLAMB(X,Y,Z)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      DATA IDGB/0/
      COMMON /DGAMRE/ REDU,AMO,AMM(15 )
      COMMON/DDREI/TEST(12)
      YZ=Y-Z
      DXLAMB=X*X-2.D0*X*(Y+Z)+YZ*YZ
      XLAM =DXLAMB
      IF (IDGB.LE.0) GO TO 11
      IF(DXLAMB.GT.1.D-12) GOTO 11
      WRITE(6,12)
      WRITE(6,10) XLAM,X,Y,Z,TEST
      WRITE(6,13)
   12 FORMAT(/,10X,' DXLAMB PRINT')
   13 FORMAT(10X,60(1H*))
   10 FORMAT(4E20.8,'DXLAMB',/,12F10.5)
   11 CONTINUE
      IF(DXLAMB.LE.0.D0)DXLAMB=ABS(DXLAMB)
      DXLAMB=SQRT(DXLAMB)
      RETURN
      END
 
*-- Author :
C     DOUBLE PRECISION FUNCTION DXLAMB(X,Y,Z)
C      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C     SAVE
C     YZ=Y-Z
C     DXLAMB=X*X-2.*X*(Y+Z)+YZ*YZ
C     IF(DXLAMB.LE.0.)DXLAMB=ABS(DXLAMB)
C     DXLAMB=SQRT(DXLAMB)
C     RETURN
C     END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE STRAFO(GAM,BGAM,CX,CY,CZ,COD,COF,SIF,P,ECM,
     1PL,CXL,CYL,CZL,EL)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
C     LORENTZ TRANSFORMATION INTO THE LAB - SYSTEM
      SID=SQRT((1.-COD)*(1.+COD)+1.E-22)
      SIF=SQRT((1.-COF)*(1.+COF)+1.E-22)
      PLX=P*SID*COF
      PLY=P*SID*SIF
      PCMZ=P*COD
      PLZ=GAM*PCMZ+BGAM*ECM
      PL=SQRT(PLX*PLX+PLY*PLY+PLZ*PLZ)
      EL=GAM*ECM+BGAM*PCMZ
C     ROTATION INTO THE ORIGINAL DIRECTION
      COZ=PLZ/PL
      IF(COZ.GE.1.)COZ=0.999999999999
      SIZ=SQRT((1.-COZ)*(1.+COZ))
      CALL DRTRAN(CX,CY,CZ,COZ,SIZ,SIF,COF,CXL,CYL,CZL)
      RETURN
      END
*-- Author :
      SUBROUTINE DRTRAN(XO,YO,ZO,CDE,SDE,SFE,CFE,X,Y,Z)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      IF (ABS(XO)-0.0001) 10,10,30
   10 IF (ABS(YO)-0.0001) 20,20,30
   20 CONTINUE
      X=SDE*CFE
      Y=SDE*SFE
      Z=CDE*ZO
      RETURN
   30 CONTINUE
      XI=SDE*CFE
      YI=SDE*SFE
      ZI=CDE
      A=SQRT(XO**2+YO**2)
      X=-YO*XI/A-ZO*XO*YI/A+XO*ZI
      Y=XO*XI/A-ZO*YO*YI/A+YO*ZI
      Z=A*YI+ZO*ZI
      RETURN
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE DCHANT
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      CHARACTER*8 ZKNAME
C      COMMON/DDECAC/ ZKNAME(540),NZK(540,3),WT(540)
 
      PARAMETER (IDMAX9=602)
C      CHARACTER*8 ZKNAME
      COMMON/DDECAC/ ZKNAME(IDMAX9),WT(IDMAX9),NZK(IDMAX9,3)
 
 
      CHARACTER*8 ANAME
      COMMON/DPAR/ANAME(210),AM(210),GA(210),TAU(210),ICH(210),IBAR(210)
     *,K1(210),K2(210)
      DIMENSION HWT(602)
C  CHANGE OF WEIGHTS WT FROM ABSOLUT VALUES INTO THE SUM OF WT OF A DEC.
      DO 10 J=1,602
   10 HWT(J)=0.
      DO 30 I=1,210
        IK1=K1(I)
        IK2=K2(I)
        HV=0.
        DO 20 J=IK1,IK2
          HV=HV+WT(J)
          HWT(J)=HV
C         IF(HWT(J).GT.1.) WRITE(6,1000) HWT(J),J,I,IK1
   20   CONTINUE
C1000 FORMAT(2X,15H ERROR IN HWT =,1F10.5,8H J,I,K1=,3I5)
   30 CONTINUE
      DO 40 J=1,602
   40 WT(J)=HWT(J)
      RETURN
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE DTWOPD(UMO,ECM1,ECM2,PCM1,PCM2,COD1,COF1,SIF1, COD2,
     +COF2,SIF2,AM1,AM2)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
C*****TWO PARTICLE DECAY IN THE CM - SYSTEM
C
      IF(UMO.LT.(AM1+AM2)) THEN
        WRITE(6,'(/,A/A,3(1PE12.4))')
     +  ' INCONSISTENT CALL OF TWOPAD / EXECUTION STOPPED',
     +  ' UMO, AM1, AM2 :', UMO, AM1, AM2
        STOP
      ENDIF
C
      ECM1=((UMO-AM2)*(UMO+AM2) + AM1*AM1)/(2.*UMO)
      ECM2=UMO-ECM1
      PCM1=SQRT((ECM1-AM1)*(ECM1+AM1))
      PCM2=PCM1
      CALL DSFECF(SIF1,COF1)
      COD1=2.*RNDM(X)-1.
      COD2=-COD1
      COF2=-COF1
      SIF2=-SIF1
      RETURN
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE DSFECF(SFE,CFE)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
   10 X=RNDM(V)
      Y=RNDM(V)
      XX=X*X
      YY=Y*Y
      XY=XX+YY
      IF(XY.GT.1)                                                 GOTO10
      CFE=(XX-YY)/XY
      SFE=2.*X*Y/XY
      IF(RNDM(V).LT.0.5D0)                                      GOTO20
      RETURN
   20 SFE=-SFE
      RETURN
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE DDATES
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      CHARACTER*8 ZKNAME,Z
C      COMMON /DDECAC/ ZKNAME(540),NZK(540,3),WT(540)
 
      PARAMETER (IDMAX9=602)
C      CHARACTER*8 ZKNAME
      COMMON/DDECAC/ ZKNAME(IDMAX9),WT(IDMAX9),NZK(IDMAX9,3)
 
 
      CHARACTER*8 ANAME
      COMMON /DPAR/ ANAME(210),AM(210),GA(210),TAU(210), ICH(210),IBAR
     +(210),K1(210),K2(210)
C----------------------
      DIMENSION ICHAR(210)
      EQUIVALENCE (ICH(1),ICHAR(1))
      DIMENSION Z(3)
C---------------------------
      WRITE(6, 1000)
 1000 FORMAT(1H1,'   ')
      WRITE(6, 1010)
 1010 FORMAT(///' TABLE OF USED PARTICLES AND RESONANCES (I)',//
     +' I = NUMBER OF PARTICLE OR RESONANCE',/
     +' IPDG = P D G NUMBER OF PARTICLE OR RESONANCE',/
     +' ANAME = NAME OF I'/, ' AM = MASS OF I  (GEV)',/
     +' GA = WIDTH OF I  (GEV)',/ ' TAU = LIFE TIME OF I  (SEC.)',/
     +' ICH = ELECTRIC CHARGE OF I, IBAR = BARYONIC CHARGE OF I',/' ', '
     +K1 = FIRST DECAY CHANNEL NUMBER, K2 = LAST DECAY CHANNEL NUMBER OF
     +I')
 
 
      WRITE(6, 1020)
 1020 FORMAT(///
     +'   I  ANAME   AM         GA         TAU       ICH IBAR K1  K2'/)
      JOO=210
      DO 10 I=1,JOO
        IPDG=MPDGHA(I)
        WRITE(6, 1030)I,IPDG,ANAME(I),AM(I),
     +  GA(I),TAU(I),ICH(I),IBAR(I), K1
     +  (I),K2(I)
 1030 FORMAT (1I4,I6,2X,1A8,3E11.4,4I4)
        IF(I.EQ.43) WRITE(6, 1000)
        IF(I.EQ.43) WRITE(6, 1020)
        IF(I.EQ.99) WRITE(6, 1000)
        IF(I.EQ.99) WRITE(6, 1020)
        IF(I.EQ.155) WRITE(6, 1000)
        IF(I.EQ.155) WRITE(6, 1020)
   10 CONTINUE
      WRITE(6, 1000)
      WRITE(6, 1040)
 1040 FORMAT(///' DECAY CHANNELS OF PARTICLES AND RESONANCES',//)
      WRITE(6, 1050)
 1050 FORMAT(' ANAME = PARTICLE AND RESONANCE NAME'/,
     +' DNAME = DECAY CHANNEL NAME'/, ' J = DECAY CHANNEL NUMBER'/,
     +' I = NUMBER OF DECAYING PARTICLE'/,
     +' WT = SUM OF DECAY CHANNEL WEIGHTS FROM K1(I) UP TO J'/,
     +' NZK = PROGRAM INTERNAL NUMBERS OF DECAY PRODUCTS')
 
      WRITE(6, 1060)
 1060 FORMAT(///'   I     J      ANAME       DNAME                DECAY
     +PRODUCTS            WT       NZK'/)
      DO 60 I=1,JOO
        IK1=K1(I)
        IK2=K2(I)
        IF (IK1.LE.0)                                           GO TO 60
        DO 50 IK=IK1,IK2
          I1=NZK(IK,1)
          I2=NZK(IK,2)
          I3=NZK(IK,3)
          IF (I1.LE.0) I1=29
          IF (I2.LE.0) I2=29
          IF (I3.LE.0) I3=29
          J1=I1
          J2=I2
          J3=I3
          Z(1)=ANAME(I1)
          Z(2)=ANAME(I2)
          Z(3)=ANAME(I3)
          WRITE(6, 1070)I,IK,ANAME(I),ZKNAME(IK),(Z(J),J=1,3),WT(IK),J1,J2,
     +    J3
 1070 FORMAT(2I5,' DECAY OF ',1A8,' (CHANNEL: ',1A6,' ) TO ',3(1A6,2X),
     +1F8.4,3I5)
          AMTEST=AM(I)-AM(J1)-AM(J2)-AM(J3)
          IBTEST=IBAR(I)-IBAR(J1)-IBAR(J2)-IBAR(J3)
          ICTEST=ICHAR(I)-ICHAR(J1)-ICHAR(J2)-ICHAR(J3)
          IF (AMTEST) 20,30,30
   20     MTEST=1
                                                                GO TO 40
   30     MTEST=0
   40     CONTINUE
          IF (MTEST+IBTEST**2+ICTEST**2.NE.0) WRITE(6, 1080)AMTEST,
     +    IBTEST,
     +    ICTEST
 1080 FORMAT (' ***** ERROR IN MASS, BAR.CH. OR E.CH. ',F10.5,2I6)
          IF(IK.EQ.27) WRITE(6, 1000)
          IF(IK.EQ.27) WRITE(6, 1060)
          IF(IK.EQ.62) WRITE(6, 1000)
          IF(IK.EQ.62) WRITE(6, 1060)
          IF(IK.EQ.101) WRITE(6, 1000)
          IF(IK.EQ.101) WRITE(6, 1060)
          IF(IK.EQ.144) WRITE(6, 1000)
          IF(IK.EQ.144) WRITE(6, 1060)
          IF(IK.EQ.183) WRITE(6, 1000)
          IF(IK.EQ.183) WRITE(6, 1060)
          IF(IK.EQ.222) WRITE(6, 1000)
          IF(IK.EQ.222) WRITE(6, 1060)
          IF(IK.EQ.261) WRITE(6, 1000)
          IF(IK.EQ.261) WRITE(6, 1060)
          IF(IK.EQ.300) WRITE(6, 1000)
          IF(IK.EQ.300) WRITE(6, 1060)
          IF(IK.EQ.362) WRITE(6, 1000)
          IF(IK.EQ.362) WRITE(6, 1060)
          IF(IK.EQ.401) WRITE(6, 1000)
          IF(IK.EQ.401) WRITE(6, 1060)
          IF(IK.EQ.440) WRITE(6, 1000)
          IF(IK.EQ.440) WRITE(6, 1060)
          IF(IK.EQ.479) WRITE(6, 1000)
          IF(IK.EQ.479) WRITE(6, 1060)
          IF(IK.EQ.518) WRITE(6, 1000)
          IF(IK.EQ.518) WRITE(6, 1060)
   50   CONTINUE
   60 CONTINUE
      RETURN
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE DDATAR
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      COMMON/DINPDA/IMPS(6,6),IMVE(6,6),IB08(6,21),IB10(6,21),
     *IA08(6,21),IA10(6,21),A1,B1,B2,B3,LT,LB,BET,AS,B8,AME,DIQ,ISU
      DIMENSION IV(36),IP(36),IB(126),IBB(126),IA(126),IAA(126)
C     DEFINE THE FIELDS FOR PARTICLE CLASSIFICATION
C     IMPS=PSEUDO SCALAR MESONS (SPIN=0)
C     IMVE=VECTOR MESONS (SPIN=1)
C     IB08(IA08)=BARYONS (ANTIBARYONS) (SPIN=1/2)
C     IB10(IA10)=BARYONS (ANTIBARYONS) (SPIN=3/2)
      DATA IP/
     *23,14,16,116,0,0,13,23,25,117,0,0,15,24,31,120,0,0,119,118,121,
     *122,14*0/
      L=0
      DO 20 I=1,6
        DO 10 J=1,6
          L=L+1
          IMPS(I,J)=IP(L)
   10   CONTINUE
   20 CONTINUE
      DATA IV/
     *33,34,38,123,0,0,32,33,39,124,0,0,36,37,96,127,0,0,126,125,128,
     *129,14*0/
      L=0
      DO 40 I=1,6
        DO 30 J=1,6
          L=L+1
          IMVE(I,J)=IV(L)
   30   CONTINUE
   40 CONTINUE
      DATA IB/
     *0,1,21,140,0,0,8,22,137,0,0,97,138,0,0,146,5*0,
     *1,8,22,137,0,0,0,20,142,0,0,98,139,0,0,147,5*0,
     *21,22,97,138,0,0,20,98,139,0,0,0,145,0,0,148,5*0,
     *140,137,138,146,0,0,142,139,147,0,0,145,148,50*0/
      L=0
      DO 60 I=1,6
        DO 50 J=1,21
          L=L+1
          IB08(I,J)=IB(L)
   50   CONTINUE
   60 CONTINUE
      DATA IBB/
     *53,54,104,161,0,0,55,105,162,0,0,107,164,0,0,167,5*0,
     *54,55,105,162,0,0,56,106,163,0,0,108,165,0,0,168,5*0,
     *104,105,107,164,0,0,106,108,165,0,0,109,166,0,0,169,5*0,
     *161,162,164,167,0,0,163,165,168,0,0,166,169,0,0,170,47*0/
      L=0
      DO 80 I=1,6
        DO 70 J=1,21
          L=L+1
          IB10(I,J)=IBB(L)
   70   CONTINUE
   80 CONTINUE
      DATA IA/
     *0,2,99,152,0,0,9,100,149,0,0,102,150,0,0,158,5*0,
     *2,9,100,149,0,0,0,101,154,0,0,103,151,0,0,159,5*0,
     *99,100,102,150,0,0,101,103,151,0,0,0,157,0,0,160,5*0,
     *152,149,150,158,0,0,154,151,159,0,0,157,160,50*0/
      L=0
      DO 100 I=1,6
        DO 90 J=1,21
          L=L+1
          IA08(I,J)=IA(L)
   90   CONTINUE
  100 CONTINUE
      DATA IAA/
     *67,68,110,171,0,0,69,111,172,0,0,113,174,0,0,177,5*0,
     *68,69,111,172,0,0,70,112,173,0,0,114,175,0,0,178,5*0,
     *110,111,113,174,0,0,112,114,175,0,0,115,176,0,0,179,5*0,
     *171,172,174,177,0,0,173,175,178,0,0,176,179,0,0,180,47*0/
      L=0
      DO 120 I=1,6
        DO 110 J=1,21
          L=L+1
          IA10(I,J)=IAA(L)
  110   CONTINUE
  120 CONTINUE
C     DEFINE THE FREE PARAMETERS FOR THE MONTE-CARLO PROGRAMMES BAMJET
C     AND PARJET
      A1=0.88
      B3=8.0
      B1=8.0
      B2=8.0
      ISU=4
c     BET=8.0
      BET=9.5
      BET=12.
      AS=0.50
      AME=0.95
      B8=0.40
      DIQ=0.375
      LT=0
      LB=0
C     THE FOLLOWING ARE THE PARAMETERS USED IN ABR8611
      A1=0.95
      A1=0.50
      A1=0.88
      B3=8.
      B1=6.
      B1=3.
      B2=6.
      B2=3.
      AS=0.25
*     AME=0.95
      B8=0.33
C     WRITE (6,123)A1,B3,B1,B2,ISU,BET,AS,AME,LT,LB,B8,DIQ
C 123 FORMAT (' DATAR3 INITIALIZATION:PARAMETERS SET LIKE IN ABR8611'/
C    *' A1    = ',F10.4/
C    *' B3    = ',F10.4/
C    *' B1    = ',F10.4/
C    *' B2    = ',F10.4/
C    *' ISU   = ',I10/
C    *' BET   = ',F10.4/
C    *' AS    = ',F10.4/
C    *' AME   = ',F10.4/
C    *' LT    = ',I10/
C    *' LB    = ',I10/
C    *' B8    = ',F10.4/
C    *' DIQ   = ',F10.4)
      RETURN
      END
*-- Author :
C
C
C--------------------------------------------------------------------
C
C     FILE TECALBAM
C
C
C--------------------------------------------------------------------
      SUBROUTINE TECALB
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
C     SUBROUTINE TECALBAM
C
C     TWO CHAIN FRAGMENTATION MODEL FOR PARTICLE PRODUCTION
C     TEST OF  CALBAM ROUTINE CALLING BAMJET
C                 JUNE   1987, J.RANFT
C********************************************************************
C
C      OPTIONS
C
C      JNI=7 BAMJET DISTRIBUTIONS ANALOG TO JNI=2
C
C      IP=1=P,  IP=2=AP,  IP=8=N,  IP=9=AN,  IP=13=PI+,  IP=14=PI-,
C      IP=15=K+,  IP=16=K-,
C
C**********************************************************************
C
*KEEP,DFINPA.
      CHARACTER*8 ANF
      PARAMETER (NFIMAX=249)
      COMMON /DFINPA/ ANF(NFIMAX),PXF(NFIMAX),PYF(NFIMAX),PZF(NFIMAX),
     +HEF(NFIMAX),AMF(NFIMAX), ICHF(NFIMAX),IBARF(NFIMAX),NREF(NFIMAX)
      COMMON /DFINPZ/IORMO(NFIMAX),IDAUG1(NFIMAX),IDAUG2(NFIMAX),
     * ISTATH(NFIMAX)
*KEEP,DINPDA.
      COMMON /DINPDA/ IMPS(6,6),IMVE(6,6),IB08(6,21),IB10(6,21), IA08
     +(6,21),IA10(6,21), A1,B1,B2,B3,LT,LE,BET,AS,B8,AME,DIQ,ISU
*KEEP,DPRIN.
      COMMON /DPRIN/  IPRI,IPEV,IPPA,IPCO,INIT,IPHKK,ITOPD,IPAUPR
*KEND.
      COMMON/JNI/JNI
      COMMON /DIFF/ IDIFF
      COMMON /DKPL/UPLO,IPQ
      COMMON /DINVV/PNUC(3),INUCVT
      COMMON/CAPKOP/XX1,XX3
C----------------------------------------------------------------------
      WRITE (6,1000)
 1000 FORMAT (' ##############################################'/
     +' PROGRAM TECABAPT'/
     +' ######################################################')
C     CALL PRIBLO
C     CALL DATAR3
C     CALL CHANWT
      INIT=0
      LT=0
      IT=1
      IP=1
      IPRI=0
   10 CONTINUE
      READ(5,1010)JNI,NEVT,IP,NCASES,POO,AOO,ZNUC
 1010 FORMAT(4I10,3F10.2)
      IF (IT.EQ.0) IT=1
      IF (JNI.LE.0)                                            GO TO 120
      IF (JNI.LT.0) THEN
        WRITE(6, 1010)JNI,NEVT,IP,NCASES,POO,AOO,ZNUC,IT
        WRITE(6,*) 'STOP IN TECALB'
        STOP
      ENDIF
C**********   JNI SELECTS OPTION   *************************************
      JNI=7
      GO TO (20,30,40,50,60,70,80,100),JNI
   20 CONTINUE
   30 CONTINUE
   40 CONTINUE
   50 CONTINUE
   60 CONTINUE
   70 CONTINUE
                                                               GO TO 110
   80 CONTINUE
C*** JNI=7 CALCUL. BAMJET EVENTS
C*** WITH ENERGY POO     (CMS ENERGY)
      IPRI=0
      LT=0
      INIT=0
      IPQ=1
      XX1=0.9
      XX3=1.
      UPLO=POO
      III=1
      CALL DISTCM(1,IPQ,POO,IPQ,IPQ)
C     CALL DISRES(1,IPQ,POO,IPQ,IPQ)
      DO 90 L=1, NEVT
        IF (IP.EQ.103)CALL CALBAM(0,1,1,1,7,1,1,POO,3,NHAD)
        IF (IP.EQ.109)CALL CALBAM(0,1,1,7,1,1,1,POO,3,NHAD)
        IF (IP.EQ.104)CALL CALBAM(0,1,1,1,2,2,1,POO,4,NHAD)
        IF (IP.EQ.1010)CALL CALBAM(0,1,1,1,2,3,1,POO,4,NHAD)
        IF (IP.EQ.105)CALL CALBAM(0,1,1,1,2,7,8,POO,5,NHAD)
        IF (IP.EQ.1011)CALL CALBAM(0,1,1,7,7,1,1,POO,5,NHAD)
        IF (IP.EQ.106)CALL CALBAM(0,1,1,1,1,1,1,POO,6,NHAD)
        IF (IP.EQ.1012)CALL CALBAM(0,1,1,7,7,7,1,POO,6,NHAD)
        IF (IP.EQ.1050)CALL CALBAM(0,1,1,1,1,2,1,POO,10,NHAD)
C
        CALL DDECAY(NHAD,2)
        CALL DISTCM(2,NHAD,POO,IPQ,NCASES)
   90 CONTINUE
C
      WRITE(6, 1020)POO,IP,NCASES
 1020 FORMAT (' BAMJET (POO,IP,NCASES) = ',1F10.2,2I10)
      CALL DISTCM(3,NEVT,POO,IPQ,NCASES)
C     CALL DISRES(3,III*NEVT,POO,IPQ,NCASES)
                                                               GO TO 110
  100 CONTINUE
  110 CONTINUE
                                                                GO TO 10
  120 CONTINUE
      RETURN
      END
*-- Author :
C
C++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE DISTCM(IOP,NHAD,POLAB,KPROJ,KTARG)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
C
C*** 1=P,  2=N, 3=PI+, 4=PI-, 5=PIO, 6=GAM+HYP, 7=K, 8=ANUC, 9=CHARGED
C*** 10=TOT, 11=TOTHAD
C
      CHARACTER*8 ANH
      PARAMETER (NFIMAX=249)
      COMMON /DFINPA/ ANH(NFIMAX),PX(NFIMAX),PY(NFIMAX),PZ(NFIMAX),
     +HE(NFIMAX),AM(NFIMAX), ICH(NFIMAX),IBAR(NFIMAX),NR(NFIMAX)
      COMMON /DFINPZ/IORMO(NFIMAX),IDAUG1(NFIMAX),IDAUG2(NFIMAX),
     * ISTATH(NFIMAX)
C---------------------
      CHARACTER*8 ANAME
      COMMON /DPAR/ ANAME(210),AAM(210),GA(210),TAU(210),IICH(210),
     +IIBAR(210),K1(210),K2(210)
C------------------
      COMMON /HISTO / XMULT(100,10),YMULT(100,10),XXFL(50,20), YXFL
     +(50,20),XYL(50,20),YYL(50,20), YYLPS(50,20),PTP(50,20),PTY(50,20),
     +FILL(6000)
      DIMENSION AVMULT(12,30),AVE(12,30),INDX(25),MU(12,30), AKNO
     +(100,2),XKNO(100,2),AKE(12,30),AASO(12,30)
      COMMON /DKPL/UPLO,KPL
      COMMON/JNI/JNI
C
      DATA IPRIOP/1/
      DATA INDX/1,8,10,10,10,10,7,2,7,10,10,7,3,4,5,6,
     *11,12,7,13,14,15,16,17,18/
C-----------------------------------------------------------------------
      GO TO (10,60,100),IOP
   10 CONTINUE
      KPL=1
      AVPT=0.
      NAVPT=0
      DXFL=0.04
      PO=POLAB
C     EEO=SQRT(PO**2+AAM(NHAD)**2)
C     UMO=SQRT(AAM(KTARG)**2+AAM(KPROJ)**2+2.*AAM(KTARG)*EEO)
      IF(JNI.EQ.7) UMO=POLAB
      UMO=POLAB
      EEO=UMO
      PO=EEO/2.D0
      WRITE(6, 1000)EEO,PO,NHAD
 1000 FORMAT (' EEO',F10.2,F10.2,I10)
      DY=0.2
      DPT=0.10
      DO 20 I=1,10
        AVMULT(KPL,I)=1.E-18
        AVE(KPL,I)=0.
        DO 20 J=1,100
          XMULT(J,I)=J-1
          YMULT(J,I)=1.D-18
          AKNO(J,1)=1.D-18
          AKNO(J,2)=1.D-18
   20 CONTINUE
      WRITE(6, 1000)EEO,PO,NHAD
      DO 30 I=1,20
        DO 30 J=1,50
          XXFL(J,I)=J*DXFL -1.
          YXFL(J,I)=1.D-18
          XYL(J,I)=-5.0+J*DY
          YYL(J,I)=1.D-18
          YYLPS(J,I)=1.E-18
          PTP(J,I)=J*DPT
          PTY(J,I)=1.D-18
   30 CONTINUE
      WRITE(6, 1000)EEO,PO,NHAD
   40 CONTINUE
      DO 50 I=1,30
        AVE(KPL,I)=1.D-18
        AVMULT(KPL,I)=1.D-18
        MU(KPL,I)=0
        AASO(KPL,I)=UPLO
   50 CONTINUE
      WRITE(6, 1000)EEO,PO,NHAD
      RETURN
C
   60 CONTINUE
C      WRITE(6, 1000)EEO,PO,NHAD
      AVMULT(KPL,30)=AVMULT(KPL,30)+NHAD
      NNHAD=NHAD+1
      IF (NNHAD.GT.100) NNHAD=100
      YMULT(NNHAD,10)=YMULT(NNHAD,10)+1.
      DO 70 I=1,30
        MU(KPL,I)=0
   70 CONTINUE
      EETOT=0.D0
      DO 71 I=1,NHAD
	IF(IBAR(I).NE.500)THEN
C         WRITE(6,*)I,ANH(I),HE(I),AM(I),IBAR(I),NR(I)
	  EETOT=EETOT+HE(I)
        ENDIF
   71 CONTINUE
      IF(EETOT.GT.POLAB+1.D-6)THEN
	WRITE(6,*)' eetot.gt.polab ',EETOT,POLAB
      ENDIF
C     WRITE(6,*)' eetot ',EETOT
      DO 80 I=1,NHAD
	IF(IBAR(I).NE.500)THEN
        NRE=NR(I)
        IF (NRE.GT.25) NRE=3
        IF (NRE.LT. 1) NRE=3
        NI=INDX(NRE)
        IF (NRE.EQ.28)NI=8
        AVE(KPL,NRE)=AVE(KPL,NRE)+HE(I)
        AVE(KPL,30)=AVE(KPL,30)+HE(I)
        IF (NI.NE.6) AVE(KPL,29)=AVE(KPL,29)+HE(I)
        AVMULT(KPL,NRE)=AVMULT(KPL,NRE)+1.
        IF (NI.NE.6) AVMULT(KPL,29)=AVMULT(KPL,29)+1.
        MU(KPL,NI)=MU(KPL,NI)+1
        IF (ICH(I).NE.0)MU(KPL,9)=MU(KPL,9)+1
C    TOTAL=30   TOTAL-GAMMA=29   ANTIHYP=28
C    CHARGED=27
        IF (ICH(I).NE.0)AVE(KPL,27)=AVE(KPL,27)+HE(I)
        IF (ICH(I).NE.0)AVMULT(KPL,27)=AVMULT(KPL,27)+1
C       XFL=PZ(I)/PO
        XFL=(PZ(I)/ABS(PZ(I)))*HE(I)/PO
        IXFL=XFL/DXFL+26.
        IF (IXFL.LT. 1) IXFL=1
        IF (IXFL.GT.50) IXFL=50
C       XXXFL=SQRT(XFL**2+(AM(I)+0.3)**2/PO**2)
        XXXFL=ABS(XFL)
        IF (ICH(I).NE.0)YXFL(IXFL,9)=YXFL(IXFL,9)+XXXFL
        YXFL(IXFL,NI)=YXFL(IXFL,NI)+XXXFL
        YXFL(IXFL,10)=YXFL(IXFL,10)+XXXFL
        PTT=PX(I)**2+PY(I)**2
        YL=0.5*LOG(ABS((HE(I)+PZ(I)+1.E-10)/(HE(I)-PZ(I)+1.E-10)))
        YLPS=LOG(ABS((PZ(I)+SQRT(PZ(I)**2+PTT))/SQRT(PTT)+1.E-18))
        IYLPS=(YLPS+5.0)/DY
        IF (IYLPS.LT.1)IYLPS=1
        IF (IYLPS.GT.50)IYLPS=50
        YYLPS(IYLPS,NI)=YYLPS(IYLPS,NI)+1.
        YYLPS(IYLPS,10)=YYLPS(IYLPS,10)+1.
        IF (ICH(I).NE.0)YYLPS(IYLPS,9)=YYLPS(IYLPS,9)+1.
        IYL=(YL+5.0)/DY
        IF (IYL.LT.1) IYL=1
        IF (IYL.GT.50) IYL=50
        IF (ICH(I).NE.0)YYL(IYL,9)=YYL(IYL,9)+1.
        YYL(IYL,NI)=YYL(IYL,NI)+1.
        YYL(IYL,10)=YYL(IYL,10)+1.
        PT=SQRT(PTT)+0.001
        AVPT=AVPT+PT
        NAVPT=NAVPT+1
        IPT=PT/DPT+1.
        IF (IPT.LT.1)IPT=1
        IF (IPT.GT.50) IPT=50
        IF (ICH(I).NE.0)PTY(IPT,9)=PTY(IPT,9)+1./PT
        PTY(IPT,NI)=PTY(IPT,NI)+1./PT
        PTY(IPT,10)=PTY(IPT,10)+1./PT
        ENDIF
   80 CONTINUE
      DO 90 I=1,9
        IM=MU(KPL,I)+1
        IF (IM.GT.100)IM=100
        YMULT(IM,I)=YMULT(IM,I)+1.
   90 CONTINUE
      RETURN
C------------------------------------------------
  100 CONTINUE
      WRITE(6, 1000)EEO,PO,NHAD
C1020 FORMAT (' AVMULT=',11F10.5/,' AVE=',11F10.5)
      DO 110 I=1,30
        AVMULT(KPL,I)=AVMULT(KPL,I)/NHAD
        AVE(KPL,I)=AVE(KPL,I)/NHAD
  110 CONTINUE
      AVPT=AVPT/NAVPT
      WRITE (6,1030)AVPT,NAVPT
 1030 FORMAT (' AVERAGE PT= ',F12.4,I10)
      WRITE(6, 1040)
 1040 FORMAT(' PARTICLE REF,CHAR,IBAR, MASS      AVERAGE',
     +' ENERGY, MULTIPLICITY, INELASTICITY')
      DO 120 I=1,30
        AKE(KPL,I)=AVE(KPL,I)/EEO
        WRITE(6, 1050)ANAME(I),I,IICH(I),IIBAR(I),
     +   AAM(I), AVE(KPL,I),AVMULT
     +  (KPL,I),AKE(KPL,I)
 1050 FORMAT (' ',A8,3I5,F10.3,3F18.6)
  120 CONTINUE
      DO 130 I=1,10
        DO 130 J=1,100
          YMULT(J,I)=YMULT(J,I)/NHAD
  130 CONTINUE
      DO 140 I=1,20
        DO 140 J=1,50
          YXFL(J,I)=YXFL(J,I)/(NHAD*DXFL)
          YY L(J,I)=YY L(J,I)/(NHAD*DY)
          YYLPS(J,I)=YYLPS(J,I)/(NHAD*DY)
          PTY(J,I)=PTY(J,I)/(NHAD*DPT)
  140 CONTINUE
  150 CONTINUE
      WRITE(6, 1060)
 1060 FORMAT('1 RAPIDITY DISTRIBUTION')
      DO 160 J=1,50
        WRITE(6, 1070)XYL(J,1),(YYL(J,I),I=1,10)
 1070 FORMAT (F10.2,10E11.3)
  160 CONTINUE
      DO 161 J=1,50
        WRITE(6, 1070)XYL(J,1),(YYL(J,I),I=11,20)
  161 CONTINUE
      WRITE(6, 1060)
      WRITE(6,*)' 1=*=p, 2=n, 3=pi+, 4=pi-, 5=K+, 6=K-,',
     &' 8=ap, 9=chargd., 10=Z=all, 11=+=Lamb, 12=A=aLam,',
     &' 13=O=sig-, 14=B=Sig+, 15=C=Sig0, 16=D=pi0'
      CALL PLOT(XYL,YYL,1000,20,50,-5.D0,DY,0.D0,0.1D0)
      WRITE(6,*)' 1=*=p, 2=n, 3=pi+, 4=pi-, 5=K+, 6=K-,',
     &' 8=ap, 9=chargd., 10=Z=all, 11=+=Lamb, 12=A=aLam,',
     &' 13=O=sig-, 14=B=Sig+, 15=C=Sig0, 16=D=pi0'
      CALL PLOT(XYL,YYLPS,1000,20,50,-5.D0,DY,0.D0,0.1D0)
C     IF (IPRIOP.EQ.1) GO TO 1423
      WRITE(6, 1080)
 1080 FORMAT ('1  LONG MOMENTUM (SCALED) DISTRIBUTION')
      DO 170 J=1,50
        WRITE(6, 1070)XXFL(J,1),(YXFL(J,I),I=1,10)
  170 CONTINUE
      DO 171 J=1,50
        WRITE(6, 1070)XXFL(J,1),(YXFL(J,I),I=11,20)
  171 CONTINUE
  180 CONTINUE
      WRITE(6, 1080)
      WRITE(6,*)' 1=*=p, 2=n, 3=pi+, 4=pi-, 5=K+, 6=K-,',
     &' 8=ap, 9=chargd., 10=Z=all, 11=+=Lamb, 12=A=aLam,',
     &' 13=O=sig-, 14=B=Sig+, 15=C=Sig0, 16=D=pi0'
      CALL PLOT(XXFL,YXFL,1000,20,50,-1.D0,DXFL,0.D0,0.05D0)
      WRITE(6, 1090)
 1090 FORMAT ('1 MULTIPLICITY DISTRIBUTIONS')
      SIMUL=0.
      SUMUL=0.
      DO 190 J=1,100
        SUMUL=SUMUL+YMULT(J,10)
        SIMUL=SIMUL+YMULT(J,9)
  190 CONTINUE
      WRITE(6, 1100)(XMULT(J,1),YMULT(J,9),YMULT(J,10),J=1,100)
 1100 FORMAT(F6.1,2E12.4,F6.1,2E12.4,F6.1,2E12.4,F6.1,2E12.4)
      WRITE(6, 1090)
      WRITE(6,*)' 1=*=p, 2=n, 3=pi+, 4=pi-, 5=K+, 6=K-,',
     &' 8=ap, 9=chargd., 10=Z=all, 11=+=Lamb, 12=A=aLam,',
     &' 13=O=sig-, 14=B=Sig+, 15=C=Sig0, 16=D=pi0'
      CALL PLOT(XMULT,YMULT,1000,10,100,0.D0,1.D0,0.D0,0.01D0)
      DO 200 I=1,100
        XKNO(I,1)=I/AVMULT(KPL,30)
        XKNO(I,2)=I/AVMULT(KPL,27)
        AKNO(I,1)=YMULT(I,10)*AVMULT(KPL,30)/SUMUL
        AKNO(I,2)=YMULT(I,9)*AVMULT(KPL,27)/SIMUL
        AKNO(I,1)=LOG10(AKNO(I,1)+1.D-9)
        AKNO(I,2)=LOG10(AKNO(I,2)+1.D-9)
  200 CONTINUE
      WRITE(6, 1110)
 1110 FORMAT ('1 KNO MULTIPLICITY DISTRIBUTIONS')
      WRITE(6,*)' 1=*=p, 2=n, 3=pi+, 4=pi-, 5=K+, 6=K-,',
     &' 8=ap, 9=chargd., 10=Z=all, 11=+=Lamb, 12=A=aLam,',
     &' 13=O=sig-, 14=B=Sig+, 15=C=Sig0, 16=D=pi0'
      CALL PLOT(XKNO,AKNO,200,2,100,0.D0,0.08D0,-4.D0,0.05D0)
      DO 210 I=1,10
        DO 210 J=1,100
          YMULT(J,I)=LOG10(YMULT(J,I))
  210 CONTINUE
      DO 220 I=1,20
        DO 220 J=1,50
          YXFL(J,I)=LOG10(ABS(YXFL(J,I)+1.D-8))
          YYL(J,I)=LOG10(YYL(J,I)+1.D-8)
          PTY(J,I)=LOG10(PTY(J,I)+1.D-8)
  220 CONTINUE
  230 CONTINUE
      WRITE(6, 1060)
      WRITE(6,*)' 1=*=p, 2=n, 3=pi+, 4=pi-, 5=K+, 6=K-,',
     &' 8=ap, 9=chargd., 10=Z=all, 11=+=Lamb, 12=A=aLam,',
     &' 13=O=sig-, 14=B=Sig+, 15=C=Sig0, 16=D=pi0'
      CALL PLOT(XYL,YYL,1000,20,50,-5.D0,DY,-3.5D0,0.05D0)
      DO 240 J=1,50
        WRITE(6, 1070)XXFL(J,1),(YXFL(J,I),I=1,10)
  240 CONTINUE
      DO 241 J=1,50
        WRITE(6, 1070)XXFL(J,1),(YXFL(J,I),I=11,20)
  241 CONTINUE
      WRITE(6, 1080)
      WRITE(6,*)' 1=*=p, 2=n, 3=pi+, 4=pi-, 5=K+, 6=K-,',
     &' 8=ap, 9=chargd., 10=Z=all, 11=+=Lamb, 12=A=aLam,',
     &' 13=O=sig-, 14=B=Sig+, 15=C=Sig0, 16=D=pi0'
      CALL PLOT(XXFL,YXFL,1000,20,50,-1.D0,DXFL,-4.5D0,0.05D0)
      WRITE(6,1120)
 1120 FORMAT ('1 PT DISTRIBUTION DN/PTDPT')
      CALL PLOT(PTP,PTY,1000,20,50,0.D0,DPT,-2.0D0,0.05D0)
      IF (IPRIOP.EQ.1)                                         GO TO 250
      WRITE(6,1090)
      WRITE(6,*)' 1=*=p, 2=n, 3=pi+, 4=pi-, 5=K+, 6=K-,',
     &' 8=ap, 9=chargd., 10=Z=all, 11=+=Lamb, 12=A=aLam,',
     &' 13=O=sig-, 14=B=Sig+, 15=C=Sig0, 16=D=pi0'
      CALL PLOT(XMULT,YMULT,1000,10,100,0.D0,1.D0, -3.5D0,0.05D0)
  250 CONTINUE
      IF (KPL.NE.12)                                           GO TO 270
      DO 260 I=1,12
        DO 260 J=1,30
          AASO(I,J)=LOG10(AASO(I,J)+1.D-18)
          AVMULT(I,J)=LOG10(AVMULT(I,J)+1.D-18)
          AKE(I,J)=LOG10(AKE(I,J)+1.D-18)
  260 CONTINUE
      WRITE(6,*)' 1=*=p, 2=n, 3=pi+, 4=pi-, 5=K+, 6=K-,',
     &' 8=ap, 9=chargd., 10=Z=all, 11=+=Lamb, 12=A=aLam,',
     &' 13=O=sig-, 14=B=Sig+, 15=C=Sig0, 16=D=pi0'
      CALL PLOT(AASO,AVMULT,360,30,12,0.D0,0.1D0,-3.D0,0.05D0)
      WRITE(6,*)' 1=*=p, 2=n, 3=pi+, 4=pi-, 5=K+, 6=K-,',
     &' 8=ap, 9=chargd., 10=Z=all, 11=+=Lamb, 12=A=aLam,',
     &' 13=O=sig-, 14=B=Sig+, 15=C=Sig0, 16=D=pi0'
      CALL PLOT(AASO,AKE,360,30,12,0.D0,0.1D0,-5.D0,0.05D0)
  270 CONTINUE
      RETURN
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE DDECAY(IHAD,ISTAB)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
C------------------
*KEEP,DFINPA.
      CHARACTER*8 ANF
      PARAMETER (NFIMAX=249)
      COMMON /DFINPA/ ANF(NFIMAX),PXF(NFIMAX),PYF(NFIMAX),PZF(NFIMAX),
     +HEF(NFIMAX),AMF(NFIMAX), ICHF(NFIMAX),IBARF(NFIMAX),NREF(NFIMAX)
      COMMON /DFINPZ/IORMO(NFIMAX),IDAUG1(NFIMAX),IDAUG2(NFIMAX),
     * ISTATH(NFIMAX)
*KEND.
      CHARACTER*8 ZKNAME
      CHARACTER*8 ANAME
C      COMMON/DDECAC/ ZKNAME(540),NZK(540,3),WT(540)
 
      PARAMETER (IDMAX9=602)
C      CHARACTER*8 ZKNAME
      COMMON/DDECAC/ ZKNAME(IDMAX9),WT(IDMAX9),NZK(IDMAX9,3)
 
 
      COMMON/DPAR/ANAME(210),AM(210),GA(210),TAU(210),ICH(210),IBAR(210)
     *,K1(210),K2(210)
      COMMON/DMETLS/ CXS(149),CYS(149),CZS(149),ELS(149),
     *PLS(149),IS,ITS(149)
      COMMON/DDRE/ TEST(12)
      COMMON/PRITT/ISYS
C------------------
      ISYS=6
      DO 10 I=1,IHAD
        ITS(I)=NREF(I)
        PLS(I)=SQRT(PXF(I)**2+PYF(I)**2+PZF(I)**2)
        IF(PLS(I).NE.0.)CXS(I)=PXF(I)/PLS(I)
        IF(PLS(I).NE.0.)CYS(I)=PYF(I)/PLS(I)
        IF(PLS(I).NE.0.)CZS(I)=PZF(I)/PLS(I)
        ELS(I)=HEF(I)
   10 CONTINUE
      IST=IHAD
      IR=0
   20 CONTINUE
C*****TEST STABLE OR UNSTABLE
C   ISTAB=1/2/3 MEANS  STRONG + WEAK DECAYS / ONLY STRONG DECAYS /
C   STRONG DECAYS + WEAK DECAYS FOR CHARMED PARTICLES AND TAU LEPTONS
      IF(ISTAB.EQ.1)                                             GOTO 30
      IF(ISTAB.EQ.2)                                             GOTO 50
      IF(ISTAB.EQ.3)                                             GOTO 40
   30 IF(ITS(IST).EQ.135.OR.ITS(IST).EQ.136)                     GOTO 60
      IF(ITS(IST).GE.1.AND.ITS(IST).LE.7)                        GOTO 60
                                                                 GOTO 70
   40 IF(ITS(IST).GE.1.AND.ITS(IST).LE.23)                       GOTO 60
      IF(ITS(IST).GE. 97.AND.ITS(IST).LE.103)                    GOTO 60
C*    IF(ITS(IST).EQ.109.AND.ITS(IST).EQ.115) GOTO 202
      IF(ITS(IST).EQ.109.OR.ITS(IST).EQ.115)                     GOTO 60
      IF(ITS(IST).GE.133.AND.ITS(IST).LE.136)                    GOTO 60
                                                                 GOTO 70
   50 IF(ITS(IST).GE. 1.AND.ITS(IST).LE. 30)                     GOTO 60
      IF(ITS(IST).GE. 97.AND.ITS(IST).LE.103)                    GOTO 60
      IF(ITS(IST).GE.115.AND.ITS(IST).LE.122)                    GOTO 60
      IF(ITS(IST).GE.131.AND.ITS(IST).LE.136)                    GOTO 60
      IF(ITS(IST).EQ.109)                                        GOTO 60
      IF(ITS(IST).GE.137.AND.ITS(IST).LE.160)                    GOTO 60
                                                                 GOTO 70
   60 IR=IR+1
      IF (IR.GT.NFIMAX)THEN
        WRITE (6,1000)IR,NFIMAX
 1000 FORMAT(' DECAY IR.GT.NFIMAX RETURN ',2I10)
        RETURN
      ENDIF
      NREF(IR)=ITS(IST)
      ITT=ITS(IST)
      AMF(IR)=AM(ITT)
      ANF(IR)=ANAME(ITT)
      ICHF(IR)=ICH(ITT)
      IBARF(IR)=IBAR(ITT)
      HEF(IR)=ELS(IST)
      PXF(IR)=CXS(IST)*PLS(IST)
      PYF(IR)=CYS(IST)*PLS(IST)
      PZF(IR)=CZS(IST)*PLS(IST)
      IST=IST-1
      IF(IST.GE.1)                                               GOTO 20
                                                                 GOTO140
   70 IT=ITS(IST)
      GAM=ELS(IST)/AM(IT)
      BGAM=PLS(IST)/AM(IT)
      ECO=AM(IT)
      KZ1=K1(IT)
   80 CONTINUE
      VV=RNDM(VW)-1.D-17
      IIK=KZ1-1
   90 IIK=IIK+1
      IF (VV.GT.WT(IIK))                                        GO TO 90
C  IIK IS THE DECAY CHANNEL
      IT1=NZK(IIK,1)
      IT2=NZK(IIK,2)
      IF (IT2-1.LT.0)                                          GO TO 120
      IT3=NZK(IIK,3)
C  IT1,IT2, IT3 ARE THE PRODUCED PARTICLES FROM  IT
      IF(IT3.EQ.0)                                             GO TO 100
      CALL DTHREP(ECO,ECM1,ECM2,ECM3,PCM1,PCM2,PCM3,COD1,COF1,SIF1,
     *COD2,COF2,SIF2,COD3,COF3,SIF3,AM(IT1),AM(IT2),AM(IT3))
                                                               GO TO 110
  100 CALL DTWOPD(ECO,ECM1,ECM2,PCM1,PCM2,COD1,COF1,SIF1,COD2,COF2,SIF2,
     +AM(IT1),AM(IT2))
  110 CONTINUE
  120 CONTINUE
      ITS(IST  )=IT1
      IF (IT2-1.LT.0)                                          GO TO 130
      ITS(IST+1)  =IT2
      ITS(IST+2)=IT3
      RX=CXS(IST)
      RY=CYS(IST)
      RZ=CZS(IST)
      CALL DTRAFO(GAM,BGAM,RX,RY,RZ,COD1,COF1,SIF1,PCM1,ECM1,
     *PLS(IST),CXS(IST),CYS(IST),CZS(IST),ELS(IST))
      IST=IST+1
      CALL DTRAFO(GAM,BGAM,RX,RY,RZ,COD2,COF2,SIF2,PCM2,ECM2,
     *PLS(IST),CXS(IST),CYS(IST),CZS(IST),ELS(IST))
      IF (IT3.LE.0)                                            GO TO 130
      IST=IST+1
      CALL DTRAFO(GAM,BGAM,RX,RY,RZ,COD3,COF3,SIF3,PCM3,ECM3,
     *PLS(IST),CXS(IST),CYS(IST),CZS(IST),ELS(IST))
  130 CONTINUE
                                                                GO TO 20
  140 CONTINUE
      IF(IR.GT.7998) WRITE(ISYS,1010)
 1010 FORMAT(2X,'  NUMBER OF STAB. FINAL PART. IS GREATER THAN 7998')
      IHAD=IR
      RETURN
      END
*-- Author :
C--------------------------------------------------------------------
C
C     FILE SHMAK
C
C--------------------------------------------------------------------
      SUBROUTINE SHMAK(ICASE,NN,NNA,NNB,NA,NB,UMO,BIMP)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
*  scoring of unbiased Glauber events sampled in KKEVT
*  (reduction of interactions possible in case event rejection because
*   of limitations from kinematics)
*
*KEEP,DPRIN.
      COMMON /DPRIN/  IPRI,IPEV,IPPA,IPCO,INIT,IPHKK,ITOPD,IPAUPR
*KEND.
      PARAMETER(NAMX=248)
      DIMENSION FNUA(NAMX),FNUB(NAMX),FNUT(NAMX)
      DIMENSION ANN(NAMX)
      DIMENSION XB(200),BIMPP(200)
C-------------------------------
C---------------------------------------------------------------
C
C                  plot impact parameter distribution
C
C----------------------------------------------------------------
C     DO 7784 II=1,200
C       BIMPP(II)=0.D0
CXB(II)=0.1D0*II
C7784 CONTINUE
C     IP=207
C     IT=207
C     KKMAT=1
C     PPROJ=PPN
C     DO 7785 II=1,100000
C     CALL SHMAKO(IP,IT,BIMP,NN,NP,NT,JSSH,JTSH,PPROJ,KKMAT)	
C     IF(II.LE.1000)WRITE(6,*)' IP,IT,BIMP,NN,NP,NT ',
C    * IP,IT,BIMP,NN,NP,NT      
C     IB=BIMP/0.1D0+1.D0
C     IF(IB.GE.200)IB=200
C     BIMPP(IB)=BIMPP(IB)+1
C7785 CONTINUE 
C     WRITE(6,*)' Impact parameter distribution B,BIMPP'
C     DO 7786 II=1,200
C     WRITE(6,*)XB(II),BIMPP(II)
C7786 CONTINUE     
C---------------------------------------------------------------
C
C                  plot impact parameter distribution
C
C---------------------------------------------------------------
      GO TO (10,30,40),ICASE
   10 CONTINUE
      DO 7784 II=1,200
        BIMPP(II)=0.D0
        XB(II)=0.1D0*II
 7784 CONTINUE
      BNUT=0.
      BNUA=0.
      BNUB=0.
      BNVV=0.
      BNSV=0.
      BNVS=0.
      BNSS=0.
      DO 20 I=1,NAMX
	ANN(I)=I
        FNU A(I)=0.
        FNU B(I)=0.
        FNU T(I)=0.
   20 CONTINUE
      ANUSD=0.D0
      RETURN
   30 CONTINUE
      IB=BIMP/0.1D0+1.D0
      IF(IB.GE.200)IB=200
      BIMPP(IB)=BIMPP(IB)+1
C     Calculate fraction of diffractive events
      IF((NN.EQ.1).AND.(NNA.EQ.1).AND.(NNB.EQ.1))THEN
        CALL SIHNDI(UMO,1,1,SINGDIF,SIGDIH) 
	SIGABS=SIINEL(1,1,UMO)
        ANUSD=ANUSD + SINGDIF/SIGABS
      ENDIF
      INTT=NN
      IF (INTT.GT.NAMX)INTT=NAMX
      NUA=NNA
      IF (NUA.GT.NAMX) NUA=NAMX
      NUB=NNB
      IF (NUB.GT.NAMX) NUB=NAMX
      FNUA(NUA)=FNUA(NUA)+1.
      FNUT(INTT)=FNUT(INTT)+1.
      FNUB(NUB)=FNUB(NUB)+1.
      BNUT=BNUT+NN
      BNUA=BNUA+NNA
      BNUB=BNUB+NNB
      IF(NNB.GE.NNA) THEN
        NNVV=NNA
        NNSV=NNB-NNA
        NNVS=0
        NNSS=NN-NNB
      ELSE
        NNVV=NNB
        NNSV=0
        NNVS=NNA-NNB
        NNSS=NN-NNA
      ENDIF
      BNVV=BNVV + NNVV
      BNSV=BNSV + NNSV
      BNVS=BNVS + NNVS
      BNSS=BNSS + NNSS
      RETURN
   40 CONTINUE
      IF(NN.EQ.0)THEN
	WRITE(6,*)' shmak(3,NN,... ) NN= ',NN
	RETURN
      ENDIF
C     WRITE(6,*)' Impact parameter distribution B,BIMPP'
C     WRITE(6,*)(XB(II),BIMPP(II),II=1,200)
C     WRITE(6,*)' Impact parameter distribution B,BIMPP'
C       CALL PLOT(XB,BIMPP,50,1,50,0.,0.4D0,0.,10.D0)
      ANUSD=ANUSD/NN
      BNUT=BNUT/NN
      BNUA=BNUA/NN
      BNUB=BNUB/NN
      BNVV=BNVV/NN
      BNSV=BNSV/NN
      BNVS=BNVS/NN
      BNSS=BNSS/NN
      WRITE(6,'(1H1,50(1H*))')
      WRITE(6,'(/10X,A/)') ' OUTPUT FROM SHMAK  all events before',
     *' diffraction modification'
      WRITE(6,'(50(1H*))')
      WRITE(6,'(A,I10)') ' NUMBER OF TOTALLY SAMPLED GLAUBER EVENTS',NN
      WRITE(6, 1000) BNUT,BNUA,BNUB
      WRITE(6,*)' Fraction of diffractive evnts: ',ANUSD
 1000 FORMAT('  AVERAGE NO OF COLLISIONS BNUT,BNUA,BNUB=',3F10.3)
      WRITE(6,'(/A)') ' AVERAGE NUMBERS OF DIFFERENT COLLISION TYPES'
      WRITE(6,'(4(5X,A,F8.2/))') ' VAL-VAL:',BNVV, ' SEA-VAL:',BNSV,
     +' VAL-SEA:',BNVS, ' SEA-SEA:',BNSS
      IF(IPRI.GE.1) THEN
        DNNA=NA/50+1
        DNNB=NB/50+1
        DNNT=2.*DNNB
        WRITE(6,1010)
 1010   FORMAT (' FNUA')
        WRITE(6,1040) FNUA
        DO 323 I=1,NAMX
          FNU A(I)=LOG10(FNU A(I)+1.D-5)
 323    CONTINUE
        CALL PLOT(ANN,FNU A,NAMX,1,NAMX,0.D0,DNNA,0.D0,0.05D0)
        WRITE(6,1020 )
        WRITE(6,1040) FNUB
 1020   FORMAT (' FNUB')
        DO 324 I=1,NAMX
          FNU B(I)=LOG10(FNU B(I)+1.D-5)
 324    CONTINUE
        CALL PLOT(ANN,FNU B,NAMX,1,NAMX,0.D0,DNNB,0.D0,0.05D0)
        WRITE(6,1030 )
        WRITE(6,1040) FNUT
 1030    FORMAT (' FNUT')
        DO 325 I=1,NAMX
          FNU T(I)=LOG10(FNU T(I)+1.E-5)
 325     CONTINUE
        CALL PLOT(ANN,FNU T,NAMX,1,NAMX,0.D0,DNNT,0.D0,0.05D0)
 1040    FORMAT (10F12.2)
      ENDIF
      RETURN
      END
C--------------------------------------------------------------------
C
C     FILE SHMAK1
C
C--------------------------------------------------------------------
      SUBROUTINE SHMAK1(ICASE,NN,NNA,NNB,NA,NB,UMO,BIMP)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
*  scoring of unbiased Glauber events sampled in KKEVT
*  (reduction of interactions possible in case event rejection because
*   of limitations from kinematics)
*
*KEEP,DPRIN.
      COMMON /DPRIN/  IPRI,IPEV,IPPA,IPCO,INIT,IPHKK,ITOPD,IPAUPR
*KEND.
      PARAMETER(NAMX=248)
      DIMENSION FNUA(NAMX),FNUB(NAMX),FNUT(NAMX)
      DIMENSION ANN(NAMX)
      DIMENSION XB(200),BIMPP(200)
C-------------------------------
      GO TO (10,30,40),ICASE
   10 CONTINUE
      DO 7784 II=1,200
        BIMPP(II)=0.D0
        XB(II)=0.1D0*II
 7784 CONTINUE
      BNUT=0.
      BNUA=0.
      BNUB=0.
      ANUSD=0.D0
      DO 20 I=1,NAMX
        ANN(I)=I
        FNU A(I)=0.
        FNU B(I)=0.
        FNU T(I)=0.
   20 CONTINUE
      RETURN
   30 CONTINUE
      IB=BIMP/0.1D0+1.D0
      IF(IB.GE.200)IB=200
      BIMPP(IB)=BIMPP(IB)+1
C     Calculate fraction of diffractive events
      IF((NN.EQ.1).AND.(NNA.EQ.1).AND.(NNB.EQ.1))THEN
        CALL SIHNDI(UMO,1,1,SINGDIF,SIGDIH) 
	SIGABS=SIINEL(1,1,UMO)
        ANUSD=ANUSD + SINGDIF/SIGABS
      ENDIF
      INTT=NN
      IF (INTT.GT.NAMX)INTT=NAMX
      NUA=NNA
      IF (NUA.GT.NAMX) NUA=NAMX
      NUB=NNB
      IF (NUB.GT.NAMX) NUB=NAMX
      FNUA(NUA)=FNUA(NUA)+1.
      FNUT(INTT)=FNUT(INTT)+1.
      FNUB(NUB)=FNUB(NUB)+1.
      BNUT=BNUT+NN
      BNUA=BNUA+NNA
      BNUB=BNUB+NNB
      RETURN
   40 CONTINUE
      IF(NN.EQ.0)THEN
	WRITE(6,*)' shmak1(3,NN,... ) NN= ',NN
	RETURN
      ENDIF
C     WRITE(6,*)' Impact parameter distribution B,BIMPP'
C     WRITE(6,*)(XB(II),BIMPP(II),II=1,200)
C     WRITE(6,*)' Impact parameter distribution B,BIMPP'
C       CALL PLOT(XB,BIMPP,50,1,50,0.D0,0.4D0,0.D0,10.D0)
      BNUT=BNUT/NN
      BNUA=BNUA/NN
      BNUB=BNUB/NN
      ANUSD=ANUSD/NN
      WRITE(6,'(1H1,50(1H*))')
      WRITE(6,'(/10X,A/)') ' OUTPUT FROM SHMAK1 after modification',
     *' of Glauber events for diffractive cross section'
      WRITE(6,'(50(1H*))')
      WRITE(6,'(A,I10)') ' NUMBER OF TOTALLY SAMPLED GLAUBER EVENTS',NN
      WRITE(6, 1000) BNUT,BNUA,BNUB
 1000 FORMAT('  AVERAGE NO OF COLLISIONS BNUT,BNUA,BNUB=',3F10.3)
      WRITE(6,*)' Fraction of diffractive evnts: ',ANUSD
C     WRITE(6,'(/A)') ' AVERAGE NUMBERS OF DIFFERENT COLLISION TYPES'
C     WRITE(6,'(4(5X,A,F8.2/))') ' VAL-VAL:',BNVV, ' SEA-VAL:',BNSV,
C    +' VAL-SEA:',BNVS, ' SEA-SEA:',BNSS
      IF(IPRI.GE.1) THEN
        DNNA=NA/50+1
        DNNB=NB/50+1
        DNNT=2.*DNNB
        WRITE(6,1010)
 1010   FORMAT (' FNUA')
        WRITE(6,1040) FNUA
        DO 323 I=1,NAMX
          FNU A(I)=LOG10(FNU A(I)+1.D-5)
323     CONTINUE
        CALL PLOT(ANN,FNU A,NAMX,1,NAMX,0.D0,DNNA,0.D0,0.05D0)
        WRITE(6,1020 )
        WRITE(6,1040) FNUB
 1020   FORMAT (' FNUB')
        DO 324 I=1,NAMX
          FNU B(I)=LOG10(FNU B(I)+1.D-5)
324     CONTINUE
        CALL PLOT(ANN,FNU B,NAMX,1,NAMX,0.D0,DNNB,0.D0,0.05D0)
        WRITE(6,1030 )
        WRITE(6,1040) FNUT
1030    FORMAT (' FNUT')
        DO 325 I=1,NAMX
          FNU T(I)=LOG10(FNU T(I)+1.E-5)
325     CONTINUE
        CALL PLOT(ANN,FNU T,NAMX,1,NAMX,0.D0,DNNT,0.D0,0.05D0)
1040    FORMAT (10F12.2)
      ENDIF
      RETURN
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE PREVIO(RA,RB,NSTB,BMAX,BSTEP,SIG,RO,G)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      COMPLEX*16 CA,CI
      COMMON/DAMP/CA,CI,GA
C     WRITE(6,*)' PREVIO(RA,RB,NSTB,BMAX,BSTEP,SIG,RO,G)',
C    &RA,RB,NSTB,BMAX,BSTEP,SIG,RO,G
C     WRITE(6,*)' /CA,CI,GA/ ',CA,CI,GA
C     WRITE(6,*)' PREVIO: RA, RB = ',RA,RB
      BMAX=4.*(RA+RB)
C     WRITE(6,*)' PREVIO(RA,RB,NSTB,BMAX,BSTEP,SIG,RO,G)',
C    &RA,RB,NSTB,BMAX,BSTEP,SIG,RO,G
C     WRITE(6,*)' /CA,CI,GA/ ',CA,CI,GA
C     WRITE(6,*)' PREVIO: RA, RB BMAX= ',RA,RB,BMAX
      BSTEP=BMAX/(NSTB-1)
C     WRITE(6,*)' PREVIO(RA,RB,NSTB,BMAX,BSTEP,SIG,RO,G)',
C    &RA,RB,NSTB,BMAX,BSTEP,SIG,RO,G
C     WRITE(6,*)' /CA,CI,GA/ ',CA,CI,GA
C     WRITE(6,*)' PREVIO: RA, RB ,BSTEP= ',RA,RB,BSTEP
      BSTEP=0.15D0
C     WRITE(6,*)' PREVIO(RA,RB,NSTB,BMAX,BSTEP,SIG,RO,G)',
C    &RA,RB,NSTB,BMAX,BSTEP,SIG,RO,G
C     WRITE(6,*)' /CA,CI,GA/ ',CA,CI,GA
C     WRITE(6,*)' PREVIO: RA, RB ,BSTEP= ',RA,RB,BSTEP
      GA=G
C     WRITE(6,*)' PREVIO(RA,RB,NSTB,BMAX,BSTEP,SIG,RO,G)',
C    &RA,RB,NSTB,BMAX,BSTEP,SIG,RO,G
C     WRITE(6,*)' /CA,CI,GA/ ',CA,CI,GA
C     WRITE(6,*)' PREVIO: RA, RB ,GA= ',RA,RB,GA
      RCA=GA*SIG/6.2831854
C     WRITE(6,*)' PREVIO(RA,RB,NSTB,BMAX,BSTEP,SIG,RO,G)',
C    &RA,RB,NSTB,BMAX,BSTEP,SIG,RO,G
C     WRITE(6,*)' /CA,CI,GA/ ',CA,CI,GA
C     WRITE(6,*)' PREVIO: RA, RB ,RCA= ',RA,RB,RCA
      FCA=-GA*SIG*RO/6.2831854
C     WRITE(6,*)' PREVIO(RA,RB,NSTB,BMAX,BSTEP,SIG,RO,G)',
C    &RA,RB,NSTB,BMAX,BSTEP,SIG,RO,G
C     WRITE(6,*)' /CA,CI,GA/ ',CA,CI,GA
C     WRITE(6,*)' PREVIO: RA, RB ,FCA= ',RA,RB,FCA
      CA=CMPLX(RCA,FCA)
C     WRITE(6,*)' PREVIO(RA,RB,NSTB,BMAX,BSTEP,SIG,RO,G)',
C    &RA,RB,NSTB,BMAX,BSTEP,SIG,RO,G
C     WRITE(6,*)' /CA,CI,GA/ ',CA,CI,GA
C     WRITE(6,*)' PREVIO: RA, RB,CA = ',RA,RB,CA
      CI=(1.D0,0.D0)
      WRITE(6,*)' PREVIO(RA,RB,NSTB,BMAX,BSTEP,SIG,RO,G)',
     &RA,RB,NSTB,BMAX,BSTEP,SIG,RO,G
      WRITE(6,*)' /CA,CI,GA/ ',CA,CI,GA
      WRITE(6,*)' PREVIO: RA, RB ,CI= ',RA,RB,CI
      RETURN
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE PROFB(BSTEP,NSTAT,NA,RA,NB,RB,BSITE,NSITEB)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
C
C  THE PROGRAM CALCULATES THE PROFIL-FUNCTION AND FILLS
C  THE ARRAY BSITE TO APPROXIMATE THE B-DISTRIBUTION.
C-------------------
      PARAMETER (INTMX=2488,INTMD=252)
*KEEP,DROPPT.
      LOGICAL INTPT,FERMP,IHADSS,IHADSV,IHADVS,IHADVV,IHADA, IPADIS,
     +ISHMAL,LPAULI
      COMMON /DROPPT/ INTPT,FERMP,IHADSS,IHADSV,IHADVS,IHADVV,IHADA,
     +IPADIS,ISHMAL,LPAULI
*KEEP,NUCKOO.
      COMMON /NUCKOO/ PKOO(3,INTMX),TKOO(3,INTMX),PPOO(3,INTMX),
     +TPOO(3,INTMX)
*KEEP,DAMP.
C     COMPLEX*16 CA,CI
      DOUBLE COMPLEX CA,CI
      COMMON /DAMP/   CA,CI,GA
*KEND.
      DIMENSION BSITE(0:1,NSITEB)
C--------
      DIMENSION HELPP(200)
      DIMENSION HELP(200)
      DIMENSION BS(200)
      COMMON /SIGLA/SIGLAU
C     COMPLEX*16 C
      DOUBLE COMPLEX C
      DATA IRW /0/
C--------
      WRITE(6,*)' PROFB: RA, RB = ',RA,RB
      WRITE(6, 1000)BSTEP,NSTAT,NA,RA,NB,RB,IRW,NSITEB
 1000 FORMAT (' PROFB',E15.5,2I10,F15.5,I10,E15.5,2I10)
      NS=NSTAT
      NSITE=NSITEB-1
      BST=BSTEP
      DO 10 I=1,NSITEB
        BS(I)=0.
   10 CONTINUE
      DO 40 I=1,NS
      CALL CONUCL(TKOO,NB,RB)
C     CALL SORTIN(TKOO,NB)
      CALL CONUCL(PKOO,NA,RA)
C     CALL SORT(PKOO,NA)
        DO 40 I3=1,NSITE
          B=I3*BST
          PI=1.
          DO 30 I1=1,NA
          X1=B-PKOO(1,I1)
	  IF(PI.LT.1.D-100)GO TO 31
          X2=-PKOO(2,I1)
            DO 32 I2=1,NB
            Q1=X1+TKOO(1,I2)
            Q2=X2+TKOO(2,I2)
              XY=GA*(Q1*Q1+Q2*Q2)
C
              IF(XY.GT.15.)                                     GO TO 20
              E=EXP(-XY)
              C=CI-CA*E
              AR=REAL(REAL(C))
              AI=IMAG(C)
              P=AR*AR+AI*AI
C	      WRITE(6,'(A,5E13.3,3I6)')' PROFB:Pi,P,AR,AI,Ei,I3,I2,I1',
C    *PI,P,AR,AI,Ei,I3,I2,I1
              PI=PI*P
   20         CONTINUE
   32     CONTINUE
   31     CONTINUE
   30     CONTINUE
          BS(I3+1)=BS(I3+1)+1.-PI
   40 CONTINUE
      BS(1)=BS(2)
      SUMB=0.
      DO 50 I=1,NSITEB
	HELPP(I)=BS(I)/NS
        BS(I)=BS(I)*(I-1)*BST/NS
        SUMB=SUMB+BS(I)
   50 CONTINUE
      BSITE(1,1)=0.
      DO 60 I=2,NSITEB
        BSITE(1,I)=BS(I)/SUMB+BSITE(1,I-1)
   60 CONTINUE
      DO 70 I=1,NSITEB
        HELP(I)=I*BST
   70 CONTINUE
      SUMB=SUMB*BST*6.2831854
      SIGLAU=SUMB*10.
      WRITE(6,1020) SUMB
 1020 FORMAT(/5X,7HSIGMA =,F7.3)
      IF(IRW.GE.1) RETURN
      IF(ISHMAL) THEN
      DO 80 I=1,200
        WRITE (6,1030) HELP(I),HELPP(I),BS(I),BSITE(1,I)
 1030 FORMAT (F10.4,3E15.5)
   80 CONTINUE
        CALL PLOT(HELP,BSITE,50,1,50,0.D0,0.5D0,0.D0,0.01D0)
        CALL PLOT(HELP,BS   ,50,1,50,0.D0,0.5D0,0.D0,0.07D0)
      ENDIF
      RETURN
      END
*-- Author :
C
C++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE DPARJE(IHAD,I)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
*KEEP,DFINPA.
      CHARACTER*8 ANF
      PARAMETER (NFIMAX=249)
      COMMON /DFINPA/ ANF(NFIMAX),PXF(NFIMAX),PYF(NFIMAX),PZF(NFIMAX),
     +HEF(NFIMAX),AMF(NFIMAX), ICHF(NFIMAX),IBARF(NFIMAX),NREF(NFIMAX)
      COMMON /DFINPZ/IORMO(NFIMAX),IDAUG1(NFIMAX),IDAUG2(NFIMAX),
     * ISTATH(NFIMAX)
*KEEP,DINPDA.
      COMMON /DINPDA/ IMPS(6,6),IMVE(6,6),IB08(6,21),IB10(6,21), IA08
     +(6,21),IA10(6,21), A1,B1,B2,B3,LT,LE,BET,AS,B8,AME,DIQ,ISU
*KEEP,DPRIN.
      COMMON /DPRIN/  IPRI,IPEV,IPPA,IPCO,INIT,IPHKK,ITOPD,IPAUPR
*KEND.
      CHARACTER*8 ANAME
      COMMON /DPAR/ ANAME(210),AM(210),GA(210),TAU(210), ICH(210),IBAR
     +(210),K1(210),K2(210)
      IHAD=1
      NREF(1)=I
      PXF(1)=0.
      PYF(1)=0.
      PZF(1)=0.
      HEF(1)=AM(I)
      AMF(1)=AM(I)
      ICHF(1)=ICH(I)
      IBARF(1)=IBAR(I)
      ANF(1)=ANAME(I)
      IF (IPCO.GE.6)THEN
        WRITE(6,1000)IHAD,I,PXF(1),PYF(1),PZF(1),HEF(1),AMF(1)
 1000 FORMAT(' PARJET: IHAD,I,PXF(1),PYF(1),PZF(1),HEP(1),AMF(1)'/ 2I5,5
     +F10.3)
      ENDIF
      RETURN
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE SORT(A,N)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      DIMENSION A(3,N)
C     WRITE(6,*)' SORT N,A',N,A
      M=N
   10 CONTINUE
      M=N-1
      IF(M.LE.0) RETURN
      L=0
      DO 20 I=1,M
        J=I+1
        IF (A(3,I).LE.A(3,J))                                   GO TO 20
        B=A(3,I)
        C=A(1,I)
        D=A(2,I)
        A(3,I)=A(3,J)
        A(2,I)=A(2,J)
        A(1,I)=A(1,J)
        A(3,J)=B
        A(1,J)=C
        A(2,J)=D
        L=1
   20 CONTINUE
      IF(L.EQ.1)                                                GO TO 10
      RETURN
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE SORTIN(A,N)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      DIMENSION A(3,N)
      M=N
   10 CONTINUE
      M=N-1
      IF(M.LE.0) RETURN
      L=0
      DO 20 I=1,M
        J=I+1
        IF (A(3,I).GE.A(3,J))                                   GO TO 20
        B=A(3,I)
        C=A(1,I)
        D=A(2,I)
        A(3,I)=A(3,J)
        A(2,I)=A(2,J)
        A(1,I)=A(1,J)
        A(3,J)=B
        A(1,J)=C
        A(2,J)=D
        L=1
   20 CONTINUE
      IF(L.EQ.1)                                                GO TO 10
      RETURN
      END
*
*=== blkdt6 ===========================================================*
*==                                                                    *
      BLOCK DATA BLKD46
       IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
*$ CREATE DBLPRC.ADD
*COPY DBLPRC
*                                                                     *
*=== dblprc ==========================================================*
*                                                                     *
*---------------------------------------------------------------------*
*                                                                     *
*      Dblprc: included in any routine                                *
*                                                                     *
*  !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!  *
*  !!!! O N   M A C H I N E S   W H E R E   T H E   D O U B L E !!!!  *
*  !!!! P R E C I S I O N   I S   N O T   R E Q U I R E D  R E -!!!!  *
*  !!!! M O V E   T H E   D O U B L E   P R E C I S I O N       !!!!  *
*  !!!! S T A T E M E N T,  S E T   K A L G N M = 1   A N D     !!!!  *
*  !!!! C H A N G E   A L L   N U M E R I C A L   C O N S -     !!!!  *
*  !!!! T A N T S   T O   S I N G L E   P R E C I S I O N       !!!!  *
*  !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!  *
*                                                                     *
*         Kalgnm = real address alignment, 2 for double precision,    *
*                  1 for single precision                             *
*         Anglgb = this parameter should be set equal to the machine  *
*                  "zero" with respect to unit                        *
*         Anglsq = this parameter should be set equal to the square   *
*                  of Anglgb                                          *
*         Axcssv = this parameter should be set equal to the number   *
*                  for which unity is negligible for the machine      *
*                  accuracy                                           *
*         Andrfl = "underflow" of the machine for floating point      *
*                  operation                                          *
*         Avrflw = "overflow"  of the machine for floating point      *
*                  operation                                          *
*         Ainfnt = code "infinite"                                    *
*         Azrzrz = code "zero"                                        *
*         Einfnt = natural logarithm of the code "infinite"           *
*         Ezrzrz = natural logarithm of the code "zero"               *
*         Onemns = 1- of the machine, it is 1 - 2 x Anglgb            *
*         Onepls = 1+ of the machine, it is 1 + 2 x Anglgb            *
*         Csnnrm = maximum tolerable error on cosine normalization,   *
*                  u**2+v**2+w**2: assuming a typical anglgb relative *
*                  error on each component we would get 2xanglgb: use *
*                  4xanglgb to avoid too many normalizations          *
*         Dmxtrn = "infinite" distance for transport (cm)             *
*                                                                     *
*---------------------------------------------------------------------*
*                                                                     *
      PARAMETER ( KALGNM = 2 )
      PARAMETER ( ANGLGB = 5.0D-16 )
      PARAMETER ( ANGLSQ = 2.5D-31 )
      PARAMETER ( AXCSSV = 0.2D+16 )
      PARAMETER ( ANDRFL = 1.0D-38 )
      PARAMETER ( AVRFLW = 1.0D+38 )
      PARAMETER ( AINFNT = 1.0D+30 )
      PARAMETER ( AZRZRZ = 1.0D-30 )
      PARAMETER ( EINFNT = +69.07755278982137 D+00 )
      PARAMETER ( EZRZRZ = -69.07755278982137 D+00 )
      PARAMETER ( ONEMNS = 0.999999999999999  D+00 )
      PARAMETER ( ONEPLS = 1.000000000000001  D+00 )
      PARAMETER ( CSNNRM = 2.0D-15 )
      PARAMETER ( DMXTRN = 1.0D+08 )
*
*======================================================================*
*======================================================================*
*=========                                                   ==========*
*=========    M A T H E M A T I C A L   C O N S T A N T S    ==========*
*=========                                                   ==========*
*======================================================================*
*======================================================================*
*                                                                      *
*   Numerical constants:                                               *
*                                                                      *
*         Zerzer = 0                                                   *
*         Oneone = 1                                                   *
*         Twotwo = 2                                                   *
*         Thrthr = 3                                                   *
*         Foufou = 4                                                   *
*         Fivfiv = 5                                                   *
*         Sixsix = 6                                                   *
*         Sevsev = 7                                                   *
*         Eigeig = 8                                                   *
*         Aninen = 9                                                   *
*         Tenten = 10                                                  *
*         Hlfhlf = 1/2                                                 *
*         Onethi = 1/3                                                 *
*         Twothi = 2/3                                                 *
*         Pipipi = Circumference / diameter                            *
*         Eneper = "e", base of natural logarithm                      *
*         Sqrent = square root of "e"                                  *
*                                                                      *
*----------------------------------------------------------------------*
*
      PARAMETER ( ZERZER = 0.D+00 )
      PARAMETER ( ONEONE = 1.D+00 )
      PARAMETER ( TWOTWO = 2.D+00 )
      PARAMETER ( THRTHR = 3.D+00 )
      PARAMETER ( FOUFOU = 4.D+00 )
      PARAMETER ( FIVFIV = 5.D+00 )
      PARAMETER ( SIXSIX = 6.D+00 )
      PARAMETER ( SEVSEV = 7.D+00 )
      PARAMETER ( EIGEIG = 8.D+00 )
      PARAMETER ( ANINEN = 9.D+00 )
      PARAMETER ( TENTEN = 10.D+00 )
      PARAMETER ( HLFHLF = 0.5D+00 )
      PARAMETER ( ONETHI = ONEONE / THRTHR )
      PARAMETER ( TWOTHI = TWOTWO / THRTHR )
      PARAMETER ( PIPIPI = 3.1415926535897932270 D+00 )
      PARAMETER ( ENEPER = 2.7182818284590452354 D+00 )
      PARAMETER ( SQRENT = 1.6487212707001281468 D+00 )
*
*======================================================================*
*======================================================================*
*=========                                                   ==========*
*=========       P H Y S I C A L   C O N S T A N T S         ==========*
*=========                                                   ==========*
*======================================================================*
*======================================================================*
*                                                                      *
*   Primary constants:                                                 *
*                                                                      *
*         Clight = speed of light in cm s-1                            *
*         Avogad = Avogadro number                                     *
*         Amelgr = electron mass (g)                                   *
*         Plckbr = reduced Planck constant (erg s)                     *
*         Elccgs = elementary charge (CGS unit)                        *
*         Elcmks = elementary charge (MKS unit)                        *
*         Amugrm = Atomic mass unit (g)                                *
*         Ammumu = Muon mass (amu)                                     *
*                                                                      *
*   Derived constants:                                                 *
*                                                                      *
*         Alpfsc = Fine structure constant  = e^2/(hbar c)             *
*         Amelct = Electron mass (GeV) = 10^-16Amelgr Clight^2 / Elcmks*
*         Amugev = Atomic mass unit (GeV) = 10^-16Amelgr Clight^2      *
*                                           / Elcmks                   *
*         Ammuon = Muon mass (GeV) = Ammumu * Amugev                   *
*         Fscto2 = (Fine structure constant)^2                         *
*         Fscto3 = (Fine structure constant)^3                         *
*         Fscto4 = (Fine structure constant)^4                         *
*         Plabrc = Reduced Planck constant times the light velocity    *
*                  expressed in GeV fm                                 *
*         Rclsel = Classical electron radius (cm) = e^2 / (m_e c^2)    *
*   Conversion constants:                                              *
*         GeVMeV = from GeV to MeV                                     *
*         eMVGeV = from MeV to GeV                                     *
*         Raddeg = from radians to degrees                             *
*         Degrad = from degrees to radians                             *
*                                                                      *
*----------------------------------------------------------------------*
*
      PARAMETER ( CLIGHT = 2.99792458         D+10 )
      PARAMETER ( AVOGAD = 6.0221367          D+23 )
      PARAMETER ( AMELGR = 9.1093897          D-28 )
      PARAMETER ( PLCKBR = 1.05457266         D-27 )
      PARAMETER ( ELCCGS = 4.8032068          D-10 )
      PARAMETER ( ELCMKS = 1.60217733         D-19 )
      PARAMETER ( AMUGRM = 1.6605402          D-24 )
      PARAMETER ( AMMUMU = 0.113428913        D+00 )
*     PARAMETER ( ALPFSC = 1.D+00 / 137.035989561D+00 )
*     PARAMETER ( FSCTO2 = ALPFSC * ALPFSC )
*     PARAMETER ( FSCTO3 = FSCTO2 * ALPFSC )
*     PARAMETER ( FSCTO4 = FSCTO3 * ALPFSC )
*    It is important to set the electron mass exactly with the same
*    rounding as in the mass tables, so use the explicit expression
*     PARAMETER ( AMELCT = 1.D-16 * AMELGR * CLIGHT * CLIGHT / ELCMKS )
*    It is important to set the amu mass exactly with the same
*    rounding as in the mass tables, so use the explicit expression
*     PARAMETER ( AMUGEV = 1.D-16 * AMUGRM * CLIGHT * CLIGHT / ELCMKS )
*    It is important to set the muon mass exactly with the same
*    rounding as in the mass tables, so use the explicit expression
*     PARAMETER ( AMMUON = AMMUMU * AMUGEV ELCMKS )
*     PARAMETER ( RCLSEL = ELCCGS * ELCCGS / CLIGHT / CLIGHT / AMELGR )
      PARAMETER ( ALPFSC = 7.2973530791728595 D-03 )
      PARAMETER ( FSCTO2 = 5.3251361962113614 D-05 )
      PARAMETER ( FSCTO3 = 3.8859399018437826 D-07 )
      PARAMETER ( FSCTO4 = 2.8357075508200407 D-09 )
      PARAMETER ( PLABRC = 0.197327053        D+00 )
      PARAMETER ( AMELCT = 0.51099906         D-03 )
      PARAMETER ( AMUGEV = 0.93149432         D+00 )
      PARAMETER ( AMMUON = 0.105658389        D+00 )
      PARAMETER ( RCLSEL = 2.8179409183694872 D-13 )
      PARAMETER ( GEVMEV = 1.0                D+03 )
      PARAMETER ( EMVGEV = 1.0                D-03 )
      PARAMETER ( RADDEG = 180.D+00 / PIPIPI )
      PARAMETER ( DEGRAD = PIPIPI / 180.D+00 )
 
*$ CREATE IOUNIT.ADD
*COPY IOUNIT
*                                                                     *
*=== iounit ==========================================================*
*                                                                     *
*---------------------------------------------------------------------*
*                                                                     *
*      Iounit: included in any routine                                *
*                                                                     *
*         lunin  = standard input unit                                *
*         lunout = standard output unit                               *
*         lunerr = standard error unit                                *
*         lunber = input file for bertini nuclear data                *
*         lunech = echo file for pegs dat                             *
*         lunflu = input file for photoelectric edges and X-ray fluo- *
*                  rescence data                                      *
*         lungeo = scratch file for combinatorial geometry            *
*         lunpgs = input file for pegs material data                  *
*         lunran = output file for the final random number seed       *
*         lunxsc = input file for low energy neutron cross sections   *
*         lunrdb = unit number for reading (extra) auxiliary external *
*                  files to be closed just after reading              *
*                                                                     *
*---------------------------------------------------------------------*
*                                                                     *
      PARAMETER ( LUNIN  = 5  )
      PARAMETER ( LUNOUT = 6  )
      PARAMETER ( LUNERR = 66 )
      PARAMETER ( LUNBER = 14 )
      PARAMETER ( LUNECH = 8  )
      PARAMETER ( LUNFLU = 86 )
      PARAMETER ( LUNGEO = 16 )
      PARAMETER ( LUNPGS = 12 )
      PARAMETER ( LUNRAN = 2  )
      PARAMETER ( LUNXSC = 81 )
      PARAMETER ( LUNRDB = 1  )
 
*$ CREATE DIMPAR.ADD
*COPY DIMPAR
*                                                                     *
*=== dimpar ==========================================================*
*                                                                     *
*---------------------------------------------------------------------*
*                                                                     *
*      DIMPAR: included in any routine                                *
*                                                                     *
*          Mxxrgn = maximum number of regions                         *
*          Mxxmdf = maximum number of media in Fluka                  *
*          Mxxmde = maximum number of media in Emf                    *
*          Mfstck = stack dimension in Fluka                          *
*          Mestck = stack dimension in Emf                            *
*          Nallwp = number of allowed particles                       *
*          Mpdpdx = number of particle types for which EM dE/dx pro-  *
*                   cesses (ion,pair,bremss) have to be computed      *
*          Icomax = maximum number of materials for compounds (equal  *
*                   to the sum of the number of materials for every   *
*                   compound )                                        *
*          Nstbis = number of stable isotopes recorded in common iso- *
*                   top                                               *
*          Idmaxp = number of particles/resonances defined in common  *
*                   part                                              *
*                                                                     *
*---------------------------------------------------------------------*
*                                                                     *
      PARAMETER ( MXXRGN = 500  )
      PARAMETER ( MXXMDF = 56   )
      PARAMETER ( MXXMDE = 50   )
      PARAMETER ( MFSTCK = 1000 )
      PARAMETER ( MESTCK = 100  )
      PARAMETER ( NALLWP = 39   )
      PARAMETER ( MPDPDX = 8    )
      PARAMETER ( ICOMAX = 180  )
      PARAMETER ( NSTBIS = 304  )
      PARAMETER ( IDMAXP = 210  )
 
 
       CHARACTER*8 ANAME
       COMMON /DPAR/ ANAME(210),AM(210),GA(210),TAU(210),
     +               ICH(210),IBAR(210),K1(210),K2(210)
* / Part /
*     datas     datas    datas      datas     datas                    *
*     ---------------------------------------------                    *
*
*
*     Particle  masses Engel version JETSET compatible                 *
*                                                                      *
      DATA (AM(K),K=1,85) /
     &   .9383D+00, .9383D+00,  AMELCT  ,  AMELCT  , .0000D+00,
     &   .0000D+00, .0000D+00, .9396D+00, .9396D+00, AMMUON   ,
     &   AMMUON   , .4977D+00, .1396D+00, .1396D+00, .4936D+00,
     &   .4936D+00, .1116D+01, .1116D+01, .4977D+00, .1197D+01,
     &   .1189D+01, .1193D+01, .1350D+00, .4977D+00, .4977D+00,
     &   .0000D+00, .0000D+00, .0000D+00, .0000D+00, .0000D+00,
     &   .5488D+00, .7669D+00, .7700D+00, .7669D+00, .7820D+00,
     &   .8921D+00, .8962D+00, .8921D+00, .8962D+00, .1300D+01,
     &   .1300D+01, .1300D+01, .1300D+01, .1421D+01, .1421D+01,
     &   .1421D+01, .1421D+01, .1383D+01, .1384D+01, .1387D+01,
     &   .1820D+01, .2030D+01, .1231D+01, .1232D+01, .1233D+01,
     &   .1234D+01, .1675D+01, .1675D+01, .1675D+01, .1675D+01,
     &   .1500D+01, .1500D+01, .1515D+01, .1515D+01, .1775D+01,
     &   .1775D+01, .1231D+01, .1232D+01, .1233D+01, .1234D+01,
     &   .1675D+01, .1675D+01, .1675D+01, .1675D+01, .1515D+01,
     &   .1515D+01, .2500D+01, .4890D+00, .4890D+00, .4890D+00,
     &   .1300D+01, .1300D+01, .1300D+01, .1300D+01, .2200D+01  /
      DATA (AM(K),K=86,183) /
     &   .2200D+01, .2200D+01, .2200D+01, .1700D+01, .1700D+01,
     &   .1700D+01, .1700D+01, .1820D+01, .2030D+01, .9575D+00,
     &   .1019D+01, .1315D+01, .1321D+01, .1189D+01, .1193D+01,
     &   .1197D+01, .1315D+01, .1321D+01, .1383D+01, .1384D+01,
     &   .1387D+01, .1532D+01, .1535D+01, .1672D+01, .1383D+01,
     &   .1384D+01, .1387D+01, .1532D+01, .1535D+01, .1672D+01,
     &   .1865D+01, .1869D+01, .1869D+01, .1865D+01, .1969D+01,
     &   .1969D+01, .2980D+01, .2007D+01, .2010D+01, .2010D+01,
     &   .2007D+01, .2113D+01, .2113D+01, .3686D+01, .3097D+01,
     &   .1777D+01, .1777D+01, .0000D+00, .0000D+00, .0000D+00,
     &   .0000D+00, .2285D+01, .2460D+01, .2460D+01, .2452D+01,
     &   .2453D+01, .2454D+01, .2560D+01, .2560D+01, .2730D+01,
     &   .3610D+01, .3610D+01, .3790D+01, .2285D+01, .2460D+01,
     &   .2460D+01, .2452D+01, .2453D+01, .2454D+01, .2560D+01,
     &   .2560D+01, .2730D+01, .3610D+01, .3610D+01, .3790D+01,
     &   .2490D+01, .2490D+01, .2490D+01, .2610D+01, .2610D+01,
     &   .2770D+01, .3670D+01, .3670D+01, .3850D+01, .4890D+01,
     &   .2490D+01, .2490D+01, .2490D+01, .2610D+01, .2610D+01,
     &   .2770D+01, .3670D+01, .3670D+01, .3850D+01, .4890D+01,
     &   .1250D+01, .1250D+01, .1250D+01  /
      DATA ( AM ( I ), I = 184,210 ) /
     & 1.44000000000000D+00, 1.44000000000000D+00, 1.30000000000000D+00,
     & 1.30000000000000D+00, 1.30000000000000D+00, 1.40000000000000D+00,
     & 1.46000000000000D+00, 1.46000000000000D+00, 1.46000000000000D+00,
     & 1.46000000000000D+00, 1.60000000000000D+00, 1.60000000000000D+00,
     & 1.66000000000000D+00, 1.66000000000000D+00, 1.66000000000000D+00,
     & 1.66000000000000D+00, 1.66000000000000D+00, 1.66000000000000D+00,
     & 1.95000000000000D+00, 1.95000000000000D+00, 1.95000000000000D+00,
     & 1.95000000000000D+00, 2.25000000000000D+00, 2.25000000000000D+00,
     & 1.44000000000000D+00, 1.44000000000000D+00, 0.00000000000000D+00/
*                                                                      *
*     Particle  mean lives                                             *
*                                                                      *
      DATA (TAU(K),K=1,183) /
     &   .1000D+19, .1000D+19, .1000D+19, .1000D+19, .1000D+19,
     &   .1000D+19, .1000D+19, .9180D+03, .9180D+03, .2200D-05,
     &   .2200D-05, .5200D-07, .2600D-07, .2600D-07, .1200D-07,
     &   .1200D-07, .2600D-09, .2600D-09, .9000D-10, .1500D-09,
     &   .8000D-10, .5000D-14, .8000D-16, .0000D+00, .0000D+00,
     &   70*.0000D+00,
     &   .0000D+00, .3000D-09, .1700D-09, .8000D-10, .1000D-13,
     &   .1500D-09, .3000D-09, .1700D-09, .0000D+00, .0000D+00,
     &   .0000D+00, .0000D+00, .0000D+00, .1000D-09, .0000D+00,
     &   .0000D+00, .0000D+00, .0000D+00, .0000D+00, .1000D-09,
     &   .0000D+00, .0000D+00, .0000D+00, .0000D+00, .0000D+00,
     &   .0000D+00, .0000D+00, .0000D+00, .0000D+00, .0000D+00,
     &   .0000D+00, .0000D+00, .0000D+00, .0000D+00, .0000D+00,
     &   .9000D-11, .9000D-11, .9000D-11, .9000D-11, .1000D+19,
     &   .1000D+19, .0000D+00, .0000D+00, .0000D+00, .0000D+00,
     &   40*.0000D+00,
     &   .0000D+00, .0000D+00, .0000D+00  /
      DATA ( TAU ( I ), I = 184,210 ) /
     & 0.00000000000000D+00, 0.00000000000000D+00, 0.00000000000000D+00,
     & 0.00000000000000D+00, 0.00000000000000D+00, 0.00000000000000D+00,
     & 0.00000000000000D+00, 0.00000000000000D+00, 0.00000000000000D+00,
     & 0.00000000000000D+00, 0.00000000000000D+00, 0.00000000000000D+00,
     & 0.00000000000000D+00, 0.00000000000000D+00, 0.00000000000000D+00,
     & 0.00000000000000D+00, 0.00000000000000D+00, 0.00000000000000D+00,
     & 0.00000000000000D+00, 0.00000000000000D+00, 0.00000000000000D+00,
     & 0.00000000000000D+00, 0.00000000000000D+00, 0.00000000000000D+00,
     & 0.00000000000000D+00, 0.00000000000000D+00, 0.00000000000000D+00/
*                                                                      *
*     Resonance width Gamma in GeV                                     *
*                                                                      *
      DATA (GA(K),K=  1,85) /
     &    30*.0000D+00,
     &   .8500D-06, .1520D+00, .1520D+00, .1520D+00, .1000D-01,
     &   .7900D-01, .7900D-01, .7900D-01, .7900D-01, .4500D+00,
     &   .4500D+00, .4500D+00, .4500D+00, .1080D+00, .1080D+00,
     &   .1080D+00, .1080D+00, .5000D-01, .5000D-01, .5000D-01,
     &   .8500D-01, .1800D+00, .1150D+00, .1150D+00, .1150D+00,
     &   .1150D+00, .2000D+00, .2000D+00, .2000D+00, .2000D+00,
     &   .2000D+00, .2000D+00, .1000D+00, .1000D+00, .2000D+00,
     &   .2000D+00, .1150D+00, .1150D+00, .1150D+00, .1150D+00,
     &   .2000D+00, .2000D+00, .2000D+00, .2000D+00, .1000D+00,
     &   .1000D+00, .2000D+00, .1000D+00, .1000D+00, .1000D+00,
     &   .1000D+00, .1000D+00, .1000D+00, .1000D+00, .2000D+00  /
      DATA (GA(K),K= 86,183) /
     &   .2000D+00, .2000D+00, .2000D+00, .1500D+00, .1500D+00,
     &   .1500D+00, .1500D+00, .8500D-01, .1800D+00, .2000D-02,
     &   .4000D-02, .0000D+00, .0000D+00, .0000D+00, .0000D+00,
     &   .0000D+00, .0000D+00, .0000D+00, .3400D-01, .3400D-01,
     &   .3600D-01, .9000D-02, .9000D-02, .0000D+00, .3400D-01,
     &   .3400D-01, .3600D-01, .9000D-02, .9000D-02, .0000D+00,
     &   .0000D+00, .0000D+00, .0000D+00, .0000D+00, .0000D+00,
     &   .0000D+00, .0000D+00, .5000D-02, .2000D-02, .2000D-02,
     &   .5000D-02, .2000D-02, .2000D-02, .2000D-03, .7000D-03,
     &   50*.0000D+00,
     &   .3000D+00, .3000D+00, .3000D+00  /
      DATA ( GA ( I ), I = 184,210 ) /
     & 2.00000000000000D-01, 2.00000000000000D-01, 3.00000000000000D-01,
     & 3.00000000000000D-01, 3.00000000000000D-01, 2.70000000000000D-01,
     & 2.50000000000000D-01, 2.50000000000000D-01, 2.50000000000000D-01,
     & 2.50000000000000D-01, 1.50000000000000D-01, 1.50000000000000D-01,
     & 1.00000000000000D-01, 1.00000000000000D-01, 1.00000000000000D-01,
     & 1.00000000000000D-01, 1.00000000000000D-01, 1.00000000000000D-01,
     & 6.00000000000000D-02, 6.00000000000000D-02, 6.00000000000000D-02,
     & 6.00000000000000D-02, 5.50000000000000D-02, 5.50000000000000D-02,
     & 2.00000000000000D-01, 2.00000000000000D-01, 0.00000000000000D+00/
*                                                                      *
*     Particle  names                                                  *
*                                                                      *
*     S+1385+Sigma+(1385)    L02030+Lambda0(2030)                      *
*     Rho77=Rho(770) Om783=Omega(783) K*14=K*(1420) and so on          *
*     designation N*@@ means N*@1(@2)                                  *
*                                                                      *
*                                                                      *
      DATA (ANAME(K),K=1,85) /
     &  'P       ','AP      ','E-      ','E+      ','NUE     ',
     &  'ANUE    ','GAM     ','NEU     ','ANEU    ','MUE+    ',
     &  'MUE-    ','K0L     ','PI+     ','PI-     ','K+      ',
     &  'K-      ','LAM     ','ALAM    ','K0S     ','SIGM-   ',
     &  'SIGM+   ','SIGM0   ','PI0     ','K0      ','AK0     ',
     &  'BLANK   ','BLANK   ','BLANK   ','BLANK   ','BLANK   ',
     &  'ETA550  ','RHO+77  ','RHO077  ','RHO-77  ','OM0783  ',
     &  'K*+892  ','K*0892  ','K*-892  ','AK*089  ','KA+125  ',
     &  'KA0125  ','KA-125  ','AKA012  ','K*+142  ','K*0142  ',
     &  'K*-142  ','AK*014  ','S+1385  ','S01385  ','S-1385  ',
     &  'L01820  ','L02030  ','N*++12  ','N*+ 12  ','N*012   ',
     &  'N*-12   ','N*++16  ','N*+16   ','N*016   ','N*-16   ',
     &  'N*+14   ','N*014   ','N*+15   ','N*015   ','N*+18   ',
     &  'N*018   ','AN--12  ','AN*-12  ','AN*012  ','AN*+12  ',
     &  'AN--16  ','AN*-16  ','AN*016  ','AN*+16  ','AN*-15  ',
     &  'AN*015  ','DE*=24  ','RPI+49  ','RPI049  ','RPI-49  ',
     &  'PIN++   ','PIN+0   ','PIN+-   ','PIN-0   ','PPPI    ' /
      DATA (ANAME(K),K=86,183) /
     &  'PNPI    ','APPPI   ','APNPI   ','K+PPI   ','K-PPI   ',
     &  'K+NPI   ','K-NPI   ','S+1820  ','S-2030  ','ETA*    ',
     &  'PHI     ','TETA0   ','TETA-   ','ASIG-   ','ASIG0   ',
     &  'ASIG+   ','ATETA0  ','ATETA+  ','SIG*+   ','SIG*0   ',
     &  'SIG*-   ','TETA*0  ','TETA*   ','OMEGA-  ','ASIG*-  ',
     &  'ASIG*0  ','ASIG*+  ','ATET*0  ','ATET*+  ','OMEGA+  ',
     &  'D0      ','D+      ','D-      ','AD0     ','DS+     ',
     &  'DS-     ','ETAC    ','D*0     ','D*+     ','D*-     ',
     &  'AD*0    ','DS*+    ','DS*-    ','CHI1C   ','JPSI    ',
     &  'TAU+    ','TAU-    ','NUET    ','ANUET   ','NUEM    ',
     &  'ANUEM   ','LAMC+   ','XIC+    ','XIC0    ','SIGC++  ',
     &  'SIGC+   ','SIGC0   ','S+      ','S0      ','T0      ',
     &  'XU++    ','XD+     ','XS+     ','ALAMC-  ','AXIC-   ',
     &  'AXIC0   ','ASIGC-- ','ASIGC-  ','ASIGC0  ','AS-     ',
     &  'AS0     ','AT0     ','AXU--   ','AXD-    ','AXS     ',
     &  'C1*++   ','C1*+    ','C1*0    ','S*+     ','S*0     ',
     &  'T*0     ','XU*++   ','XD*+    ','XS*+    ','TETA++  ',
     &  'AC1*--  ','AC1*-   ','AC1*0   ','AS*-    ','AS*0    ',
     &  'AT*0    ','AXU*--  ','AXD*-   ','AXS*-   ','ATET--  ',
     &  'RO      ','R+      ','R-      '  /
      DATA (    ANAME ( I ), I = 184,210 ) /
     &'AN*-14  ','AN*014  ','PI+130  ','PI0130  ','PI-130  ','F01400  ',
     &'K*+146  ','K*-146  ','K*0146  ','AK0146  ','L01600  ','AL0160  ',
     &'S+1660  ','S01660  ','S-1660  ','AS-166  ','AS0166  ','AS+166  ',
     &'X01950  ','X-1950  ','AX0195  ','AX+195  ','OM-225  ','AOM+22  ',
     &'N*+14   ','N*014   ','BLANK   '/
*                                                                      *
*     Charge of particles and resonances                               *
*                                                                      *
      DATA ( ICH ( I ), I =   1,210 ) /
     &  1, -1, -1,  1,  0,  0,  0,  0,  0,  1, -1,  0,  1, -1,  1,
     & -1,  0,  0,  0, -1,  1,  0,  0,  0,  0,  0,  0,  0,  0,  0,
     &  0,  1,  0, -1,  0,  1,  0, -1,  0,  1,  0, -1,  0,  1,  0,
     & -1,  0,  1,  0, -1,  0,  0,  2,  1,  0, -1,  2,  1,  0, -1,
     &  1,  0,  1,  0,  1,  0, -2, -1,  0,  1, -2, -1,  0,  1, -1,
     &  0,  1,  1,  0, -1,  2,  1,  0, -1,  2,  1,  0, -1,  2,  0,
     &  1, -1,  1, -1,  0,  0,  0, -1, -1,  0,  1,  0,  1,  1,  0,
     & -1,  0, -1, -1, -1,  0,  1,  0,  1,  1,  0,  1, -1,  0,  1,
     & -1,  0,  0,  1, -1,  0,  1, -1,  0,  0,  1, -1,  0,  0,  0,
     &  0,  1,  1,  0,  2,  1,  0,  1,  0,  0,  2,  1,  1, -1, -1,
     &  0, -2, -1,  0, -1,  0,  0, -2, -1, -1,  2,  1,  0,  1,  0,
     &  0,  2,  1,  1,  2, -2, -1,  0, -1,  0,  0, -2, -1, -1, -2,
     &  0,  1, -1, -1,  0,  1,  0, -1,  0,  1, -1,  0,  0,  0,  0,
     &  1,  0, -1, -1,  0,  1,  0, -1,  0,  1, -1,  1,  1,  0,  0/
*                                                                      *
*     Particle  baryonic charges                                       *
*                                                                      *
      DATA ( IBAR ( I ), I =   1,210 ) /
     &  1, -1,  0,  0,  0,  0,  0,  1, -1,  0,  0,  0,  0,  0,  0,
     &  0,  1, -1,  0,  1,  1,  1,  0,  0,  0,  0,  0,  0,  0,  0,
     &  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
     &  0,  0,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,
     &  1,  1,  1,  1,  1,  1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
     & -1,  2,  0,  0,  0,  1,  1,  1,  1,  2,  2,  0,  0,  1,  1,
     &  1,  1,  1,  1,  0,  0,  1,  1, -1, -1, -1, -1, -1,  1,  1,
     &  1,  1,  1,  1, -1, -1, -1, -1, -1, -1,  0,  0,  0,  0,  0,
     &  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
     &  0,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1, -1, -1,
     & -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,  1,  1,  1,  1,  1,
     &  1,  1,  1,  1,  1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
     &  0,  0,  0, -1, -1,  0,  0,  0,  0,  0,  0,  0,  0,  1, -1,
     &  1,  1,  1, -1, -1, -1,  1,  1, -1, -1,  1, -1,  1,  1,  0/
*                                                                      *
*     First number of decay channels used for resonances               *
*     and decaying particles                                           *
*                                                                      *
      DATA K1/   1,  2,  3,  4,  5,  6,  7,  8,  9, 10, 11, 12, 16, 17,
     &  18, 24, 30, 34, 38, 40, 41, 43, 44, 136, 138, 330, 327, 328,
     &   2*330, 46, 51, 52, 54, 55, 58,
     &  60, 62, 64, 66, 68, 70, 72, 74, 82, 90, 98, 106, 109, 112, 114,
     & 123, 140, 141, 143, 145, 146, 150, 157, 164, 168, 174, 180, 187,
     & 194, 202, 210, 211, 213, 215, 216, 220, 227, 234, 238, 245, 252,
     & 254, 255, 256, 257, 259, 262, 265, 267, 269, 272, 276, 279, 282,
     & 286, 290, 293, 299, 331, 335, 339, 340, 341, 343, 344, 345, 346,
     & 347, 350, 353, 356, 358, 360, 363, 366, 369, 372, 374, 376, 379,
     & 383, 385, 387, 391, 394, 397, 400, 402, 405, 408, 410, 412, 414,
     & 417, 420, 425, 430, 431, 432, 433, 434, 448, 452, 457, 458, 459,
     & 460, 461, 462, 466, 468, 470, 472, 486, 490, 495, 496, 497, 498,
     & 499, 500, 504, 506, 508, 510, 511, 512, 513, 514, 515, 516, 517,
     & 518, 519, 522, 523, 524, 525, 526, 527, 528, 529, 530, 531, 534,
     & 537, 539, 541, 547, 553, 558, 563, 568, 572, 573, 574, 575, 576,
     & 577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 588, 589,
     & 590, 596, 602 /
*                                                                      *
*     Last number of decay channels used for resonances                *
*     and decaying particles                                           *
*                                                                      *
      DATA K2/   1,  2,  3,  4,  5,  6,  7,  8,  9, 10, 11, 15, 16, 17,
     & 23, 29, 31, 35, 39, 40, 42, 43, 45, 137, 139, 330, 327, 328,
     & 2* 330, 50, 51, 53, 54, 57,
     & 59, 61, 63, 65, 67, 69, 71, 73, 81, 89, 97, 105, 108, 111, 113,
     & 122, 135, 140, 142, 144, 145, 149, 156, 163, 167, 173, 179, 186,
     & 193, 201, 209, 210, 212, 214, 215, 219, 226, 233, 237, 244, 251,
     & 253, 254, 255, 256, 258, 261, 264, 266, 268, 271, 275, 278, 281,
     & 285, 289, 292, 298, 307, 334, 338, 339, 340, 342, 343, 344, 345,
     & 346, 349, 352, 355, 357, 359, 362, 365, 368, 371, 373, 375, 378,
     & 382, 384, 386, 390, 393, 396, 399, 401, 404, 407, 409, 411, 413,
     & 416, 419, 424, 429, 430, 431, 432, 433, 447, 451, 456, 457, 458,
     & 459, 460, 461, 465, 467, 469, 471, 485, 489, 494, 495, 496, 497,
     & 498, 499, 503, 505, 507, 509, 510, 511, 512, 513, 514, 515, 516,
     & 517, 518, 521, 522, 523, 524, 525, 526, 527, 528, 529, 530, 533,
     & 536, 538, 540, 546, 552, 557, 562, 567, 571, 572, 573, 574, 575,
     & 576, 577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 588,
     & 589, 595, 601, 602 /
*                                                                      *
*
       END
*
 
*=== blkdt7 ===========================================================*
*==                                                                    *
      BLOCK DATA BLKD47
       IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
* * Block data 7 (ex 2)                                                *
C      INCLUDE '(DECAYC)'
C***********************************************************************
      PARAMETER (IDMAX9=602)
      CHARACTER*8 ZKNAME
      COMMON/DDECAC/ ZKNAME(IDMAX9),WT(IDMAX9),NZK(IDMAX9,3)
 
 
*                                                                      *
*     Name of decay channel                                            *
*                                                                      *
*                                                                      *
*   Designation N*@ means N*@1(1236)                                   *
*   @1=# means ++,  @1 = = means --                                    *
*   Designation  P+/0/- means Pi+/Pi0/Pi- , respectively               *
*                                                                      *
      DATA (ZKNAME(K),K=  1, 85) /
     &  'P       ','AP      ','E-      ','E+      ','NUE     ',
     &  'ANUE    ','GAM     ','PE-NUE  ','APEANU  ','EANUNU  ',
     &  'E-NUAN  ','3PI0    ','PI+-0   ','PIMUNU  ','PIE-NU  ',
     &  'MU+NUE  ','MU-NUE  ','MU+NUE  ','PI+PI0  ','PI++-   ',
     &  'PI+00   ','M+P0NU  ','E+P0NU  ','MU-NU   ','PI-0    ',
     &  'PI+--   ','PI-00   ','M-P0NU  ','E-P0NU  ','PPI-    ',
     &  'NPI0    ','PD-NUE  ','PM-NUE  ','APPI+   ','ANPI0   ',
     &  'APE+NU  ','APM+NU  ','PI+PI-  ','PI0PI0  ','NPI-    ',
     &  'PPI0    ','NPI+    ','LAGA    ','GAGA    ','GAE+E-  ',
     &  'GAGA    ','GAGAP0  ','PI000   ','PI+-0   ','PI+-GA  ',
     &  'PI+0    ','PI+-    ','PI00    ','PI-0    ','PI+-0   ',
     &  'PI+-    ','PI0GA   ','K+PI0   ','K0PI+   ','KOPI0   ',
     &  'K+PI-   ','K-PI0   ','AK0PI-  ','AK0PI0  ','K-PI+   ',
     &  'K+PI0   ','K0PI+   ','K0PI0   ','K+PI-   ','K-PI0   ',
     &  'K0PI-   ','AK0PI0  ','K-PI+   ','K+PI0   ','K0PI+   ',
     &  'K+89P0  ','K08PI+  ','K+RO77  ','K0RO+7  ','K+OM07  ',
     &  'K+E055  ','K0PI0   ','K+PI+   ','K089P0  ','K+8PI-  '  /
      DATA (ZKNAME(K),K= 86,170) /
     &  'K0R077  ','K+R-77  ','K+R-77  ','K0OM07  ','K0E055  ',
     &  'K-PI0   ','K0PI-   ','K-89P0  ','AK08P-  ','K-R077  ',
     &  'AK0R-7  ','K-OM07  ','K-E055  ','AK0PI0  ','K-PI+   ',
     &  'AK08P0  ','K-8PI+  ','AK0R07  ','AK0OM7  ','AK0E05  ',
     &  'LA0PI+  ','SI0PI+  ','SI+PI0  ','LA0PI0  ','SI+PI-  ',
     &  'SI-PI+  ','LA0PI-  ','SI0PI-  ','NEUAK0  ','PK-     ',
     &  'SI+PI-  ','SI0PI0  ','SI-PI+  ','LA0ET0  ','S+1PI-  ',
     &  'S-1PI+  ','SO1PI0  ','NEUAK0  ','PK-     ','LA0PI0  ',
     &  'LA0OM0  ','LA0RO0  ','SI+RO-  ','SI-RO+  ','SI0RO0  ',
     &  'LA0ET0  ','SI0ET0  ','SI+PI-  ','SI-PI+  ','SI0PI0  ',
     &  'K0S     ','K0L     ','K0S     ','K0L     ','P PI+   ',
     &  'P PI0   ','N PI+   ','P PI-   ','N PI0   ','N PI-   ',
     &  'P PI+   ','N*#PI0  ','N*+PI+  ','PRHO+   ','P PI0   ',
     &  'N PI+   ','N*#PI-  ','N*+PI0  ','N*0PI+  ','PRHO0   ',
     &  'NRHO+   ','P PI-   ','N PI0   ','N*+PI-  ','N*0PI0  ',
     &  'N*-PI+  ','PRHO-   ','NRHO0   ','N PI-   ','N*0PI-  ',
     &  'N*-PI0  ','NRHO-   ','PETA0   ','N*#PI-  ','N*+PI0  '  /
      DATA (ZKNAME(K),K=171,255) /
     &  'N*0PI+  ','PRHO0   ','NRHO+   ','NETA0   ','N*+PI-  ',
     &  'N*0PI0  ','N*-PI+  ','PRHO-   ','NRHO0   ','P PI0   ',
     &  'N PI+   ','N*#PI-  ','N*+PI0  ','N*0PI+  ','PRHO0   ',
     &  'NRHO+   ','P PI-   ','N PI0   ','N*+PI-  ','N*0PI0  ',
     &  'N*-PI+  ','PRHO-   ','NRHO0   ','P PI0   ','N PI+   ',
     &  'PRHO0   ','NRHO+   ','LAMK+   ','S+ K0   ','S0 K+   ',
     &  'PETA0   ','P PI-   ','N PI0   ','PRHO-   ','NRHO0   ',
     &  'LAMK0   ','S0 K0   ','S- K+   ','NETA/   ','APPI-   ',
     &  'APPI0   ','ANPI-   ','APPI+   ','ANPI0   ','ANPI+   ',
     &  'APPI-   ','AN*=P0  ','AN*-P-  ','APRHO-  ','APPI0   ',
     &  'ANPI-   ','AN*=P+  ','AN*-P0  ','AN*0P-  ','APRHO0  ',
     &  'ANRHO-  ','APPI+   ','ANPI0   ','AN*-P+  ','AN*0P0  ',
     &  'AN*+P-  ','APRHO+  ','ANRHO0  ','ANPI+   ','AN*0P+  ',
     &  'AN*+P0  ','ANRHO+  ','APPI0   ','ANPI-   ','AN*=P+  ',
     &  'AN*-P0  ','AN*0P-  ','APRHO0  ','ANRHO-  ','APPI+,  ',
     &  'ANPI0   ','AN*-P+  ','AN*0P0  ','AN*+P-  ','APRHO+  ',
     &  'ANRHO0  ','PN*014  ','NN*=14  ','PI+0    ','PI+-    '  /
      DATA (ZKNAME(K),K=256,340) /
     &  'PI-0    ','P+0     ','N++     ','P+-     ','P00     ',
     &  'N+0     ','N+-     ','N00     ','P-0     ','N-0     ',
     &  'P--     ','PPPI0   ','PNPI+   ','PNPI0   ','PPPI-   ',
     &  'NNPI+   ','APPPI0  ','APNPI+  ','ANNPI0  ','ANPPI-  ',
     &  'APNPI0  ','APPPI-  ','ANNPI-  ','K+PPI0  ','K+NPI+  ',
     &  'K0PPI0  ','K-PPI0  ','K-NPI+  ','AKPPI-  ','AKNPI0  ',
     &  'K+NPI0  ','K+PPI-  ','K0PPI0  ','K0NPI+  ','K-NPI0  ',
     &  'K-PPI-  ','AKNPI-  ','PAK0    ','SI+PI0  ','SI0PI+  ',
     &  'SI+ETA  ','S+1PI0  ','S01PI+  ','NEUK-   ','LA0PI-  ',
     &  'SI-OM0  ','LA0RO-  ','SI0RO-  ','SI-RO0  ','SI-ET0  ',
     &  'SI0PI-  ','SI-0    ','BLANC   ','BLANC   ','BLANC   ',
     &  'BLANC   ','BLANC   ','BLANC   ','BLANC   ','BLANC   ',
     &  'BLANC   ','BLANC   ','BLANC   ','BLANC   ','BLANC   ',
     &  'BLANC   ','BLANC   ','BLANC   ','BLANC   ','BLANC   ',
     &  'BLANC   ','BLANC   ','BLANC   ','BLANC   ','BLANC   ',
     &  'EPI+-   ','EPI00   ','GAPI+-  ','GAGA*   ','K+-     ',
     &  'KLKS    ','PI+-0   ','EGA     ','LPI0    ','LPI     '  /
      DATA (ZKNAME(K),K=341,425) /
     &  'APPI0   ','ANPI-   ','ALAGA   ','ANPI    ','ALPI0   ',
     &  'ALPI+   ','LAPI+   ','SI+PI0  ','SI0PI+  ','LAPI0   ',
     &  'SI+PI-  ','SI-PI+  ','LAPI-   ','SI-PI0  ','SI0PI-  ',
     &  'TE0PI0  ','TE-PI+  ','TE0PI-  ','TE-PI0  ','TE0PI   ',
     &  'TE-PI   ','LAK-    ','ALPI-   ','AS-PI0  ','AS0PI-  ',
     &  'ALPI0   ','AS+PI-  ','AS-PI+  ','ALPI+   ','AS+PI0  ',
     &  'AS0PI+  ','AT0PI0  ','AT+PI-  ','AT0PI+  ','AT+PI0  ',
     &  'AT0PI   ','AT+PI   ','ALK+    ','K-PI+   ','K-PI+0  ',
     &  'K0PI+-  ','K0PI0   ','K-PI++  ','AK0PI+  ','K+PI--  ',
     &  'K0PI-   ','K+PI-   ','K+PI-0  ','AKPI-+  ','AK0PI0  ',
     &  'ETAPIF  ','K++-    ','K+AK0   ','ETAPI-  ','K--+    ',
     &  'K-K0    ','PI00    ','PI+-    ','GAGA    ','D0PI0   ',
     &  'D0GA    ','D0PI+   ','D+PI0   ','DFGA    ','AD0PI-  ',
     &  'D-PI0   ','D-GA    ','AD0PI0  ','AD0GA   ','F+GA    ',
     &  'F+GA    ','F-GA    ','F-GA    ','PSPI+-  ','PSPI00  ',
     &  'PSETA   ','E+E-    ','MUE+-   ','PI+-0   ','M+NN    ',
     &  'E+NN    ','RHO+NT  ','PI+ANT  ','K*+ANT  ','M-NN    '  /
      DATA (ZKNAME(K),K=426,510) /
     &  'E-NN    ','RHO-NT  ','PI-NT   ','K*-NT   ','NUET    ',
     &  'ANUET   ','NUEM    ','ANUEM   ','SI+ETA  ','SI+ET*  ',
     &  'PAK0    ','TET0K+  ','SI*+ET  ','N*+AK0  ','N*++K-  ',
     &  'LAMRO+  ','SI0RO+  ','SI+RO0  ','SI+OME  ','PAK*0   ',
     &  'N*+AK*  ','N*++K*  ','SI+AK0  ','TET0PI  ','SI+AK*  ',
     &  'TET0RO  ','SI0AK*  ','SI+K*-  ','TET0OM  ','TET-RO  ',
     &  'SI*0AK  ','C0+PI+  ','C0+PI0  ','C0+PI-  ','A+GAM   ',
     &  'A0GAM   ','TET0AK  ','TET0K*  ','OM-RO+  ','OM-PI+  ',
     &  'C1++AK  ','A+PI+   ','C0+AK0  ','A0PI+   ','A+AK0   ',
     &  'T0PI+   ','ASI-ET  ','ASI-E*  ','APK0    ','ATET0K  ',
     &  'ASI*-E  ','AN*-K0  ','AN*--K  ','ALAMRO  ','ASI0RO  ',
     &  'ASI-RO  ','ASI-OM  ','APK*0   ','AN*-K*  ','AN*--K  ',
     &  'ASI-K0  ','ATETPI  ','ASI-K*  ','ATETRO  ','ASI0K*  ',
     &  'ASI-K*  ','ATE0OM  ','ATE+RO  ','ASI*0K  ','AC-PI-  ',
     &  'AC-PI0  ','AC-PI+  ','AA-GAM  ','AA0GAM  ','ATET0K  ',
     &  'ATE0K*  ','AOM+RO  ','AOM+PI  ','AC1--K  ','AA-PI-  ',
     &  'AC0-K0  ','AA0PI-  ','AA-K0   ','AT0PI-  ','C1++GA  '  /
      DATA (ZKNAME(K),K=511,540) /
     &  'C1++GA  ','C10GAM  ','S+GAM   ','S0GAM   ','T0GAM   ',
     &  'XU++GA  ','XD+GAM  ','XS+GAM  ','A+AKPI  ','T02PI+  ',
     &  'C1++2K  ','AC1--G  ','AC1-GA  ','AC10GA  ','AS-GAM  ',
     &  'AS0GAM  ','AT0GAM  ','AXU--G  ','AXD-GA  ','AXS-GA  ',
     &  'AA-KPI  ','AT02PI  ','AC1--K  ','RH-PI+  ','RH+PI-  ',
     &  'RH3PI0  ','RH0PI+  ','RH+PI0  ','RH0PI-  ','RH-PI0  '  /
      DATA (ZKNAME(I),I=541,602)/
     & 'APETA ','AN=P+ ','AN-PO ','ANOPO ','APRHO0','ANRHO-','ANETA ',
     & 'AN-P+ ','AN0PO ','AN+P- ','APRHO+','ANRHO0','RH0PI+','RH+PI0',
     & '3PI+00','3PI-++','F0PI+ ','RH+PI-','RH0PI0','3PI000','3PI0+-',
     & 'F0PI0 ','RH0PI-','RH-PI0','3PI-00','3PI--+','F0PI- ','PI0PI0',
     & 'PI+PI-','K+K-  ','K0AK0 ','L01600','AL0160','K*+146','K*-146',
     & 'K*0146','AK0146','S+1660','S01660','S-1660','AS-166','AS0166',
     & 'AS+166','X01690','X-1690','AX0169','AX+169','OM-225','AOM+22',
     & 'N*PPI0','N*NPI+','N*P2P0','N*PP+-','N*D+P0','N*D0P+','N*NPI0',
     & 'N*PPI-','N*N2P0','N*NP+-','N*D+P-','N*D0P0','BLANK '/
*                                                                      *
*     Weight of decay channel                                          *
*                                                                      *
      DATA (WT(K),K=  1, 85) /
     &   .1000D+01, .1000D+01, .1000D+01, .1000D+01, .1000D+01,
     &   .1000D+01, .1000D+01, .1000D+01, .1000D+01, .1000D+01,
     &   .1000D+01, .2100D+00, .1200D+00, .2700D+00, .4000D+00,
     &   .1000D+01, .1000D+01, .6400D+00, .2100D+00, .6000D-01,
     &   .2000D-01, .3000D-01, .4000D-01, .6400D+00, .2100D+00,
     &   .6000D-01, .2000D-01, .3000D-01, .4000D-01, .6400D+00,
     &   .3600D+00, .0000D+00, .0000D+00, .6400D+00, .3600D+00,
     &   .0000D+00, .0000D+00, .6900D+00, .3100D+00, .1000D+01,
     &   .5200D+00, .4800D+00, .1000D+01, .9900D+00, .1000D-01,
     &   .3800D+00, .3000D-01, .3000D+00, .2400D+00, .5000D-01,
     &   .1000D+01, .1000D+01, .0000D+00, .1000D+01, .9000D+00,
     &   .1000D-01, .9000D-01, .3300D+00, .6700D+00, .3300D+00,
     &   .6700D+00, .3300D+00, .6700D+00, .3300D+00, .6700D+00,
     &   .3300D+00, .6700D+00, .3300D+00, .6700D+00, .3300D+00,
     &   .6700D+00, .3300D+00, .6700D+00, .1900D+00, .3800D+00,
     &   .9000D-01, .2000D+00, .3000D-01, .4000D-01, .5000D-01,
     &   .2000D-01, .1900D+00, .3800D+00, .9000D-01, .2000D+00  /
      DATA (WT(K),K= 86,170) /
     &   .3000D-01, .4000D-01, .5000D-01, .2000D-01, .1900D+00,
     &   .3800D+00, .9000D-01, .2000D+00, .3000D-01, .4000D-01,
     &   .5000D-01, .2000D-01, .1900D+00, .3800D+00, .9000D-01,
     &   .2000D+00, .3000D-01, .4000D-01, .5000D-01, .2000D-01,
     &   .8800D+00, .6000D-01, .6000D-01, .8800D+00, .6000D-01,
     &   .6000D-01, .8800D+00, .1200D+00, .1900D+00, .1900D+00,
     &   .1600D+00, .1600D+00, .1700D+00, .3000D-01, .3000D-01,
     &   .3000D-01, .4000D-01, .1000D+00, .1000D+00, .2000D+00,
     &   .1200D+00, .1000D+00, .4000D-01, .4000D-01, .5000D-01,
     &   .7500D-01, .7500D-01, .3000D-01, .3000D-01, .4000D-01,
     &   .5000D+00, .5000D+00, .5000D+00, .5000D+00, .1000D+01,
     &   .6700D+00, .3300D+00, .3300D+00, .6700D+00, .1000D+01,
     &   .2500D+00, .2700D+00, .1800D+00, .3000D+00, .1700D+00,
     &   .8000D-01, .1800D+00, .3000D-01, .2400D+00, .2000D+00,
     &   .1000D+00, .8000D-01, .1700D+00, .2400D+00, .3000D-01,
     &   .1800D+00, .1000D+00, .2000D+00, .2500D+00, .1800D+00,
     &   .2700D+00, .3000D+00, .5000D+00, .3000D+00, .1250D+00  /
C    &   .2700D+00, .3000D+00, .4000D+00, .2000D+00, .1250D+00  /
C    &   .7500D-01, .7500D-01, .1250D+00, .4000D+00, .7500D-01,
C    &   .1250D+00, .2000D+00, .1250D+00, .7500D-01, .1800D+00,
      DATA (WT(K),K=171,255) /
     &   .7500D-01, .0000D+00, .0000D+00, .5000D+00, .7500D-01,
     &   .1250D+00, .3000D+00, .0000D+00, .0000D+00, .1800D+00,
     &   .3700D+00, .1300D+00, .8000D-01, .4000D-01, .7000D-01,
     &   .1300D+00, .3700D+00, .1800D+00, .4000D-01, .8000D-01,
     &   .1300D+00, .1300D+00, .7000D-01, .7000D-01, .1300D+00,
     &   .2300D+00, .4700D+00, .5000D-01, .2000D-01, .1000D-01,
     &   .2000D-01, .1300D+00, .7000D-01, .4700D+00, .2300D+00,
     &   .5000D-01, .1000D-01, .2000D-01, .2000D-01, .1000D+01,
     &   .6700D+00, .3300D+00, .3300D+00, .6700D+00, .1000D+01,
     &   .2500D+00, .2700D+00, .1800D+00, .3000D+00, .1700D+00,
     &   .8000D-01, .1800D+00, .3000D-01, .2400D+00, .2000D+00,
     &   .1000D+00, .8000D-01, .1700D+00, .2400D+00, .3000D-01,
     &   .1800D+00, .1000D+00, .2000D+00, .2500D+00, .1800D+00,
     &   .2700D+00, .3000D+00, .1800D+00, .3700D+00, .1300D+00,
     &   .8000D-01, .4000D-01, .7000D-01, .1300D+00, .3700D+00,
     &   .1800D+00, .4000D-01, .8000D-01, .1300D+00, .1300D+00,
     &   .7000D-01, .5000D+00, .5000D+00, .1000D+01, .1000D+01  /
      DATA (WT(K),K=256,340) /
     &   .1000D+01, .8000D+00, .2000D+00, .6000D+00, .3000D+00,
     &   .1000D+00, .6000D+00, .3000D+00, .1000D+00, .8000D+00,
     &   .2000D+00, .3300D+00, .6700D+00, .6600D+00, .1700D+00,
     &   .1700D+00, .3200D+00, .1700D+00, .3200D+00, .1900D+00,
     &   .3300D+00, .3300D+00, .3400D+00, .3000D+00, .5000D-01,
     &   .6500D+00, .3800D+00, .1200D+00, .3800D+00, .1200D+00,
     &   .3800D+00, .1200D+00, .3800D+00, .1200D+00, .3000D+00,
     &   .5000D-01, .6500D+00, .3800D+00, .2500D+00, .2500D+00,
     &   .2000D-01, .5000D-01, .5000D-01, .2000D+00, .2000D+00,
     &   .1200D+00, .1000D+00, .7000D-01, .7000D-01, .1400D+00,
     &   .5000D-01, .5000D-01, .1000D+01, .1000D+01, .1000D+01,
     &   .1000D+01, .1000D+01, .1000D+01, .1000D+01, .1000D+01,
     &   .1000D+01, .1000D+01, .1000D+01, .1000D+01, .1000D+01,
     &   .1000D+01, .1000D+01, .1000D+01, .1000D+01, .1000D+01,
     &   .1000D+01, .1000D+01, .1000D+01, .1000D+01, .1000D+01,
     &   .4800D+00, .2400D+00, .2600D+00, .2000D-01, .4700D+00,
     &   .3500D+00, .1500D+00, .3000D-01, .1000D+01, .1000D+01  /
      DATA (WT(K),K=341,425) /
     &   .5200D+00, .4800D+00, .1000D+01, .1000D+01, .1000D+01,
     &   .1000D+01, .9000D+00, .5000D-01, .5000D-01, .9000D+00,
     &   .5000D-01, .5000D-01, .9000D+00, .5000D-01, .5000D-01,
     &   .3300D+00, .6700D+00, .6700D+00, .3300D+00, .2500D+00,
     &   .2500D+00, .5000D+00, .9000D+00, .5000D-01, .5000D-01,
     &   .9000D+00, .5000D-01, .5000D-01, .9000D+00, .5000D-01,
     &   .5000D-01, .3300D+00, .6700D+00, .6700D+00, .3300D+00,
     &   .2500D+00, .2500D+00, .5000D+00, .1000D+00, .5000D+00,
     &   .1600D+00, .2400D+00, .7000D+00, .3000D+00, .7000D+00,
     &   .3000D+00, .1000D+00, .5000D+00, .1600D+00, .2400D+00,
     &   .3000D+00, .4000D+00, .3000D+00, .3000D+00, .4000D+00,
     &   .3000D+00, .4900D+00, .4900D+00, .2000D-01, .5500D+00,
     &   .4500D+00, .6800D+00, .3000D+00, .2000D-01, .6800D+00,
     &   .3000D+00, .2000D-01, .5500D+00, .4500D+00, .9000D+00,
     &   .1000D+00, .9000D+00, .1000D+00, .6000D+00, .3000D+00,
     &   .1000D+00, .1000D+00, .1000D+00, .8000D+00, .2800D+00,
     &   .2800D+00, .3500D+00, .7000D-01, .2000D-01, .2800D+00  /
      DATA (WT(K),K=426,510) /
     &   .2800D+00, .3500D+00, .7000D-01, .2000D-01, .1000D+01,
     &   .1000D+01, .1000D+01, .1000D+01, .2000D-01, .3000D-01,
     &   .7000D-01, .2000D-01, .2000D-01, .4000D-01, .1300D+00,
     &   .7000D-01, .6000D-01, .6000D-01, .2000D+00, .1400D+00,
     &   .4000D-01, .1000D+00, .2500D+00, .3000D-01, .3000D+00,
     &   .4200D+00, .2200D+00, .3500D+00, .1900D+00, .1600D+00,
     &   .8000D-01, .1000D+01, .1000D+01, .1000D+01, .1000D+01,
     &   .1000D+01, .3700D+00, .2000D+00, .3600D+00, .7000D-01,
     &   .5000D+00, .5000D+00, .5000D+00, .5000D+00, .5000D+00,
     &   .5000D+00, .2000D-01, .3000D-01, .7000D-01, .2000D-01,
     &   .2000D-01, .4000D-01, .1300D+00, .7000D-01, .6000D-01,
     &   .6000D-01, .2000D+00, .1400D+00, .4000D-01, .1000D+00,
     &   .2500D+00, .3000D-01, .3000D+00, .4200D+00, .2200D+00,
     &   .3500D+00, .1900D+00, .1600D+00, .8000D-01, .1000D+01,
     &   .1000D+01, .1000D+01, .1000D+01, .1000D+01, .3700D+00,
     &   .2000D+00, .3600D+00, .7000D-01, .5000D+00, .5000D+00,
     &   .5000D+00, .5000D+00, .5000D+00, .5000D+00, .1000D+01  /
      DATA (WT(K),K=511,540) /
     &   .1000D+01, .1000D+01, .1000D+01, .1000D+01, .1000D+01,
     &   .1000D+01, .1000D+01, .1000D+01, .3000D+00, .3000D+00,
     &   .4000D+00, .1000D+01, .1000D+01, .1000D+01, .1000D+01,
     &   .1000D+01, .1000D+01, .1000D+01, .1000D+01, .1000D+01,
     &   .3000D+00, .3000D+00, .4000D+00, .3300D+00, .3300D+00,
     &   .3400D+00, .5000D+00, .5000D+00, .5000D+00, .5000D+00  /
C
      DATA (WT(I),I=541,602) / .0D+00, .3334D+00, .2083D+00, 2*.125D+00,
     & .2083D+00, .0D+00, .125D+00, .2083D+00, .3334D+00, .2083D+00,
     & .125D+00,  0.2D+00, 0.2D+00, 0.3D+00, 0.3D+00, 0.0D+00, 0.2D+00,
     & 0.2D+00, 0.3D+00, 0.3D+00, 0.0D+00, 0.2D+00, 0.2D+00, 0.3D+00,
     & 0.3D+00, 0.0D+00, 0.31D+00, 0.62D+00, 0.035D+00, 0.035D+00,
     & 18*1.D+00, 0.5D+00, 0.16D+00, 2*0.12D+00, 2*0.05D+00, 0.5D+00,
     & 0.16D+00, 2*0.12D+00, 2*0.05D+00, 1.D+00 /
*
*     Particle numbers in decay channel                                *
*                                                                      *
      DATA (NZK(K,1),K=  1,170) /
     &     1,   2,   3,   4,   5,   6,   7,   1,   2,   4,
     &     3,  23,  13,  13,  13,  10,  11,  10,  13,  13,
     &    13,  10,   4,  11,  14,  14,  14,  11,   3,   1,
     &     8,   1,   1,   2,   9,   2,   2,  13,  23,   8,
     &     1,   8,  17,   7,   7,   7,  23,  23,  13,  13,
     &    13,  13,  23,  14,  13,  13,  23,  15,  24,  24,
     &    15,  16,  25,  25,  16,  15,  24,  24,  15,  16,
     &    24,  25,  16,  15,  24,  36,  37,  15,  24,  15,
     &    15,  24,  15,  37,  36,  24,  15,  24,  24,  16,
     &    24,  38,  39,  16,  25,  16,  16,  25,  16,  39,
     &    38,  25,  16,  25,  25,  17,  22,  21,  17,  21,
     &    20,  17,  22,   8,   1,  21,  22,  20,  17,  48,
     &    50,  49,   8,   1,  17,  17,  17,  21,  20,  22,
     &    17,  22,  21,  20,  22,  19,  12,  19,  12,   1,
     &     1,   8,   1,   8,   8,   1,  53,  54,   1,   1,
     &     8,  53,  54,  55,   1,   8,   1,   8,  54,  55,
     &    56,   1,   8,   8,  55,  56,   8,   1,  53,  54  /
      DATA (NZK(K,1),K=171,340) /
     &    55,   1,   8,   8,  54,  55,  56,   1,   8,   1,
     &     8,  53,  54,  55,   1,   8,   1,   8,  54,  55,
     &    56,   1,   8,   1,   8,   1,   8,  17,  21,  22,
     &     1,   1,   8,   1,   8,  17,  22,  20,   8,   2,
     &     2,   9,   2,   9,   9,   2,  67,  68,   2,   2,
     &     9,  67,  68,  69,   2,   9,   2,   9,  68,  69,
     &    70,   2,   9,   9,  69,  70,   9,   2,   9,  67,
     &    68,  69,   2,   9,   2,   9,  68,  69,  70,   2,
     &     9,   1,   8,  13,  13,  14,   1,   8,   1,   1,
     &     8,   8,   8,   1,   8,   1,   1,   1,   1,   1,
     &     8,   2,   2,   9,   9,   2,   2,   9,  15,  15,
     &    24,  16,  16,  25,  25,  15,  15,  24,  24,  16,
     &    16,  25,   1,  21,  22,  21,  48,  49,   8,  17,
     &    20,  17,  22,  20,  20,  22,  20,   0,   0,   0,
     &     0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
     &     0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
     &    31,  31,  13,   7,  15,  12,  13,  31,  17,  17  /
      DATA (NZK(K,1),K=341,510) /
     &     2,   9,  18,   9,  18,  18,  17,  21,  22,  17,
     &    21,  20,  17,  20,  22,  97,  98,  97,  98,  97,
     &    98,  17,  18,  99, 100,  18, 101,  99,  18, 101,
     &   100, 102, 103, 102, 103, 102, 103,  18,  16,  16,
     &    24,  24,  16,  25,  15,  24,  15,  15,  25,  25,
     &    31,  15,  15,  31,  16,  16,  23,  13,   7, 116,
     &   116, 116, 117, 117, 119, 118, 118, 119, 119, 120,
     &   120, 121, 121, 130, 130, 130,   4,  10,  13,  10,
     &     4,  32,  13,  36,  11,   3,  34,  14,  38, 133,
     &   134, 135, 136,  21,  21,   1,  97, 104,  54,  53,
     &    17,  22,  21,  21,   1,  54,  53,  21,  97,  21,
     &    97,  22,  21,  97,  98, 105, 137, 137, 137, 138,
     &   139,  97,  97, 109, 109, 140, 138, 137, 139, 138,
     &   145,  99,  99,   2, 102, 110,  68,  67,  18, 100,
     &    99,  99,   2,  68,  67,  99, 102,  99, 102, 100,
     &    99, 102, 103, 111, 149, 149, 149, 150, 151, 113,
     &   113, 115, 115, 152, 150, 149, 151, 150, 157, 140  /
      DATA (NZK(K,1),K=511,540) /
     &   141, 142, 143, 144, 145, 146, 147, 148, 138, 145,
     &   140, 152, 153, 154, 155, 156, 157, 158, 159, 160,
     &   150, 157, 152,  34,  32,  33,  33,  32,  33,  34  /
      DATA (NZK(I,1),I=541,602) /  2, 67, 68, 69,  2,  9,  9, 68, 69,
     & 70,  2,  9, 33, 32, 13, 14, 189, 32, 34, 23, 23, 189, 33, 34, 14,
     & 14, 189, 23, 13, 15, 24,  36,  38,  37,  39, 194, 195, 196, 197,
     & 198, 199, 200, 201, 202, 203, 204, 205, 206, 207, 1, 8, 1, 1, 54,
     & 55, 8, 1, 8, 8, 54, 55, 210/
      DATA (NZK(K,2),K=  1,170) /
     &     0,   0,   0,   0,   0,   0,   0,   3,   4,   6,
     &     5,  23,  14,  11,   3,   5,   5,   5,  23,  13,
     &    23,  23,  23,   5,  23,  13,  23,  23,  23,  14,
     &    23,   3,  11,  13,  23,   4,  10,  14,  23,  14,
     &    23,  13,   7,   7,   4,   7,   7,  23,  14,  14,
     &    23,  14,  23,  23,  14,  14,   7,  23,  13,  23,
     &    14,  23,  14,  23,  13,  23,  13,  23,  14,  23,
     &    14,  23,  13,  23,  13,  23,  13,  33,  32,  35,
     &    31,  23,  14,  23,  14,  33,  34,  35,  31,  23,
     &    14,  23,  14,  33,  34,  35,  31,  23,  13,  23,
     &    13,  33,  32,  35,  31,  13,  13,  23,  23,  14,
     &    13,  14,  14,  25,  16,  14,  23,  13,  31,  14,
     &    13,  23,  25,  16,  23,  35,  33,  34,  32,  33,
     &    31,  31,  14,  13,  23,   0,   0,   0,   0,  13,
     &    23,  13,  14,  23,  14,  13,  23,  13,  78,  23,
     &    13,  14,  23,  13,  79,  78,  14,  23,  14,  23,
     &    13,  80,  79,  14,  14,  23,  80,  31,  14,  23  /
      DATA (NZK(K,2),K=171,340) /
     &    13,  79,  78,  31,  14,  23,  13,  80,  79,  23,
     &    13,  14,  23,  13,  79,  78,  14,  23,  14,  23,
     &    13,  80,  79,  23,  13,  33,  32,  15,  24,  15,
     &    31,  14,  23,  34,  33,  24,  24,  15,  31,  14,
     &    23,  14,  13,  23,  13,  14,  23,  14,  80,  23,
     &    14,  13,  23,  14,  79,  80,  13,  23,  13,  23,
     &    14,  78,  79,  13,  13,  23,  78,  23,  14,  13,
     &    23,  14,  79,  80,  13,  23,  13,  23,  14,  78,
     &    79,  62,  61,  23,  14,  23,  13,  13,  13,  23,
     &    13,  13,  23,  14,  14,  14,   1,   8,   8,   1,
     &     8,   1,   8,   8,   1,   8,   1,   8,   1,   8,
     &     1,   1,   8,   1,   8,   8,   1,   1,   8,   8,
     &     1,   8,  25,  23,  13,  31,  23,  13,  16,  14,
     &    35,  34,  34,  33,  31,  14,  23,   0,   0,   0,
     &     0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
     &     0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
     &    13,  23,  14,   7,  16,  19,  14,   7,  23,  14  /
      DATA (NZK(K,2),K=341,510) /
     &    23,  14,   7,  13,  23,  13,  13,  23,  13,  23,
     &    14,  13,  14,  23,  14,  23,  13,  14,  23,  14,
     &    23,  16,  14,  23,  14,  23,  14,  13,  13,  23,
     &    13,  23,  14,  13,  23,  13,  23,  15,  13,  13,
     &    13,  23,  13,  13,  14,  14,  14,  14,  14,  23,
     &    13,  16,  25,  14,  15,  24,  23,  14,   7,  23,
     &     7,  13,  23,   7,  14,  23,   7,  23,   7,   7,
     &     7,   7,   7,  13,  23,  31,   3,  11,  14, 135,
     &     5, 134, 134, 134, 136,   6, 133, 133, 133,   0,
     &     0,   0,   0,  31,  95,  25,  15,  31,  95,  16,
     &    32,  32,  33,  35,  39,  39,  38,  25,  13,  39,
     &    32,  39,  38,  35,  32,  39,  13,  23,  14,   7,
     &     7,  25,  37,  32,  13,  25,  13,  25,  13,  25,
     &    13,  31,  95,  24,  16,  31,  24,  15,  34,  34,
     &    33,  35,  37,  37,  36,  24,  14,  37,  34,  37,
     &    36,  35,  34,  37,  14,  23,  13,   7,   7,  24,
     &    39,  34,  14,  24,  14,  24,  14,  24,  14,   7  /
      DATA (NZK(K,2),K=511,540) /
     &     7,   7,   7,   7,   7,   7,   7,   7,  25,  13,
     &    25,   7,   7,   7,   7,   7,   7,   7,   7,   7,
     &    24,  14,  24,  13,  14,  23,  13,  23,  14,  23  /
      DATA (NZK(I,2),I=541,602) / 31, 13, 23, 14, 79, 80, 31, 13, 23,
     & 14, 78, 79, 13, 23, 23, 13, 13, 14, 13, 23, 13, 23, 14, 23, 23,
     & 14, 14, 23, 14, 16, 25,
     & 4*23, 14*0, 23, 13, 23, 13, 23, 13, 23, 14,
     & 23, 13, 14, 23,  0 /
      DATA (NZK(K,3),K=  1,170) /
     &     0,   0,   0,   0,   0,   0,   0,   5,   6,   5,
     &     6,  23,  23,   5,   5,   0,   0,   0,   0,  14,
     &    23,   5,   5,   0,   0,  14,  23,   5,   5,   0,
     &     0,   5,   5,   0,   0,   5,   5,   0,   0,   0,
     &     0,   0,   0,   0,   3,   0,   7,  23,  23,   7,
     &     0,   0,   0,   0,  23,   0,   0,   0,   0,   0,
     &     110*0   /
      DATA (NZK(K,3),K=171,340) /
     &     80*0,
     &     0,   0,   0,   0,   0,   0,  23,  13,  14,  23,
     &    23,  14,  23,  23,  23,  14,  23,  13,  23,  14,
     &    13,  23,  13,  23,  14,  23,  14,  14,  23,  13,
     &    13,  23,  13,  14,  23,  23,  14,  23,  13,  23,
     &    14,  14,   0,   0,   0,   0,   0,   0,   0,   0,
     &     30*0,
     &    14,  23,   7,   0,   0,   0,  23,   0,   0,   0  /
      DATA (NZK(K,3),K=341,510) /
     &     30*0,
     &     0,   0,   0,   0,   0,   0,   0,   0,   0,  23,
     &    14,   0,  13,   0,  14,   0,   0,  23,  13,   0,
     &     0,  15,   0,   0,  16,   0,   0,   0,   0,   0,
     &     0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
     &     0,   0,   0,  14,  23,   0,   0,   0,  23, 134,
     &   134,   0,   0,   0, 133, 133,   0,   0,   0,   0,
     &     80*0  /
      DATA (NZK(K,3),K=511,540) /
     &     0,   0,   0,   0,   0,   0,   0,   0,  13,  13,
     &    25,   0,   0,   0,   0,   0,   0,   0,   0,   0,
     &    14,  14,  24,   0,   0,   0,   0,   0,   0,   0  /
      DATA (NZK(I,3),I=541,602) / 12*0, 2*0, 23, 13, 0, 2*0, 23, 14, 0,
     & 2*0, 23, 13, 0, 4*0, 18*0, 2*0, 23, 14, 2*0, 2*0, 23, 14, 2*0, 0/
*=                                               end.block.blkdt7      *
*                                                                      *
      END
 
*
*===xsglau=============================================================*
*
      SUBROUTINE XSGLAU(NA,NB,IJPROJ,NTARG)

************************************************************************
* Total, elastic, quasi-elastic, inelastic cross sections according to *
* Glauber's approach.                                                  *
*  NA / NB     mass numbers of proj./target nuclei                     *
*  IJPROJ      bamjet-index of projectile (=1 in case of proj.nucleus) *
*  ECMI kinematical variables   E_cm                      *
*  IE       indices of energy 
*  NTARG       index of target nucleus set o NTARG=1 here             *
* This version dated 17.3.98  is written by S. Roesler mod by J.R.    *
************************************************************************

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      PARAMETER (LOUT=6,LLOOK=9)

      COMPLEX*16 CZERO,CONE,CTWO
      PARAMETER (ZERO=0.0D0,ONE=1.0D0,TWO=2.0D0,THREE=3.0D0,
     &           ONETHI=ONE/THREE,TINY25=1.0D-25)
      PARAMETER (TWOPI  = 6.283185307179586454D+00,
     &           PI     = TWOPI/TWO,
     &           GEV2MB = 0.38938D0,
     &           GEV2FM = 0.1972D0,
     &           ALPHEM = ONE/137.0D0,
* proton mass
     &           AMP    = 0.938D0,
     &           AMP2   = AMP**2,
* approx. nucleon radius
     &           RNUCLE = 1.12D0,
* number of bins in b-space
     &           KSITEB = 200    )

      CHARACTER*8  ANAME
      COMMON /DPAR/  ANAME(210),AAM(210),GAM(210),TAU(210),IICH(210),
     &               IIBAR(210),KA1(210),KA2(210)

      PARAMETER (NCOMPX=1,NEB=50) 
      COMMON /DSHMM/   RASH,RBSH(NCOMPX),BMAX(NCOMPX),BSTEP(NCOMPX),
     &                SIGSH,ROSH,GSH,BSITE(0:NEB,NCOMPX,KSITEB),
     &                NSTATB,NSITEB
      COMMON /GLABER/ ECMNN(NEB),ECMNOW,
     &                XSTOT(NEB),XSELA(NEB),
     &                XSQEP(NEB),XSQET(NEB),
     &                XSQE2(NEB),XSPRO(NEB),
     &                XETOT(NEB),XEELA(NEB),
     &                XEQEP(NEB),XEQET(NEB),
     &                XEQE2(NEB),XEPRO(NEB),
     &                BSLOPE,ELABB(NEB)

      COMMON /VDMPAR/ RL2,EPSPOL,INTRGE(2),IDPDF,MODEGA,ISHAD(3)
      COMMON /GLAPAR/ JSTATB

      COMPLEX*16 C,CA,CI
      COMMON /DAMP/   CA,CI,GA
      COMMON /XSECNU/ECMUU,ECMOO,NGRITT,NEVTT
      COMMON /KGLAUB/JGLAUB

      PARAMETER (MAXNCL = 210)
      COMPLEX*16 PP11,PP12,PP21,PP22,
     &           OMPP11,OMPP12,OMPP21,OMPP22
      DIMENSION COOP1(3,MAXNCL),COOT1(3,MAXNCL),
     &          COOP2(3,MAXNCL),COOT2(3,MAXNCL),
     &          BPROD(KSITEB),SIGSHH(NEB),
     &          SIGTO(NEB),SIGEL(NEB),SIGIN(NEB),SIGSD(NEB),SIGDIF(NEB)

      JGLAUB=1
      Write(6,*)' XSGLAU(NA,NB,IJPROJ,NTARG)',
     &NA,NB,IJPROJ,NTARG
      WRITE(6,*)'/XSECNU/ECMUU,ECMOO,NGRITT,NEVTT',
     &ECMUU,ECMOO,NGRITT,NEVTT 

      CZERO  = DCMPLX(ZERO,ZERO)
      CONE   = DCMPLX(ONE,ZERO)
      CTWO   = DCMPLX(TWO,ZERO)

* re-define kinematics
      EC000=ECMUU
      DELLOG=(LOG10(ECMOO)-LOG10(ECMUU))/(NGRITT-1)
      DELDEL=10.D0**DELLOG
      EC111=ECMUU/DELDEL
      DO 1123 IEEE=1,NGRITT
      IE=IEEE
      EC111=DELDEL*EC111
      S=EC111**2
      ECMNN(IE) = EC111
      WRITE(6,*)'IE,EC111,S',IE,EC111,S

* parameters determining statistics in evaluating Glauber-xsection
      JSTATB=NEVTT
      NSTATB = JSTATB
      NSITEB = KSITEB

* set up interaction geometry (common /DSHM/)
*  projectile/target radii
         RASH = RNUCLE*DBLE(NA)**ONETHI
      RBSH(NTARG) = RNUCLE*DBLE(NB)**ONETHI
      IF(JGLAUB.EQ.1)THEN
        IF(NA.EQ.9)RASH=2.52D0
        IF(NA.EQ.10)RASH=2.45D0
        IF(NA.EQ.11)RASH=2.37D0
        IF(NA.EQ.12)RASH=2.45D0
        IF(NA.EQ.13)RASH=2.44D0
        IF(NA.EQ.14)RASH=2.55D0
        IF(NA.EQ.15)RASH=2.58D0
        IF(NA.EQ.16)RASH=2.71D0
        IF(NA.EQ.17)RASH=2.66D0
        IF(NA.EQ.18)RASH=2.71D0
        IF(NB.EQ.9)RBSH(NTARG)=2.52D0
        IF(NB.EQ.10)RBSH(NTARG)=2.45D0
        IF(NB.EQ.11)RBSH(NTARG)=2.37D0
        IF(NB.EQ.12)RBSH(NTARG)=2.45D0
        IF(NB.EQ.13)RBSH(NTARG)=2.44D0
        IF(NB.EQ.14)RBSH(NTARG)=2.55D0
        IF(NB.EQ.15)RBSH(NTARG)=2.58D0
	IF(NB.EQ.16)RBSH(NTARG)=2.71D0
        IF(NB.EQ.17)RBSH(NTARG)=2.66D0
        IF(NB.EQ.18)RBSH(NTARG)=2.71D0
       ENDIF
*  maximum impact-parameter
      BMAX(NTARG) = 4.0D0*(RASH+RBSH(NTARG))
      BSTEP(NTARG)= BMAX(NTARG)/DBLE(NSITEB-1)

* slope, rho ( Re(f(0))/Im(f(0)) )
      IF (IJPROJ.LE.12) THEN
            BSLOPE = 8.5D0*(1.0D0+0.065D0*LOG(S))
         IF (ECMNN(IE).LE.3.0D0) THEN
            ROSH = -0.43D0
         ELSEIF ((ECMNN(IE).GT.3.0D0).AND.(ECMNN(IE).LE.50.D0)) THEN
            ROSH = -0.63D0+0.175D0*LOG(ECMNN(IE))
         ELSEIF (ECMNN(IE).GT.50.0D0) THEN
            ROSH = 0.1D0
         ENDIF
      ELSE
         BSLOPE = 6.0D0*(1.0D0+0.065D0*LOG(S))
         ROSH   = 0.01D0
      ENDIF

* projectile-nucleon xsection (in fm)
         ELAB  = (S-AAM(IJPROJ)**2-AMP2)/(TWO*AMP)
	 ELABB(IE)=ELAB/1000.
         PLAB  = SQRT( (ELAB-AAM(IJPROJ))*(ELAB+AAM(IJPROJ)) )
C        SIGSH = SHNTOT(IJPROJ,1,ZERO,PLAB)/10.0D0
         SIGSH = DSHPTO(IJPROJ,PLAB)/10.D0
	 SIGSHH(IE)=SIGSH*10.D0
      WRITE(6,*)' NSTATB,NSITEB,RASH,RBSH(NTARG),BMAX(NTARG),
     &BSLOPE,ROSH,SIGSH,ECM ELAB',
     & NSTATB,NSITEB,RASH,RBSH(NTARG),BMAX(NTARG),
     &BSLOPE,ROSH,SIGSH,EC111,ELAB 
* initializations
      DO 10 I=1,NSITEB
         BSITE( 0,NTARG,I) = ZERO
         BSITE(IE,NTARG,I) = ZERO
         BPROD(I) = ZERO
   10 CONTINUE
      STOT  = ZERO
      STOT2 = ZERO
      SELA  = ZERO
      SELA2 = ZERO
      SQEP  = ZERO
      SQEP2 = ZERO
      SQET  = ZERO
      SQET2 = ZERO
      SQE2  = ZERO
      SQE22 = ZERO
      SPRO  = ZERO
      SPRO2 = ZERO
      FACN   = ONE/DBLE(NSTATB)

      IPNT = 0
      RPNT = ZERO

C------------------------------------------------------

* cross sections averaged over NSTATB nucleon configurations
      DO 11 IS=1,NSTATB
         STOTN = ZERO
         SELAN = ZERO
         SQEPN = ZERO
         SQETN = ZERO
         SQE2N = ZERO
         SPRON = ZERO
         CALL CONUCLX(COOP1,NA,RASH,0)
         CALL CONUCLX(COOT1,NB,RBSH(NTARG),1)
         CALL CONUCLX(COOP2,NA,RASH,0)
         CALL CONUCLX(COOT2,NB,RBSH(NTARG),1)

*  integration over impact parameter B
         DO 12 IB=1,NSITEB-1
            STOTB = ZERO
            SELAB = ZERO
            SQEPB = ZERO
            SQETB = ZERO
            SQE2B = ZERO
            SPROB = ZERO
            SDIR  = ZERO
            B     = DBLE(IB)*BSTEP(NTARG)
            FACB  = 10.0D0*TWOPI*B*BSTEP(NTARG)

*   integration over M_V^2 for photon-proj.
C           DO 14 IM=1,JPOINT
               PP11 = CONE
               PP12 = CONE
               PP21 = CONE
               PP22 = CONE
               SHI  = ZERO
               FACM = ONE
               DCOH = 1.0D10

C------------------------------------------------------------

               GSH = 10.0D0/(TWO*BSLOPE*GEV2MB)
*    common /DAMP/
               GA  = GSH
               RCA = GA*SIGSH/TWOPI
               FCA = -ROSH*RCA
               CA  = DCMPLX(RCA,FCA)
               CI  = CONE

               DO 15 INA=1,NA
                  KK1  = 1
                  KK2  = 1
                  DO 16 INB=1,NB

                     X11 = B+COOT1(1,INB)-COOP1(1,INA)
                     Y11 =   COOT1(2,INB)-COOP1(2,INA)
                     XY11 = GA*(X11*X11+Y11*Y11)
                     X12 = B+COOT2(1,INB)-COOP1(1,INA)
                     Y12 =   COOT2(2,INB)-COOP1(2,INA)
                     XY12 = GA*(X12*X12+Y12*Y12)
                     X21 = B+COOT1(1,INB)-COOP2(1,INA)
                     Y21 =   COOT1(2,INB)-COOP2(2,INA)
                     XY21 = GA*(X21*X21+Y21*Y21)
                     X22 = B+COOT2(1,INB)-COOP2(1,INA)
                     Y22 =   COOT2(2,INB)-COOP2(2,INA)
                     XY22 = GA*(X22*X22+Y22*Y22)
                     IF (XY11.LE.15.0D0) THEN
                        C = CONE-CA*EXP(-XY11)
                        AR = DBLE(PP11)
                        AI = DIMAG(PP11)
                        IF (ABS(AR).LT.TINY25) AR = ZERO
                        IF (ABS(AI).LT.TINY25) AI = ZERO
                        PP11 = DCMPLX(AR,AI)
                        PP11 = PP11*C
                        AR  = DBLE(C)
                        AI  = DIMAG(C)
                        SHI = SHI+LOG(AR*AR+AI*AI)
                     ENDIF
                     IF (XY12.LE.15.0D0) THEN
                        C = CONE-CA*EXP(-XY12)
                        AR = DBLE(PP12)
                        AI = DIMAG(PP12)
                        IF (ABS(AR).LT.TINY25) AR = ZERO
                        IF (ABS(AI).LT.TINY25) AI = ZERO
                        PP12 = DCMPLX(AR,AI)
                        PP12 = PP12*C
                     ENDIF
                     IF (XY21.LE.15.0D0) THEN
                        C = CONE-CA*EXP(-XY21)
                        AR = DBLE(PP21)
                        AI = DIMAG(PP21)
                        IF (ABS(AR).LT.TINY25) AR = ZERO
                        IF (ABS(AI).LT.TINY25) AI = ZERO
                        PP21 = DCMPLX(AR,AI)
                        PP21 = PP21*C
                     ENDIF
                     IF (XY22.LE.15.0D0) THEN
                        C = CONE-CA*EXP(-XY22)
                        AR = DBLE(PP22)
                        AI = DIMAG(PP22)
                        IF (ABS(AR).LT.TINY25) AR = ZERO
                        IF (ABS(AI).LT.TINY25) AI = ZERO
                        PP22 = DCMPLX(AR,AI)
                        PP22 = PP22*C
                     ENDIF
   16             CONTINUE
   15          CONTINUE

               OMPP11 = CZERO
               OMPP21 = CZERO
               OMPP11 = OMPP11+(CONE-PP11)
               OMPP21 = OMPP21+(CONE-PP21)
               OMPP12 = CZERO
               OMPP22 = CZERO
               OMPP12 = OMPP12+(CONE-PP12)
               OMPP22 = OMPP22+(CONE-PP22)

               STOTM = DBLE(OMPP11+OMPP22)
               SELAM = DBLE(OMPP11*DCONJG(OMPP22))
               SPROM = ONE-EXP(SHI)
               SQEPM = DBLE(OMPP11*DCONJG(OMPP21))-SELAM
               SQETM = DBLE(OMPP11*DCONJG(OMPP12))-SELAM
               SQE2M = DBLE(OMPP11*DCONJG(OMPP11))-SELAM-SQEPM-SQETM

               STOTB = STOTB+FACM*STOTM
               SELAB = SELAB+FACM*SELAM
               IF (NB.GT.1) SQEPB = SQEPB+FACM*SQEPM
               IF (NA.GT.1) SQETB = SQETB+FACM*SQETM
               IF ((NA.GT.1).AND.(NB.GT.1)) SQE2B = SQE2B+FACM*SQE2M
               SPROB = SPROB+FACM*SPROM

C  14       CONTINUE

            STOTN = STOTN+FACB*STOTB
            SELAN = SELAN+FACB*SELAB
            SQEPN = SQEPN+FACB*SQEPB
            SQETN = SQETN+FACB*SQETB
            SQE2N = SQE2N+FACB*SQE2B
            SPRON = SPRON+FACB*SPROB
            BPROD(IB+1)= BPROD(IB+1)+FACN*FACB*SPROB

   12    CONTINUE

         STOT  = STOT +FACN*STOTN
         STOT2 = STOT2+FACN*STOTN**2
         SELA  = SELA +FACN*SELAN
         SELA2 = SELA2+FACN*SELAN**2
         SQEP  = SQEP +FACN*SQEPN
         SQEP2 = SQEP2+FACN*SQEPN**2
         SQET  = SQET +FACN*SQETN
         SQET2 = SQET2+FACN*SQETN**2
         SQE2  = SQE2 +FACN*SQE2N
         SQE22 = SQE22+FACN*SQE2N**2
         SPRO  = SPRO +FACN*SPRON
         SPRO2 = SPRO2+FACN*SPRON**2

   11 CONTINUE

* final cross sections
* 1) total
      XSTOT(IE) = STOT
* 2) elastic
      XSELA(IE) = SELA
* 3) quasi-el.: A+B-->A+X (excluding 2)
      XSQEP(IE) = SQEP
* 4) quasi-el.: A+B-->X+B (excluding 2)
      XSQET(IE) = SQET
* 5) quasi-el.: A+B-->X (excluding 2-4)
      XSQE2(IE) = SQE2
* 6) production (= STOT-SELA-SQEP-SQET-SQE2!)
      XSPRO(IE) = SPRO
      WRITE(6,*)' STOT,SELA ,SQEP,SQET,SQE2,SPRO ',
     & STOT,SELA ,SQEP,SQET,SQE2,SPRO
*  stat. errors
      XETOT(IE) = SQRT(ABS(STOT2-STOT**2)/DBLE(NSTATB-1))
      XEELA(IE) = SQRT(ABS(SELA2-SELA**2)/DBLE(NSTATB-1))
      XEQEP(IE) = SQRT(ABS(SQEP2-SQEP**2)/DBLE(NSTATB-1))
      XEQET(IE) = SQRT(ABS(SQET2-SQET**2)/DBLE(NSTATB-1))
      XEQE2(IE) = SQRT(ABS(SQE22-SQE2**2)/DBLE(NSTATB-1))
      XEPRO(IE) = SQRT(ABS(SPRO2-SPRO**2)/DBLE(NSTATB-1))
      WRITE(6,*)' XETOT,XEELA,XEQEP,XEQET,XEQE2,XEPRO ',
     & XETOT(IE),XEELA(IE),XEQEP(IE),
     &XEQET(IE),XEQE2(IE),XEPRO(IE)
1123  CONTINUE
      DO 19 I=2,NSITEB
         BSITE(IE,NTARG,I) = BPROD(I)/SPRO+BSITE(IE,NTARG,I-1)
         IF (IE.EQ.1)
     &      BSITE(0,NTARG,I) = BPROD(I)/SPRO+BSITE(0,NTARG,I-1)
   19 CONTINUE
      WRITE (6,*)' ECMNN,ELABB,SIGSHH,SIGTO,SIGEL,SIGIN,SIGSD'
C    &          SIGTO(NEB),SIGEL(NEB),SIGIN(NEB),SIGSD(NEB),SIGDIF(NEB)
      DO 129 I=1,NGRITT
        SIGTO(I)=DSHNTO(1,1,ECMNN(I))
        SIGEL(I)=DSHNEL(1,1,ECMNN(I))
        SIGIN(I)=SIINEL(1,1,ECMNN(I))
        SIGSD(I)=SIPPSD(ECMNN(I))
	CALL SIHNDI(ECMNN(I),1,1,SIGDIF(I),SIGDIH)
        WRITE (6,'(2F18.4,6F11.3)')ECMNN(I),ELABB(I),SIGSHH(I),
     &  SIGTO(I),SIGEL(I),SIGIN(I),SIGSD(I),SIGDIF(I) 
 129  CONTINUE      
      WRITE (6,*)' ECMNN,ELABB,XSQEP,XEQEP,XSQET,XEQET,XSQE2,XEQE2'
      DO 139 I=1,NGRITT
      WRITE (6,'(2F18.4,6F11.3)')ECMNN(I),ELABB(I),XSQEP(I),XEQEP(I),
     * XSQET(I),XEQET(I),XSQE2(I),XEQE2(I)
 139  CONTINUE      
      WRITE (6,*)' ECMNN,ELABB,XSTOT,XETOT,XSELA,XEELA,XSPRO,XEPRO'
      DO 119 I=1,NGRITT
      WRITE (6,'(2F18.4,6F11.3)')ECMNN(I),ELABB(I),XSTOT(I),XETOT(I),
     * XSELA(I),XEELA(I),XSPRO(I),XEPRO(I)
 119  CONTINUE      

      RETURN
      END


      SUBROUTINE CONUCLX(COOP1,NA,RASH,I)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      PARAMETER (MAXNCL = 210)
      DIMENSION COOP1(3,MAXNCL)
      CALL CONUCL(COOP1,NA,RASH)
      RETURN
      END
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE DBKLAS(I,J,K,I8,I10)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
C*** I,J,K QUARK FLAVOURS U,D,S,C=1,2,3,4
C*** AQ = -Q
C*** I8,I10 BARYON INDICES
*KEEP,DINPDA.
      COMMON /DINPDA/ IMPS(6,6),IMVE(6,6),IB08(6,21),IB10(6,21), IA08
     +(6,21),IA10(6,21), A1,B1,B2,B3,LT,LE,BET,AS,B8,AME,DIQ,ISU
*KEND.
      IF (I) 20,20,10
C*** BARYON
   10 CONTINUE
      CALL INDEXD(J,K,IND)
      I8=IB08(I,IND)
      I10=IB10(I,IND)
      IF (I8.LE.0) I8=I10
      RETURN
   20 CONTINUE
C*** ANTIBARYONS
      II=IABS(I)
      JJ=IABS(J)
      KK=IABS(K)
      CALL INDEXD(JJ,KK,IND)
      I8=IA08(II,IND)
      I10=IA10(II,IND)
      IF (I8.LE.0) I8=I10
      RETURN
      END
C-----------------------------------------------------------

      DOUBLE PRECISION FUNCTION SIPPSD(ECM)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C     Single Diffraction cross section in p-p collision
C     Tables calculated with DPMJET-II.4.2
      DIMENSION EC(30),SD(30)
      DATA EC /0.D0, 5.D0, 20.D0, 50.D0, 100.D0,
     *       200.D0, 500.D0, 1000.D0, 1500.D0, 2000.D0,
     *      3000.D0, 4000.D0, 6000.D0, 8000.D0, 10000.D0,
     *     15000.D0, 20000.D0, 30000.D0, 40000.D0, 60000.D0, 
     *     80000.D0, 100000.D0, 150000.D0, 200000.D0, 300000.D0,
     *    400000.D0, 600000.D0, 800000.D0, 1000000.D0, 2000000.D0/
      DATA SD /0.D0, 0.D0, 5.00D0, 6.14D0, 6.93D0,
     *       7.64D0, 8.43D0, 8.87D0, 9.07D0, 9.17D0,
     *       9.33D0, 9.40D0, 9.49D0, 9.56D0, 9.58D0,
     *       9.69D0, 9.72D0, 9.82D0, 9.85D0, 9.97D0,
     *      10.02D0, 10.03D0, 10.13D0, 10.16D0, 10.25D0,
     *      10.28D0, 10.39D0, 10.42D0, 10.43D0, 10.53D0/
      II=1
      DO 1 I=1,30
        IF((ECM.GE.EC(I)).AND.(ECM.LT.EC(I+1)))THEN
          II=I
          DEL=(ECM-EC(I))*(SD(I+1)-SD(I))/(EC(I+1)-EC(I))
          SIPPSD=SD(I)+DEL
          RETURN
        ENDIF
 1    CONTINUE  
      SIPPSD=0.D0
      RETURN
      END
      DOUBLE PRECISION FUNCTION SIINEL(KPROJ,KTARG,UMO)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C     Inelastic cross section
      SIINEL=DSHNTO(KPROJ,KTARG,UMO)-DSHNEL(KPROJ,KTARG,UMO)
      RETURN
      END
C---------------------------------------------------------------
C                 was dpmsicha.f
C---------------------------------------------------------------
*$ CREATE PHNSCH.FOR
*COPY PHNSCH
*
*=== phnsch ===========================================================*
*
      DOUBLE PRECISION FUNCTION PHNSCH ( KP, KTARG, PLAB )

C      INCLUDE '(DBLPRC)'
C      INCLUDE '(DIMPAR)'
C      INCLUDE '(IOUNIT)'
*
*----------------------------------------------------------------------*
*                                                                      *
*     Probability for Hadron Nucleon Single CHain interactions:        *
*                                                                      *
*     Created on 30 december 1993  by    Alfredo Ferrari & Paola Sala  *
*                                                   Infn - Milan       *
*                                                                      *
*     Last change on 04-jan-94     by    Alfredo Ferrari               *
*                                                                      *
*             modified by J.R.for use in DTUNUC  6.1.94                *
*                                                                      *
*     Input variables:                                                 *
*                      Kp = hadron projectile index (Part numbering    *
*                           scheme)                                    *
*                   Ktarg = target nucleon index (1=proton, 8=neutron) *
*                    Plab = projectile laboratory momentum (GeV/c)     *
*     Output variable:                                                 *
*                  Phnsch = probability per single chain (particle     *
*                           exchange) interactions                     *
*                                                                      *
*----------------------------------------------------------------------*
*
C      INCLUDE '(PAPROP)'
C      INCLUDE '(PART2)'
C      INCLUDE '(QQUARK)'

*$ CREATE DBLPRC.ADD
*COPY DBLPRC
*                                                                     *
*=== dblprc ==========================================================*
*                                                                     *
*---------------------------------------------------------------------*
*                                                                     *
*      Dblprc: included in any routine                                *
*                                                                     *
*  !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!  *
*  !!!! O N   M A C H I N E S   W H E R E   T H E   D O U B L E !!!!  *
*  !!!! P R E C I S I O N   I S   N O T   R E Q U I R E D  R E -!!!!  *
*  !!!! M O V E   T H E   D O U B L E   P R E C I S I O N       !!!!  *
*  !!!! S T A T E M E N T,  S E T   K A L G N M = 1   A N D     !!!!  *
*  !!!! C H A N G E   A L L   N U M E R I C A L   C O N S -     !!!!  *
*  !!!! T A N T S   T O   S I N G L E   P R E C I S I O N       !!!!  *
*  !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!  *
*                                                                     *
*         Kalgnm = real address alignment, 2 for double precision,    *
*                  1 for single precision                             *
*         Anglgb = this parameter should be set equal to the machine  *
*                  "zero" with respect to unit                        *
*         Anglsq = this parameter should be set equal to the square   *
*                  of Anglgb                                          *
*         Axcssv = this parameter should be set equal to the number   *
*                  for which unity is negligible for the machine      *
*                  accuracy                                           *
*         Andrfl = "underflow" of the machine for floating point      *
*                  operation                                          *
*         Avrflw = "overflow"  of the machine for floating point      *
*                  operation                                          *
*         Ainfnt = code "infinite"                                    *
*         Azrzrz = code "zero"                                        *
*         Einfnt = natural logarithm of the code "infinite"           *
*         Ezrzrz = natural logarithm of the code "zero"               *
*         Onemns = 1- of the machine, it is 1 - 2 x Anglgb            *
*         Onepls = 1+ of the machine, it is 1 + 2 x Anglgb            *
*         Csnnrm = maximum tolerable error on cosine normalization,   *
*                  u**2+v**2+w**2: assuming a typical anglgb relative *
*                  error on each component we would get 2xanglgb: use *
*                  4xanglgb to avoid too many normalizations          *
*         Dmxtrn = "infinite" distance for transport (cm)             *
*                                                                     *
*---------------------------------------------------------------------*
*                                                                     *
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      PARAMETER ( KALGNM = 2 )
      PARAMETER ( ANGLGB = 5.0D-16 )
      PARAMETER ( ANGLSQ = 2.5D-31 )
      PARAMETER ( AXCSSV = 0.2D+16 )
      PARAMETER ( ANDRFL = 1.0D-38 )
      PARAMETER ( AVRFLW = 1.0D+38 )
      PARAMETER ( AINFNT = 1.0D+30 )
      PARAMETER ( AZRZRZ = 1.0D-30 )
      PARAMETER ( EINFNT = +69.07755278982137 D+00 )
      PARAMETER ( EZRZRZ = -69.07755278982137 D+00 )
      PARAMETER ( ONEMNS = 0.999999999999999  D+00 )
      PARAMETER ( ONEPLS = 1.000000000000001  D+00 )
      PARAMETER ( CSNNRM = 2.0D-15 )
      PARAMETER ( DMXTRN = 1.0D+08 )
*
*======================================================================*
*======================================================================*
*=========                                                   ==========*
*=========    M A T H E M A T I C A L   C O N S T A N T S    ==========*
*=========                                                   ==========*
*======================================================================*
*======================================================================*
*                                                                      *
*   Numerical constants:                                               *
*                                                                      *
*         Zerzer = 0                                                   *
*         Oneone = 1                                                   *
*         Twotwo = 2                                                   *
*         Thrthr = 3                                                   *
*         Foufou = 4                                                   *
*         Fivfiv = 5                                                   *
*         Sixsix = 6                                                   *
*         Sevsev = 7                                                   *
*         Eigeig = 8                                                   *
*         Aninen = 9                                                   *
*         Tenten = 10                                                  *
*         Hlfhlf = 1/2                                                 *
*         Onethi = 1/3                                                 *
*         Twothi = 2/3                                                 *
*         Pipipi = Circumference / diameter                            *
*         Eneper = "e", base of natural logarithm                      *
*         Sqrent = square root of "e"                                  *
*                                                                      *
*----------------------------------------------------------------------*
*
      PARAMETER ( ZERZER = 0.D+00 )
      PARAMETER ( ONEONE = 1.D+00 )
      PARAMETER ( TWOTWO = 2.D+00 )
      PARAMETER ( THRTHR = 3.D+00 )
      PARAMETER ( FOUFOU = 4.D+00 )
      PARAMETER ( FIVFIV = 5.D+00 )
      PARAMETER ( SIXSIX = 6.D+00 )
      PARAMETER ( SEVSEV = 7.D+00 )
      PARAMETER ( EIGEIG = 8.D+00 )
      PARAMETER ( ANINEN = 9.D+00 )
      PARAMETER ( TENTEN = 10.D+00 )
      PARAMETER ( HLFHLF = 0.5D+00 )
      PARAMETER ( ONETHI = ONEONE / THRTHR )
      PARAMETER ( TWOTHI = TWOTWO / THRTHR )
      PARAMETER ( PIPIPI = 3.1415926535897932270 D+00 )
      PARAMETER ( ENEPER = 2.7182818284590452354 D+00 )
      PARAMETER ( SQRENT = 1.6487212707001281468 D+00 )
*
*======================================================================*
*======================================================================*
*=========                                                   ==========*
*=========       P H Y S I C A L   C O N S T A N T S         ==========*
*=========                                                   ==========*
*======================================================================*
*======================================================================*
*                                                                      *
*   Primary constants:                                                 *
*                                                                      *
*         Clight = speed of light in cm s-1                            *
*         Avogad = Avogadro number                                     *
*         Amelgr = electron mass (g)                                   *
*         Plckbr = reduced Planck constant (erg s)                     *
*         Elccgs = elementary charge (CGS unit)                        *
*         Elcmks = elementary charge (MKS unit)                        *
*         Amugrm = Atomic mass unit (g)                                *
*         Ammumu = Muon mass (amu)                                     *
*                                                                      *
*   Derived constants:                                                 *
*                                                                      *
*         Alpfsc = Fine structure constant  = e^2/(hbar c)             *
*         Amelct = Electron mass (GeV) = 10^-16Amelgr Clight^2 / Elcmks*
*         Amugev = Atomic mass unit (GeV) = 10^-16Amelgr Clight^2      *
*                                           / Elcmks                   *
*         Ammuon = Muon mass (GeV) = Ammumu * Amugev                   *
*         Fscto2 = (Fine structure constant)^2                         *
*         Fscto3 = (Fine structure constant)^3                         *
*         Fscto4 = (Fine structure constant)^4                         *
*         Plabrc = Reduced Planck constant times the light velocity    *
*                  expressed in GeV fm                                 *
*         Rclsel = Classical electron radius (cm) = e^2 / (m_e c^2)    *
*   Conversion constants:                                              *
*         GeVMeV = from GeV to MeV                                     *
*         eMVGeV = from MeV to GeV                                     *
*         Raddeg = from radians to degrees                             *
*         Degrad = from degrees to radians                             *
*                                                                      *
*----------------------------------------------------------------------*
*
      PARAMETER ( CLIGHT = 2.99792458         D+10 )
      PARAMETER ( AVOGAD = 6.0221367          D+23 )
      PARAMETER ( AMELGR = 9.1093897          D-28 )
      PARAMETER ( PLCKBR = 1.05457266         D-27 )
      PARAMETER ( ELCCGS = 4.8032068          D-10 )
      PARAMETER ( ELCMKS = 1.60217733         D-19 )
      PARAMETER ( AMUGRM = 1.6605402          D-24 )
      PARAMETER ( AMMUMU = 0.113428913        D+00 )
*     PARAMETER ( ALPFSC = 1.D+00 / 137.035989561D+00 )
*     PARAMETER ( FSCTO2 = ALPFSC * ALPFSC )
*     PARAMETER ( FSCTO3 = FSCTO2 * ALPFSC )
*     PARAMETER ( FSCTO4 = FSCTO3 * ALPFSC )
*    It is important to set the electron mass exactly with the same
*    rounding as in the mass tables, so use the explicit expression
*     PARAMETER ( AMELCT = 1.D-16 * AMELGR * CLIGHT * CLIGHT / ELCMKS )
*    It is important to set the amu mass exactly with the same
*    rounding as in the mass tables, so use the explicit expression
*     PARAMETER ( AMUGEV = 1.D-16 * AMUGRM * CLIGHT * CLIGHT / ELCMKS )
*    It is important to set the muon mass exactly with the same
*    rounding as in the mass tables, so use the explicit expression
*     PARAMETER ( AMMUON = AMMUMU * AMUGEV ELCMKS )
*     PARAMETER ( RCLSEL = ELCCGS * ELCCGS / CLIGHT / CLIGHT / AMELGR )
      PARAMETER ( ALPFSC = 7.2973530791728595 D-03 )
      PARAMETER ( FSCTO2 = 5.3251361962113614 D-05 )
      PARAMETER ( FSCTO3 = 3.8859399018437826 D-07 )
      PARAMETER ( FSCTO4 = 2.8357075508200407 D-09 )
      PARAMETER ( PLABRC = 0.197327053        D+00 )
      PARAMETER ( AMELCT = 0.51099906         D-03 )
      PARAMETER ( AMUGEV = 0.93149432         D+00 )
      PARAMETER ( AMMUON = 0.105658389        D+00 )
      PARAMETER ( RCLSEL = 2.8179409183694872 D-13 )
      PARAMETER ( GEVMEV = 1.0                D+03 )
      PARAMETER ( EMVGEV = 1.0                D-03 )
      PARAMETER ( RADDEG = 180.D+00 / PIPIPI )
      PARAMETER ( DEGRAD = PIPIPI / 180.D+00 )
  

*$ CREATE DIMPAR.ADD
*COPY DIMPAR
*                                                                     *
*=== dimpar ==========================================================*
*                                                                     *
*---------------------------------------------------------------------*
*                                                                     *
*      DIMPAR: included in any routine                                *
*                                                                     *
*          Mxxrgn = maximum number of regions                         *
*          Mxxmdf = maximum number of media in Fluka                  *
*          Mxxmde = maximum number of media in Emf                    *
*          Mfstck = stack dimension in Fluka                          *
*          Mestck = stack dimension in Emf                            *
*          Nallwp = number of allowed particles                       *
*          Mpdpdx = number of particle types for which EM dE/dx pro-  *
*                   cesses (ion,pair,bremss) have to be computed      *
*          Icomax = maximum number of materials for compounds (equal  *
*                   to the sum of the number of materials for every   *
*                   compound )                                        *
*          Nstbis = number of stable isotopes recorded in common iso- *
*                   top                                               *
*          Idmaxp = number of particles/resonances defined in common  *
*                   part                                              *
*                                                                     *
*---------------------------------------------------------------------*
*                                                                     *
      PARAMETER ( MXXRGN = 500  )
      PARAMETER ( MXXMDF = 56   )
      PARAMETER ( MXXMDE = 50   )
      PARAMETER ( MFSTCK = 1000 )
      PARAMETER ( MESTCK = 100  )
      PARAMETER ( NALLWP = 39   )
      PARAMETER ( MPDPDX = 8    )
      PARAMETER ( ICOMAX = 180  )
      PARAMETER ( NSTBIS = 304  )
      PARAMETER ( IDMAXP = 210  )



*$ CREATE IOUNIT.ADD
*COPY IOUNIT
*                                                                     *
*=== iounit ==========================================================*
*                                                                     *
*---------------------------------------------------------------------*
*                                                                     *
*      Iounit: included in any routine                                *
*                                                                     *
*         lunin  = standard input unit                                *
*         lunout = standard output unit                               *
*         lunerr = standard error unit                                *
*         lunber = input file for bertini nuclear data                *
*         lunech = echo file for pegs dat                             *
*         lunflu = input file for photoelectric edges and X-ray fluo- *
*                  rescence data                                      *
*         lungeo = scratch file for combinatorial geometry            *
*         lunpgs = input file for pegs material data                  *
*         lunran = output file for the final random number seed       *
*         lunxsc = input file for low energy neutron cross sections   *
*         lunrdb = unit number for reading (extra) auxiliary external *
*                  files to be closed just after reading              *
*                                                                     *
*---------------------------------------------------------------------*
*                                                                     *
      PARAMETER ( LUNIN  = 5  )
      PARAMETER ( LUNOUT = 6  )
      PARAMETER ( LUNERR = 66 )
      PARAMETER ( LUNBER = 14 )
      PARAMETER ( LUNECH = 8  )
      PARAMETER ( LUNFLU = 86 )
      PARAMETER ( LUNGEO = 16 )
      PARAMETER ( LUNPGS = 12 )
      PARAMETER ( LUNRAN = 2  )
      PARAMETER ( LUNXSC = 81 )
      PARAMETER ( LUNRDB = 1  )


*$ CREATE PAPROP.ADD
*COPY PAPROP
*
*=== paprop ===========================================================*
*
*----------------------------------------------------------------------*
*     include file: paprop copy                   created 26/11/86 by p*
*     changes: on  16 december 1992 by Alfredo Ferrari                 *
*     included in the following subroutines or functions: not updated  *
*                                                                      *
*     description of the common block(s) and variable(s)               *
*                                                                      *
*     /paprop/ contains particle properties                            *
*        btype  = literal name of the particle                         *
*        am     = particle mass in gev                                 *
*        ichrge = electric charge of the particle                      *
*        iscore = explanations for the scored distribution             *
*        genpar = names of the generalized particles                   *
*        ijdisc = list of the particle types to be discarded           *
*        thalf  = half life of the particle in sec                     *
*        biasdc = decay biasing factors                                *
*        biasin = inelastic interaction biasing factors                *
*        lhadro = flag for hadrons                                     *
*        jspinp = particle spin (in units of 1/2)                      *
*        lbsdcy = logical flag for biased decay: if .true. the biasing *
*                 factor is used as an upper limit to the decay length *
*        lprbsd = logical flag for biased decay: if .true. the biasing *
*                 factor is applied only to primaries                  *
*        lprbsi = logical flag for inelastic interaction biasing: if   *
*                 .true. the biasing factor is applied only to prima-  *
*                 ries                                                 *
*                                                                      *
*----------------------------------------------------------------------*
*
C     LOGICAL LHADRO, LBSDCY, LPRBSD, LPRBSI
C     CHARACTER*8 BTYPE,GENPAR
C     COMMON / PAPROP / AM  (NALLWP), AMDISC (NALLWP), THALF  (NALLWP),
C    &               BIASDC (NALLWP), BIASIN (NALLWP), ICHRGE (NALLWP),
C    &               ISCORE     (10), IJDISC (NALLWP), LHADRO (NALLWP),
C    &               JSPINP (NALLWP), LBSDCY (NALLWP), LPRBSD, LPRBSI
C     COMMON / CHPPRP / BTYPE  (NALLWP), GENPAR (30)

      DIMENSION ICHRGE(39),AM(39)

*$ CREATE PART2.ADD
*COPY PART2
*
*=== part2 ============================================================*
*
*----------------------------------------------------------------------*
*     Include file: part2 copy        Revised on 20-7-90 by A. Ferrari *
*     Note: see also part copy and part3 copy                          *
*     Changes: none                                                    *
*     Included in the following subroutines or functions: not updated  *
*                                                                      *
*     Description of the common block(s) and variable(s)               *
*                                                                      *
*         Kptoip = conversion from part to paprop numbering            *
*         Iptokp = conversion from paprop to part numbering            *
*                                                                      *
*----------------------------------------------------------------------*
*
C     CHARACTER*8  ANAME
C     COMMON / PART / AAM    (IDMAXP), GA     (IDMAXP), TAU    (IDMAXP),
C    &                AAMDSC (IDMAXP), ZMNABS (IDMAXP), ATNMNA (IDMAXP),
C    &                IICH   (IDMAXP), IIBAR  (IDMAXP), K1     (IDMAXP),
C    &                K2     (IDMAXP), KPTOIP (IDMAXP), IPTOKP (NALLWP)
C     COMMON / CHPART / ANAME (IDMAXP)

*KEEP,DPAR.
C     /DPAR/   CONTAINS PARTICLE PROPERTIES
C        ANAME  = LITERAL NAME OF THE PARTICLE
C        AAM    = PARTICLE MASS IN GEV
C        GA     = DECAY WIDTH
C        TAU    = LIFE TIME OF INSTABLE PARTICLES
C        IICH   = ELECTRIC CHARGE OF THE PARTICLE
C        IIBAR  = BARYON NUMBER
C        K1,K1  = BIGIN AND END OF DECAY CHANNELS OF PARTICLE
C
      CHARACTER*8  ANAME
       COMMON /DPAR/ ANAME(210),AAM(210),GA(210),TAU(210),
     +               IICH(210),IIBAR(210),K1(210),K2(210)
       DIMENSION KPTOIP(210),IPTOKP(39)
C      DATA KPTOIP/1, 2, 3, 4, 5, 6, 7, 8, 9, 10,
C    +             11,12,13,14,15,16,17,18,19,20,
C    +             21,22,23,24,25, 0, 0, 0, 0, 0,
C    +             60*0,
C    +              0, 0, 0, 0, 0, 0,34,36,31,32,
C    +             33,35,37, 0, 0, 0, 0, 0,38, 0,
C    +              0, 0, 0, 0,39, 0, 0, 0, 0, 0,
C    +             90*0/
C      DATA IPTOKP/1, 2, 3, 4, 5, 6, 7, 8, 9, 10,
C    +             11,12,13,14,15,16,17,18,19,20,
C    +             21,22,23,24,25, 0, 0, 0, 0, 0,
C    +             99,100,101,97,102,98,103,109,115/
*                                                                      *
*     Conversion from part to paprop numbering                         *
*                                                                      *
      DATA KPTOIP / 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15,
     & 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 66*0,
     & 34, 36, 31, 32, 33, 35, 37, 5*0, 38, 5*0, 39, 19*0, 27, 28, 74*0/
*                                                                      *
*     Conversion from paprop to part numbering                         *
*                                                                      *
      DATA IPTOKP / 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15,
     & 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 99,
     & 100, 101, 97, 102, 98, 103, 109, 115 /
       

*$ CREATE QQUARK.ADD
*COPY QQUARK
*
*=== qquark ===========================================================*
*
*----------------------------------------------------------------------*
*                                                                      *
*     Created on    6 february 1991    by        Alfredo Ferrari       *
*                                                  INFN - Milan        *
*                                                                      *
*     Last change  on  6 february 1991  by       Alfredo Ferrari       *
*                                                                      *
*     Included in the following routines :                             *
*                                                                      *
*                     COREVT                                           *
*                     CORRIN                                           *
*                     HADEVV                                           *
*                     HADEVT                                           *
*                     NUCEVV                                           *
*                     NUCEVT                                           *
*                                                                      *
*     Quark content of particles:                                      *
*          index   quark   el. charge  bar. charge  isospin  isospin3  *
*              1 = u          2/3          1/3        1/2       1/2    *
*             -1 = ubar      -2/3         -1/3        1/2      -1/2    *
*              2 = d         -1/3          1/3        1/2      -1/2    *
*             -2 = dbar       1/3         -1/3        1/2       1/2    *
*              3 = s         -1/3          1/3         0         0     *
*             -3 = sbar       1/3         -1/3         0         0     *
*              4 = c          2/3          1/3         0         0     *
*             -4 = cbar      -2/3         -1/3         0         0     *
*              5 = b         -1/3          1/3         0         0     *
*             -5 = bbar       1/3         -1/3         0         0     *
*              6 = t          2/3          1/3         0         0     *
*             -6 = tbar      -2/3         -1/3         0         0     *
*                                                                      *
*         Mquark = particle quark composition (Paprop numbering)       *
*         Iqechr = electric charge ( in 1/3 unit )                     *
*         Iqbchr = baryonic charge ( in 1/3 unit )                     *
*         Iqichr = isospin ( in 1/2 unit ), z component                *
*         Iqschr = strangeness                                         *
*         Iqcchr = charm                                               *
*         Iquchr = beauty                                              *
*         Iqtchr = ......                                              *
*                                                                      *
*----------------------------------------------------------------------*
*
      COMMON / QQUARK / IQECHR (-6:6), IQBCHR (-6:6), IQICHR (-6:6),
     &                  IQSCHR (-6:6), IQCCHR (-6:6), IQUCHR (-6:6),
     &                  IQTCHR (-6:6), MQUARK (3,39)
C
      DIMENSION SIEAPP (11), SITAPP (16), PLAETB (16)
      DIMENSION SGTCOE (5,33), PLALIM (2,33), IHLP (NALLWP)
      DIMENSION SGTCO1(5,10),SGTCO2(5,8),SGTCO3(5,15) 
      SAVE PLAETB, SIEAPP, SITAPP, SGTCOE, PLALIM, IHLP
      SAVE IQFSC1, IQFSC2, IQBSC1, IQBSC2
      EQUIVALENCE (SGTCO1(1,1),SGTCOE(1,1))
      EQUIVALENCE (SGTCO2(1,1),SGTCOE(1,11))
      EQUIVALENCE (SGTCO3(1,1),SGTCOE(1,19))
*  1=baryon, 2=pion, 3=kaon, 4=antibaryon:
      DATA IHLP/1,4,5*0,1,4,2*0,3,2*2,2*3,1,4,3,3*1,2,
     &    2*3, 2, 4*0, 3*4, 1, 4, 1, 4, 1, 4 /
C     DATA ( ( SGTCOE (J,I), J=1,5 ), I=1,10 ) /
      DATA  SGTCO1  /
* 1st reaction: gamma p total
     &0.147 D+00, ZERZER  , ZERZER   , 0.0022D+00, -0.0170D+00,
* 2nd reaction: gamma d total
     &0.300 D+00, ZERZER  , ZERZER   , 0.0095D+00, -0.057 D+00,
* 3rd reaction: pi+ p total
     &16.4  D+00, 19.3D+00, -0.42D+00, 0.19  D+00, ZERZER     ,
* 4th reaction: pi- p total
     &33.0  D+00, 14.0D+00, -1.36D+00, 0.456 D+00, -4.03  D+00,
* 5th reaction: pi+/- d total
     &56.8  D+00, 42.2D+00, -1.45D+00, 0.65  D+00, -5.39  D+00,
* 6th reaction: K+ p total
     &18.1  D+00, ZERZER  , ZERZER   , 0.26  D+00, -1.0   D+00,
* 7th reaction: K+ n total
     &18.7  D+00, ZERZER  , ZERZER   , 0.21  D+00, -0.89  D+00,
* 8th reaction: K+ d total
     &34.2  D+00, 7.9 D+00, -2.1 D+00, 0.346 D+00, -0.99  D+00,
* 9th reaction: K- p total
     &32.1  D+00, ZERZER  , ZERZER   , 0.66  D+00, -5.6   D+00,
* 10th reaction: K- n total
     &25.2  D+00, ZERZER  , ZERZER   , 0.38  D+00, -2.9   D+00/
C     DATA ( ( SGTCOE (J,I), J=1,5 ), I=11,18 ) /
      DATA  SGTCO2  /
* 11th reaction: K- d total
     &57.6  D+00, ZERZER  , ZERZER   , 1.17  D+00, -9.5   D+00,
* 12th reaction: p p total
     &48.0  D+00, ZERZER  , ZERZER   , 0.522 D+00, -4.51  D+00,
* 13th reaction: p n total
     &47.30 D+00, ZERZER  , ZERZER   , 0.513 D+00, -4.27  D+00,
* 14th reaction: p d total
     &91.3  D+00, ZERZER  , ZERZER   , 1.05  D+00, -8.8   D+00,
* 15th reaction: pbar p total
     &38.4  D+00, 77.6D+00, -0.64D+00, 0.26  D+00, -1.2   D+00,
* 16th reaction: pbar n total
     &ZERZER    ,133.6D+00, -0.70D+00, -1.22 D+00, 13.7   D+00,
* 17th reaction: pbar d total
     &112.  D+00, 125.D+00, -1.08D+00, 1.14  D+00, -12.4  D+00,
* 18th reaction: Lamda p total
     &30.4  D+00, ZERZER  , ZERZER   , ZERZER    , 1.6    D+00/
C     DATA ( ( SGTCOE (J,I), J=1,5 ), I=19,33 ) /
      DATA SGTCO3  /
* 19th reaction: pi+ p elastic
     &ZERZER    , 11.4D+00, -0.4 D+00, 0.079 D+00, ZERZER     ,
* 20th reaction: pi- p elastic
     &1.76  D+00, 11.2D+00, -0.64D+00, 0.043 D+00, ZERZER     ,
* 21st reaction: K+ p elastic
     &5.0   D+00, 8.1 D+00, -1.8 D+00, 0.16  D+00, -1.3   D+00,
* 22nd reaction: K- p elastic
     &7.3   D+00, ZERZER  , ZERZER   , 0.29  D+00, -2.40  D+00,
* 23rd reaction: p p elastic
     &11.9  D+00, 26.9D+00, -1.21D+00, 0.169 D+00, -1.85  D+00,
* 24th reaction: p d elastic
     &16.1  D+00, ZERZER  , ZERZER   , 0.32  D+00, -3.4   D+00,
* 25th reaction: pbar p elastic
     &10.2  D+00, 52.7D+00, -1.16D+00, 0.125 D+00, -1.28  D+00,
* 26th reaction: pbar p elastic bis
     &10.6  D+00, 53.1D+00, -1.19D+00, 0.136 D+00, -1.41  D+00,
* 27th reaction: pbar n elastic
     &36.5  D+00, ZERZER  , ZERZER   , ZERZER    , -11.9  D+00,
* 28th reaction: Lamda p elastic
     &12.3  D+00, ZERZER  , ZERZER   , ZERZER    , -2.4   D+00,
* 29th reaction: K- p ela bis
     &7.24  D+00, 46.0D+00, -4.71D+00, 0.279 D+00, -2.35  D+00,
* 30th reaction: pi- p cx
     &ZERZER    ,0.912D+00, -1.22D+00, ZERZER    , ZERZER     ,
* 31st reaction: K- p cx
     &ZERZER    , 3.39D+00, -1.75D+00, ZERZER    , ZERZER     ,
* 32nd reaction: K+ n cx
     &ZERZER    , 7.18D+00, -2.01D+00, ZERZER    , ZERZER     ,
* 33rd reaction: pbar p cx
     &ZERZER    , 18.8D+00, -2.01D+00, ZERZER    , ZERZER     /
*
      DATA PLALIM /
*          gamma p tot     ,     gamma d tot     ,       pi+ p tot     ,
     & 3.0D+00, 183.D+00, 2.0D+00, 17.8D+00, 4.0D+00, 340.D+00,
*            pi- p tot     ,     pi+/- d tot     ,        K+ p tot     ,
     & 2.5D+00, 370.D+00, 2.5D+00, 370.D+00, 2.0D+00, 310.D+00,
*             K+ n tot     ,        K+ d tot     ,        K- p tot     ,
     & 2.0D+00, 310.D+00, 2.0D+00, 310.D+00, 3.0D+00, 310.D+00,
*             K- n tot     ,        K- d tot     ,         p p tot     ,
     & 1.8D+00, 310.D+00, 3.0D+00, 310.D+00, 3.0D+00, 2100.D+00,
*              p n tot     ,         p d tot     ,      pbar p tot     ,
     & 3.0D+00, 370.D+00, 3.0D+00, 370.D+00, 5.0D+00, 1.73D+06,
*           pbar n tot     ,      pbar d tot     ,     Lamda p tot     ,
     & 1.1D+00, 280.D+00, 2.0D+00, 280.D+00, 0.6D+00, 21.D+00,
*            pi+ p ela     ,       pi- p ela     ,        K+ p ela     ,
     & 2.0D+00, 200.D+00, 2.0D+00, 360.D+00, 2.0D+00, 175.D+00,
*             K- p ela     ,         p p ela     ,         p d ela     ,
     & 3.0D+00, 175.D+00, 3.0D+00, 2100.D+00, 2.0D+00, 384.D+00,
*           pbar p ela     ,      pbar p ela bis ,      pbar n ela     ,
     & 5.0D+00, 1.73D+06, 2.0D+00, 1.59D+05, 1.1D+00, 5.55D+00,
*          Lamda p ela     ,        K- p ela bis ,       pi- p cx      ,
     & 0.6D+00, 24.D+00, 2.0D+00, 175.D+00, 3.5D+00, 200.D+00,
*             K- p cx      ,        K+ n cx      ,      pbar p cx      /
     & 2.0D+00, 40.D+00, 2.0D+00, 12.8D+00, 3.0D+00, 350.D+00/
*  Momenta for which tabulated data exist for elastic/total pbar p
      DATA PLAETB / 0.1D+00, 0.2D+00,
     &      0.3D+00, 0.4D+00, 0.5D+00, 0.6D+00, 0.8D+00, 1.D+00,
     &      1.2D+00, 1.5D+00, 2. D+00, 2.5D+00, 3. D+00, 4.D+00,
     &      4.5D+00, 5. D+00 /
*  Tabulated data for pbar p elastic:
*  The two lowest energy points are educated guesses:
      DATA SIEAPP / 142.D+00, 95.1D+00,
     &      75.0D+00, 70.0D+00, 62.0D+00, 57.0D+00, 48.0D+00,
     &      44.5D+00, 43.5D+00, 38.0D+00, 33.0D+00 /
*  Tabulated data for pbar p total cross section:
      DATA SITAPP /1129.D+00, 424.D+00,
     &      239.D+00, 195.D+00, 172.D+00, 150.D+00, 124.D+00,
     &      117.D+00, 109.D+00, 100.D+00, 90.2D+00, 81.5D+00,
     &      78.0D+00, 72.0D+00, 67.0D+00, 64.8D+00 /
*
*  +-------------------------------------------------------------------*
         ICHRGE(KTARG)=IICH(KTARG)
         AM    (KTARG)=AAM (KTARG)
*  |  Check for pi0 (d-dbar)
      IF ( KP .NE. 26 ) THEN
         IP  = KPTOIP (KP)
         IF(IP.EQ.0)IP=1 
         ICHRGE(IP)=IICH(KP)
         AM    (IP)=AAM (KP)
*  |
*  +-------------------------------------------------------------------*
*  |
      ELSE
         IP = 23
         ICHRGE(IP)=0
      END IF
*  |
*  +-------------------------------------------------------------------*
*  +-------------------------------------------------------------------*
*  |  No such interactions for baryon-baryon
      IF ( IIBAR (KP) .GT. 0 ) THEN
         PHNSCH = ZERZER
         RETURN
*  |
*  +-------------------------------------------------------------------*
*  |  No "annihilation" diagram possible for K+ p/n
      ELSE IF ( IP .EQ. 15 ) THEN
         PHNSCH = ZERZER
         RETURN
*  |
*  +-------------------------------------------------------------------*
*  |  No "annihilation" diagram possible for K0 p/n
      ELSE IF ( IP .EQ. 24 ) THEN
         PHNSCH = ZERZER
         RETURN
*  |
*  +-------------------------------------------------------------------*
*  |  No "annihilation" diagram possible for Omebar p/n
      ELSE IF ( IP .GE. 38 ) THEN
         PHNSCH = ZERZER
         RETURN
      END IF
*  |
*  +-------------------------------------------------------------------*
*  +-------------------------------------------------------------------*
*  |  If the momentum is larger than 50 GeV/c, compute the single
*  |  chain probability at 50 GeV/c and extrapolate to the present
*  |  momentum according to 1/sqrt(s)
*  |  sigma = sigma_sch (50) * sqrt (s(50)/s) + sigma_dch
*  |  P_sch (50) = sigma_sch (50) / ( sigma_dch + sigma_sch (50) )
*  |  sigma_dch / sigma_sch (50) = 1 / P_sch (50) - 1
*  |  sigma_dch / sigma_sch = 1 / P_sch - 1 = ( 1 / P_sch (50) - 1 )
*  |                        x sqrt(s/s(50))
*  |  P_sch = 1 / [ ( 1 / P_sch (50) - 1 ) x sqrt(s/s(50)) + 1 ]
      IF ( PLAB .GT. 50.D+00 ) THEN
         PLA    = 50.D+00
         AMPSQ  = AM (IP)**2
         AMTSQ  = AM (KTARG)**2
         EPROJ  = SQRT ( PLAB**2 + AMPSQ )
         UMOSQ  = AMPSQ + AMTSQ + TWOTWO * AM (KTARG) * EPROJ
         EPROJ  = SQRT ( PLA**2 + AMPSQ )
         UMO50  = AMPSQ + AMTSQ + TWOTWO * AM (KTARG) * EPROJ
         UMORAT = SQRT ( UMOSQ / UMO50 )
*  |
*  +-------------------------------------------------------------------*
*  |  P < 3 GeV/c
      ELSE IF ( PLAB .LT. 3.D+00 ) THEN
         PLA    = 3.D+00
         AMPSQ  = AM (IP)**2
         AMTSQ  = AM (KTARG)**2
         EPROJ  = SQRT ( PLAB**2 + AMPSQ )
         UMOSQ  = AMPSQ + AMTSQ + TWOTWO * AM (KTARG) * EPROJ
         EPROJ  = SQRT ( PLA**2 + AMPSQ )
         UMO50  = AMPSQ + AMTSQ + TWOTWO * AM (KTARG) * EPROJ
         UMORAT = SQRT ( UMOSQ / UMO50 )
*  |
*  +-------------------------------------------------------------------*
*  |  P < 50 GeV/c
      ELSE
         PLA    = PLAB
         UMORAT = ONEONE
      END IF
*  |
*  +-------------------------------------------------------------------*
      ALGPLA = LOG (PLA)
*  +-------------------------------------------------------------------*
*  |  Pions:
      IF ( IHLP (IP) .EQ. 2 ) THEN
         ACOF = SGTCOE (1,3)
         BCOF = SGTCOE (2,3)
         ENNE = SGTCOE (3,3)
         CCOF = SGTCOE (4,3)
         DCOF = SGTCOE (5,3)
*  |  Compute the pi+ p total cross section:
         SPPPTT = ACOF + BCOF * PLA**ENNE + CCOF * ALGPLA**2
     &          + DCOF * ALGPLA
         ACOF = SGTCOE (1,19)
         BCOF = SGTCOE (2,19)
         ENNE = SGTCOE (3,19)
         CCOF = SGTCOE (4,19)
         DCOF = SGTCOE (5,19)
*  |  Compute the pi+ p elastic cross section:
         SPPPEL = ACOF + BCOF * PLA**ENNE + CCOF * ALGPLA**2
     &          + DCOF * ALGPLA
*  |  Compute the pi+ p inelastic cross section:
         SPPPIN = SPPPTT - SPPPEL
         ACOF = SGTCOE (1,4)
         BCOF = SGTCOE (2,4)
         ENNE = SGTCOE (3,4)
         CCOF = SGTCOE (4,4)
         DCOF = SGTCOE (5,4)
*  |  Compute the pi- p total cross section:
         SPMPTT = ACOF + BCOF * PLA**ENNE + CCOF * ALGPLA**2
     &          + DCOF * ALGPLA
         ACOF = SGTCOE (1,20)
         BCOF = SGTCOE (2,20)
         ENNE = SGTCOE (3,20)
         CCOF = SGTCOE (4,20)
         DCOF = SGTCOE (5,20)
*  |  Compute the pi- p elastic cross section:
         SPMPEL = ACOF + BCOF * PLA**ENNE + CCOF * ALGPLA**2
     &          + DCOF * ALGPLA
*  |  Compute the pi- p inelastic cross section:
         SPMPIN = SPMPTT - SPMPEL
         SIGDIA = SPMPIN - SPPPIN
*  |  +----------------------------------------------------------------*
*  |  |  Charged pions: besides isospin consideration it is supposed
*  |  |                 that (pi+ n)el is almost equal to (pi- p)el
*  |  |                 and  (pi+ p)el "    "     "    "  (pi- n)el
*  |  |                 and all are almost equal among each others
*  |  |                 (reasonable above 5 GeV/c)
         IF ( ICHRGE (IP) .NE. 0 ) THEN
            KHELP = KTARG / 8
            JREAC = 3 + IP - 13 + ICHRGE (IP) * KHELP
            ACOF = SGTCOE (1,JREAC)
            BCOF = SGTCOE (2,JREAC)
            ENNE = SGTCOE (3,JREAC)
            CCOF = SGTCOE (4,JREAC)
            DCOF = SGTCOE (5,JREAC)
*  |  |  Compute the total cross section:
            SHNCTT = ACOF + BCOF * PLA**ENNE + CCOF * ALGPLA**2
     &             + DCOF * ALGPLA
            JREAC = 19 + IP - 13 + ICHRGE (IP) * KHELP
            ACOF = SGTCOE (1,JREAC)
            BCOF = SGTCOE (2,JREAC)
            ENNE = SGTCOE (3,JREAC)
            CCOF = SGTCOE (4,JREAC)
            DCOF = SGTCOE (5,JREAC)
*  |  |  Compute the elastic cross section:
            SHNCEL = ACOF + BCOF * PLA**ENNE + CCOF * ALGPLA**2
     &             + DCOF * ALGPLA
*  |  |  Compute the inelastic cross section:
            SHNCIN = SHNCTT - SHNCEL
*  |  |  Number of diagrams:
            NDIAGR = 1 + IP - 13 + ICHRGE (IP) * KHELP
*  |  |  Now compute the chain end (anti)quark-(anti)diquark
            IQFSC1 = 1 + IP - 13
            IQFSC2 = 0
            IQBSC1 = 1 + KHELP
            IQBSC2 = 1 + IP - 13
*  |  |
*  |  +----------------------------------------------------------------*
*  |  |  pi0: besides isospin consideration it is supposed that the
*  |  |       elastic cross section is not very different from
*  |  |       pi+ p and/or pi- p (reasonable above 5 GeV/c)
         ELSE
            KHELP  = KTARG / 8
            K2HLP  = ( KP - 23 ) / 3
*  |  |  Number of diagrams:
*  |  |  For u ubar (k2hlp=0):
*           NDIAGR = 2 - KHELP
*  |  |  For d dbar (k2hlp=1):
*           NDIAGR = 2 + KHELP - K2HLP
            NDIAGR = 2 + KHELP * ( 2 * K2HLP - 1 ) - K2HLP
            SHNCIN = HLFHLF * ( SPPPIN + SPMPIN )
*  |  |  Now compute the chain end (anti)quark-(anti)diquark
            IQFSC1 = 1 + K2HLP
            IQFSC2 = 0
            IQBSC1 = 1 + KHELP
            IQBSC2 = 2 - K2HLP
         END IF
*  |  |
*  |  +----------------------------------------------------------------*
*  |                                                   end pi's
*  +-------------------------------------------------------------------*
*  |  Kaons:
      ELSE IF ( IHLP (IP) .EQ. 3 ) THEN
         ACOF = SGTCOE (1,6)
         BCOF = SGTCOE (2,6)
         ENNE = SGTCOE (3,6)
         CCOF = SGTCOE (4,6)
         DCOF = SGTCOE (5,6)
*  |  Compute the K+ p total cross section:
         SKPPTT = ACOF + BCOF * PLA**ENNE + CCOF * ALGPLA**2
     &          + DCOF * ALGPLA
         ACOF = SGTCOE (1,21)
         BCOF = SGTCOE (2,21)
         ENNE = SGTCOE (3,21)
         CCOF = SGTCOE (4,21)
         DCOF = SGTCOE (5,21)
*  |  Compute the K+ p elastic cross section:
         SKPPEL = ACOF + BCOF * PLA**ENNE + CCOF * ALGPLA**2
     &          + DCOF * ALGPLA
*  |  Compute the K+ p inelastic cross section:
         SKPPIN = SKPPTT - SKPPEL
         ACOF = SGTCOE (1,9)
         BCOF = SGTCOE (2,9)
         ENNE = SGTCOE (3,9)
         CCOF = SGTCOE (4,9)
         DCOF = SGTCOE (5,9)
*  |  Compute the K- p total cross section:
         SKMPTT = ACOF + BCOF * PLA**ENNE + CCOF * ALGPLA**2
     &          + DCOF * ALGPLA
         ACOF = SGTCOE (1,22)
         BCOF = SGTCOE (2,22)
         ENNE = SGTCOE (3,22)
         CCOF = SGTCOE (4,22)
         DCOF = SGTCOE (5,22)
*  |  Compute the K- p elastic cross section:
         SKMPEL = ACOF + BCOF * PLA**ENNE + CCOF * ALGPLA**2
     &          + DCOF * ALGPLA
*  |  Compute the K- p inelastic cross section:
         SKMPIN = SKMPTT - SKMPEL
         SIGDIA = HLFHLF * ( SKMPIN - SKPPIN )
*  |  +----------------------------------------------------------------*
*  |  |  Charged Kaons: actually only K-
         IF ( ICHRGE (IP) .NE. 0 ) THEN
            KHELP = KTARG / 8
*  |  |  +-------------------------------------------------------------*
*  |  |  |  Proton target:
            IF ( KHELP .EQ. 0 ) THEN
               SHNCIN = SKMPIN
*  |  |  |  Number of diagrams:
               NDIAGR = 2
*  |  |  |
*  |  |  +-------------------------------------------------------------*
*  |  |  |  Neutron target: besides isospin consideration it is supposed
*  |  |  |              that (K- n)el is almost equal to (K- p)el
*  |  |  |              (reasonable above 5 GeV/c)
            ELSE
               ACOF = SGTCOE (1,10)
               BCOF = SGTCOE (2,10)
               ENNE = SGTCOE (3,10)
               CCOF = SGTCOE (4,10)
               DCOF = SGTCOE (5,10)
*  |  |  |  Compute the total cross section:
               SHNCTT = ACOF + BCOF * PLA**ENNE + CCOF * ALGPLA**2
     &                + DCOF * ALGPLA
*  |  |  |  Compute the elastic cross section:
               SHNCEL = SKMPEL
*  |  |  |  Compute the inelastic cross section:
               SHNCIN = SHNCTT - SHNCEL
*  |  |  |  Number of diagrams:
               NDIAGR = 1
            END IF
*  |  |  |
*  |  |  +-------------------------------------------------------------*
*  |  |  Now compute the chain end (anti)quark-(anti)diquark
            IQFSC1 = 3
            IQFSC2 = 0
            IQBSC1 = 1 + KHELP
            IQBSC2 = 2
*  |  |
*  |  +----------------------------------------------------------------*
*  |  |  K0's: (actually only K0bar)
         ELSE
            KHELP  = KTARG / 8
*  |  |  +-------------------------------------------------------------*
*  |  |  |  Proton target: (K0bar p)in supposed to be given by
*  |  |  |                 (K- p)in - Sig_diagr
            IF ( KHELP .EQ. 0 ) THEN
               SHNCIN = SKMPIN - SIGDIA
*  |  |  |  Number of diagrams:
               NDIAGR = 1
*  |  |  |
*  |  |  +-------------------------------------------------------------*
*  |  |  |  Neutron target: (K0bar n)in supposed to be given by
*  |  |  |                 (K- n)in + Sig_diagr
*  |  |  |              besides isospin consideration it is supposed
*  |  |  |              that (K- n)el is almost equal to (K- p)el
*  |  |  |              (reasonable above 5 GeV/c)
            ELSE
               ACOF = SGTCOE (1,10)
               BCOF = SGTCOE (2,10)
               ENNE = SGTCOE (3,10)
               CCOF = SGTCOE (4,10)
               DCOF = SGTCOE (5,10)
*  |  |  |  Compute the total cross section:
               SHNCTT = ACOF + BCOF * PLA**ENNE + CCOF * ALGPLA**2
     &                + DCOF * ALGPLA
*  |  |  |  Compute the elastic cross section:
               SHNCEL = SKMPEL
*  |  |  |  Compute the inelastic cross section:
               SHNCIN = SHNCTT - SHNCEL + SIGDIA
*  |  |  |  Number of diagrams:
               NDIAGR = 2
            END IF
*  |  |  |
*  |  |  +-------------------------------------------------------------*
*  |  |  Now compute the chain end (anti)quark-(anti)diquark
            IQFSC1 = 3
            IQFSC2 = 0
            IQBSC1 = 1
            IQBSC2 = 1 + KHELP
         END IF
*  |  |
*  |  +----------------------------------------------------------------*
*  |                                                   end Kaon's
*  +-------------------------------------------------------------------*
*  |  Antinucleons:
      ELSE IF ( IHLP (IP) .EQ. 4 .AND. IP .LE. 9 ) THEN
*  |  For momenta between 3 and 5 GeV/c the use of tabulated data
*  |  should be implemented!
         ACOF = SGTCOE (1,15)
         BCOF = SGTCOE (2,15)
         ENNE = SGTCOE (3,15)
         CCOF = SGTCOE (4,15)
         DCOF = SGTCOE (5,15)
*  |  Compute the pbar p total cross section:
         SAPPTT = ACOF + BCOF * PLA**ENNE + CCOF * ALGPLA**2
     &          + DCOF * ALGPLA
         IF ( PLA .LT. FIVFIV ) THEN
            JREAC = 26
         ELSE
            JREAC = 25
         END IF
         ACOF = SGTCOE (1,JREAC)
         BCOF = SGTCOE (2,JREAC)
         ENNE = SGTCOE (3,JREAC)
         CCOF = SGTCOE (4,JREAC)
         DCOF = SGTCOE (5,JREAC)
*  |  Compute the pbar p elastic cross section:
         SAPPEL = ACOF + BCOF * PLA**ENNE + CCOF * ALGPLA**2
     &          + DCOF * ALGPLA
*  |  Compute the pbar p inelastic cross section:
         SAPPIN = SAPPTT - SAPPEL
         ACOF = SGTCOE (1,12)
         BCOF = SGTCOE (2,12)
         ENNE = SGTCOE (3,12)
         CCOF = SGTCOE (4,12)
         DCOF = SGTCOE (5,12)
*  |  Compute the p p total cross section:
         SPPTOT = ACOF + BCOF * PLA**ENNE + CCOF * ALGPLA**2
     &          + DCOF * ALGPLA
         ACOF = SGTCOE (1,23)
         BCOF = SGTCOE (2,23)
         ENNE = SGTCOE (3,23)
         CCOF = SGTCOE (4,23)
         DCOF = SGTCOE (5,23)
*  |  Compute the p p elastic cross section:
         SPPELA = ACOF + BCOF * PLA**ENNE + CCOF * ALGPLA**2
     &          + DCOF * ALGPLA
*  |  Compute the K- p inelastic cross section:
         SPPINE = SPPTOT - SPPELA
         SIGDIA = ( SAPPIN - SPPINE ) / FIVFIV
         KHELP  = KTARG / 8
*  |  +----------------------------------------------------------------*
*  |  |  Pbar:
         IF ( ICHRGE (IP) .NE. 0 ) THEN
            NDIAGR = 5 - KHELP
*  |  |  +-------------------------------------------------------------*
*  |  |  |  Proton target:
            IF ( KHELP .EQ. 0 ) THEN
*  |  |  |  Number of diagrams:
               SHNCIN = SAPPIN
               PUUBAR = 0.8D+00
*  |  |  |
*  |  |  +-------------------------------------------------------------*
*  |  |  |  Neutron target: it is supposed that (ap n)el is almost equal
*  |  |  |                  to (ap p)el (reasonable above 5 GeV/c)
            ELSE
               ACOF = SGTCOE (1,16)
               BCOF = SGTCOE (2,16)
               ENNE = SGTCOE (3,16)
               CCOF = SGTCOE (4,16)
               DCOF = SGTCOE (5,16)
*  |  |  |  Compute the total cross section:
               SHNCTT = ACOF + BCOF * PLA**ENNE + CCOF * ALGPLA**2
     &                + DCOF * ALGPLA
*  |  |  |  Compute the elastic cross section:
               SHNCEL = SAPPEL
*  |  |  |  Compute the inelastic cross section:
               SHNCIN = SHNCTT - SHNCEL
               PUUBAR = HLFHLF
            END IF
*  |  |  |
*  |  |  +-------------------------------------------------------------*
*  |  |  Now compute the chain end (anti)quark-(anti)diquark
*  |  |  there are different possibilities, make a random choiche:
            IQFSC1 = -1
            RNCHEN = RNDM (RNCHEN)
            IF ( RNCHEN .LT. PUUBAR ) THEN
               IQFSC2 = -2
            ELSE
               IQFSC2 = -1
            END IF
            IQBSC1 = -IQFSC1 + KHELP
            IQBSC2 = -IQFSC2
*  |  |
*  |  +----------------------------------------------------------------*
*  |  |  nbar:
         ELSE
            NDIAGR = 4 + KHELP
*  |  |  +-------------------------------------------------------------*
*  |  |  |  Proton target: (nbar p)in supposed to be given by
*  |  |  |                 (pbar p)in - Sig_diagr
            IF ( KHELP .EQ. 0 ) THEN
               SHNCIN = SAPPIN - SIGDIA
               PDDBAR = HLFHLF
*  |  |  |
*  |  |  +-------------------------------------------------------------*
*  |  |  |  Neutron target: (nbar n)el is supposed to be equal to
*  |  |  |                  (pbar p)el (reasonable above 5 GeV/c)
            ELSE
*  |  |  |  Compute the total cross section:
               SHNCTT = SAPPTT
*  |  |  |  Compute the elastic cross section:
               SHNCEL = SAPPEL
*  |  |  |  Compute the inelastic cross section:
               SHNCIN = SHNCTT - SHNCEL
               PDDBAR = 0.8D+00
            END IF
*  |  |  |
*  |  |  +-------------------------------------------------------------*
*  |  |  Now compute the chain end (anti)quark-(anti)diquark
*  |  |  there are different possibilities, make a random choiche:
            IQFSC1 = -2
            RNCHEN = RNDM (RNCHEN)
            IF ( RNCHEN .LT. PDDBAR ) THEN
               IQFSC2 = -1
            ELSE
               IQFSC2 = -2
            END IF
            IQBSC1 = -IQFSC1 + KHELP - 1
            IQBSC2 = -IQFSC2
         END IF
*  |  |
*  |  +----------------------------------------------------------------*
*  |
*  +-------------------------------------------------------------------*
*  |  Others: not yet implemented
      ELSE
         SIGDIA = ZERZER
         SHNCIN = ONEONE
         NDIAGR = 0
         PHNSCH = ZERZER
         RETURN
      END IF
*  |                                                   end others
*  +-------------------------------------------------------------------*
      PHNSCH = NDIAGR * SIGDIA / SHNCIN
      IQECHC = IQECHR (IQFSC1) + IQECHR (IQFSC2) + IQECHR (IQBSC1)
     &       + IQECHR (IQBSC2)
      IQBCHC = IQBCHR (IQFSC1) + IQBCHR (IQFSC2) + IQBCHR (IQBSC1)
     &       + IQBCHR (IQBSC2)
      IQECHC = IQECHC / 3
      IQBCHC = IQBCHC / 3
      IQSCHC = IQSCHR (IQFSC1) + IQSCHR (IQFSC2) + IQSCHR (IQBSC1)
     &       + IQSCHR (IQBSC2)
      IQSPRO = IQSCHR (MQUARK(1,IP)) + IQSCHR (MQUARK(2,IP))
     &       + IQSCHR (MQUARK(3,IP))
*  +-------------------------------------------------------------------*
*  |  Consistency check:
      IF ( PHNSCH .LE. ZERZER .OR. PHNSCH .GT. ONEONE ) THEN
         WRITE (LUNOUT,*)' *** Phnsch,kp,ktarg,pla',
     &                         PHNSCH,KP,KTARG,PLA,' ****'
         WRITE (LUNERR,*)' *** Phnsch,kp,ktarg,pla',
     &                         PHNSCH,KP,KTARG,PLA,' ****'
         PHNSCH = MAX ( PHNSCH, ZERZER )
         PHNSCH = MIN ( PHNSCH, ONEONE )
      END IF
*  |
*  +-------------------------------------------------------------------*
*  +-------------------------------------------------------------------*
*  |  Consistency check:
      IF ( IQSPRO .NE. IQSCHC .OR. ICHRGE (IP) + ICHRGE (KTARG)
     &     .NE. IQECHC .OR. IIBAR (KP) + IIBAR (KTARG) .NE. IQBCHC) THEN
         WRITE (LUNOUT,*)
     &' *** Phnsch,iqspro,iqschc,ichrge,iqechc,ibar,iqbchc,ktarg',
     &      IQSPRO,IQSCHC,ICHRGE(IP),IQECHC,IIBAR(KP),IQBCHC,KTARG
         WRITE (LUNERR,*)
     &' *** Phnsch,iqspro,iqschc,ichrge,iqechc,ibar,iqbchc,ktarg',
     &      IQSPRO,IQSCHC,ICHRGE(IP),IQECHC,IIBAR(KP),IQBCHC,KTARG
      END IF
*  |
*  +-------------------------------------------------------------------*
*  P_sch = 1 / [ ( 1 / P_sch (50) - 1 ) x sqrt(s/s(50)) + 1 ]
      IF ( UMORAT .GT. ONEPLS ) PHNSCH = ONEONE / ( ( ONEONE / PHNSCH
     &                                 - ONEONE ) * UMORAT + ONEONE )
      RETURN
*
      ENTRY SCHQUA ( JQFSC1, JQFSC2, JQBSC1, JQBSC2 )
      SCHQUA = ONEONE
      JQFSC1 = IQFSC1
      JQFSC2 = IQFSC2
      JQBSC1 = IQBSC1
      JQBSC2 = IQBSC2
*=== End of function Phnsch ===========================================*
      RETURN
      END
*
*=== qprop ============================================================*
*
      BLOCK DATA QPROP
*----------------------------------------------------------------------*
*                                                                      *
*     Created on    6 february 1991    by        Alfredo Ferrari       *
*                                                  INFN - Milan        *
*                                                                      *
*     Last change  on  6 february 1991  by       Alfredo Ferrari       *
*                                                                      *
*     Included in the following routines :                             *
*                                                                      *
*                     COREVT                                           *
*                     CORRIN                                           *
*                     HADEVV                                           *
*                     HADEVT                                           *
*                     NUCEVV                                           *
*                     NUCEVT                                           *
*                                                                      *
*     Quark content of particles:                                      *
*          index   quark   el. charge  bar. charge  isospin  isospin3  *
*              1 = u          2/3          1/3        1/2       1/2    *
*             -1 = ubar      -2/3         -1/3        1/2      -1/2    *
*              2 = d         -1/3          1/3        1/2      -1/2    *
*             -2 = dbar       1/3         -1/3        1/2       1/2    *
*              3 = s         -1/3          1/3         0         0     *
*             -3 = sbar       1/3         -1/3         0         0     *
*              4 = c          2/3          1/3         0         0     *
*             -4 = cbar      -2/3         -1/3         0         0     *
*              5 = b         -1/3          1/3         0         0     *
*             -5 = bbar       1/3         -1/3         0         0     *
*              6 = t          2/3          1/3         0         0     *
*             -6 = tbar      -2/3         -1/3         0         0     *
*                                                                      *
*         Mquark = particle quark composition (Paprop numbering)       *
*         Iqechr = electric charge ( in 1/3 unit )                     *
*         Iqbchr = baryonic charge ( in 1/3 unit )                     *
*         Iqichr = isospin ( in 1/2 unit ), z component                *
*         Iqschr = strangeness                                         *
*         Iqcchr = charm                                               *
*         Iquchr = beauty                                              *
*         Iqtchr = ......                                              *
*                                                                      *
*----------------------------------------------------------------------*
*
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)

      COMMON / QQUARK / IQECHR (-6:6), IQBCHR (-6:6), IQICHR (-6:6),
     &                  IQSCHR (-6:6), IQCCHR (-6:6), IQUCHR (-6:6),
     &                  IQTCHR (-6:6), MQUARK (3,39)

*
* / Qquark / 
      DATA IQECHR / -2, 1, -2, 1, 1, -2, 0, 2, -1, -1, 2, -1, 2 /
      DATA IQBCHR / 6*-1, 0, 6*1 /
      DATA IQICHR / 4*0, 1, -1, 0, 1, -1, 4*0 /
      DATA IQSCHR / 3*0, 1, 5*0, -1, 3*0 /
      DATA IQCCHR / 2*0, -1, 7*0, 1, 2*0 /
      DATA IQUCHR / 0, 1, 9*0, -1, 0 /
      DATA IQTCHR / -1, 11*0, 1 /
      DATA MQUARK /                1,1,2,    -1,-1,-2,
     *   0,0,0,       0,0,0,       0,0,0,       0,0,0,       0,0,0,
     *   1,2,2,    -1,-2,-2,       0,0,0,       0,0,0,       0,0,0,
     *  1,-2,0,      2,-1,0,      1,-3,0,      3,-1,0,
     *   1,2,3,    -1,-2,-3,       0,0,0,
     *   2,2,3,     1,1,3,     1,2,3,     1,-1,0,
     *   2,-3,0,    3,-2,0,    2,-2,0,    0,0,0,
     *   0,0,0,       0,0,0,       0,0,0,
     *  -1,-1,-3,    -1,-2,-3,    -2,-2,-3,
     *   1,3,3,      -1,-3,-3,     2,3,3,      -2,-3,-3,
     *   3,3,3,      -3,-3,-3 /

      END
C******************************************************************
      SUBROUTINE SELPTS( PTXSQ1,PTYSQ1,
     +PLQ1,EQ1,PTXSA2,
     +PTYSA2,PLAQ2,EAQ2, AMCH1,IREJ,IKVALA,PTTQ1)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C  SELECT PT VALUES FOR A SINGLE CHAIN SYSTEM
C                            SELECT SEA QUARK AND ANTIQUARK PT-VALUES
*KEEP,DPRIN.
      COMMON /DPRIN/  IPRI,IPEV,IPPA,IPCO,INIT,IPHKK,ITOPD,IPAUPR
*KEEP,DROPPT.
      LOGICAL INTPT,FERMP,IHADSS,IHADSV,IHADVS,IHADVV,IHADA, IPADIS,
     +ISHMAL,LPAULI
      COMMON /DROPPT/ INTPT,FERMP,IHADSS,IHADSV,IHADVS,IHADVV,IHADA,
     +IPADIS,ISHMAL,LPAULI
*KEND.
      COMMON /NUCC/   IT,ITZ,IP,IPZ,IJPROJ,IBPROJ,IJTARG,IBTARG
C--------------------------------
C                                        change j.r.6.5.93
      QTXSQ1=PTXSQ1
      QTXSA2=PTXSA2
      QTYSQ1=PTYSQ1
      QTYSA2=PTYSA2
      QLQ1=PLQ1
      QLAQ2=PLAQ2
      QEQ1=EQ1
      QEAQ2=EAQ2
C                                        ----------------
      IANFA=0
      ITAGPT=0
C                           changed from 3.  j.r.21.8.93
      B33=3.00
      IF (IKVALA.EQ.1)B33=6.0
      ICOUNT=0
      IREJ=0
   10 CONTINUE
      ICOUNT=ICOUNT+1
      IF (ICOUNT.EQ.10)THEN
        IREJ=1
C                            REJECT EVENT
        RETURN
      ENDIF
      IF (ICOUNT.GE.1)THEN
        HPS=HPS*0.9
      PTXSQ1=QTXSQ1+HPS*CFE
      PTYSQ1=QTYSQ1+HPS*SFE
      PTXSA2=QTXSA2-HPS*CFE
      PTYSA2=QTYSA2-HPS*SFE
        GO TO 111       
      ENDIF
      B33=2.*B33
C
      ES=-2./(B33**2)*LOG(ABS(RNDM(V)*RNDM(U))+0.00000001)
      HPS=SQRT(ES*ES+2.*ES*0.94)
C............................................................
  110 CONTINUE
      IF (.NOT.INTPT) HPS=0.0000001
C.............................................................
      CALL DSFECF(SFE,CFE)
C                                       change j.r.6.5.93
      PTXSQ1=QTXSQ1+HPS*CFE
      PTYSQ1=QTYSQ1+HPS*SFE
      PTXSA2=QTXSA2-HPS*CFE
      PTYSA2=QTYSA2-HPS*SFE
  111 CONTINUE
C                                      -----------------
C
      IF (IPEV.GE.6)WRITE(6,1000)PTXSQ1,PTYSQ1,
     +PTXSA2,PTYSA2
 1000 FORMAT (' PT S  ',8F12.6)
C                           KINEMATICS OF THE TWO CHAINS Q1-AQ2,AQ1-Q2
      PTTQ1=PTXSQ1**2+PTYSQ1**2
      IF((EQ1**2.LE.PTTQ1))            GO TO 10
C                                      
       IANFA2=0
      ITAGP2=0
      B33=3.00
      IF (IKVALA.EQ.1)B33=6.0
      ICOUN2=0
      IREJ=0
   12 CONTINUE
      ICOUN2=ICOUN2+1
      IF (ICOUN2.EQ.12)THEN
        IREJ=1
C                            REJECT EVENT
        RETURN
      ENDIF
C                                      -----------------
C
      IF (IPEV.GE.6)WRITE(6,1000)PTXSQ1,PTYSQ1,
     +PTXSA2,PTYSA2
C                           KINEMATICS OF THE TWO CHAINS Q1-AQ2,AQ1-Q2
      PTTA2=PTXSA2**2+PTYSA2**2
      IF((EAQ2**2.LE.PTTA2))            GO TO 12
 
C
      IF(IP.GE.1)GO TO 1779
        PLQ1=SQRT(EQ1**2-PTTQ1)
        PLAQ2=-SQRT(EAQ2**2-PTTA2)
 1779 CONTINUE
C-----------
C-----------
C                          CHAIN 1: Q1-AQ2     CHAIN2:  AQ1-Q2
      AMCH1Q=(EQ1+EAQ2)**2-(PTXSQ1+PTXSA2)** 2-(PTYSQ1+PTYSA2)**2-(PLQ1
     ++PLAQ2)**2
      IF (AMCH1Q.LE.0.D0)THEN
        WRITE(6,301)AMCH1Q
  301   FORMAT(' inconsistent Kinematics in SELPT AMCH1Q=',E12.3)
       WRITE(6,305) QTXSQ1,QTYSQ1,
     +QLQ1,QEQ1,QTXSA1,QTYSA1,QLAQ1,QEAQ1, QTXSQ2,QTYSQ2,QLQ2,QEQ2,
     +QTXSA2,
     +QTYSA2,QLAQ2,QEAQ2, AMCH1,AMCH2
  305 FORMAT( 'PTXSQ1,PTYSQ1,
     +PLQ1,EQ1,PTXSA1,PTYSA1,PLAQ1,EAQ1, PTXSQ2,PTYSQ2,PLQ2,EQ2,PTXSA2,
     +PTYSA2,PLAQ2,EAQ2, AMCH1,AMCH2',5(4E15.5/))
        IREJ=1
        RETURN
      ENDIF
      AMCH1=SQRT(AMCH1Q)
C
      RETURN
      END
*-- Author :
C-------------------------------------------------------------------
C
C                 FILE DNDISTRM FORTRAN
C
C------------------------------------------------------------------
C     DEBUG SUBCHK
C     END DEBUG
      SUBROUTINE DISTR(IOP,NHKKH1,PO,IGENER)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C***
C   REDUCED VERSION FOR SCORING RESULTS FROM PRIMARY AA INTERACTION
C   FROM /HKKEVT/
C   kinematics in lab (target rest system)
C      - MULTIPLICITIES
C      - number of inc generations inside the nucleus
C      - RAPIDITY DISTRIBUTION         (without cuts)
C      - pseudorapidity distribution   (without cuts)
C***
C  conventions for rapidity distributions:
C       1  Proton                       11  NEGATIVES
C       2  Neutron                      12  NBAR=9
C       3  PI+=13                       13  LAMBDA=17
C       4  PI-=14                       14  SIGMA==20,21,22
C       5  K+ =15                       15  LAMBDABAR=18
C       6  K- =16                       16  SIGMABAR=99,100,101
C       7  neutral kaons=12,19,24,25    17  THETA=97,98
C       8  pbar=2                       18  THETABAR=102,103
C       9  charged hadrons
C      10  total hadrons
C-----------------------------------------------------------------------
      DIMENSION P4P4P4(4)
*KEEP,HKKEVT.
c     INCLUDE (HKKEVT)
      PARAMETER (NMXHKK= 49998)
c     PARAMETER (NMXHKK=25000)
      COMMON /HKKEVT/ NHKK,NEVHKK,ISTHKK(NMXHKK),IDHKK(NMXHKK), JMOHKK
     +(2,NMXHKK),JDAHKK(2,NMXHKK), PHKK(5,NMXHKK),VHKK(4,NMXHKK),WHKK
     +(4,NMXHKK)
C
C                       WHKK(4,NMXHKK) GIVES POSITIONS AND TIMES IN
C                       PROJECTILE FRAME, THE CHAINS ARE CREATED ON
C                       THE POSITIONS OF THE PROJECTILE NUCLEONS
C                       IN THE PROJECTILE FRAME (TARGET NUCLEONS IN
C                       TARGET FRAME) BOTH POSITIONS ARE THREFORE NOT
C                       COMPLETELY CONSISTENT. THE TIMES IN THE
C                       PROJECTILE FRAME HOWEVER ARE OBTAINED BY
C                       LORENTZ TRANSFORMING FROM THE LAB SYSTEM.
C
C  Based on the proposed standard COMMON block (Sjostrand Memo 17.3,89)
C
C NMXHKK: maximum numbers of entries (partons/particles) that can be
C    stored in the commonblock.
C
C NHKK: the actual number of entries stored in current event. These are
C    found in the first NHKK positions of the respective arrays below.
C    Index IHKK, 1 <= IHKK <= NHKK, is below used to denote a given
C    entry.
C
C ISTHKK(IHKK): status code for entry IHKK, with following meanings:
C    = 0 : null entry.
C    = 1 : an existing entry, which has not decayed or fragmented.
C        This is the main class of entries which represents the
C        "final state" given by the generator.
C    = 2 : an entry which has decayed or fragmented and therefore
C        is not appearing in the final state, but is retained for
C        event history information.
C    = 3 : a documentation line, defined separately from the event
C        history. (incoming reacting
C        particles, etc.)
C    = 4 - 10 : undefined, but reserved for future standards.
C    = 11 - 20 : at the disposal of each model builder for constructs
C        specific to his program, but equivalent to a null line in the
C        context of any other program. One example is the cone defining
C        vector of HERWIG, another cluster or event axes of the JETSET
C        analysis routines.
C    = 21 - : at the disposal of users, in particular for event tracking
C        in the detector.
C
C IDHKK(IHKK) : particle identity, according to the Particle Data Group
C    standard.
C
C JMOHKK(1,IHKK) : pointer to the position where the mother is stored.
C    The value is 0 for initial entries.
C
C JMOHKK(2,IHKK) : pointer to position of second mother. Normally only
C    one mother exist, in which case the value 0 is used. In cluster
C    fragmentation models, the two mothers would correspond to the q
C    and qbar which join to form a cluster. In string fragmentation,
C    the two mothers of a particle produced in the fragmentation would
C    be the two endpoints of the string (with the range in between
C    implied).
C
C JDAHKK(1,IHKK) : pointer to the position of the first daughter. If an
C    entry has not decayed, this is 0.
C
C JDAHKK(2,IHKK) : pointer to the position of the last daughter. If an
C    entry has not decayed, this is 0. It is assumed that the daughters
C    of a particle (or cluster or string) are stored sequentially, so
C    that the whole range JDAHKK(1,IHKK) - JDAHKK(2,IHKK) contains
C    daughters. Even in cases where only one daughter is defined (e.g.
C    K0 -> K0S) both values should be defined, to make for a uniform
C    approach in terms of loop constructions.
C
C PHKK(1,IHKK) : momentum in the x direction, in GeV/c.
C
C PHKK(2,IHKK) : momentum in the y direction, in GeV/c.
C
C PHKK(3,IHKK) : momentum in the z direction, in GeV/c.
C
C PHKK(4,IHKK) : energy, in GeV.
C
C PHKK(5,IHKK) : mass, in GeV/c**2. For spacelike partons, it is allowed
C    to use a negative mass, according to PHKK(5,IHKK) = -sqrt(-m**2).
C
C VHKK(1,IHKK) : production vertex x position, in mm.
C
C VHKK(2,IHKK) : production vertex y position, in mm.
C
C VHKK(3,IHKK) : production vertex z position, in mm.
C
C VHKK(4,IHKK) : production time, in mm/c (= 3.33*10**(-12) s).
C********************************************************************
*KEEP,NSHMAK.
      COMMON /NSHMAK/ NNSHMA,NPSHMA,NTSHMA,NSHMAC
*KEEP,DPAR.
C     /DPAR/   CONTAINS PARTICLE PROPERTIES
C        ANAME  = LITERAL NAME OF THE PARTICLE
C        AAM    = PARTICLE MASS IN GEV
C        GA     = DECAY WIDTH
C        TAU    = LIFE TIME OF INSTABLE PARTICLES
C        IICH   = ELECTRIC CHARGE OF THE PARTICLE
C        IIBAR  = BARYON NUMBER
C        K1,K1  = BIGIN AND END OF DECAY CHANNELS OF PARTICLE
C
      CHARACTER*8  ANAME
      COMMON /DPAR/ ANAME(210),AAM(210),GA(210),TAU(210),IICH(210),
     +IIBAR(210),K1(210),K2(210)
C------------------
*KEEP,NUCC.
      COMMON /NUCC/   IT,ITZ,IP,IPZ,IJPROJ,IBPROJ,IJTARG,IBTARG
*KEEP,DPRIN.
      COMMON /DPRIN/  IPRI,IPEV,IPPA,IPCO,INIT,IPHKK,ITOPD,IPAUPR
*KEND.
C                                   modified DPMJET
       COMMON /BUFUEH/ ANNVV,ANNSS,ANNSV,ANNVS,ANNCC,
     *                 ANNDV,ANNVD,ANNDS,ANNSD,
     *                 ANNHH,ANNZZ,
     *                 PTVV,PTSS,PTSV,PTVS,PTCC,PTDV,PTVD,PTDS,PTSD,
     *                 PTHH,PTZZ,
     *                 EEVV,EESS,EESV,EEVS,EECC,EEDV,EEVD,EEDS,EESD,
     *                 EEHH,EEZZ
     *                ,ANNDI,PTDI,EEDI
     *                ,ANNZD,ANNDZ,PTZD,PTDZ,EEZD,EEDZ
C---------------------
C---------------------
      DIMENSION  XYL(50,20),YYL(50,20),YYLPS(50,20),INDX(28)
      DIMENSION DISGEN(50),XGEN(50)
      PARAMETER (NUMTYP=160)
      DIMENSION AVMULT(NUMTYP),AVE(NUMTYP),AKE(NUMTYP),AVEPT(NUMTYP)
      DATA DISGEN /50*0.0/
      DATA INDX/ 1, 8,-1,-1,-1,-1,-1, 2,12,-1,-1,7,3,4,5,6,13,15,7,14,
     *          14,14,19, 7, 7,-1,-1,-1/
C----------------------------------------------------------------------
      ONEONE=1
      ZERO=0
      TWOTWO=2
      HUNDTH=1.D-2
C     CALL DISPT(IOP,NHKKH1,PO)
C     CALL DISEVA(IOP,NHKKH1,PO,IGENER)
      GO TO (1,2,3),IOP
*  initialization call
1     CONTINUE
      ANCHSQ=0.
      DELRAP=1.
      IF(IP.EQ.1)DELRAP=0.1
      NHKKH2=NHKKH1
      IF (NHKKH1.EQ.0)NHKKH2=1
      EEO=SQRT(PO**2+AAM(NHKKH2)**2)
      WRITE(6, 1001)EEO,PO,NHKKH2,AAM(NHKKH2)
 1001 FORMAT (' EEO',F10.2,F10.2,I10,F10.2)
      DY=0.4
C
      DO 11 I=1,20
        DO 13 J=1,50
          XYL(J,I)=-2.0 + (J-1)*DY
          YYL(J,I)=1.E-18
          YYLPS(J,I)=1.E-18
13      CONTINUE
11    CONTINUE
      DO 61 I=1,NUMTYP
        AVE(I)       =1.E-18
        AVEPT(I)       =1.E-18
        AVMULT(I)    =1.E-18
   61 CONTINUE
      RETURN
C-------------------------------------------------------------------
  2   CONTINUE
C                               SEWEW secondary interactions
      CALL SEWEW(1,NHKKH1)
*  scoring of results from individual events
C                            NUMBER OF GENERATIONS INSIDE THE NUCLEUS
      IF(IGENER.LT.1.OR.IGENER.GT.50) IGENER=50
      DISGEN(IGENER)=DISGEN(IGENER) + 1.0
C
C     WRITE (18,1711)
C1711 FORMAT (' event px,py,pz,e,id ')
      NHAD=0
      AVMULC=0.
C                          HBOOK HISTOGRAMS
C++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C     WRITE(6,'(A)')' before plomb'
      CALL PLOMB (2,P4P4P4,CCCHRG,XFXFXF,1,IJPROJ)
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C                Here we include the decayed resonances into the
C                        multiplicity Table
      IPRIEV=0
      DO 521 I=NHKKH1,NHKK
        IF (ISTHKK(I).EQ.2)THEN
C         WRITE(18,1712)PHKK(1,I),PHKK(2,I),PHKK(3,I),Phkk(4,I),IDHKK(I)
C         NHAD=NHAD+1
          NRHKK=MCIHAD(IDHKK(I))
          IF (NRHKK.LE.0.OR.NRHKK.GT.210)THEN
            WRITE(6,1389)NRHKK,I,IDHKK(I),NHKKH1,NHKK
            NRHKK=1
          ENDIF
          NRE=NRHKK
          NREM=NRE
          ICHHKK=IICH(NRHKK)
	  IF(NRE.GT.30)THEN
	  IF(NRE.GT.160)GO TO 521
            AVE(NREM)=AVE(NREM) + PHKK(4,I)
            AVEPT(NREM)=AVEPT(NREM) + PT
            AVMULT(NREM)=AVMULT(NREM) + 1.
	  ENDIF
        ENDIF
  521 CONTINUE
      DO 21 I=NHKKH1,NHKK
        IF (ISTHKK(I).EQ.1)THEN
C         WRITE(18,1712)PHKK(1,I),PHKK(2,I),PHKK(3,I),Phkk(4,I),IDHKK(I)
 1712     FORMAT (4E14.5,I8)
          NHAD=NHAD+1
          NRHKK=MCIHAD(IDHKK(I))
          IF (NRHKK.LE.0.OR.NRHKK.GT.210)THEN
            WRITE(6,1389)NRHKK,I,IDHKK(I),NHKKH1,NHKK
 1389       FORMAT (' DISTR: NRHKK ERROR ',5I10)
            NRHKK=1
          ENDIF
          NRE=NRHKK
          NREM=NRE
          ICHHKK=IICH(NRHKK)
*  rapidity
          PTT=PHKK(1,I)**2+PHKK(2,I)**2+0.000001
          PT=SQRT(PTT)
C         IF(PT.LT.0.5)GO TO 21
          AMT=SQRT(PTT+PHKK(5,I)**2)
C***      AMT=SQRT(PTT+AMPI**2)
C         ETOT=SQRT(AMT**2 + PHKK(3,I)**2)
C         YL=LOG((ETOT + PHKK(3,I))/AMT+1.E-18)
          YL=LOG((ABS(PHKK(3,I) + PHKK(4,I)))/AMT+1.E-18)
C         IF(YL.LT.0.75.OR.YL.GT.3.) GO TO 21  
          IF (NRE.GT.25) NRE=28
          IF (NRE.LT. 1) NRE=28
          IF(NREM.GT.NUMTYP) NREM=28
          IF(NREM.LT.1) NREM=28
          NI=INDX(NRE)
          IF (NRHKK.LE.101.AND.NRHKK.GE.99) NI=16
          IF (NRHKK.EQ.97.OR.NRHKK.EQ.98)   NI=17
          IF (NRHKK.EQ.102.OR.NRHKK.EQ.103) NI=18
          AVE(NREM)=AVE(NREM) + PHKK(4,I)
          AVEPT(NREM)=AVEPT(NREM) + PT
          AVMULT(NREM)=AVMULT(NREM) + 1.
C    TOTAL=30
          AVE(30)=AVE(30) + PHKK(4,I)
          AVEPT(30)=AVEPT(30) + PT
C    CHARGED=27
          IF (ICHHKK.NE.0)  THEN
            AVE(27)=AVE(27) + PHKK(4,I)
            AVEPT(27)=AVEPT(27) + PT
            AVMULC=AVMULC + 1.
            AVMULT(27)=AVMULT(27) + 1.
          ENDIF
          IYL=(YL+2.0)/DY + 1
          IF (IYL.LT.1)  IYL=1
          IF (IYL.GT.50) IYL=50
          IF (ICHHKK.NE.0) THEN
            YYL(IYL,9)=YYL(IYL,9)+1.
          ENDIF
          IF (ICHHKK.LT.0)    YYL(IYL,11)=YYL(IYL,11)+1.
          IF(NI.GT.0) YYL(IYL,NI)=YYL(IYL,NI)+1.
          YYL(IYL,10)=YYL(IYL,10)+1.
*  pseudorapidity
          PT=SQRT(PTT)
          PTOT=SQRT(PTT+PHKK(3,I)**2)
          YLPS=LOG((PTOT+PHKK(3,I))/PT)
          IYL=(YLPS+2.0)/DY + 1
          IF (IYL.LT.1)  IYL=1
          IF (IYL.GT.50) IYL=50
          IF (ICHHKK.NE.0) YYLPS(IYL,9)=YYLPS(IYL,9)+1.
          IF (ICHHKK.LT.0) YYLPS(IYL,11)=YYLPS(IYL,11)+1.
          IF(NI.GT.0) YYLPS(IYL,NI)=YYLPS(IYL,NI)+1.
          YYLPS(IYL,10)=YYLPS(IYL,10)+1.
C                         HBOOK HISTOGRAMS
C                          HBOOK HISTOGRAMS
C++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
           P4P4P4 (1) = PHKK(1,I)
           P4P4P4 (2) = PHKK(2,I)
           P4P4P4 (3) = PHKK(3,I)
           P4P4P4 (4) = PHKK(4,I)
           ITIF = NRHKK
            XFL=PHKK(4,I)/EEO	
           XFXFXF=XFL
           CCCHRG = ICHHKK
       	 CALL PLOMB (3,P4P4P4,
     *    CCCHRG,XFXFXF,ITIF,IJPROJ)
C++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
        ENDIF
21    CONTINUE
*  total multiplicity
      AVMULT(30)=AVMULT(30) + NHAD
      ANCHSQ=ANCHSQ+AVMULC**2
      ANHAD=NHAD
C                         HBOOK HISTOGRAMS
C++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
        CALL PLOMB (4,P4P4P4,
     *                  CCCHRG,XFXFXF,1,IJPROJ)
C++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
      RETURN
C
C--------------------------------------------------------------------
C
  3   CONTINUE
* output of final results
C      WRITE(6,'(1H1,50(1H*))')
C      WRITE(6,'(/10X,A/)')'OUTP.FR.DISTR 0.75.lt.y.lt.3., pt.gt.o.5'
C      WRITE(6,'(50(1H*))')
C                           NORMALIZE AND PRINT COUNTERS
      IF (ANNVV.GT.1.)THEN
        PTVV=PTVV/ANNVV
        EEVV=EEVV/ANNVV
      ENDIF
      IF (ANNSS.GT.1.)THEN
        PTSS=PTSS/ANNSS
        EESS=EESS/ANNSS
      ENDIF
      IF (ANNSV.GT.1.)THEN
        PTSV=PTSV/ANNSV
        EESV=EESV/ANNSV
      ENDIF
      IF (ANNVS.GT.1.)THEN
        PTVS=PTVS/ANNVS
        EEVS=EEVS/ANNVS
      ENDIF
      IF (ANNCC.GE.1.)THEN
        PTCC=PTCC/ANNCC
        EECC=EECC/ANNCC
      ENDIF
      IF (ANNVD.GT.1.)THEN
        PTVD=PTVD/ANNVD
        EEVD=EEVD/ANNVD
      ENDIF
      IF (ANNDV.GT.1.)THEN
        PTDV=PTDV/ANNDV
        EEDV=EEDV/ANNDV
      ENDIF
      IF (ANNSD.GT.1.)THEN
        PTSD=PTSD/ANNSD
        EESD=EESD/ANNSD
      ENDIF
      IF (ANNDS.GT.1.)THEN
        PTDS=PTDS/ANNDS
        EEDS=EEDS/ANNDS
      ENDIF
      IF (ANNHH.GE.1.)THEN
        PTHH=PTHH/ANNHH
        EEHH=EEHH/ANNHH
      ENDIF
      IF (ANNZZ.GE.1.)THEN
        PTZZ=PTZZ/ANNZZ
        EEZZ=EEZZ/ANNZZ
      ENDIF
      IF (NHKKH1.GT.1.)THEN
        ANNVV=ANNVV/NHKKH1
        ANNSS=ANNSS/NHKKH1
        ANNSV=ANNSV/NHKKH1
        ANNVS=ANNVS/NHKKH1
        ANNCC=ANNCC/NHKKH1
        ANNHH=ANNHH/NHKKH1
        ANNZZ=ANNZZ/NHKKH1
        ANNDV=ANNDV/NHKKH1
        ANNVD=ANNVD/NHKKH1
        ANNDS=ANNDS/NHKKH1
        ANNSD=ANNSD/NHKKH1
        ANCHSQ=ANCHSQ/NHKKH1
C       WRITE (6,7431)ANNVV,PTVV,EEVV,
C    *              ANNSS,PTSS,EESS,
C    *              ANNSV,PTSV,EESV,
C    *              ANNVS,PTVS,EEVS,
C    *              ANNDV,PTDV,EEDV,
C    *              ANNVD,PTVD,EEVD,
C    *              ANNDS,PTDS,EEDS,
C    *              ANNSD,PTSD,EESD,
C    *              ANNHH,PTHH,EEHH,
C    *              ANNZZ,PTZZ,EEZZ,
C    *              ANNCC,PTCC,EECC
C7431   FORMAT ('  VV CHAINS NN,PT ECM: ',3F12.4/
C    *          '  SS CHAINS NN,PT ECM: ',3F12.4/
C    *          '  SV CHAINS NN,PT ECM: ',3F12.4/
C    *          '  VS CHAINS NN,PT ECM: ',3F12.4/
C    *          '  DV CHAINS NN,PT ECM: ',3F12.4/
C    *          '  VD CHAINS NN,PT ECM: ',3F12.4/
C    *          '  DS CHAINS NN,PT ECM: ',3F12.4/
C    *          '  SD CHAINS NN,PT ECM: ',3F12.4/
C    *          '  HH CHAINS NN,PT ECM: ',3F12.4/
C    *          '  ZZ CHAINS NN,PT ECM: ',3F12.4/
C    *          '  CC CHAINS NN,PT ECM: ',3F12.4)
      ENDIF
C
C                            DISTRIBUTION FOR
C                            NUMBER OF GENERATIONS INSIDE THE NUCLEUS
C                            (NORMALIZED TO 1)
      AVGNOR=0.0
      AVGEN=0.0
      DO 801 IGE=1,50
        AVGNOR=AVGNOR + DISGEN(IGE)
        AVGEN=AVGEN + IGE*DISGEN(IGE)
 801  CONTINUE
      DO 802 IGE=1,50
        XGEN(IGE)=FLOAT(IGE) - 0.5
        DISGEN(IGE)=DISGEN(IGE)/AVGNOR
 802  CONTINUE
      AVGEN=AVGEN/AVGNOR
C     WRITE(*,'(A,1PE10.2//A)')
C    &      ' AVERAGE NUMBER OF GENERATIONS INSIDE THE NUCLEUS =',
C    &      AVGEN,
C    &      ' CORRESPONDING DISTRIBUTION (NORMALIZED TO 1.0)'
C     CALL PLOT(XGEN,DISGEN,50,1,50,ZERO,ONEONE,ZERO,HUNDTH)
C
      DO 310 I=1,NUMTYP
        AVMULT(I)=AVMULT(I)/NHKKH1
        AVE(I)=AVE(I)/NHKKH1
        AVEPT(I)=AVEPT(I)/(NHKKH1*AVMULT(I))
310   CONTINUE
      FFFF2=SQRT(ANCHSQ-AVMULT(27)**2)/AVMULT(27)
C     WRITE(6,7772)FFFF2,ANCHSQ,AVMULT(27)
C7772 FORMAT(' FFFF2,ANCHSQ,AVMULT(27):',3E15.5)
      WRITE(6, 64)
   64 FORMAT(' PARTICLE REF,CHAR,IBAR, MASS      AVERAGE',
     *' ENERGY, MULTIPLICITY, INELASTICITY')
      DO 62 I=1,NUMTYP
        AKE(I)=AVE(I)/EEO
        WRITE(6, 63) ANAME(I),I,IICH(I),IIBAR(I),AAM(I),
     *               AVE(I),AVMULT(I),AKE(I),AVEPT(I)
   63   FORMAT (' ',A8,3I5,F10.3,4F15.6)
   62 CONTINUE
C
      DO 33 I=1,20
      DO 35 J=1,50
        YYL(J,I)  =YYL(J,I)  /(NHKKH1*DY)
        YYLPS(J,I)=YYLPS(J,I)/(NHKKH1*DY)
35    CONTINUE
33    CONTINUE
      WRITE(6,'(1H1,11(A/))')
     &   '  Conventions for rapidity distributions: ',
     &   '     1  Proton                       11  NEGATIVES          ',
     &   '     2  Neutron                      12  NBAR=9             ',
     &   '     3  PI+=13                       13  LAMBDA=17          ',
     &   '     4  PI-=14                       14  SIGMA==20,21,22    ',
     &   '     5  K+ =15                       15  LAMBDABAR=18       ',
     &   '     6  K- =16                       16  SIGMABAR=99,100,101',
     &   '     7  neutral kaons=12,19,24,25    17  THETA=97,98        ',
     &   '     8  pbar=2                       18  THETABAR=102,103   ',
     &   '     9  charged hadrons ',
     &   '    10  total hadrons '
      WRITE(6, 66)
   66 FORMAT(' RAPIDITY DISTRIBUTION')
      WRITE(6,302)
 302  FORMAT ('   (first number gives the lower bin limit)')
      DO 36 J=1,50
        WRITE(6, 37) XYL(J,1),(YYL(J,I),I=1,10)
37      FORMAT (F10.2,10E11.3)
36    CONTINUE
      WRITE(6, 66)
      WRITE(6,302)
      DO 306 J=1,50
      WRITE(6, 37) XYL(J,1),(YYL(J,I),I=11,20)
306   CONTINUE
C
      WRITE(6, 66 )
      CALL PLOT(XYL,YYL,1000,20,50,-TWOTWO,DY,ZERO,DELRAP)
*  rescaled rapidity distribution
      CALL PLOT(XYL,YYL,1000,20,50,-TWOTWO,DY,ZERO,5.*DELRAP)
*  logarithmic rapidity distribution
      DO 38 I=1,20
      DO 38 J=1,50
        YYL(J,I)=LOG10(ABS(YYL(J,I))+1.E-8)
 38   CONTINUE
      WRITE(6, 66)
      CALL PLOT(XYL,YYL,1000,20,50,-TWOTWO,DY,-TWOTWO,5.*HUNDTH)
C
      WRITE(6,301)
  301 FORMAT ('1 PSEUDORAPIDITY DISTRIBUTION')
      WRITE(6,302)
      DO 303 J=1,50
        WRITE(6,37) XYL(J,1),(YYLPS(J,I),I=1,10)
  303 CONTINUE
      WRITE(6,301)
      WRITE(6,302)
      DO 304 J=1,50
      WRITE(6,37) XYL(J,1),(YYLPS(J,I),I=11,20)
  304 CONTINUE
      WRITE(6,301)
      CALL PLOT(XYL,YYLPS,1000,20,50,-TWOTWO,DY,ZERO,DELRAP)
      CALL PLOT(XYL,YYLPS,1000,20,50,-TWOTWO,DY,ZERO,5.D0*DELRAP)
      RETURN
      END
*CMZ :  1.00/02 08/01/92  17.24.06  by  H.-J. Moehring & J. Ranft
*CMZ :  1.00/01 25/11/91  15.30.00  by  H.-J. Mhring
*-- Author :
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
      SUBROUTINE DISTRC(IOP,NHKKH1,PO,IGENER)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C***
C   REDUCED VERSION FOR SCORING RESULTS FROM PRIMARY AA INTERACTION
C   FROM /HKKEVT/
C   kinematics in cms 
C      - MULTIPLICITIES
C      - number of inc generations inside the nucleus
C      - RAPIDITY DISTRIBUTION         (without cuts)
C      - pseudorapidity distribution   (without cuts)
C***
C  conventions for rapidity distributions:
C       1  Proton                       11  NEGATIVES
C       2  Neutron                      12  NBAR=9
C       3  PI+=13                       13  LAMBDA=17
C       4  PI-=14                       14  SIGMA==20,21,22
C       5  K+ =15                       15  LAMBDABAR=18
C       6  K- =16                       16  SIGMABAR=99,100,101
C       7  neutral kaons=12,19,24,25    17  THETA=97,98
C       8  pbar=2                       18  THETABAR=102,103
C       9  charged hadrons
C      10  total hadrons
C-----------------------------------------------------------------------
*KEEP,HKKEVT.
c     INCLUDE (HKKEVT)
C     PARAMETER (NMXHKK=49998)
      PARAMETER (NMXHKK= 49998)
c     PARAMETER (NMXHKK=25000)
      COMMON /HKKEVT/ NHKK,NEVHKK,ISTHKK(NMXHKK),IDHKK(NMXHKK), JMOHKK
     +(2,NMXHKK),JDAHKK(2,NMXHKK), PHKK(5,NMXHKK),VHKK(4,NMXHKK),WHKK
     +(4,NMXHKK)
C
C                       WHKK(4,NMXHKK) GIVES POSITIONS AND TIMES IN
C                       PROJECTILE FRAME, THE CHAINS ARE CREATED ON
C                       THE POSITIONS OF THE PROJECTILE NUCLEONS
C                       IN THE PROJECTILE FRAME (TARGET NUCLEONS IN
C                       TARGET FRAME) BOTH POSITIONS ARE THREFORE NOT
C                       COMPLETELY CONSISTENT. THE TIMES IN THE
C                       PROJECTILE FRAME HOWEVER ARE OBTAINED BY
C                       LORENTZ TRANSFORMING FROM THE LAB SYSTEM.
C
C  Based on the proposed standard COMMON block (Sjostrand Memo 17.3,89)
C
C NMXHKK: maximum numbers of entries (partons/particles) that can be
C    stored in the commonblock.
C
C NHKK: the actual number of entries stored in current event. These are
C    found in the first NHKK positions of the respective arrays below.
C    Index IHKK, 1 <= IHKK <= NHKK, is below used to denote a given
C    entry.
C
C ISTHKK(IHKK): status code for entry IHKK, with following meanings:
C    = 0 : null entry.
C    = 1 : an existing entry, which has not decayed or fragmented.
C        This is the main class of entries which represents the
C        "final state" given by the generator.
C    = 2 : an entry which has decayed or fragmented and therefore
C        is not appearing in the final state, but is retained for
C        event history information.
C    = 3 : a documentation line, defined separately from the event
C        history. (incoming reacting
C        particles, etc.)
C    = 4 - 10 : undefined, but reserved for future standards.
C    = 11 - 20 : at the disposal of each model builder for constructs
C        specific to his program, but equivalent to a null line in the
C        context of any other program. One example is the cone defining
C        vector of HERWIG, another cluster or event axes of the JETSET
C        analysis routines.
C    = 21 - : at the disposal of users, in particular for event tracking
C        in the detector.
C
C IDHKK(IHKK) : particle identity, according to the Particle Data Group
C    standard.
C
C JMOHKK(1,IHKK) : pointer to the position where the mother is stored.
C    The value is 0 for initial entries.
C
C JMOHKK(2,IHKK) : pointer to position of second mother. Normally only
C    one mother exist, in which case the value 0 is used. In cluster
C    fragmentation models, the two mothers would correspond to the q
C    and qbar which join to form a cluster. In string fragmentation,
C    the two mothers of a particle produced in the fragmentation would
C    be the two endpoints of the string (with the range in between
C    implied).
C
C JDAHKK(1,IHKK) : pointer to the position of the first daughter. If an
C    entry has not decayed, this is 0.
C
C JDAHKK(2,IHKK) : pointer to the position of the last daughter. If an
C    entry has not decayed, this is 0. It is assumed that the daughters
C    of a particle (or cluster or string) are stored sequentially, so
C    that the whole range JDAHKK(1,IHKK) - JDAHKK(2,IHKK) contains
C    daughters. Even in cases where only one daughter is defined (e.g.
C    K0 -> K0S) both values should be defined, to make for a uniform
C    approach in terms of loop constructions.
C
C PHKK(1,IHKK) : momentum in the x direction, in GeV/c.
C
C PHKK(2,IHKK) : momentum in the y direction, in GeV/c.
C
C PHKK(3,IHKK) : momentum in the z direction, in GeV/c.
C
C PHKK(4,IHKK) : energy, in GeV.
C
C PHKK(5,IHKK) : mass, in GeV/c**2. For spacelike partons, it is allowed
C    to use a negative mass, according to PHKK(5,IHKK) = -sqrt(-m**2).
C
C VHKK(1,IHKK) : production vertex x position, in mm.
C
C VHKK(2,IHKK) : production vertex y position, in mm.
C
C VHKK(3,IHKK) : production vertex z position, in mm.
C
C VHKK(4,IHKK) : production time, in mm/c (= 3.33*10**(-12) s).
C********************************************************************
*KEEP,NSHMAK.
      COMMON /NSHMAK/ NNSHMA,NPSHMA,NTSHMA,NSHMAC
*KEEP,DPAR.
C     /DPAR/   CONTAINS PARTICLE PROPERTIES
C        ANAME  = LITERAL NAME OF THE PARTICLE
C        AAM    = PARTICLE MASS IN GEV
C        GA     = DECAY WIDTH
C        TAU    = LIFE TIME OF INSTABLE PARTICLES
C        IICH   = ELECTRIC CHARGE OF THE PARTICLE
C        IIBAR  = BARYON NUMBER
C        K1,K1  = BIGIN AND END OF DECAY CHANNELS OF PARTICLE
C
      CHARACTER*8  ANAME
      COMMON /DPAR/ ANAME(210),AAM(210),GA(210),TAU(210),IICH(210),
     +IIBAR(210),K1(210),K2(210)
C------------------
*KEEP,NUCC.
      COMMON /NUCC/   IT,ITZ,IP,IPZ,IJPROJ,IBPROJ,IJTARG,IBTARG
*KEEP,DPRIN.
      COMMON /DPRIN/  IPRI,IPEV,IPPA,IPCO,INIT,IPHKK,ITOPD,IPAUPR
*KEND.
C                                   modified DPMJET
       COMMON /BUFUEH/ ANNVV,ANNSS,ANNSV,ANNVS,ANNCC,
     *                 ANNDV,ANNVD,ANNDS,ANNSD,
     *                 ANNHH,ANNZZ,
     *                 PTVV,PTSS,PTSV,PTVS,PTCC,PTDV,PTVD,PTDS,PTSD,
     *                 PTHH,PTZZ,
     *                 EEVV,EESS,EESV,EEVS,EECC,EEDV,EEVD,EEDS,EESD,
     *                 EEHH,EEZZ
     *                ,ANNDI,PTDI,EEDI
     *                ,ANNZD,ANNDZ,PTZD,PTDZ,EEZD,EEDZ
C---------------------
      CHARACTER*80 TITLE
      CHARACTER*8 PROJTY,TARGTY
C     COMMON /USER/TITLE,PROJTY,TARGTY,CMENER,ISTRUF
C    &            ,ISINGD,IDUBLD,SDFRAC,PTLAR
      COMMON /USER1/TITLE,PROJTY,TARGTY
      COMMON /USER2/CMENER,SDFRAC,PTLAR,ISTRUF,ISINGD,IDUBLD
      DIMENSION  XYL(50,20),YYL(50,20),YYLPS(50,20),INDX(28)
      DIMENSION DISGEN(50),XGEN(50)
      PARAMETER (NUMTYP=160)
      DIMENSION AVMULT(NUMTYP),AVE(NUMTYP),AKE(NUMTYP),AVEPT(NUMTYP)
      DATA DISGEN /50*0.0/
      DATA INDX/ 1, 8,-1,-1,-1,-1,-1, 2,12,-1,-1,7,3,4,5,6,13,15,7,14,
     *          14,14,19, 7, 7,-1,-1,-1/
      DATA NIPRIE /0/
C----------------------------------------------------------------------
C     CALL DISPT(IOP,NHKKH1,PO)
      GO TO (1,2,3),IOP
*  initialization call
1     CONTINUE
C                             initialize ALICE output
C     CALL SHINIT
C
      ANCHSQ=0.
      DELRAP=1.
      IF(IP.EQ.1)DELRAP=0.1
      NHKKH2=NHKKH1
      IF (NHKKH1.EQ.0)NHKKH2=1
      EEO=SQRT(PO**2+AAM(NHKKH2)**2)
      WRITE(6, 1001)EEO,PO,NHKKH2,AAM(NHKKH2)
 1001 FORMAT (' EEO',F10.2,F10.2,I10,F10.2)
      DY=0.4
C
      DO 11 I=1,20
        DO 13 J=1,50
          XYL(J,I)=-10.0 + (J-1)*DY
          YYL(J,I)=1.E-18
          YYLPS(J,I)=1.E-18
13      CONTINUE
11    CONTINUE
      DO 61 I=1,NUMTYP
        AVE(I)       =1.E-18
        AVEPT(I)       =1.E-18
        AVMULT(I)    =1.E-18
   61 CONTINUE
      RETURN
C-------------------------------------------------------------------
  2   CONTINUE
C                               SEWEW secondary interactions
      CALL SEWEW(1,NHKKH1)
      IEVT=IEVT+1
C                  output for ALICE
C     CALL SHEVUT(IEVT)
C
*  scoring of results from individual events
C                            NUMBER OF GENERATIONS INSIDE THE NUCLEUS
      IF(IGENER.LT.1.OR.IGENER.GT.50) IGENER=50
      DISGEN(IGENER)=DISGEN(IGENER) + 1.0
C
C     WRITE (18,1711)
C1711 FORMAT (' event px,py,pz,e,id ')
      NHAD=0
      AVMULC=0.
C                Here we include the decayed resonances into the
C                        multiplicity Table
      IPRIEV=0
      DO 521 I=NHKKH1,NHKK
        IF (ISTHKK(I).EQ.2)THEN
C         WRITE(18,1712)PHKK(1,I),PHKK(2,I),PHKK(3,I),Phkk(4,I),IDHKK(I)
C         NHAD=NHAD+1
          NRHKK=MCIHAD(IDHKK(I))
          IF (NRHKK.LE.0.OR.NRHKK.GT.210)THEN
            WRITE(6,1389)NRHKK,I,IDHKK(I),NHKKH1,NHKK
            NRHKK=1
          ENDIF
          NRE=NRHKK
          NREM=NRE
          ICHHKK=IICH(NRHKK)
	  IF(NRE.GT.30)THEN
	  IF(NRE.GT.160)GO TO 521
            AVEPT(NREM)=AVEPT(NREM) + PT
            AVMULT(NREM)=AVMULT(NREM) + 1.
	  ENDIF
        ENDIF
  521 CONTINUE
      DO 21 I=NHKKH1,NHKK
        IF (ISTHKK(I).EQ.1)THEN
C         WRITE(18,1712)PHKK(1,I),PHKK(2,I),PHKK(3,I),Phkk(4,I),IDHKK(I)
 1712     FORMAT (4E14.5,I8)
          IF(PHKK(4,I).GT.CMENER/2.D0)THEN
            IPRIEV=1
            NIPRIE=NIPRIE+1
          ENDIF 
          NHAD=NHAD+1
          NRHKK=MCIHAD(IDHKK(I))
          IF (NRHKK.LE.0.OR.NRHKK.GT.210)THEN
            WRITE(6,1389)NRHKK,I,IDHKK(I),NHKKH1,NHKK
 1389       FORMAT (' DISTR: NRHKK ERROR ',5I10)
            NRHKK=1
          ENDIF
          NRE=NRHKK
          NREM=NRE
          ICHHKK=IICH(NRHKK)
*  rapidity
          PTT=PHKK(1,I)**2+PHKK(2,I)**2+0.000001
          PT=SQRT(PTT)
C         IF(PT.LT.0.5)GO TO 21
          AMT=SQRT(PTT+PHKK(5,I)**2)
C***      AMT=SQRT(PTT+AMPI**2)
C         ETOT=SQRT(AMT**2 + PHKK(3,I)**2)
C         YL=LOG((ETOT + PHKK(3,I))/AMT+1.E-18)
          YL=LOG((ABS(PHKK(3,I) + PHKK(4,I)))/AMT+1.E-18)
C         IF(YL.LT.0.75.OR.YL.GT.3.) GO TO 21  
          IF (NRE.GT.25) NRE=28
          IF (NRE.LT. 1) NRE=28
          IF(NREM.GT.NUMTYP) NREM=28
          IF(NREM.LT.1) NREM=28
          NI=INDX(NRE)
          IF (NRHKK.LE.101.AND.NRHKK.GE.99) NI=16
          IF (NRHKK.EQ.97.OR.NRHKK.EQ.98)   NI=17
          IF (NRHKK.EQ.102.OR.NRHKK.EQ.103) NI=18
          AVE(NREM)=AVE(NREM) + PHKK(4,I)
          AVEPT(NREM)=AVEPT(NREM) + PT
          AVMULT(NREM)=AVMULT(NREM) + 1.
C    TOTAL=30
          AVE(30)=AVE(30) + PHKK(4,I)
          AVEPT(30)=AVEPT(30) + PT
C    CHARGED=27
          IF (ICHHKK.NE.0)  THEN
            AVE(27)=AVE(27) + PHKK(4,I)
            AVEPT(27)=AVEPT(27) + PT
            AVMULC=AVMULC + 1.
            AVMULT(27)=AVMULT(27) + 1.
          ENDIF
          IYL=(YL+10.0)/DY + 1
          IF (IYL.LT.1)  IYL=1
          IF (IYL.GT.50) IYL=50
          IF (ICHHKK.NE.0) THEN
            YYL(IYL,9)=YYL(IYL,9)+1.
          ENDIF
          IF (ICHHKK.LT.0)    YYL(IYL,11)=YYL(IYL,11)+1.
          IF(NI.GT.0) YYL(IYL,NI)=YYL(IYL,NI)+1.
          YYL(IYL,10)=YYL(IYL,10)+1.
*  pseudorapidity
          PT=SQRT(PTT)
          PTOT=SQRT(PTT+PHKK(3,I)**2)
          YLPS=LOG((PTOT+PHKK(3,I))/PT)
          IYL=(YLPS+10.0)/DY + 1
          IF (IYL.LT.1)  IYL=1
          IF (IYL.GT.50) IYL=50
          IF (ICHHKK.NE.0) YYLPS(IYL,9)=YYLPS(IYL,9)+1.
          IF (ICHHKK.LT.0) YYLPS(IYL,11)=YYLPS(IYL,11)+1.
          IF(NI.GT.0) YYLPS(IYL,NI)=YYLPS(IYL,NI)+1.
          YYLPS(IYL,10)=YYLPS(IYL,10)+1.
        ENDIF
21    CONTINUE
      IF(IPRIEV.EQ.-1)THEN
      IF(NIPRIE.LT.20)THEN
         WRITE(6,*)' IPRIEV = 1 '
         DO 120 IHKK=1,NHKK
          WRITE(6,1050) IHKK,ISTHKK(IHKK),IDHKK(IHKK),JMOHKK(1,IHKK),
     +    JMOHKK(2,IHKK), JDAHKK(1,IHKK),JDAHKK(2,IHKK),
     +    (PHKK(KHKK,IHKK),KHKK=1,5)
120   CONTINUE
 1050 FORMAT (I6,I4,5I6,5E16.8)
      ENDIF
      ENDIF
*  total multiplicity
      AVMULT(30)=AVMULT(30) + NHAD
      ANCHSQ=ANCHSQ+AVMULC**2
      ANHAD=NHAD
      RETURN
C
C--------------------------------------------------------------------
C
  3   CONTINUE
C                             output for ALICE
C     CALL SHEND
C
* output of final results
C     WRITE(6,'(1H1,50(1H*))')
C     WRITE(6,'(/10X,A/)')'OUTP.FR.DISTR 0.75.lt.y.lt.3., pt.gt.o.5'
C     WRITE(6,'(50(1H*))')
C                           NORMALIZE AND PRINT COUNTERS
      IF (ANNVV.GT.1.)THEN
        PTVV=PTVV/ANNVV
        EEVV=EEVV/ANNVV
      ENDIF
      IF (ANNSS.GT.1.)THEN
        PTSS=PTSS/ANNSS
        EESS=EESS/ANNSS
      ENDIF
      IF (ANNSV.GT.1.)THEN
        PTSV=PTSV/ANNSV
        EESV=EESV/ANNSV
      ENDIF
      IF (ANNVS.GT.1.)THEN
        PTVS=PTVS/ANNVS
        EEVS=EEVS/ANNVS
      ENDIF
      IF (ANNCC.GE.1.)THEN
        PTCC=PTCC/ANNCC
        EECC=EECC/ANNCC
      ENDIF
      IF (NHKKH1.GT.1.)THEN
        ANNVV=ANNVV/NHKKH1
        ANNSS=ANNSS/NHKKH1
        ANNSV=ANNSV/NHKKH1
        ANNVS=ANNVS/NHKKH1
        ANNCC=ANNCC/NHKKH1
        ANCHSQ=ANCHSQ/NHKKH1
        WRITE (6,7431)ANNVV,PTVV,EEVV,
     *              ANNSS,PTSS,EESS,
     *              ANNSV,PTSV,EESV,
     *              ANNVS,PTVS,EEVS,
     *              ANNCC,PTCC,EECC
 7431   FORMAT ('  VV CHAINS NN,PT ECM: ',3F12.4/
     *          '  SS CHAINS NN,PT ECM: ',3F12.4/
     *          '  SV CHAINS NN,PT ECM: ',3F12.4/
     *          '  VS CHAINS NN,PT ECM: ',3F12.4/
     *          '  CC CHAINS NN,PT ECM: ',3F12.4)
      ENDIF
C
C                            DISTRIBUTION FOR
C                            NUMBER OF GENERATIONS INSIDE THE NUCLEUS
C                            (NORMALIZED TO 1)
      AVGNOR=0.0
      AVGEN=0.0
      DO 801 IGE=1,50
        AVGNOR=AVGNOR + DISGEN(IGE)
        AVGEN=AVGEN + IGE*DISGEN(IGE)
 801  CONTINUE
      DO 802 IGE=1,50
        XGEN(IGE)=FLOAT(IGE) - 0.5
        DISGEN(IGE)=DISGEN(IGE)/AVGNOR
 802  CONTINUE
      AVGEN=AVGEN/AVGNOR
C     WRITE(*,'(A,1PE10.2//A)')
C    &      ' AVERAGE NUMBER OF GENERATIONS INSIDE THE NUCLEUS =',
C    &      AVGEN,
C    &      ' CORRESPONDING DISTRIBUTION (NORMALIZED TO 1.0)'
C     CALL PLOT(XGEN,DISGEN,50,1,50,0.0D0,1.0D0,0.0D0,0.01D0)
C
      DO 310 I=1,NUMTYP
        AVMULT(I)=AVMULT(I)/NHKKH1
        AVE(I)=AVE(I)/NHKKH1
        AVEPT(I)=AVEPT(I)/(NHKKH1*AVMULT(I))
310   CONTINUE
      FFFF2=SQRT(ANCHSQ-AVMULT(27)**2)/AVMULT(27)
      WRITE(6,7772)FFFF2,ANCHSQ,AVMULT(27)
 7772 FORMAT(' FFFF2,ANCHSQ,AVMULT(27):',3E15.5)
      WRITE(6, 64)
   64 FORMAT(' PARTICLE REF,CHAR,IBAR, MASS      AVERAGE',
     *' ENERGY, MULTIPLICITY, INELASTICITY')
      DO 62 I=1,NUMTYP
        AKE(I)=AVE(I)/CMENER
        WRITE(6, 63) ANAME(I),I,IICH(I),IIBAR(I),AAM(I),
     *               AVE(I),AVMULT(I),AKE(I),AVEPT(I)
   63   FORMAT (' ',A8,3I5,F10.3,4E15.5)
   62 CONTINUE
C
      DO 33 I=1,20
      DO 35 J=1,50
        YYL(J,I)  =YYL(J,I)  /(NHKKH1*DY)
        YYLPS(J,I)=YYLPS(J,I)/(NHKKH1*DY)
35    CONTINUE
33    CONTINUE
      WRITE(6,'(1H1,11(A/))')
     &   '  Conventions for rapidity distributions: ',
     &   '     1  Proton                       11  NEGATIVES          ',
     &   '     2  Neutron                      12  NBAR=9             ',
     &   '     3  PI+=13                       13  LAMBDA=17          ',
     &   '     4  PI-=14                       14  SIGMA==20,21,22    ',
     &   '     5  K+ =15                       15  LAMBDABAR=18       ',
     &   '     6  K- =16                       16  SIGMABAR=99,100,101',
     &   '     7  neutral kaons=12,19,24,25    17  THETA=97,98        ',
     &   '     8  pbar=2                       18  THETABAR=102,103   ',
     &   '     9  charged hadrons ',
     &   '    10  total hadrons '
      WRITE(6, 66)
   66 FORMAT(' RAPIDITY DISTRIBUTION')
      WRITE(6,302)
 302  FORMAT ('   (first number gives the lower bin limit)')
      DO 36 J=1,50
        WRITE(6, 37) XYL(J,1),(YYL(J,I),I=1,10)
37      FORMAT (F10.2,10E11.3)
36    CONTINUE
      WRITE(6, 66)
      WRITE(6,302)
      DO 306 J=1,50
      WRITE(6, 37) XYL(J,1),(YYL(J,I),I=11,20)
306   CONTINUE
C
      WRITE(6, 66 )
      CALL PLOT(XYL,YYL,1000,20,50,-10.D0,DY,0.D0,DELRAP)
*  rescaled rapidity distribution
      CALL PLOT(XYL,YYL,1000,20,50,-10.D0,DY,0.D0,5.D0*DELRAP)
*  logarithmic rapidity distribution
      DO 38 I=1,20
      DO 38 J=1,50
        YYL(J,I)=LOG10(ABS(YYL(J,I))+1.E-8)
 38   CONTINUE
      WRITE(6, 66)
      CALL PLOT(XYL,YYL,1000,20,50,-10.D0,DY,-2.0D0,0.05D0)
C
      WRITE(6,301)
  301 FORMAT ('1 PSEUDORAPIDITY DISTRIBUTION')
      WRITE(6,302)
      DO 303 J=1,50
        WRITE(6,37) XYL(J,1),(YYLPS(J,I),I=1,10)
  303 CONTINUE
      WRITE(6,301)
      WRITE(6,302)
      DO 304 J=1,50
      WRITE(6,37) XYL(J,1),(YYLPS(J,I),I=11,20)
  304 CONTINUE
      WRITE(6,301)
      CALL PLOT(XYL,YYLPS,1000,20,50,-10.D0,DY,0.D0,DELRAP)
      CALL PLOT(XYL,YYLPS,1000,20,50,-10.D0,DY,0.D0,5.D0*DELRAP)
      RETURN
      END
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE DISTRP(IOP,NHKKH1,PO)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      RETURN
      END
C--------------------------------------------Dummies----------
      SUBROUTINE DISTCO(IOP,IJPROJ,PPN,IDUMMY)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      RETURN
      END
      SUBROUTINE DISTPA(IOP)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      RETURN
      END
      SUBROUTINE DISRES(IOP,IJPROJ,PPN)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      RETURN
      END
      SUBROUTINE EDENSI(I,J)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      RETURN
      END
   
C***********************************************************************


      SUBROUTINE PLOMB(IFL,PP,CHAR,XLA,ITIF,IJPROJ) 
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C
C---------------------------------------------------------------------
C
C                 DEFINITION of variables:
C
C         PP(4) REAL:PPP(4): 4-momentum of hadron in GeV/v
C
C         CHAR REAL:CHARCH:  Charge of hadron
C
C         XLA Real:XLAXLA:   Lab. x of hadron
C
C         PPROJ REAL:POPO:   Lab. momentum of projectile GeV/c
C
C         TMA:               Mass of projectile in GeV/c**2
C
C         PT REAL:PTPT       Trans. momentum of hadron GeV/c
C
C         PPCMS(4) REAL:PPCMSP(4): cms 4-momentum of hadron GeV/c
C
C         UMO                cms energy of collision GeV
C
C         XF REAL:XFXF:      Feynman x of hadron
C
C         YLAB REAL:YLABYL:  Lab. rapidity
C
C         ETALA REAL:ETALAB: Lab pseudorapidity
C
C         ETACM REAL ETACME: cms pseudorapidity
C
C         YCM REAL:YCMYCM:   cms rapidity
C
C         THET REAL:THETET:  production angle of hadron
C
C         PMOD REAL:PMODOD:  mod of lab momentum GeV/c
C    
C         REAL:YBEAM:        log(UMO/TMA)
C
C         IT                 (BAMJET) kind of hadron
C
C         IJPROJ             (BAMJET) kind of projectile
C
C---------------------------------------------------------------------
C
      COMMON/NNCMS/GAMCM,BGCM,UMO,PCM,EPROJ,PPROJ
C     REAL POPO,PPPP(4),CHARCH,PTPT,PPCMSP(4),XFXF,YLABYL,
C    *ETALAB,ETACME,YCMYCM,YBEAM,XLAXLA,THETET,PMODOD,E6
      DIMENSION PPPP(4),PPCMSP(4)
      PARAMETER (E6=1.D18)
      DIMENSION PP(4),PPCMS(4)                                                  
      CHARACTER*8 ANAME
      COMMON /DPAR/ANAME(210),AAM(210),GA(210),TAU(210),IICH(210),
     *IIBAR(210),K1(210),K2(210)
      DATA TMA /.938D0 /
C   
C  INTERFACE between DPMJET DISTR (Lab) and PLOMBR HB Histograms
C
C  PLOMB still DOUBLE PRECISION PLOMBR single precision
C
C  FURTHERMORE plomb calculates CMS-QUANTITIES
C
C IFL=1 START JOB=2 START EVENT=3 PART. LOOP=4 END EV.=5 END JOB        
C PP CHAR ITIF MOMENTUM CHARGE ID. (FLUKA-LIKE) OF CURRENT PARTICLE
C   
C-----------------------------------------------------------   
      IF(IFL.EQ.1)THEN
C                          Start job
      TMA=AAM(IJPROJ)
      POPO=PPROJ
      WRITE(6,'(A,2F10.2)')' plomb:pproj,popo',PPROJ,POPO
      IF(POPO.GE.E6)POPO=E6
C-----------------------------------------------------------   
      ELSEIF(IFL.EQ.2)THEN
C                          START event
      YBEAM=LOG(UMO/TMA)
      POPO=PPROJ
      IF(POPO.GE.E6)POPO=E6
C-----------------------------------------------------------   
      ELSEIF(IFL.EQ.3)THEN
C                          Particle loop
      CHARCH=CHAR
      CALL KIN(PP,PT,RAP,PPCMS,XF,YLAB,ETALA,ETACM,YCM,
     * THET,PMOD,XLA)
      XLAXLA=XLA
      PMODOD=PMOD
      THETET=THET
      YCMYCM=YCM
      ETACME=ETACM
      ETALAB=ETALA
      YLABYL=YLAB
      DO 30 II=1,4
      PPPP(II)=PP(II)
      IF(PPPP(II).GE.E6)PPPP(II)=E6
      PPCMSP(II)=PPCMS(II)
   30 CONTINUE
      IBARF=IIBAR(ITIF)
      XFXF=XF
      PTPT=PT
C-----------------------------------------------------------   
      ELSEIF(IFL.EQ.4)THEN
C                          End event
C-----------------------------------------------------------   
      ELSEIF(IFL.EQ.5)THEN
C                          End job
      ENDIF
      CALL PLOMBR(POPO,IJPROJ,IFL,PPPP,CHARCH,XFXF,XLAXLA,
     *PTPT,PPCMSP,YLABYL,ETALAB,ETACME,YCMYCM,YBEAM,
     *ITIF,THETET,PMODOD,IBARF)
      RETURN
      END
C***********************************************************************

      SUBROUTINE PLOMBC(IFL,PPCMS,CHAR,XLA,ITIF,IJPROJ) 
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C
C---------------------------------------------------------------------
C
C                 DEFINITION of variables:
C
C         PP(4) REAL:PPP(4): 4-momentum of hadron in GeV/v
C
C         CHAR REAL:CHARCH:  Charge of hadron
C
C         XLA Real:XLAXLA:   Lab. x of hadron
C
C         PPROJ REAL:POPO:   Lab. momentum of projectile GeV/c
C
C         TMA:               Mass of projectile in GeV/c**2
C
C         PT REAL:PTPT       Trans. momentum of hadron GeV/c
C
C         PPCMS(4) REAL:PPCMSP(4): cms 4-momentum of hadron GeV/c
C
C         UMO                cms energy of collision GeV
C
C         XF REAL:XFXF:      Feynman x of hadron
C
C         YLAB REAL:YLABYL:  Lab. rapidity
C
C         ETALA REAL:ETALAB: Lab pseudorapidity
C
C         ETACM REAL ETACME: cms pseudorapidity
C
C         YCM REAL:YCMYCM:   cms rapidity
C
C         THET REAL:THETET:  production angle of hadron
C
C         PMOD REAL:PMODOD:  mod of lab momentum GeV/c
C    
C         REAL:YBEAM:        log(UMO/TMA)
C
C         IT                 (BAMJET) kind of hadron
C
C         IJPROJ             (BAMJET) kind of projectile
C
C---------------------------------------------------------------------
C
      COMMON/NNCMS/GAMCM,BGCM,UMO,PCM,EPROJ,PPROJ
C     REAL POPO,PPPP(4),CHARCH,PTPT,PPCMSP(4),XFXF,YLABYL,
C    *ETALAB,ETACME,YCMYCM,YBEAM,XLAXLA,THETET,PMODOD,E6
      DIMENSION PPPP(4),PPCMSP(4)
      PARAMETER (E6=1.D18)
      DIMENSION PP(4),PPCMS(4)                                                  
      CHARACTER*8 ANAME
      COMMON /DPAR/ANAME(210),AAM(210),GA(210),TAU(210),IICH(210),
     *IIBAR(210),K1(210),K2(210)
      DATA TMA /.938D0 /
C   
C  INTERFACE between DPMJET DISTR (Lab) and PLOMBR HB Histograms
C
C  PLOMB still DOUBLE PRECISION PLOMBR single precision
C
C  FURTHERMORE plomb calculates CMS-QUANTITIES
C
C IFL=1 START JOB=2 START EVENT=3 PART. LOOP=4 END EV.=5 END JOB        
C PP CHAR ITIF MOMENTUM CHARGE ID. (FLUKA-LIKE) OF CURRENT PARTICLE
C   
C-----------------------------------------------------------   
      IF(IFL.EQ.1)THEN
C                          Start job
      TMA=AAM(IJPROJ)
      POPO=PPROJ
      WRITE(6,'(A,2F10.2)')' plomb:pproj,popo',PPROJ,POPO
      IF(POPO.GE.E6)POPO=E6
C-----------------------------------------------------------   
      ELSEIF(IFL.EQ.2)THEN
C                          START event
      YBEAM=LOG(UMO/TMA)
      POPO=PPROJ
      IF(POPO.GE.E6)POPO=E6
C-----------------------------------------------------------   
      ELSEIF(IFL.EQ.3)THEN
C                          Particle loop
      CHARCH=CHAR
      CALL KINC(PP,PT,RAP,PPCMS,XF,YLAB,ETALA,ETACM,YCM,
     * THET,PMOD,XLA)
      XLAXLA=XLA
      PMODOD=PMOD
      THETET=THET
      YCMYCM=YCM
      ETACME=ETACM
      ETALAB=ETALA
      YLABYL=YLAB
      DO 30 II=1,4
      PPPP(II)=PP(II)
      IF(PPPP(II).GE.E6)PPPP(II)=E6
      PPCMSP(II)=PPCMS(II)
   30 CONTINUE
      IBARF=IIBAR(ITIF)
      XFXF=XF
      PTPT=PT
C-----------------------------------------------------------   
      ELSEIF(IFL.EQ.4)THEN
C                          End event
C-----------------------------------------------------------   
      ELSEIF(IFL.EQ.5)THEN
C                          End job
      ENDIF
      CALL PLOMBR(POPO,IJPROJ,IFL,PPPP,CHARCH,XFXF,XLAXLA,
     *PTPT,PPCMSP,YLABYL,ETALAB,ETACME,YCMYCM,YBEAM,
     *ITIF,THETET,PMODOD,IBARF)
      RETURN
      END

C***********************************************************************
       SUBROUTINE KIN(PP,PT,RAP,PPCMS,XF,YLAB,ETALA,ETACM,YCM,
     *THET,PMOD ,XLA )
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C
C----------------------------------------------------------------------
C
C                  Input variables: PP(4)
C                  Output variables:PPCMS(4),XF,YLAB,ETALA,ETACM,
C                                   YCM,THET,PMAD,PT,RAP
C
C-------------------------------------------------------------------------  
C
C---------------------------------------------------------------------
C
C                 DEFINITION of variables:
C
C         PP(4) REAL:PPP(4): 4-momentum of hadron in GeV/v
C
C         CHAR REAL:CHARCH:  Charge of hadron
C
C         XLA Real:XLAXLA:   Lab. x of hadron
C
C         PPROJ REAL:POPO:   Lab. momentum of projectile GeV/c
C
C         TMA:               Mass of projectile in GeV/c**2
C
C         PT REAL:PTPT       Trans. momentum of hadron GeV/c
C
C         PPCMS(4) REAL:PPCMSP(4): cms 4-momentum of hadron GeV/c
C
C         UMO                cms energy of collision GeV
C
C         XF REAL:XFXF:      Feynman x of hadron
C
C         YLAB REAL:YLABYL:  Lab. rapidity
C
C         ETALA REAL:ETALAB: Lab pseudorapidity
C
C         ETACM REAL ETACME: cms pseudorapidity
C
C         YCM REAL:YCMYCM:   cms rapidity
C
C         THET REAL:THETET:  production angle of hadron
C
C         PMOD REAL:PMODOD:  mod of lab momentum GeV/c
C    
C         REAL:YBEAM:        log(UMO/TMA)
C
C         IT                 (BAMJET) kind of hadron
C
C         IJPROJ             (BAMJET) kind of projectile
C
C---------------------------------------------------------------------
C
C                                                                      
C  GIVE PT,ETA FROM MOMENTUM PP                                        
C              
      COMMON/NNCMS/GAMCM,BGCM,UMO,PCM,EPROJ,PPROJ
      COMMON /NUCC/   IT,ITZ,IP,IPZ,IJPROJ,IBPROJ,IJTARG,IBTARG
      DIMENSION PP(4),PPCMS(4)                                         
      DATA PIGR/3.14159/                                             
C                   
      ZERO=0.
      PT=SQRT(PP(1)**2+PP(2)**2)                                       
      PZ=PP(3)
      XLA=PZ/PPROJ                                                         
      PMOD=SQRT(PP(1)**2+PP(2)**2+PP(3)**2)  
      PPCMS(1)=PP(1)
      PPCMS(2)=PP(2)
      PPCMS(3)=GAMCM*PP(3)-BGCM*PP(4)
      PPCMS(4)=GAMCM*PP(4)-BGCM*PP(3)
      XF=2.*PPCMS(3)/UMO
      PPCMSM=SQRT(PPCMS(1)**2+PPCMS(2)**2+PPCMS(3)**2)
      XXXX=PPCMSM-PPCMS(3)
      IF(XXXX.EQ.ZERO)XXXX=1.E-12
      ETACM=0.5*LOG(ABS((PPCMSM+PPCMS(3))/XXXX))
      YYYY=PMOD-PP(3)
      IF(YYYY.EQ.ZERO)YYYY=1.E-12
      ETALA=0.5*LOG(ABS((PMOD+PP(3))/YYYY))
      ZZZZ=PP(4)-PP(3)
      IF(ZZZZ.EQ.ZERO)ZZZZ=1.E-12
      YLAB=0.5*LOG(ABS((PP(4)+PP(3))/ZZZZ))
      WWWW=PPCMS(4)-PPCMS(3)
      IF(WWWW.EQ.ZERO)WWWW=1.E-12
      YCM=0.5*LOG(ABS((PPCMS(4)+PPCMS(3))/WWWW))
      THET=PT/PMOD                                                     
       THET=ASIN(THET)                                                 
       IF(PZ.LT.ZERO) THET=PIGR-THET                                 
       THETG=THET*180./PIGR                                            
       RAP=TAN(THET/2.)                                                
       IF(RAP.NE.ZERO)RAP=1./RAP                                       
       RAP=LOG(RAP)                                                   
C                                                                      
       RETURN                                                          
       END         
C

C***********************************************************************
       SUBROUTINE KINC(PP,PT,RAP,PPCMS,XF,YLAB,ETALA,ETACM,YCM,
     *THET,PMOD ,XLA )
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C
C----------------------------------------------------------------------
C
C                  Input variables: PP(4)
C                  Output variables:PPCMS(4),XF,YLAB,ETALA,ETACM,
C                                   YCM,THET,PMAD,PT,RAP
C
C-------------------------------------------------------------------------  
C
C---------------------------------------------------------------------
C
C                 DEFINITION of variables:
C
C         PP(4) REAL:PPP(4): 4-momentum of hadron in GeV/v
C
C         CHAR REAL:CHARCH:  Charge of hadron
C
C         XLA Real:XLAXLA:   Lab. x of hadron
C
C         PPROJ REAL:POPO:   Lab. momentum of projectile GeV/c
C
C         TMA:               Mass of projectile in GeV/c**2
C
C         PT REAL:PTPT       Trans. momentum of hadron GeV/c
C
C         PPCMS(4) REAL:PPCMSP(4): cms 4-momentum of hadron GeV/c
C
C         UMO                cms energy of collision GeV
C
C         XF REAL:XFXF:      Feynman x of hadron
C
C         YLAB REAL:YLABYL:  Lab. rapidity
C
C         ETALA REAL:ETALAB: Lab pseudorapidity
C
C         ETACM REAL ETACME: cms pseudorapidity
C
C         YCM REAL:YCMYCM:   cms rapidity
C
C         THET REAL:THETET:  production angle of hadron
C
C         PMOD REAL:PMODOD:  mod of lab momentum GeV/c
C    
C         REAL:YBEAM:        log(UMO/TMA)
C
C         IT                 (BAMJET) kind of hadron
C
C         IJPROJ             (BAMJET) kind of projectile
C
C---------------------------------------------------------------------
C
C                                                                      
C  GIVE PT,ETA FROM MOMENTUM PP                                        
C              
      COMMON/NNCMS/GAMCM,BGCM,UMO,PCM,EPROJ,PPROJ
      COMMON /NUCC/   IT,ITZ,IP,IPZ,IJPROJ,IBPROJ,IJTARG,IBTARG
      DIMENSION PP(4),PPCMS(4)                                         
      DATA PIGR/3.14159/                                             
C                   
      ZERO=0.
      PP(1)=PPCMS(1)
      PP(2)=PPCMS(2)
      PP(3)=GAMCM*PPCMS(3)+BGCM*PPCMS(4)
      PP(4)=GAMCM*PPCMS(4)+BGCM*PPCMS(3)
      PT=SQRT(PP(1)**2+PP(2)**2)                                       
      PZ=PP(3)
      XLA=PZ/PPROJ                                                         
      PMOD=SQRT(PP(1)**2+PP(2)**2+PP(3)**2)  
      XF=2.*PPCMS(3)/UMO
      PPCMSM=SQRT(PPCMS(1)**2+PPCMS(2)**2+PPCMS(3)**2)
      XXXX=PPCMSM-PPCMS(3)
      IF(XXXX.EQ.ZERO)XXXX=1.E-18
      ETACM=0.5*LOG(ABS((PPCMSM+PPCMS(3))/XXXX))
      YYYY=PMOD-PP(3)
      IF(YYYY.EQ.ZERO)YYYY=1.E-18
      ETALA=0.5*LOG(ABS((PMOD+PP(3))/YYYY))
      ZZZZ=PP(4)-PP(3)
      IF(ZZZZ.EQ.ZERO)ZZZZ=1.E-18
      YLAB=0.5*LOG(ABS((PP(4)+PP(3))/ZZZZ))
      WWWW=PPCMS(4)-PPCMS(3)
      IF(WWWW.EQ.ZERO)WWWW=1.E-18
      YCM=0.5*LOG(ABS((PPCMS(4)+PPCMS(3))/WWWW))
      THET=PT/PMOD                                                     
       THET=ASIN(THET)                                                 
       IF(PZ.LT.ZERO) THET=PIGR-THET                                 
       THETG=THET*180./PIGR                                            
       RAP=TAN(THET/2.)                                                
       IF(RAP.NE.ZERO)RAP=1./RAP                                       
       RAP=LOG(RAP)                                                   
C                                                                      
       RETURN                                                          
       END         
C
      SUBROUTINE DISPT(IOP,NHKKH1,PO)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C
C*** 1=P,  2=N, 3=PI+, 4=PI-, 5=PIO, 6=GAM+HYP, 7=K, 8=ANUC, 9=CHARGED
C*** 10=TOT, 11=TOTHAD
C
*KEEP,HKKEVT.
c     INCLUDE (HKKEVT)
      PARAMETER (NMXHKK= 49998)
c     PARAMETER (NMXHKK=25000)
      COMMON /HKKEVT/ NHKK,NEVHKK,ISTHKK(NMXHKK),IDHKK(NMXHKK), JMOHKK
     +(2,NMXHKK),JDAHKK(2,NMXHKK), PHKK(5,NMXHKK),VHKK(4,NMXHKK),WHKK
     +(4,NMXHKK)
C
C                       WHKK(4,NMXHKK) GIVES POSITIONS AND TIMES IN
C                       PROJECTILE FRAME, THE CHAINS ARE CREATED ON
C                       THE POSITIONS OF THE PROJECTILE NUCLEONS
C                       IN THE PROJECTILE FRAME (TARGET NUCLEONS IN
C                       TARGET FRAME) BOTH POSITIONS ARE THREFORE NOT
C                       COMPLETELY CONSISTENT. THE TIMES IN THE
C                       PROJECTILE FRAME HOWEVER ARE OBTAINED BY
C                       LORENTZ TRANSFORMING FROM THE LAB SYSTEM.
C
C  Based on the proposed standard COMMON block (Sjostrand Memo 17.3,89)
C
C NMXHKK: maximum numbers of entries (partons/particles) that can be
C    stored in the commonblock.
C
C NHKK: the actual number of entries stored in current event. These are
C    found in the first NHKK positions of the respective arrays below.
C    Index IHKK, 1 <= IHKK <= NHKK, is below used to denote a given
C    entry.
C
C ISTHKK(IHKK): status code for entry IHKK, with following meanings:
C    = 0 : null entry.
C    = 1 : an existing entry, which has not decayed or fragmented.
C        This is the main class of entries which represents the
C        "final state" given by the generator.
C    = 2 : an entry which has decayed or fragmented and therefore
C        is not appearing in the final state, but is retained for
C        event history information.
C    = 3 : a documentation line, defined separately from the event
C        history. (incoming reacting
C        particles, etc.)
C    = 4 - 10 : undefined, but reserved for future standards.
C    = 11 - 20 : at the disposal of each model builder for constructs
C        specific to his program, but equivalent to a null line in the
C        context of any other program. One example is the cone defining
C        vector of HERWIG, another cluster or event axes of the JETSET
C        analysis routines.
C    = 21 - : at the disposal of users, in particular for event tracking
C        in the detector.
C
C IDHKK(IHKK) : particle identity, according to the Particle Data Group
C    standard.
C
C JMOHKK(1,IHKK) : pointer to the position where the mother is stored.
C    The value is 0 for initial entries.
C
C JMOHKK(2,IHKK) : pointer to position of second mother. Normally only
C    one mother exist, in which case the value 0 is used. In cluster
C    fragmentation models, the two mothers would correspond to the q
C    and qbar which join to form a cluster. In string fragmentation,
C    the two mothers of a particle produced in the fragmentation would
C    be the two endpoints of the string (with the range in between
C    implied).
C
C JDAHKK(1,IHKK) : pointer to the position of the first daughter. If an
C    entry has not decayed, this is 0.
C
C JDAHKK(2,IHKK) : pointer to the position of the last daughter. If an
C    entry has not decayed, this is 0. It is assumed that the daughters
C    of a particle (or cluster or string) are stored sequentially, so
C    that the whole range JDAHKK(1,IHKK) - JDAHKK(2,IHKK) contains
C    daughters. Even in cases where only one daughter is defined (e.g.
C    K0 -> K0S) both values should be defined, to make for a uniform
C    approach in terms of loop constructions.
C
C PHKK(1,IHKK) : momentum in the x direction, in GeV/c.
C
C PHKK(2,IHKK) : momentum in the y direction, in GeV/c.
C
C PHKK(3,IHKK) : momentum in the z direction, in GeV/c.
C
C PHKK(4,IHKK) : energy, in GeV.
C
C PHKK(5,IHKK) : mass, in GeV/c**2. For spacelike partons, it is allowed
C    to use a negative mass, according to PHKK(5,IHKK) = -sqrt(-m**2).
C
C VHKK(1,IHKK) : production vertex x position, in mm.
C
C VHKK(2,IHKK) : production vertex y position, in mm.
C
C VHKK(3,IHKK) : production vertex z position, in mm.
C
C VHKK(4,IHKK) : production time, in mm/c (= 3.33*10**(-12) s).
C********************************************************************
*KEEP,NSHMAK.
      COMMON /NSHMAK/ NNSHMA,NPSHMA,NTSHMA,NSHMAC
*KEEP,DPAR.
C     /DPAR/   CONTAINS PARTICLE PROPERTIES
C        ANAME  = LITERAL NAME OF THE PARTICLE
C        AAM    = PARTICLE MASS IN GEV
C        GA     = DECAY WIDTH
C        TAU    = LIFE TIME OF INSTABLE PARTICLES
C        IICH   = ELECTRIC CHARGE OF THE PARTICLE
C        IIBAR  = BARYON NUMBER
C        K1,K1  = BIGIN AND END OF DECAY CHANNELS OF PARTICLE
C
      CHARACTER*8  ANAME
      COMMON /DPAR/ ANAME(210),AAM(210),GA(210),TAU(210),IICH(210),
     +IIBAR(210),K1(210),K2(210)
C------------------
*KEEP,NUCC.
      COMMON /NUCC/   IT,ITZ,IP,IPZ,IJPROJ,IBPROJ,IJTARG,IBTARG
*KEEP,DPRIN.
      COMMON /DPRIN/  IPRI,IPEV,IPPA,IPCO,INIT,IPHKK,ITOPD,IPAUPR
*KEND.

C                                   modified DPMJET
       COMMON /BUFUES/ BNNVV,BNNSS,BNNSV,BNNVS,BNNCC,
     *                 BNNDV,BNNVD,BNNDS,BNNSD,
     *                 BNNHH,BNNZZ,
     *                 BPTVV,BPTSS,BPTSV,BPTVS,BPTCC,BPTDV,
     *                 BPTVD,BPTDS,BPTSD,
     *                 BPTHH,BPTZZ,
     *                 BEEVV,BEESS,BEESV,BEEVS,BEECC,BEEDV,
     *                 BEEVD,BEEDS,BEESD,
     *                 BEEHH,BEEZZ
     *                ,BNNDI,BPTDI,BEEDI
     *                ,BNNZD,BNNDZ,BPTZD,BPTDZ,BEEZD,BEEDZ
       COMMON /NCOUCS/ BCOUVV,BCOUSS,BCOUSV,BCOUVS,
     *                 BCOUZZ,BCOUHH,BCOUDS,BCOUSD,
     *                 BCOUDZ,BCOUZD,BCOUDI,
     *                 BCOUDV,BCOUVD,BCOUCC
       COMMON /BUFUEH/ ANNVV,ANNSS,ANNSV,ANNVS,ANNCC,
     *                 ANNDV,ANNVD,ANNDS,ANNSD,
     *                 ANNHH,ANNZZ,
     *                 PTVV,PTSS,PTSV,PTVS,PTCC,PTDV,PTVD,PTDS,PTSD,
     *                 PTHH,PTZZ,
     *                 EEVV,EESS,EESV,EEVS,EECC,EEDV,EEVD,EEDS,EESD,
     *                 EEHH,EEZZ
     *                ,ANNDI,PTDI,EEDI
     *                ,ANNZD,ANNDZ,PTZD,PTDZ,EEZD,EEDZ
       COMMON /NCOUCH/ ACOUVV,ACOUSS,ACOUSV,ACOUVS,
     *                 ACOUZZ,ACOUHH,ACOUDS,ACOUSD,
     *                 ACOUDZ,ACOUZD,ACOUDI,
     *                 ACOUDV,ACOUVD,ACOUCC
C---------------------
      COMMON /EVENTA/IDUMTP
C
      DIMENSION PTP(50,20),PTY(50,20),EMTY(50,20),INDX(28)
      COMMON /SIGLA/SIGLAU
      COMMON /FINAL/IFINAL
C------------------------------------------------------------------
C------------------------------------------------------------------

      DATA INDX/1,8,10,10,10,10,7,2,7,10,10,7,3,4,5,6,
     *          7,7,7,7,7,7,7,7,7,7,7,7/
C   kinematics in lab (target rest system)
C***
C  conventions for rapidity distributions:
C       1  Proton                       11  NEGATIVES
C       2  Neutron                      12  NBAR=9
C       3  PI+=13                       13  LAMBDA=17
C       4  PI-=14                       14  SIGMA==20,21,22
C       5  K+ =15                       15  LAMBDABAR=18
C       6  K- =16                       16  SIGMABAR=99,100,101
C       7  neutral kaons=12,19,24,25    17  THETA=97,98
C       8  pbar=2                       18  THETABAR=102,103
C       9  charged hadrons              19  neutral Kaons 12,19,24,25
C      10  total hadrons
C-----------------------------------------------------------------------
      DATA KPL /1/
      DATA IEVL /0/
C----------------------------------------------------------------------
      ZERO=0
      ONEONE=1
      TWOTWO=2
      NIP=IP
      AIP=IP
      DELRAP=1.
      IF(IP.EQ.1)DELRAP=0.1
C
C-----------------------------
      GO TO (1,2,3),IOP
1     CONTINUE
      DXFL=0.02
      DY=0.4
      DPT=0.10
C     DIMENSION PTP(50,20),PTY(50,20),EMTY(50,20)
      DO 102 I=1,20
	DO 102 J=1,50
	  PTP(J,I)=(J-1)*DPT
	  PTY(J,I)=1.D-12
	  EMTY(J,I)=1.D-12
 102  CONTINUE
      NHKKH2=NHKKH1
      IF (NHKKH1.EQ.0)NHKKH2=1
      EEO=SQRT(PO**2+AAM(NHKKH2)**2)
      WRITE(6, 1001)EEO,PO,NHKKH2,AAM(NHKKH2)
 1001 FORMAT (' EEO,PO ',F13.2,F13.2,I10,F10.2)
2     CONTINUE
      NHAD=0
C                          HBOOK HISTOGRAMS
C++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C     WRITE(6,'(A)')' before plomb'
      CALL PLOMB (2,P4P4P4,CCCHRG,XFXFXF,1,IJPROJ)
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
      DO 21 I=NHKKH1,NHKK
        IF (ISTHKK(I).EQ.1)THEN
C                                  j.r. temp for s-s
          PTT=PHKK(1,I)**2+PHKK(2,I)**2+0.00001
          PT=SQRT(PTT)+0.001
C         IF(PT.LT.0.5)GO TO 21
C
          NHAD=NHAD+1
          NRHKK=MCIHAD(IDHKK(I))
           IF (NRHKK.LE.0.OR.NRHKK.GT.210)THEN
             NRHKK=1
           ENDIF
          NRE=NRHKK
          ICHHKK=IICH(NRHKK)
          IF (NRE.GT.160) NRE=28
          IF (NRE.LT. 1) NRE=28
          NREX=NRE
          IF(NREX.GE.28)NREX=28
          NI=INDX(NREX)
          NIX=NI
          IF (NRHKK.EQ.9)NIX=12
          IF (NRHKK.EQ.17.OR.NRHKK.EQ.22)NIX=13
          IF (NRHKK.LE.22.AND.NRHKK.GE.20)NIX=14
          IF (NRHKK.EQ.18.OR.NRHKK.EQ.100)NIX=15
          IF (NRHKK.LE.101.AND.NRHKK.GE.99)NIX=16
          IF (NRHKK.EQ.98)NIX=17
          IF (NRHKK.EQ.103)NIX=18
          IF (NRHKK.EQ.12.OR.NRHKK.EQ.19)NIX=19
          IF (NRHKK.EQ.24.OR.NRHKK.EQ.25)NIX=19
          IF(NRE.EQ.28) NI=7
          PTT=PHKK(1,I)**2+PHKK(2,I)**2+0.00001
          PT=SQRT(PTT)+0.001
          AMT=SQRT(PTT+PHKK(5,I)**2)
          YL=LOG((ABS(PHKK(3,I)+SQRT(PHKK(3,I)**2+AMT**2)))/AMT+1.E-18)
          YLLPS=LOG((ABS(PHKK(3,I)+SQRT(PHKK(3,I)**2+PTT)))/SQRT(PTT)
     *               +1.E-18)
          KPL=1
          IPT=PT/DPT+1.
          IF (IPT.LT.1)IPT=1
          IF (IPT.GT.50) IPT=50
          IF (ICHHKK.NE.0)PTY(IPT,9)=PTY(IPT,9)+1./PT
          IF (ICHHKK.EQ.-1)PTY(IPT,11)=PTY(IPT,11)+1./PT
          PTY(IPT,NIX)=PTY(IPT,NIX)+1./PT
          PTY(IPT,10)=PTY(IPT,10)+1./PT
          IF(YL.GT.2.3.AND.YL.LE.3.)THEN
            IAMT=AMT/DPT+1.
            IF (IAMT.LT.1)IAMT=1
            IF (IAMT.GT.48) IAMT=48
            IF (ICHHKK.NE.0)EMTY(IAMT,9)=EMTY(IAMT,9)+1./AMT
            IF (ICHHKK.EQ.-1)EMTY(IAMT,11)=EMTY(IAMT,11)+1./AMT
            EMTY(IAMT,NIX)=EMTY(IAMT,NIX)+1./AMT
            EMTY(IAMT,10)=EMTY(IAMT,10)+1./AMT
            IF(PT.GT.1.0.AND.PT.LT.2.0)THEN
              IAMT=49
              IF (ICHHKK.NE.0)EMTY(IAMT,9)=EMTY(IAMT,9)+DPT
              IF (ICHHKK.EQ.-1)EMTY(IAMT,11)=EMTY(IAMT,11)+DPT
              EMTY(IAMT,NIX)=EMTY(IAMT,NIX)+DPT
              EMTY(IAMT,10)=EMTY(IAMT,10)+DPT
            ENDIF
            IF(AMT.GT.1.72.AND.YL.LE.2.6)THEN
              IAMT=50
              IF (ICHHKK.NE.0)EMTY(IAMT,9)=EMTY(IAMT,9)+DPT
              IF (ICHHKK.EQ.-1)EMTY(IAMT,11)=EMTY(IAMT,11)+DPT
              EMTY(IAMT,NIX)=EMTY(IAMT,NIX)+DPT
              EMTY(IAMT,10)=EMTY(IAMT,10)+DPT
            ENDIF
          ENDIF
        ENDIF
21    CONTINUE
      RETURN
C
C--------------------------------------------------------------------
C
  3   CONTINUE
C          Normalization and Printing
C------------------------------------------------------------------
C------------------------------------------------------------------
      KKK=13
C             Normalization
C
C                           NORMALIZE AND PRINT COUNTERS
      IF (BNNDI.GT.1.)THEN
        BPTDI=BPTDI/BNNDI
        BEEDI=BEEDI/BNNDI
      ENDIF
      IF (BNNVV.GT.1.)THEN
        BPTVV=BPTVV/BNNVV
        BEEVV=BEEVV/BNNVV
      ENDIF
      IF (BNNSS.GT.1.)THEN
        BPTSS=BPTSS/BNNSS
        BEESS=BEESS/BNNSS
      ENDIF
      IF (BNNSV.GT.1.)THEN
        BPTSV=BPTSV/BNNSV
        BEESV=BEESV/BNNSV
      ENDIF
      IF (BNNVS.GT.1.)THEN
        BPTVS=BPTVS/BNNVS
        BEEVS=BEEVS/BNNVS
      ENDIF
      IF (BNNCC.GE.1.)THEN
        BPTCC=BPTCC/BNNCC
        BEECC=BEECC/BNNCC
      ENDIF
      IF (BNNDV.GE.1.)THEN
        BPTDV=BPTDV/BNNDV
        BEEDV=BEEDV/BNNDV
      ENDIF
      IF (BNNVD.GE.1.)THEN
        BPTVD=BPTVD/BNNVD
        BEEVD=BEEVD/BNNVD
      ENDIF
      IF (BNNDS.GE.1.)THEN
        BPTDS=BPTDS/BNNDS
        BEEDS=BEEDS/BNNDS
      ENDIF
      IF (BNNDZ.GE.1.)THEN
        BPTDZ=BPTDZ/BNNDZ
        BEEDZ=BEEDZ/BNNDZ
      ENDIF
      IF (BNNHH.GE.1.)THEN
        BPTHH=BPTHH/BNNHH
        BEEHH=BEEHH/BNNHH
      ENDIF
      IF (BNNZZ.GE.1.)THEN
        BPTZZ=BPTZZ/BNNZZ
        BEEZZ=BEEZZ/BNNZZ
      ENDIF
      IF (BNNSD.GE.1.)THEN
        BPTSD=BPTSD/BNNSD
        BEESD=BEESD/BNNSD
      ENDIF
      IF (BNNZD.GE.1.)THEN
        BPTZD=BPTZD/BNNZD
        BEEZD=BEEZD/BNNZD
      ENDIF
      IF (NHKKH1.GT.1.)THEN
        BNNVV=BNNVV/NHKKH1
        BNNDI=BNNDI/NHKKH1
        BNNSS=BNNSS/NHKKH1
        BNNSV=BNNSV/NHKKH1
        BNNVS=BNNVS/NHKKH1
        BNNCC=BNNCC/NHKKH1
        BNNVD=BNNVD/NHKKH1
        BNNDV=BNNDV/NHKKH1
        BNNDS=BNNDS/NHKKH1
        BNNSD=BNNSD/NHKKH1
        BNNDZ=BNNDZ/NHKKH1
        BNNZD=BNNZD/NHKKH1
        BNNHH=BNNHH/NHKKH1
        BNNZZ=BNNZZ/NHKKH1
        BCOUVV=BCOUVV/NHKKH1
        BCOUSS=BCOUSS/NHKKH1
        BCOUSV=BCOUSV/NHKKH1
        BCOUVS=BCOUVS/NHKKH1
        BCOUZZ=BCOUZZ/NHKKH1
        BCOUHH=BCOUHH/NHKKH1
        BCOUDS=BCOUDS/NHKKH1
        BCOUSD=BCOUSD/NHKKH1
        BCOUDZ=BCOUDZ/NHKKH1
        BCOUZD=BCOUZD/NHKKH1
        BCOUDI=BCOUDI/NHKKH1
        BCOUDV=BCOUDV/NHKKH1
        BCOUVD=BCOUVD/NHKKH1
        BCOUCC=BCOUCC/NHKKH1
        WRITE (6,7431)BNNVV,BPTVV,BEEVV,BCOUVV,
     *              BNNSS,BPTSS,BEESS,BCOUSS,
     *              BNNSV,BPTSV,BEESV,BCOUSV,
     *              BNNVS,BPTVS,BEEVS,BCOUVS,
     *              BNNCC,BPTCC,BEECC,BCOUCC,
     *              BNNDV,BPTDV,BEEDV,BCOUDV,
     *              BNNVD,BPTVD,BEEVD,BCOUVD,
     *              BNNDS,BPTDS,BEEDS,BCOUDS,
     *              BNNSD,BPTSD,BEESD,BCOUSD,
     *              BNNDZ,BPTDZ,BEEDZ,BCOUDZ,
     *              BNNZD,BPTZD,BEEZD,BCOUZD,
     *              BNNHH,BPTHH,BEEHH,BCOUHH,
     *              BNNDI,BPTDI,BEEDI,BCOUDI,
     *              BNNZZ,BPTZZ,BEEZZ,BCOUZZ
 7431   FORMAT ('  VV CHAINS NN,PT ECM: ',4F12.4/
     *          '  SS CHAINS NN,PT ECM: ',4F12.4/
     *          '  SV CHAINS NN,PT ECM: ',4F12.4/
     *          '  VS CHAINS NN,PT ECM: ',4F12.4/
     *          '  CC CHAINS NN,PT ECM: ',4F12.4/
     *          '  DV CHAINS NN,PT ECM: ',4F12.4/
     *          '  VD CHAINS NN,PT ECM: ',4F12.4/
     *          '  DS CHAINS NN,PT ECM: ',4F12.4/
     *          '  SD CHAINS NN,PT ECM: ',4F12.4/
     *          '  DZ CHAINS NN,PT ECM: ',4F12.4/
     *          '  ZD CHAINS NN,PT ECM: ',4F12.4/
     *          '  HH CHAINS NN,PT ECM: ',4F12.4/
     *          '  DI CHAINS NN,PT ECM: ',4F12.4/
     *          '  ZZ CHAINS NN,PT ECM: ',4F12.4)
      ENDIF
C
C
C
C============================================================
      DO 33 I=1,20
      DO 35 J=1,50
        DO 335 JJJJ=0,1
  335   CONTINUE
        PTY(J,I)   =PTY(J,I)   /(NHKKH1*DPT)
        EMTY(J,I)   =EMTY(J,I)   /(NHKKH1*DPT)
35    CONTINUE
33    CONTINUE
      DO 5136 J=1,50
        WRITE(6, 37)(PTY(J,I),I=1,11)
5137    FORMAT (11E11.3)
  37    FORMAT (11E11.3)
5136  CONTINUE
      WRITE(6,3654)
 3654 FORMAT(' pt-Distribution')
      DO 3614 J=1,50
        WRITE(6, 37)PTP(J,1),(PTY  (J,I),I=1,10)
 3614 CONTINUE
      DO 5914 J=1,50
        WRITE(6, 37)PTP(J,1),(PTY  (J,I),I=11,20)
 5914 CONTINUE
      WRITE(6,4654)
 4654 FORMAT(' Et-Distribution')
      WRITE(6, 37)PTP(1,1),(EMTY  (1,I),I=1,10)
      DO 4614 J=2,50
        WRITE(6, 37)PTP(J-1,1),(EMTY  (J,I),I=1,10)
        WRITE(6, 37)PTP(J,1),(EMTY  (J,I),I=1,10)
 4614 CONTINUE
      WRITE(6, 37)PTP(1,1),(EMTY  (1,I),I=11,20)
      DO 6914 J=2,50
        WRITE(6, 37)PTP(J-1,1),(EMTY  (J,I),I=11,20)
        WRITE(6, 37)PTP(J,1),(EMTY  (J,I),I=11,20)
 6914 CONTINUE
      DO 514 J=1,50
        DO 312 I=1,20
          PTY(J,I)     =LOG10(ABS(PTY(J,I))+1.E-8)
          EMTY(J,I)     =LOG10(ABS(EMTY(J,I))+1.E-8)
312     CONTINUE
        PTY(J,10)     =PTY(J,11)
        EMTY(J,10)     =EMTY(J,11)
514   CONTINUE
      WRITE(6,3654)
      CALL PLOT(PTP,PTY,1000,20,50,ZERO,DPT,-ONEONE,0.05D0)
C     CALL PLOT(PTP,PTY,1000,20,50,ZERO,DPT,ONEONE,0.05D0)
      WRITE(6,4654)

      CALL PLOT(PTP,EMTY,1000,20,50,ZERO,DPT,-6.0D0,0.10D0)
C
      RETURN
      END
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
      SUBROUTINE HISTOG(I)
C
      RETURN
      END
C----------------------------------------------------------------
      SUBROUTINE DISEVA(IOP,NHKKH1,PO,IGENER)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
*KEEP,HKKEVT.
c     INCLUDE (HKKEVT)
      PARAMETER (NMXHKK= 49998)
c     PARAMETER (NMXHKK=25000)
      COMMON /HKKEVT/ NHKK,NEVHKK,ISTHKK(NMXHKK),IDHKK(NMXHKK), JMOHKK
     +(2,NMXHKK),JDAHKK(2,NMXHKK), PHKK(5,NMXHKK),VHKK(4,NMXHKK),WHKK
     +(4,NMXHKK)
      COMMON /EXTEVT/ IDRES(NMXHKK),IDXRES(NMXHKK),NOBAM(NMXHKK),
     &                IDBAM(NMXHKK),IDCH(NMXHKK),NPOINT(10)
C
C                       WHKK(4,NMXHKK) GIVES POSITIONS AND TIMES IN
C                       PROJECTILE FRAME, THE CHAINS ARE CREATED ON
C                       THE POSITIONS OF THE PROJECTILE NUCLEONS
C                       IN THE PROJECTILE FRAME (TARGET NUCLEONS IN
C                       TARGET FRAME) BOTH POSITIONS ARE THREFORE NOT
C                       COMPLETELY CONSISTENT. THE TIMES IN THE
C                       PROJECTILE FRAME HOWEVER ARE OBTAINED BY
C                       LORENTZ TRANSFORMING FROM THE LAB SYSTEM.
C
C  Based on the proposed standard COMMON block (Sjostrand Memo 17.3,89)
C
C NMXHKK: maximum numbers of entries (partons/particles) that can be
C    stored in the commonblock.
C
C NHKK: the actual number of entries stored in current event. These are
C    found in the first NHKK positions of the respective arrays below.
C    Index IHKK, 1 <= IHKK <= NHKK, is below used to denote a given
C    entry.
C
C ISTHKK(IHKK): status code for entry IHKK, with following meanings:
C    = 0 : null entry.
C    = 1 : an existing entry, which has not decayed or fragmented.
C        This is the main class of entries which represents the
C        "final state" given by the generator.
C    = 2 : an entry which has decayed or fragmented and therefore
C        is not appearing in the final state, but is retained for
C        event history information.
C    = 3 : a documentation line, defined separately from the event
C        history. (incoming reacting
C        particles, etc.)
C    = 4 - 10 : undefined, but reserved for future standards.
C    = 11 - 20 : at the disposal of each model builder for constructs
C        specific to his program, but equivalent to a null line in the
C        context of any other program. One example is the cone defining
C        vector of HERWIG, another cluster or event axes of the JETSET
C        analysis routines.
C    = 21 - : at the disposal of users, in particular for event tracking
C        in the detector.
C
C IDHKK(IHKK) : particle identity, according to the Particle Data Group
C    standard.
C
C JMOHKK(1,IHKK) : pointer to the position where the mother is stored.
C    The value is 0 for initial entries.
C
C JMOHKK(2,IHKK) : pointer to position of second mother. Normally only
C    one mother exist, in which case the value 0 is used. In cluster
C    fragmentation models, the two mothers would correspond to the q
C    and qbar which join to form a cluster. In string fragmentation,
C    the two mothers of a particle produced in the fragmentation would
C    be the two endpoints of the string (with the range in between
C    implied).
C
C JDAHKK(1,IHKK) : pointer to the position of the first daughter. If an
C    entry has not decayed, this is 0.
C
C JDAHKK(2,IHKK) : pointer to the position of the last daughter. If an
C    entry has not decayed, this is 0. It is assumed that the daughters
C    of a particle (or cluster or string) are stored sequentially, so
C    that the whole range JDAHKK(1,IHKK) - JDAHKK(2,IHKK) contains
C    daughters. Even in cases where only one daughter is defined (e.g.
C    K0 -> K0S) both values should be defined, to make for a uniform
C    approach in terms of loop constructions.
C
C PHKK(1,IHKK) : momentum in the x direction, in GeV/c.
C
C PHKK(2,IHKK) : momentum in the y direction, in GeV/c.
C
C PHKK(3,IHKK) : momentum in the z direction, in GeV/c.
C
C PHKK(4,IHKK) : energy, in GeV.
C
C PHKK(5,IHKK) : mass, in GeV/c**2. For spacelike partons, it is allowed
C    to use a negative mass, according to PHKK(5,IHKK) = -sqrt(-m**2).
C
C VHKK(1,IHKK) : production vertex x position, in mm.
C
C VHKK(2,IHKK) : production vertex y position, in mm.
C
C VHKK(3,IHKK) : production vertex z position, in mm.
C
C VHKK(4,IHKK) : production time, in mm/c (= 3.33*10**(-12) s).
C********************************************************************
C------------------------------------------------------------------
C--------------------------------evaporation-----------------------
      DIMENSION ANEVA(4),PEVAP(50,2),XPEVAP(50,2),AMEVAP(250),
     * XMEVAP(250)
      DIMENSION ANEVAP(4),AMEVPP(250)
      COMMON /FINAL/IFINAL
      COMMON /NOMIJE/ PTMIJE(10),NNMIJE(10)
      COMMON /NOMIJU/ NNMIJU(10)
       CHARACTER*8  ANAME
       COMMON /DPAR/ANAME(210),AAM(210),GA(210),TAU(210),IICH(210),
     +IIBAR(210),K1(210),K2(210)
C------------------------------------------------------------------
C------------------------------------------------------------------
      GO TO (1,2,3),IOP
C------------------------------------------------------------------
C--------------------------------evaporation-----------------------
    1 CONTINUE
      DPEVA=0.02D0
      DIT=IT/50+1
      IF(DIT.LT.1.D0)DIT=1
      IF (IFINAL.EQ.0) THEN
        DO 3112 I=1,4
          ANEVA(I)=0
          ANEVAP(I)=0
 3112   CONTINUE
        DO 3123 I=1,250
          AMEVAP(I)=0
          AMEVPP(I)=0
          XMEVAP(I)=I
 3123   CONTINUE
        DO 3113 I=1,50
          DO 3113 II=1,2
            PEVAP(I,II)=0
            XPEVAP(I,II)=I*DPEVA
 3113   CONTINUE  
      ENDIF
C        s(shower), g (grey), h(heavy) and b (black) particles
C        n- (neg prongs) sp8,sp5 (slow protons) p=0.15-0.8, 0.15-0.5
       ANSHO=0 
       ANGRE=0
       ANGRE2=0
       ANHEA=0
       ANBLA=0
       ANMIN=0
       ANSP8=0
       ANSP5=0
       RETURN
C------------------------------------------------------------------
C------------------------------------------------------------------
    2 CONTINUE
C------------------------------------------------------------------
C--------------------------------evaporation-----------------------
C     WRITE(6,'(A)')' DISTR 2 '
	DO 1121 I=NHKKH1,NHKK
          IF (ISTHKK(I).EQ.1)THEN
         NRHKK=MCIHAD(IDHKK(I))
           ICHHKK=IICH(NRHKK)
            PPTT=SQRT(PHKK(1,I)**2+PHKK(2,I)**2+0.000001)
            PTT=PPTT**2
       	  PTOT=SQRT(PPTT**2+PHKK(3,I)**2+0.000001)
           IF(ICHHKK.NE.0)THEN
            BETP=PTOT/PHKK(4,I)
	     IF(ICHHKK.EQ.-1)ANMIN=ANMIN+1
             IF(BETP.GE.0.7D0)ANSHO=ANSHO+1
             IF(BETP.LE.0.7D0)ANHEA=ANHEA+1
             IF(BETP.LE.0.2D0)ANBLA=ANBLA+1
             IF(BETP.GE.0.2D0.AND.BETP.LE.0.7D0)ANGRE=ANGRE+1
             IF(BETP.GE.0.23D0.AND.BETP.LE.0.7D0)ANGRE2=ANGRE2+1
            ENDIF
	  ENDIF
 1121   CONTINUE
      IF (IFINAL.EQ.0) THEN
        DO 3114 I=NHKKH1,NHKK
          IF(ISTHKK(I).EQ.-1) THEN
C                                      Neutrons
            IF (IDHKK(I).EQ.2112)THEN
              PPTT=(PHKK(1,I)**2+PHKK(2,I)**2+0.000001)
              PTOT=SQRT(PPTT+PHKK(3,I)**2+0.000001)
	      IF(NOBAM(I).EQ.2)THEN
                ANEVA(2)=ANEVA(2)+1.D0
                IPTOT=PTOT/DPEVA
                IF(IPTOT.LT.1)IPTOT=1
                IF(IPTOT.GT.50)IPTOT=50
                PEVAP(IPTOT,2)=PEVAP(IPTOT,2)+1.E0
              ELSEIF(NOBAM(I).EQ.1)THEN
                ANEVAP(2)=ANEVAP(2)+1.D0
              ENDIF
C                                        Protons
            ELSEIF(IDHKK(I).EQ.2212)THEN
              PPTT=(PHKK(1,I)**2+PHKK(2,I)**2+0.000001)
              PTOT=SQRT(PPTT+PHKK(3,I)**2+0.000001)
	      IF(NOBAM(I).EQ.2)THEN
                ANEVA(1)=ANEVA(1)+1.D0
                IF(PTOT.GT.0.15D0.AND.PTOT.LE.0.8D0)ANSP8=ANSP8+1
                IF(PTOT.GT.0.15D0.AND.PTOT.LE.0.5D0)ANSP5=ANSP5+1
                IPTOT=PTOT/DPEVA
                IF(IPTOT.LT.1)IPTOT=1
                IF(IPTOT.GT.50)IPTOT=50
                PEVAP(IPTOT,1)=PEVAP(IPTOT,1)+1.E0
                BETP=PTOT/PHKK(4,I)
                IF(BETP.GE.0.7D0)ANSHO=ANSHO+1
                IF(BETP.LE.0.7D0)ANHEA=ANHEA+1
                IF(BETP.LE.0.23D0)ANBLA=ANBLA+1
                IF(BETP.GE.0.2D0.AND.BETP.LE.0.7D0)ANGRE=ANGRE+1
C               IF(BETP.GE.0.23D0.AND.BETP.LE.0.7D0)
C    *                                  	ANGRE2=ANGRE2+1
                IF(PTOT.GE.0.026D0.AND.PTOT.LE.0.375D0)
     *                                  	ANGRE2=ANGRE2+1
              ELSEIF(NOBAM(I).EQ.1)THEN
                ANEVAP(1)=ANEVAP(1)+1.D0
              ENDIF
C                                        Photons
            ELSEIF(IDHKK(I).EQ.22)THEN
              PPTT=(PHKK(1,I)**2+PHKK(2,I)**2+0.000001)
              PTOT=SQRT(PPTT+PHKK(3,I)**2+0.000001)
	      IF(NOBAM(I).EQ.2)THEN
                ANEVA(3)=ANEVA(3)+1.D0
              ELSEIF(NOBAM(I).EQ.1)THEN
                ANEVAP(3)=ANEVAP(3)+1.D0
              ENDIF
C                       transform deexcitation photons into
C                       electron neutrinos (pdg=12, bamjet=5
C                       to allow separate histograms of pi-0
C                       and deexcitation photons
	      ISTHKK(I)=1
	      IDHKK(I) =12
            ENDIF
          ENDIF
          IF(IDHKK(I).EQ.80000)THEN
C                                         heavy fragments
              PPTT=(PHKK(1,I)**2+PHKK(2,I)**2+0.000001)
              PTOT=SQRT(PPTT+PHKK(3,I)**2+0.000001)
	      IF(NOBAM(I).EQ.2)THEN
                ANEVA(4)=ANEVA(4)+1.D0
                IDIT=IDRES(I)
                IF(IDIT.EQ.0)GO TO 3115
                AMEVAP(IDIT)=AMEVAP(IDIT)+1.D0
                ANHEA=ANHEA+1
                ANBLA=ANBLA+1
              ELSEIF(NOBAM(I).EQ.1)THEN
                ANEVAP(4)=ANEVAP(4)+1.D0
                IDIT=IDRES(I)
                IF(IDIT.EQ.0)GO TO 3115
                AMEVPP(IDIT)=AMEVPP(IDIT)+1.D0
              ENDIF
 3115       CONTINUE
          ENDIF
 3114   CONTINUE
      ENDIF
       RETURN
C------------------------------------------------------------------
C------------------------------------------------------------------
    3 CONTINUE
C------------------------------------------------------------------
C--------------------------------evaporation-----------------------
      IF (IFINAL.EQ.0) THEN
	WRITE(6,'(A)')' Target fragments'
        DO 3117 I=1,4
          ANEVA(I)=ANEVA(I)/NHKKH1
 3117   CONTINUE
        WRITE(6,'(A,F10.3)')' Number of evap. protons:  ',ANEVA(1)
        WRITE(6,'(A,F10.3)')' Number of evap. neutrans: ',ANEVA(2)
        WRITE(6,'(A,F10.3)')' Number of ex. gammas:     ',ANEVA(3)
        WRITE(6,'(A,F10.3)')' Number of heavy fragments:',ANEVA(4)
	WRITE(6,'(A)')' Projectile fragments'
        DO 3118 I=1,4
          ANEVAP(I)=ANEVAP(I)/NHKKH1
 3118   CONTINUE
        WRITE(6,'(A,F10.3)')
     *	' Number of evap. protons:  ',ANEVAP(1)
        WRITE(6,'(A,F10.3)')
     *	' Number of evap. neutrans: ',ANEVAP(2)
        WRITE(6,'(A,F10.3)')
     *	' Number of ex. gammas:     ',ANEVAP(3)
        WRITE(6,'(A,F10.3)')
     *	' Number of heavy fragments:',ANEVAP(4)
        ANSHO=ANSHO/NHKKH1
        ANGRE=ANGRE/NHKKH1
        ANGRE2=ANGRE2/NHKKH1
        ANHEA=ANHEA/NHKKH1
        ANBLA=ANBLA/NHKKH1
        ANMIN=ANMIN/NHKKH1
        ANSP8=ANSP8/NHKKH1
        ANSP5=ANSP5/NHKKH1
        WRITE(6,'(A,F10.3)')' Number of shower part.:',ANSHO
        WRITE(6,'(A,F10.3)')' Number of grey   part.:',ANGRE
        WRITE(6,'(A,F10.3)')' Number of grey23 part.:',ANGRE2
        WRITE(6,'(A,F10.3)')' Number of heavy  part.:',ANHEA
        WRITE(6,'(A,F10.3)')' Number of black  part.:',ANBLA
        WRITE(6,'(A,F10.3)')' Number of neg.ch.part.:',ANMIN
        WRITE(6,'(A,F10.3)')' Number of slow 8 prot.:',ANSP8
        WRITE(6,'(A,F10.3)')' Number of slow 5 prot.:',ANSP5
        DO 3128 I=1,250
          AMEVAP(I)=AMEVAP(I)/NHKKH1
          AMEVPP(I)=AMEVPP(I)/NHKKH1
	WRITE(6,'(F12.4,2E15.5)')XMEVAP(I),AMEVAP(I),AMEVPP(I)
          AMEVAP(I)=LOG10(AMEVAP(I)+1.D-9)
          AMEVPP(I)=LOG10(AMEVPP(I)+1.D-9)
 3128   CONTINUE
        WRITE(6,'(A)')' Heavy fragment spectrum'
        DIT=IT/50+1
        IF(DIT.LT.1.D0)DIT=1
        CALL PLOT(XMEVAP,AMEVAP,IT,1,IT,0.D0,DIT,-5.D0,0.1D0)
        DIP=IP/50+1
        IF(DIP.LT.1.D0)DIP=1
        CALL PLOT(XMEVAP,AMEVPP,IP,1,IP,0.D0,DIP,-5.D0,0.1D0)
        DO 3119 I=1,50
          DO 3119 II=1,2
            PEVAP(I,II)=LOG10(PEVAP(I,II)/(NHKKH1*DPEVA)+1.D-9)
 3119   CONTINUE  
      ENDIF
        WRITE(6,'(A)')' Ev. p and n momentum  spectrum'
        CALL PLOT(XPEVAP,PEVAP,100,2,50,0.D0,DPEVA,-5.D0,0.1D0)
C------------------------------------------------------------------
C------------------------------------------------------------------
      RETURN
      END
*
*===sdiff================================================================*
*
      SUBROUTINE SDIFF(EPROJ,PPROJ,KPROJ,NHKKH1,IQQDD)
 
**************************************************************************
* Version November 1993                         by Stefan Roesler        *
*                                                  University of Leipzig *
* This subroutine calls one single-diffractive event depending on the    *
* single-diffractive cross section for a given hadron-hadron interaction.*
**************************************************************************
 
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      PARAMETER (LOUT=6,LLOOK=9)
      PARAMETER (NMXHKK= 49998,INTMX=2488)
      CHARACTER*8 ANAME,ANC
      COMMON /DIQI/ IPVQ(248),   IPPV1(248),   IPPV2(248), ITVQ(248),
     &              ITTV1(248),  ITTV2(248),   IPSQ(INTMX),IPSQ2(INTMX),
     &              IPSAQ(INTMX),IPSAQ2(INTMX),ITSQ(INTMX),ITSQ2(INTMX),
     &              ITSAQ(INTMX),ITSAQ2(INTMX),KKPROJ(248),KKTARG(248)
      COMMON /HKKEVT/ NHKK,NEVHKK,     ISTHKK(NMXHKK),  IDHKK(NMXHKK),
     &                JMOHKK(2,NMXHKK),JDAHKK(2,NMXHKK),PHKK(5,NMXHKK),
     &                VHKK(4,NMXHKK),  WHKK(4,NMXHKK)
      COMMON /DIFFRA/ ISINGD,IDIFTP,IOUDIF,IFLAGD
      COMMON /NUCC/   IT,ITZ,IP,IPZ,IJPROJ,IBPROJ,IJTARG,IBTARG
      COMMON /CMHICO/ CMHIS
      COMMON /DPRIN/ IPRI,IPEV,IPPA,IPCO,INIT,IPHKK,ITOPD,IPAUPR
      COMMON /DPAR/ ANAME(210),AAM(210),GA(210),TAU(210),IICH(210),
     &              IIBAR(210),K1(210),K2(210)
      COMMON /DIFPAR/ PXC(902),  PYC(902),PZC(902),
     &                HEC(902),  AMC(902),ICHC(902),
     &                IBARC(902),ANC(902),NRC(902)
*----------------- S. Roesler 07/07/93
C     COMMON /COUNTEV/NCDIFF,NCSDIF
*---------- S. Roesler 5-11-93
      COMMON /IFRAGM/IFRAG
      COMMON/XXLMDD/IJLMDD,KDLMDD 
      COMMON /NUCCMS/GAMV,BGLV,DUMMY(7)

*
 
      DATA NCIREJ /0/
C     DATA NCDIFF /0/
      DATA SIGDIF,SIGDIH /6.788790702D0,3.631283998D0/
*
      IJLMDD= 0
      IREJ  = 0
      KTARG = 0
      PPROX = 0.0D0
      PPROY = 0.0D0
      PPROL = PPROJ
      EPRO  = EPROJ
      AMPRO = AAM(KPROJ)
      IF(IPRI.GE.1)WRITE(6,'(A,2E20.8)')' SDIFF:EPROJ,PPROJ ',
     * EPROJ,PPROJ
C     WRITE(6,'(A,2E20.8)')' SDIFF:EPROJ,PPROJ ',
C    * EPROJ,PPROJ
*
      DO 10 I=1,IT
         IHKK = I+IP
         IF (ISTHKK(IHKK).EQ.12) THEN
            KTARG = KKTARG(I)
            PTARX = PHKK(1,IHKK)
            PTARY = PHKK(2,IHKK)
            PTARL = PHKK(3,IHKK)
            ETAR  = PHKK(4,IHKK)
            AMTAR = PHKK(5,IHKK)
            PTOTX = PPROX + PTARX
            PTOTY = PPROY + PTARY
            PTOTL = PPROL + PTARL
            ETOT  = EPRO  + ETAR
            PTOT  = SQRT(PTOTX**2+PTOTY**2+PTOTL**2)
            AMTOT = SQRT(ABS(ETOT-PTOT)*(ETOT+PTOT))
            GAM   = ETOT /(AMTOT)
            BGX   = PTOTX/(AMTOT)
            BGY   = PTOTY/(AMTOT)
            BGL   = PTOTL/(AMTOT)
            IF (IPEV.GE.6) THEN
               WRITE(LOUT,1000) PPROX,PPROY,PPROL,EPRO,AMPRO,KPROJ
               WRITE(LOUT,1001) PTARX,PTARY,PTARL,ETAR,AMTAR,KTARG
               WRITE(LOUT,1011) PTOTX,PTOTY,PTOTL,ETOT,AMTOT,KTARG
               WRITE(LOUT,1002) AMTOT,GAM,BGX,BGY,BGL
               WRITE(LOUT,1702) GAMV,BGLV
 1000          FORMAT('SDIFF: PPROX,PPROY,PPROL,EPRO,AMPRO,KPROJ',
     &                        2E15.5,2E15.5,E15.6,I2)
 1001          FORMAT('SDIFF: PTARX,PTARY,PTARL,ETAR,AMTAR,KTARG',
     &                        5E15.6,I2)
 1011          FORMAT('SDIFF: PTOTX,PTOTY,PTOTL,ETOT,AMTOT,KTARG',
     &                        5E15.6,I2)
 1002          FORMAT('SDIFF: AMTOT,GAM,BGX,BGY,BGL',5E15.6)
 1702          FORMAT('SDIFF: GAMV,BGLV',2E15.6)
            ENDIF
C                 This is the hadron-hadron cms mot the overall cms
C                     (due to Fermi momenta)
            CALL DALTRA(GAM,-BGX,-BGY,-BGL,PPROX,PPROY,PPROL,EPRO,
     &                  PPCM,PPCMX,PPCMY,PPCML,EPCM)
            CALL DALTRA(GAM,-BGX,-BGY,-BGL,PTARX,PTARY,PTARL,ETAR,
     &                  PTCM,PTCMX,PTCMY,PTCML,ETCM)
C                 Back to lab frame
	    CALL DALTRA(GAM,BGX,BGY,BGL,PPCMX,PPCMY,PPCML,EPCM,
     &                  PPLA,PPLAX,PPLAY,PPLAL,EPLA)
            CALL DALTRA(GAM,BGX,BGY,BGL,PTCMX,PTCMY,PTCML,ETCM,
     &                  PTLA,PTLAX,PTLAY,PTLAL,ETLA)
C                And now into the real cms frame     
             EPCMS=GAMV*EPLA-BGLV*PPLAL
	     PPLCMS=GAMV*PPLAL-BGLV*EPLA
	     ETCMS=GAMV*ETLA-BGLV*PTLAL
	     PTLCMS=GAMV*PTLAL-BGLV*ETLA
            IF (IPEV.GE.6) THEN
               WRITE(LOUT,1003) PPCM,PPCMX,PPCMY,PPCML,EPCM
               WRITE(LOUT,1004) PTCM,PTCMX,PTCMY,PTCML,ETCM
 1003          FORMAT('SDIFF: PPCM,PPCMX,PPCMY,PPCML,EPCM',5E15.5)
 1004          FORMAT('SDIFF: PTCM,PTCMX,PTCMY,PTCML,ETCM',5E15.5)
               WRITE(LOUT,1703) PPLA,PPLAX,PPLAY,PPLAL,EPLA
               WRITE(LOUT,1704) PTLA,PTLAX,PTLAY,PTLAL,ETLA
 1703          FORMAT('SDIFF: PPLA,PPLAX,PPLAY,PPLAL,EPLA',5E15.5)
 1704          FORMAT('SDIFF: PTLA,PTLAX,PTLAY,PTLAL,ETLA',5E15.5)
               WRITE(LOUT,1803) PPCM,PPCMX,PPCMY,PPLCMS,EPCMS
               WRITE(LOUT,1804) PTCM,PTCMX,PTCMY,PTLCMS,ETCMS
 1803          FORMAT('SDIFF: PPCM,PPCMX,PPCMY,PPLCMS,EPCMS',5E15.5)
 1804          FORMAT('SDIFF: PTCM,PTCMX,PTCMY,PTLCMS,ETCMS',5E15.5)
            ENDIF
            COD  = PPCML/PPCM
            COD2 = COD**2
            IF (COD2.GT.0.999999999999D0) COD2 = 0.999999999999D0
            SID  = SQRT((1.0D0-COD)*(1.0D0+COD))
            COF  = 1.0D0
            SIF  = 0.0D0
            IF (PPCM*SID.GT.1.0D-9) THEN
               COF   = PPCMX/(SID*PPCM)
               SIF   = PPCMY/(SID*PPCM)
               ANORF = SQRT(COF**2+SIF**2)
               COF   = COF/ANORF
               SIF   = SIF/ANORF
            ENDIF
            IF (IPEV.GE.6) THEN
               WRITE(LOUT,1005) COD,SID,COF,SIF
 1005          FORMAT('SDIFF: COD,SID,COF,SIF',4E15.5)
            ENDIF
C                 This is the hadron-hadron cms mot the overall cms
C                     (due to Fermi momenta)
            ECM = EPCM + ETCM
            IF (IPEV.GE.6) THEN
               WRITE(LOUT,1705)ECM,EPCM,ETCM 
 1705          FORMAT('SDIFF:ECM,EPCM,ETCM',3E15.5)
            ENDIF
C------------------------------------------------------------------
C
C                                         Test J.R.2/94
C
C------------------------------------------------------------------
            CALL SIHNDI(ECM,KPROJ,KTARG,SIGDIF,SIGDIH)
c                j.r.30.8.01
            IF (IBPROJ.EQ.0)THEN
              SIGDIF=0.85D0*SIGDIF
              SIGDIH=0.85D0*SIGDIH
            ENDIF

C------------------------------------------------------------------
C
C                                         Test J.R.2/94
C
C------------------------------------------------------------------
            FAKK=1.9
C ------------------------------------------------------------------
C
C                             further modification j.r.6.1.95
C
C--------------------------------------------------------------------
            IF(ECM.LE.10.D0)THEN
              FAKK=1.D0
            ELSEIF(ECM.GE.30.D0)THEN
              FAKK=1.9D0
            ELSE
              FAK=(ECM-10.D0)/20.D0
              FAKK=1.D0+FAK*0.9D0
            ENDIF
	    AITT=IT
            IF((ISINGD.LE.2).AND.(KPROJ.EQ.1.OR.KPROJ.EQ.8))THEN
	      AADIFF=FAKK*AITT**0.17D0
              SIGDIF=AADIFF*SIGDIF
            ELSEIF((ISINGD.LE.2).AND.
     *      ((KPROJ.EQ.13).OR.(KPROJ.EQ.14).OR.(KPROJ.EQ.23)))THEN
	      AADIFF=FAKK*AITT**0.15D0
              SIGDIF=AADIFF*SIGDIF
            ELSEIF((ISINGD.LE.2).AND.
     *      ((KPROJ.EQ.15).OR.(KPROJ.EQ.16).OR.
     *      (KPROJ.EQ.24).OR.(KPROJ.EQ.25)))THEN
	      AADIFF=FAKk*AITT**0.13D0
              SIGDIF=AADIFF*SIGDIF
	    ENDIF
C------------------------------------------------------------------
C
            SIGIN = DSHNTO(KPROJ,KTARG,ECM)-DSHNEL(KPROJ,KTARG,ECM)
            IF (IPEV.GE.6) THEN
        WRITE(LOUT,1060)KPROJ,KTARG,ECM,SIGDIF/SIGIN
               WRITE(LOUT,1006)SIGDIF,SIGDIF-SIGDIH,SIGDIH,SIGIN
 1006          FORMAT('SDIFF: SIGDIF,SIGDIL,SIGDIH,SIGIN',4F10.5)
 1060          FORMAT('SDIFF: KPROJ,KTARG,ECM,SIGDIF/SIGIN',2I3,2F10.5)
            ENDIF
            IFLAGD = 0
            R = RNDM(V)
            IF ((R.LE.(SIGDIF/SIGIN)).OR.(ISINGD.GE.2)) THEN
C              NCDIFF = NCDIFF+1
 2000          CONTINUE
C              IFLAGD = 1
C                         j.r.11/98 drop the following two lines
C              GAMV=GAM
C              BGLV=BGL
               R = RNDM(V)
*---------------------- S.Roesler 5/26/93
               IF (((R.LT.(SIGDIH/SIGDIF)).OR.(ISINGD.EQ.5).OR.
     &              (ISINGD.EQ.6)).AND.(ISINGD.LE.6)) THEN
*
*--------------------- call high mass single diffractive event
*
		  IF(ISINGD.GE.1)THEN
                  CALL VAHMSD(IHKK,ECM,KPROJ,KTARG,IREJ)
		  IFLAGD=1
		  ENDIF
*
               ELSE IF((R.GE.(SIGDIH/SIGDIF)).OR.(ISINGD.EQ.7).OR.
     &              (ISINGD.EQ.8)) THEN
*
*
*--------------------- call low mass single diffractive event
*
C----------------------------------------------------------------
C
C                                     j.r. test 2/94
C
C----------------------------------------------------------------
	    RRRR=RNDM(VV)
	    IF(ISINGD.GE.3.AND.ISINGD.LE.6)RRRR=1.D0
            IF((RRRR.LE.0.33D0).AND.
     *      ((KPROJ.EQ.15).OR.(KPROJ.EQ.16).OR.
     *      (KPROJ.EQ.1).OR.(KPROJ.EQ.8).OR.
     *      (KPROJ.EQ.13).OR.(KPROJ.EQ.14).OR.(KPROJ.EQ.23).OR.
     *      (KPROJ.EQ.24).OR.(KPROJ.EQ.25)))THEN
                  CALL VALMDD(IHKK,ECM,KPROJ,KTARG,IREJ)
		  IFLAGD=1
            ELSE      
C----------------------------------------------------------------
		  IF(ISINGD.GE.1)THEN
                  CALL VALMSD(IHKK,ECM,KPROJ,KTARG,IREJ)
		  IFLAGD=1
		  ENDIF
            ENDIF
*
               ENDIF
               IF (IREJ.GT.0) THEN
                  NCIREJ = NCIREJ + 1
                  IF (MOD(NCIREJ,1000).EQ.0) THEN
                     IF (IPEV.GE.1)WRITE(LOUT,1007) NCIREJ
 1007                FORMAT('SDIFF: REJECTION, NCIREJ = ',I8)
                  ENDIF
                  GOTO 2000
               ENDIF
*
	       IF(IFLAGD.EQ.1)THEN
               CALL HADRDI(NAUX,KPROJ,KTARG,NHKKH1)
*
               IIHKK = NHKK -NAUX
               DO 11 J=1,NAUX
                  CALL DTRANS(PXC(J),PYC(J),PZC(J),
     &                        COD,SID,COF,SIF,PXX,PYY,PLL)
                  IIHKK = IIHKK + 1
                  IF (IPEV.GE.6) THEN
                     WRITE(LOUT,1008) IIHKK,PXX,PYY,PLL
 1008                FORMAT('SDIFF: NHKK,PXX,PYY,PLL',I4,3F10.5)
                  ENDIF
                  PHKK(1,IIHKK) = PXX
                  PHKK(2,IIHKK) = PYY
                  PHKK(3,IIHKK) = PLL
C                 IF (CMHIS.EQ.0.0D0) THEN
C                    CALL DALTRA(GAM,BGX,BGY,BGL,PXX,PYY,PLL,HEC(J),
C    &                    PLAB,PHKK(1,IIHKK),PHKK(2,IIHKK),
C    &                    PHKK(3,IIHKK),PHKK(4,IIHKK))
C                         Test j.r. 11/98
C---------------------------------------------------------------
C                 Back to lab frame
C           DO 1277 III=NHKKH1,NHKK
            III=IIHKK
	    IF(ISTHKK(III).EQ.1)THEN
	    CALL DALTRA(GAM,BGX,BGY,BGL,PHKK(1,III),PHKK(2,III),
     &      PHKK(3,III),PHKK(4,III),
     &                  PPLA,PPLAX,PPLAY,PPLAL,EPLA)
C                And now into the real cms frame     
             EPCMS=GAMV*EPLA-BGLV*PPLAL
	     PPLCMS=GAMV*PPLAL-BGLV*EPLA
	     PHKK(1,III)=PPLAX
	     PHKK(2,III)=PPLAY
	     PHKK(3,III)=PPLCMS
	     PHKK(4,III)=EPCMS
                  IF (IPEV.GE.6) THEN
               WRITE(LOUT,1903) PPLCMS,EPCMS
 1903          FORMAT('SDIFF TEST cms: PPLCMS,EPCMS',2E15.5)
                  ENDIF
	     ENDIF
C1277        CONTINUE	     
C---------------------------------------------------------------
                     IF (IPEV.GE.6) THEN
                        WRITE(LOUT,1009) IIHKK,
     &                  PHKK(1,IIHKK),PHKK(2,IIHKK),PHKK(3,IIHKK),
     &                  PHKK(4,IIHKK)
 1009                   FORMAT('SDIFF: NHKK,PHKK(1..4)',I4,4E15.5)
                     ENDIF
C                 ENDIF
   11          CONTINUE
	       ENDIF
            ENDIF
         ENDIF
   10 CONTINUE
      IF (KTARG.EQ.0) WRITE(LOUT,*)'SDIFF: NO INTERACTION'
 9999 CONTINUE
      RETURN
      END
*
*===vahmsd===============================================================*
*
      SUBROUTINE VAHMSD(ITAPOI,ECM,KPROJ,KTARG,IREJ)
 
**************************************************************************
* Version November 1993                         by Stefan Roesler        *
*                                                  University of Leipzig *
* This subroutine selects x-values, flavors and 4-momenta of partons     *
* in high-mass single diffractive chains.                                *
**************************************************************************
 
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      PARAMETER (LOUT=6,LLOOK=9)
      PARAMETER (NMXHKK= 49998)
      CHARACTER*8 ANAME
      COMMON /HKKEVT/ NHKK,NEVHKK,     ISTHKK(NMXHKK),  IDHKK(NMXHKK),
     &                JMOHKK(2,NMXHKK),JDAHKK(2,NMXHKK),PHKK(5,NMXHKK),
     &                VHKK(4,NMXHKK),  WHKK(4,NMXHKK)
      COMMON /DPRIN/  IPRI,IPEV,IPPA,IPCO,INIT,IPHKK,ITOPD,IPAUPR
      COMMON /DIFFRA/ ISINGD,IDIFTP,IOUDIF,IFLAGD
      COMMON /ABRDIF/ XDQ1,XDQ2,XDDQ1,XDDQ2,
     &                IKVQ1,IKVQ2,IKD1Q1,IKD2Q1,IKD1Q2,IKD2Q2,
     &                IDIFFP,IDIFAP,
     &                AMDCH1,AMDCH2,AMDCH3,GAMDC1,GAMDC2,GAMDC3,
     &                PGXVC1,PGYVC1,PGZVC1,PGXVC2,PGYVC2,PGZVC2,
     &                PGXVC3,PGYVC3,PGZVC3,NDCH1,NDCH2,NDCH3,
     &                IKDCH1,IKDCH2,IKDCH3,
     &                PDQ1(4),PDQ2(4),PDD1(4),PDD2(4),PDFQ1(4)
      COMMON /DPAR/   ANAME(210),AM(210),GA(210),TAU(210),ICH(210),
     &                IBAR(210),K1(210),K2(210)
      COMMON /TRAFOP/ GAMP,BGAMP,BETP
      COMMON /ENERIN/ EPROJ,ETARG
      COMMON /SDFLAG/ ISD
      COMMON /XDIDID/XDIDI
*
      DIMENSION MQUARK(3,30),IHKKQ(-6:6),IHKKQQ(-3:3,-3:3),
     &          IDX(-4:4)
      DATA IDX   /-4,-3,-1,-2,0,2,1,3,4/
      DATA IHKKQ /-6,-5,-4,-3,-1,-2,0,2,1,3,4,5,6/
      DATA IHKKQQ/-3301,-3103,-3203,0,   0,0,0,
     &            -3103,-1103,-2103,0,   0,   0,   0,
     &            -3203,-2103,-2203,0,   0,   0,   0,
     &                0,    0,    0,0,   0,   0,   0,
     &                0,    0,    0,0,2203,2103,3202,
     &                0,    0,    0,0,2103,1103,3103,
     &                0,    0,    0,0,3203,3103,3303/
*
*----------------------------------- quark content of hadrons:
*                                     1, 2, 3, 4  -   u, d, s, c
*                                    -1,-2,-3,-4  -  au,ad,as,ac
*
      DATA MQUARK/
     &   1,1,2,    -1,-1,-2,       0,0,0,       0,0,0,       0,0,0,
     &   0,0,0,       0,0,0,       1,2,2,    -1,-2,-2,       0,0,0,
     &   0,0,0,       0,0,0,      1,-2,0,      2,-1,0,      1,-3,0,
     &  3,-1,0,       1,2,3,    -1,-2,-3,       0,0,0,       2,2,3,
     &   1,1,3,       1,2,3,      1,-1,0,      2,-3,0,      3,-2,0,
     &  2,-2,0,      3,-3,0,       0,0,0,       0,0,0,       0,0,0/
      DATA UNON/2.0/
      DATA NCREJ, NCXDI, NCXP, NCXT /0, 0, 0, 0/
*
      ISD   = 1
      IREJ  = 0
      IIREJ = 0
      EPROJ = (AM(KPROJ)**2-AM(KTARG)**2+ECM**2)/(2.0D0*ECM)
      ETARG = (AM(KTARG)**2-AM(KPROJ)**2+ECM**2)/(2.0D0*ECM)
      IF(IPEV.GE.2) WRITE(LOUT,1001) EPROJ,ETARG
 1001 FORMAT('VAHMSD: EPROJ,ETARG ',2F10.5)
      IBPROJ = IBAR(KPROJ)
      IBTARG = IBAR(KTARG)
      IF (IBTARG.LE.0) THEN
         WRITE(LOUT,1002) IBTARG
 1002    FORMAT('VAHMSD: NO HMSD FOR TARGET WITH BARYON-CHARGE',I4)
         IIREJ=1
         GOTO 9999
      ENDIF
      IQP1 = MQUARK(1,KPROJ)
      IQP2 = MQUARK(2,KPROJ)
      IQP3 = MQUARK(3,KPROJ)
      IQT1 = MQUARK(1,KTARG)
      IQT2 = MQUARK(2,KTARG)
      IQT3 = MQUARK(3,KTARG)
      IF(IPEV.GE.2) WRITE(LOUT,1003)
     &                IBPROJ,IBTARG,IQP1,IQP2,IQP3,IQT1,IQT2,IQT3
 1003 FORMAT('VAHMSD: IBPROJ,IBTARG,IQP1,IQP2,IQP3,IQT1,IQT2,IQT3 ',8I4)
*
      IF (IBPROJ.NE.0) THEN
*
*-------------------- q-qq (aq-aqaq) - flavors of projectile (baryon)
*
         ISAM = 1.0D0+2.999D0*RNDM(V)
         GOTO (10,11,12) ISAM
   10    CONTINUE
         IQP    = IQP1
         IDIQP1 = IQP2
         IDIQP2 = IQP3
         GOTO 13
   11    CONTINUE
         IQP    = IQP2
         IDIQP1 = IQP1
         IDIQP2 = IQP3
         GOTO 13
   12    CONTINUE
         IQP    = IQP3
         IDIQP1 = IQP1
         IDIQP2 = IQP2
   13    CONTINUE
*
      ELSE IF (IBPROJ.EQ.0) THEN
*
*-------------------- q-aq - flavors of projectile (meson)
*
         ISAM = 1.0D0+1.999D0*RNDM(V)
         GOTO (14,15) ISAM
   14    CONTINUE
         IQP    = IQP1
         IDIQP1 = IQP2
         GOTO 16
   15    CONTINUE
         IQP    = IQP2
         IDIQP1 = IQP1
   16    CONTINUE
         IDIQP2 = 0
*
      ENDIF
*
*-------------------- q-qq - flavors of target (baryon)
*
      ISAM = 1.0D0+2.999D0*RNDM(V)
      GOTO (17,18,19) ISAM
   17 CONTINUE
      IQT    = IQT1
      IDIQT1 = IQT2
      IDIQT2 = IQT3
      GOTO 20
   18 CONTINUE
      IQT    = IQT2
      IDIQT1 = IQT1
      IDIQT2 = IQT3
      GOTO 20
   19 CONTINUE
      IQT    = IQT3
      IDIQT1 = IQT1
      IDIQT2 = IQT2
   20 CONTINUE
*
      IKVQ1  = IQP
      IKD1Q1 = IDIQP1
      IKD2Q1 = IDIQP2
*
      IKVQ2  = IQT
      IKD1Q2 = IDIQT1
      IKD2Q2 = IDIQT2
*
      IF (IPEV.GE.2) WRITE(LOUT,1004)
     &                 IKVQ1,IKD1Q1,IKD2Q1,IKVQ2,IKD1Q2,IKD2Q2
 1004 FORMAT('VAHMSD: IKVQ1,IKD1Q1,IKD2Q1,IKVQ2,IKD1Q2,IKD2Q2 ',6I4)
*
*-------------------- q-aq - flavors of diffractive parton
*
      IDIFFP = 1.0D0+2.3D0*RNDM(V)
      IDIFAP = -IDIFFP
      IF (IPEV.GE.2) WRITE(LOUT,1005) IDIFFP,IDIFAP
 1005 FORMAT('VAHMSD: IDIFFP,IDIFAP ',2I4)
*
*-------------------- IDIFTP = 1  target     (backward) hadron  excited
*                     IDIFTP = 2  projectile (forward)  hadron  excited
*
      IDIFTP = 1.0D0+1.999D0*RNDM(V)
*----------------------- S.Roesler 5/26/93
      IF ((ISINGD.EQ.3).OR.(ISINGD.EQ.5)) IDIFTP = 1
      IF ((ISINGD.EQ.4).OR.(ISINGD.EQ.6)) IDIFTP = 2
*
      IF (IPEV.GE.2) WRITE(LOUT,1006) IDIFTP
 1006 FORMAT('VAHMSD: IDIFTP ',I4)
      IF ((IDIFTP.NE.1).AND.(IDIFTP.NE.2)) THEN
         IF (IPEV.GE.2) WRITE(LOUT,'(A19)') 'VAHMSD-ERROR: IDIFTP'
         GOTO 9999
      ENDIF
*
*-------------------- momentum fractions of quarks and diquarks
*
      XXMAX = 0.8D0
   30 CONTINUE
      XP  = DBETAR(0.5D0,UNON)
      IF (XP.GE.XXMAX) THEN
         NCXP = NCXP+1
         IF(MOD(NCXP,500).EQ.0) then
         IF (IPEV.GE.1) WRITE(LOUT,1007) NCXP
 1007      FORMAT('VAHMSD: INEFFICIENT XP-SELECTION, NCXP=',I8)
         endif
         GOTO 30
      ENDIF
      XXP = 1.0D0-XP
   31 CONTINUE
      XT  = DBETAR(0.5D0,UNON)
      IF (XT.GE.XXMAX)  THEN
         NCXT = NCXT+1
         IF(MOD(NCXT,2500).EQ.0) then
           IF (IPEV.GE.1)WRITE(LOUT,1008) NCXT
 1008    FORMAT('VAHMSD: INEFFICIENT XT-SELECTION, NCXT=',I8)
         endif
         GOTO 31
      ENDIF
      XXT = 1.0D0-XT
      IF (IPEV.GE.2) WRITE(LOUT,1010) XP,XXP,XT,XXT
 1010 FORMAT('VAHMSD: XP,XXP,XT,XXT ',4D10.5)
*-------------------- x - values of diffractive partons
*
      NCXDI = 0
   32 CONTINUE
      R = RNDM(V)
      IF (IDIFTP.EQ.1) THEN
         XDIMIN = (3.0D0+400.0D0*(R**2))/(4.0D0*(ETARG**2)*XXT)
         IF (ECM.LE.300.0D0) THEN
            RR = (1.0D0-EXP(-((ECM/140.0D0)**4)))
            XDIMIN = (3.0D0+400.0D0*(R**2)*RR)/(4.0D0*(ETARG**2)*XXT)
         ENDIF
      ELSE IF (IDIFTP.EQ.2) THEN
         XDIMIN = (3.0D0+400.0D0*(R**2))/(4.0D0*(EPROJ**2)*XXP)
         IF (ECM.LE.300.0D0) THEN
            RR = (1.0D0-EXP(-((ECM/140.0D0)**4)))
            XDIMIN = (3.0D0+400.0D0*(R**2)*RR)/(4.0D0*(EPROJ**2)*XXP)
         ENDIF
      ENDIF
C-----------------------------------------------------------------
C                                    original version
C-----------------------------------------------------------------
C     XDIMAX = 0.05D0
C     IF (ECM.LE.1000.0D0) THEN
C        XDIMAX = 0.05D0*(1.0D0+EXP(-((ECM/420.0D0)**2)))
C        IF (IBPROJ.EQ.0) XDIMAX = 0.05D0*
CC---------------- change mass-cuts
CC   &                    (1.0D0+4.0D0*EXP(-((ECM/420.0D0)**2)))
C    &                    (1.0D0+2.0D0*EXP(-((ECM/420.0D0)**2)))
C     ENDIF
C-----------------------------------------------------------------
C-----------------------------------------------------------------
C                           version j.r.28.1.94
C extend diffraction beyond limits of single diffractive experiments
C-----------------------------------------------------------------
      XDIMAA = 0.15D0
      XDIMAX = XDIMAA
      IF (ECM.LE.10000.0D0) THEN
         XDIMAX = XDIMAA*(1.0D0+EXP(-((ECM/420.0D0)**2)))
         IF (IBPROJ.EQ.0) XDIMAX = XDIMAA*
C----------------- change mass-cuts
C    &                    (1.0D0+4.0D0*EXP(-((ECM/420.0D0)**2)))
     &                    (1.0D0+2.0D0*EXP(-((ECM/420.0D0)**2)))
      ENDIF
C-----------------------------------------------------------------
   40 CONTINUE
      IF (XDIMIN.GE.XDIMAX) THEN
         NCXDI = NCXDI+1
         IF (NCXDI.EQ.200) GOTO 9999
         GOTO 32
      ENDIF
      XDITOT = SAMPEY(XDIMIN,XDIMAX)
      R    = RNDM(V)**6
      DX   = XDITOT-XDIMIN
      XDI  = DX*R
C     IF (XDI.LT.XMINQ1) THEN
C        NCXDI = NCXDI+1
C        IF (MOD(NCXDI,2000).EQ.0) WRITE(LOUT,1011) NCXDI
C1011    FORMAT('VAHMSD: INEFFICIENT XDI-SELECTION, NCXDI=',I8)
C        GOTO 40
C     ENDIF
      XXDI = XDIMIN+(1.0D0-R)*DX
      IF (IDIFTP.EQ.1) THEN
         XXP = XXP-XDI-XXDI
         IF (XXP.LT.8.0D-2) GOTO 9999
      ELSE IF (IDIFTP.EQ.2) THEN
         XXT = XXT-XDI-XXDI
         IF (XXT.LT.8.0D-2) GOTO 9999
      ENDIF
      IF (IPEV.GE.2) WRITE(LOUT,1012) XP,XXP,XT,XXT,XDI,XXDI
 1012 FORMAT('VAHMSD: XP,XXP,XT,XXT,XDI,XXDI ',6F10.5)
       XDIDI=XDI+XXDI
       AMDIDI=SQRT(XDIDI*ECM**2)
      IF(IPEV.GE.2)WRITE(LOUT,*)'HM AMDIDI,XDIDI ',AMDIDI,XDIDI
*
*-------------------- kinematical parameters of three chains in CMS
*
      IF ((IBPROJ.EQ.-1).AND.(IDIFTP.EQ.1)) THEN
*
*-------------------- target: baryon,   projectile: antibaryon
*                             (excited)
*
         XDIFAP = XDI
         XDIFFP = XXDI
         CALL DIFFCH (XDIFAP, IDIFAP,     XT,  IKVQ2,     99,
     &                XDIFFP, IDIFFP,    XXT,    XXP,  ETARG,
     &                AMDCH1,   ECH1,   PCH1, GAMDC1,  PGVC1,
     &                 NDCH1, IKDCH1,  EPROJ,   NUNO,  IIREJ,      1)
         IF (IIREJ.EQ.1) GOTO 9999
         CALL DIFFCH (XDIFFP, IDIFFP,    XXT, IKD1Q2, IKD2Q2,
     &                   DUM,   IDUM,    DUM,    XXP,  ETARG,
     &                AMDCH2,   ECH2,   PCH2, GAMDC2,  PGVC2,
     &                 NDCH2, IKDCH2,  EPROJ,   NUNO,  IIREJ,      2)
         IF (IIREJ.EQ.1) GOTO 9999
         CALL DIFFCH (    XP,  IKVQ1,    XXP, IKD1Q1, IKD2Q1,
     &                   DUM,   IDUM,    DUM,    DUM,  EPROJ,
     &                AMDCH3,   ECH3,   PCH3, GAMDC3,  PGVC3,
     &                 NDCH3,   IDUM,    DUM,   NUNO,  IIREJ,      3)
         IF (IIREJ.EQ.1)  GOTO 9999
*
*
      ELSE IF ((IBPROJ.EQ.-1).AND.(IDIFTP.EQ.2)) THEN
*
*-------------------- target: baryon,   projectile: antibaryon
*                                                   (excited)
*
         XDIFAP = XXDI
         XDIFFP = XDI
         CALL DIFFCH (XDIFFP, IDIFFP,     XP,  IKVQ1,     99,
     &                XDIFAP, IDIFAP,    XXP,    XXT,  EPROJ,
     &                AMDCH1,   ECH1,   PCH1, GAMDC1,  PGVC1,
     &                 NDCH1, IKDCH1,  ETARG,   NUNO,  IIREJ,      1)
         IF (IIREJ.EQ.1) GOTO 9999
         CALL DIFFCH (XDIFAP, IDIFAP,    XXP, IKD1Q1, IKD2Q1,
     &                   DUM,   IDUM,    DUM,    XXT,  EPROJ,
     &                AMDCH2,   ECH2,   PCH2, GAMDC2,  PGVC2,
     &                 NDCH2, IKDCH2,  ETARG,   NUNO,  IIREJ,      2)
         IF (IIREJ.EQ.1) GOTO 9999
         CALL DIFFCH (    XT,  IKVQ2,    XXT, IKD1Q2, IKD2Q2,
     &                   DUM,   IDUM,    DUM,    DUM,  ETARG,
     &                AMDCH3,   ECH3,   PCH3, GAMDC3,  PGVC3,
     &                 NDCH3,   IDUM,    DUM,   NUNO,  IIREJ,      3)
         IF (IIREJ.EQ.1)  GOTO 9999
*
*
      ELSE IF ((IBPROJ.EQ.0).AND.(IDIFTP.EQ.1)) THEN
*
*-------------------- target: baryon,   projectile: meson
*                             (excited)
*
         XDIFAP = XDI
         XDIFFP = XXDI
         CALL DIFFCH (XDIFAP, IDIFAP,     XT,  IKVQ2,     99,
     &                XDIFFP, IDIFFP,    XXT,    XXP,  ETARG,
     &                AMDCH1,   ECH1,   PCH1, GAMDC1,  PGVC1,
     &                 NDCH1, IKDCH1,  EPROJ,   NUNO,  IIREJ,      1)
         IF (IIREJ.EQ.1) GOTO 9999
         CALL DIFFCH (XDIFFP, IDIFFP,    XXT, IKD1Q2, IKD2Q2,
     &                   DUM,   IDUM,    DUM,    XXP,  ETARG,
     &                AMDCH2,   ECH2,   PCH2, GAMDC2,  PGVC2,
     &                 NDCH2, IKDCH2,  EPROJ,   NUNO,  IIREJ,      2)
         IF (IIREJ.EQ.1) GOTO 9999
         CALL DIFFCH (    XP,  IKVQ1,    XXP, IKD1Q1,     99,
     &                   DUM,   IDUM,    DUM,    DUM,  EPROJ,
     &                AMDCH3,   ECH3,   PCH3, GAMDC3,  PGVC3,
     &                 NDCH3,   IDUM,    DUM,   NUNO,  IIREJ,      3)
         IF (IIREJ.EQ.1)  GOTO 9999
*
*
      ELSEIF ((IBPROJ.EQ.0).AND.(IDIFTP.EQ.2)) THEN
*
*-------------------- target: baryon,   projectile: meson
*                                                   (excited)
*
         IF (IKD1Q1.LT.0) THEN
            XDIFAP = XDI
            XDIFFP = XXDI
            CALL DIFFCH (XDIFAP, IDIFAP,     XP,  IKVQ1,     99,
     &                   XDIFFP, IDIFFP,    XXP,    XXT,  EPROJ,
     &                   AMDCH1,   ECH1,   PCH1, GAMDC1,  PGVC1,
     &                    NDCH1, IKDCH1,  ETARG,   NUNO,  IIREJ,      1)
            IF (IIREJ.EQ.1)  GOTO 9999
            CALL DIFFCH (XDIFFP, IDIFFP,    XXP, IKD1Q1,     99,
     &                   XDIFAP, IDIFAP,     XP,    XXT,  EPROJ,
     &                   AMDCH2,   ECH2,   PCH2, GAMDC2,  PGVC2,
     &                    NDCH2, IKDCH2,  ETARG,   NUNO,  IIREJ,      1)
            IF (IIREJ.EQ.1)  GOTO 9999
         ELSE
            XDIFAP = XXDI
            XDIFFP = XDI
            CALL DIFFCH (XDIFFP, IDIFFP,     XP,  IKVQ1,     99,
     &                   XDIFAP, IDIFAP,    XXP,    XXT,  EPROJ,
     &                   AMDCH1,   ECH1,   PCH1, GAMDC1,  PGVC1,
     &                    NDCH1, IKDCH1,  ETARG,   NUNO,  IIREJ,      1)
            IF (IIREJ.EQ.1)  GOTO 9999
            CALL DIFFCH (XDIFAP, IDIFAP,    XXP, IKD1Q1,     99,
     &                   XDIFFP, IDIFFP,     XP,    XXT,  EPROJ,
     &                   AMDCH2,   ECH2,   PCH2, GAMDC2,  PGVC2,
     &                    NDCH2, IKDCH2,  ETARG,   NUNO,  IIREJ,      1)
            IF (IIREJ.EQ.1)  GOTO 9999
         ENDIF
         CALL DIFFCH (    XT,  IKVQ2,    XXT, IKD1Q2, IKD2Q2,
     &                   DUM,   IDUM,    DUM,    DUM,  ETARG,
     &                AMDCH3,   ECH3,   PCH3, GAMDC3,  PGVC3,
     &                 NDCH3,   IDUM,    DUM,   NUNO,  IIREJ,      3)
         IF (IIREJ.EQ.1)  GOTO 9999
*
*
      ELSEIF ((IBPROJ.EQ.1).AND.(IDIFTP.EQ.1)) THEN
*
*-------------------- target: baryon,   projectile: baryon
*                             (excited)
*
         XDIFAP = XDI
         XDIFFP = XXDI
         CALL DIFFCH (XDIFAP, IDIFAP,     XT,  IKVQ2,     99,
     &                XDIFFP, IDIFFP,    XXT,    XXP,  ETARG,
     &                AMDCH1,   ECH1,   PCH1, GAMDC1,  PGVC1,
     &                 NDCH1, IKDCH1,  EPROJ,   NUNO,  IIREJ,      1)
         IF (IIREJ.EQ.1)  GOTO 9999
         CALL DIFFCH (XDIFFP, IDIFFP,    XXT, IKD1Q2, IKD2Q2,
     &                   DUM,   IDUM,    DUM,    XXP,  ETARG,
     &                AMDCH2,   ECH2,   PCH2, GAMDC2,  PGVC2,
     &                 NDCH2, IKDCH2,  EPROJ,   NUNO,  IIREJ,      2)
         IF (IIREJ.EQ.1)  GOTO 9999
         CALL DIFFCH (    XP,  IKVQ1,    XXP, IKD1Q1, IKD2Q1,
     &                   DUM,   IDUM,    DUM,    DUM,  EPROJ,
     &                AMDCH3,   ECH3,   PCH3, GAMDC3,  PGVC3,
     &                 NDCH3,   IDUM,    DUM,   NUNO,  IIREJ,      3)
         IF (IIREJ.EQ.1)  GOTO 9999
*
*
      ELSE IF ((IBPROJ.EQ.1).AND.(IDIFTP.EQ.2)) THEN
*
*-------------------- target: baryon,   projectile: baryon
*                                                   (excited)
*
         XDIFAP = XDI
         XDIFFP = XXDI
         CALL DIFFCH (XDIFAP, IDIFAP,     XP,  IKVQ1,     99,
     &                XDIFFP, IDIFFP,    XXP,    XXT,  EPROJ,
     &                AMDCH1,   ECH1,   PCH1, GAMDC1,  PGVC1,
     &                 NDCH1, IKDCH1,  ETARG,   NUNO,  IIREJ,      1)
         IF (IIREJ.EQ.1)  GOTO 9999
         CALL DIFFCH (XDIFFP, IDIFFP,    XXP, IKD1Q1, IKD2Q1,
     &                   DUM,   IDUM,    DUM,    XXT,  EPROJ,
     &                AMDCH2,   ECH2,   PCH2, GAMDC2,  PGVC2,
     &                 NDCH2, IKDCH2,  ETARG,   NUNO,  IIREJ,      2)
         IF (IIREJ.EQ.1) GOTO 9999
         CALL DIFFCH (    XT,  IKVQ2,    XXT, IKD1Q2, IKD2Q2,
     &                   DUM,   IDUM,    DUM,    DUM,  ETARG,
     &                AMDCH3,   ECH3,   PCH3, GAMDC3,  PGVC3,
     &                 NDCH3,   IDUM,    DUM,   NUNO,  IIREJ,      3)
         IF (IIREJ.EQ.1)  GOTO 9999
*
      ENDIF
*
*-------------------- store results in common block /ABRDIF/
*
      XDQ1  = XP
      XDQ2  = XT
      XDDQ1 = XXP
      XDDQ2 = XXT
*
      IF (IPEV.GE.2) THEN
         WRITE(LOUT,1013) AMDCH1,ECH1,PCH1,GAMDC1,PGVC1,IKDCH1,NDCH1
 1013    FORMAT('VAHMSD: AMDCH1,ECH1,PCH1,GAMDC1,PGVC1,IKDCH1,NDCH1 ',
     &                                                     5F10.5,2I4)
         WRITE(LOUT,1014) AMDCH2,ECH2,PCH2,GAMDC2,PGVC2,IKDCH2,NDCH2
 1014    FORMAT('VAHMSD: AMDCH2,ECH2,PCH2,GAMDC2,PGVC2,IKDCH2,NDCH2 ',
     &                                                     5F10.5,2I4)
         WRITE(LOUT,1015) AMDCH3,ECH3,PCH3,GAMDC3,PGVC3,NDCH3
 1015    FORMAT('VAHMSD: AMDCH3,ECH3,PCH3,GAMDC3,PGVC3,NDCH3 ',
     &                                                     5F10.5,I4)
      ENDIF
*
*-------------------- select transverse momenta
*
      IF (IDIFTP.EQ.1) THEN
         CALL DIFFPT(   ECH1,   PCH1, XDIFAP,     XT,
     &                  ECH2,   PCH2, XDIFFP,    XXT,
     &                  ECH3,   PCH3,  EPROJ,  KPROJ,
     &                 ETARG,  EPROJ,  IIREJ)
      ELSE IF (IDIFTP.EQ.2) THEN
         IF ((IBPROJ.LT.0).OR.(IKVQ1.LT.0)) THEN
            CALL DIFFPT(   ECH1,   PCH1, XDIFFP,     XP,
     &                     ECH2,   PCH2, XDIFAP,    XXP,
     &                     ECH3,   PCH3,  ETARG,  KTARG,
     &                    EPROJ,  ETARG,  IIREJ)
         ELSE
            CALL DIFFPT(   ECH1,   PCH1, XDIFAP,     XP,
     &                     ECH2,   PCH2, XDIFFP,    XXP,
     &                     ECH3,   PCH3,  ETARG,  KTARG,
     &                    EPROJ,  ETARG,  IIREJ)
         ENDIF
      ENDIF
      IF (IIREJ.EQ.1) GOTO 9999
*
*-------------------- store results in common-block /HKKEVT/
*
*                     partonen of projectile
*
      NHKK = NHKK+1
      ISTHKK(NHKK)   = 21
      IDHKK (NHKK)   = IHKKQ(IDX(IKVQ1))
      JMOHKK(1,NHKK) = 1
      JMOHKK(2,NHKK) = 0
      JDAHKK(1,NHKK) = 0
      JDAHKK(2,NHKK) = 0
      PHKK  (1,NHKK) = 0.0D0
      PHKK  (2,NHKK) = 0.0D0
      PHKK  (3,NHKK) = XDQ1
      PHKK  (4,NHKK) = XDQ1
      PHKK  (5,NHKK) = 0.0D0
      VHKK  (1,NHKK) = VHKK(1,1)
      VHKK  (2,NHKK) = VHKK(2,1)
      VHKK  (3,NHKK) = VHKK(3,1)
      VHKK  (4,NHKK) = VHKK(4,1)
*
      NHKK = NHKK+1
      ISTHKK(NHKK)   = 21
      IDHKK (NHKK)   = IHKKQQ(IDX(IKD1Q1),IDX(IKD2Q1))
      JMOHKK(1,NHKK) = 1
      JMOHKK(2,NHKK) = 0
      JDAHKK(1,NHKK) = 0
      JDAHKK(2,NHKK) = 0
      PHKK  (1,NHKK) = 0.0D0
      PHKK  (2,NHKK) = 0.0D0
      PHKK  (3,NHKK) = XDDQ1
      PHKK  (4,NHKK) = XDDQ1
      PHKK  (5,NHKK) = 0.0D0
      VHKK  (1,NHKK) = VHKK(1,1)
      VHKK  (2,NHKK) = VHKK(2,1)
      VHKK  (3,NHKK) = VHKK(3,1)
      VHKK  (4,NHKK) = VHKK(4,1)
*
*                     partonen of target
*
      NHKK = NHKK+1
      ISTHKK(NHKK)   = 22
      IDHKK (NHKK)   = IHKKQ(IDX(IKVQ2))
      JMOHKK(1,NHKK) = ITAPOI
      JMOHKK(2,NHKK) = 0
      JDAHKK(1,NHKK) = 0
      JDAHKK(2,NHKK) = 0
      PHKK  (1,NHKK) = 0.0D0
      PHKK  (2,NHKK) = 0.0D0
      PHKK  (3,NHKK) = XDQ2
      PHKK  (4,NHKK) = XDQ2
      PHKK  (5,NHKK) = 0.0D0
      VHKK  (1,NHKK) = VHKK(1,ITAPOI)
      VHKK  (2,NHKK) = VHKK(2,ITAPOI)
      VHKK  (3,NHKK) = VHKK(3,ITAPOI)
      VHKK  (4,NHKK) = VHKK(4,ITAPOI)
*
      NHKK = NHKK+1
      ISTHKK(NHKK)   = 22
      IDHKK (NHKK)   = IHKKQQ(IDX(IKD1Q2),IDX(IKD2Q2))
      JMOHKK(1,NHKK) = ITAPOI
      JMOHKK(2,NHKK) = 0
      JDAHKK(1,NHKK) = 0
      JDAHKK(2,NHKK) = 0
      PHKK  (1,NHKK) = 0.0D0
      PHKK  (2,NHKK) = 0.0D0
      PHKK  (3,NHKK) = XDDQ2
      PHKK  (4,NHKK) = XDDQ2
      PHKK  (5,NHKK) = 0.0D0
      VHKK  (1,NHKK) = VHKK(1,ITAPOI)
      VHKK  (2,NHKK) = VHKK(2,ITAPOI)
      VHKK  (3,NHKK) = VHKK(3,ITAPOI)
      VHKK  (4,NHKK) = VHKK(4,ITAPOI)
*
*                     sea q-aq pair
*
      NHKK = NHKK+1
      ISTHKK(NHKK)   = 30+IDIFTP
      IDHKK (NHKK)   = IHKKQ(IDX(IDIFFP))
      IF (IDIFTP.EQ.1) JMOHKK(1,NHKK) = 1
      IF (IDIFTP.EQ.2) JMOHKK(1,NHKK) = ITAPOI
      JMOHKK(2,NHKK) = 0
      JDAHKK(1,NHKK) = 0
      JDAHKK(2,NHKK) = 0
      PHKK  (1,NHKK) = 0.0D0
      PHKK  (2,NHKK) = 0.0D0
      PHKK  (3,NHKK) = XXDI
      PHKK  (4,NHKK) = XXDI
      PHKK  (5,NHKK) = 0.0D0
      VHKK  (1,NHKK) = VHKK(1,JMOHKK(1,NHKK))
      VHKK  (2,NHKK) = VHKK(2,JMOHKK(1,NHKK))
      VHKK  (3,NHKK) = VHKK(3,JMOHKK(1,NHKK))
      VHKK  (4,NHKK) = VHKK(4,JMOHKK(1,NHKK))
*
      NHKK = NHKK+1
      ISTHKK(NHKK)   = 30+IDIFTP
      IDHKK (NHKK)   = IHKKQ(IDX(IDIFAP))
      IF (IDIFTP.EQ.1) JMOHKK(1,NHKK) = 1
      IF (IDIFTP.EQ.2) JMOHKK(1,NHKK) = ITAPOI
      JMOHKK(2,NHKK) = 0
      JDAHKK(1,NHKK) = 0
      JDAHKK(2,NHKK) = 0
      PHKK  (1,NHKK) = 0.0D0
      PHKK  (2,NHKK) = 0.0D0
      PHKK  (3,NHKK) = XDI
      PHKK  (4,NHKK) = XDI
      PHKK  (5,NHKK) = 0.0D0
      VHKK  (1,NHKK) = VHKK(1,JMOHKK(1,NHKK))
      VHKK  (2,NHKK) = VHKK(2,JMOHKK(1,NHKK))
      VHKK  (3,NHKK) = VHKK(3,JMOHKK(1,NHKK))
      VHKK  (4,NHKK) = VHKK(4,JMOHKK(1,NHKK))
*
*                     ends of chain 1
*
      NHKK = NHKK+1
      ISTHKK(NHKK)   = 123-IDIFTP
      IND = NHKK-2-2*IDIFTP
      IDHKK (NHKK)   = IDHKK(IND)
      JMOHKK(1,NHKK) = IND
      JMOHKK(2,NHKK) = JMOHKK(1,IND)
      JDAHKK(1,NHKK) = NHKK+2
      JDAHKK(2,NHKK) = NHKK+2
      PHKK  (1,NHKK) = PDQ1(1)
      PHKK  (2,NHKK) = PDQ1(2)
      PHKK  (3,NHKK) = PDQ1(3)
      PHKK  (4,NHKK) = PDQ1(4)
      PHKK  (5,NHKK) = 0.0D0
C               Add position of parton in hadron
       CALL QINNUC(XXPP,YYPP)
      VHKK  (1,NHKK) = VHKK(1,IND)+XXPP
      VHKK  (2,NHKK) = VHKK(2,IND)+YYPP
      VHKK  (3,NHKK) = VHKK(3,IND)
      VHKK  (4,NHKK) = VHKK(4,IND)
*
      NHKK = NHKK+1
      ISTHKK(NHKK)   = 130+IDIFTP
      IF (IDHKK(NHKK-1).GT.0) JMOHKK(1,NHKK) = NHKK-2
      IF (IDHKK(NHKK-1).LE.0) JMOHKK(1,NHKK) = NHKK-3
      JMOHKK(2,NHKK) = JMOHKK(1,NHKK-3)
      JDAHKK(1,NHKK) = NHKK+1
      JDAHKK(2,NHKK) = NHKK+1
      IDHKK (NHKK)   = IDHKK(JMOHKK(1,NHKK))
      PHKK  (1,NHKK) = PDD2(1)
      PHKK  (2,NHKK) = PDD2(2)
      PHKK  (3,NHKK) = PDD2(3)
      PHKK  (4,NHKK) = PDD2(4)
      PHKK  (5,NHKK) = 0.0D0
C               Add position of parton in hadron
       CALL QINNUC(XXPP,YYPP)
      VHKK  (1,NHKK) = VHKK(1,JMOHKK(1,NHKK))+XXPP
      VHKK  (2,NHKK) = VHKK(2,JMOHKK(1,NHKK))+YYPP
      VHKK  (3,NHKK) = VHKK(3,JMOHKK(1,NHKK))
      VHKK  (4,NHKK) = VHKK(4,JMOHKK(1,NHKK))
*
*                     chain 1
*
      NHKK = NHKK+1
      ISTHKK(NHKK)   = 199
      IDHKK (NHKK)   = 88888
      JMOHKK(1,NHKK) = NHKK-2
      JMOHKK(2,NHKK) = NHKK-1
      JDAHKK(1,NHKK) = 0
      JDAHKK(2,NHKK) = 0
      PHKK  (5,NHKK) = AMDCH1
      VHKK  (1,NHKK) = VHKK(1,NHKK-1)
      VHKK  (2,NHKK) = VHKK(2,NHKK-1)
      VHKK  (3,NHKK) = VHKK(3,NHKK-1)
      IF ((BETP.NE.0.0D0).AND.(BGAMP.NE.0.0D0))
     &VHKK  (4,NHKK) = VHKK(3,NHKK)/BETP-VHKK(3,NHKK-2)/BGAMP
*
*                     ends of chain 2
*
      NHKK = NHKK+1
      ISTHKK(NHKK)   = 123-IDIFTP
      IND = NHKK-4-2*IDIFTP
      IDHKK (NHKK)   = IDHKK(IND)
      JMOHKK(1,NHKK) = IND
      JMOHKK(2,NHKK) = JMOHKK(1,IND)
      JDAHKK(1,NHKK) = NHKK+2
      JDAHKK(2,NHKK) = NHKK+2
      PHKK  (1,NHKK) = PDD1(1)
      PHKK  (2,NHKK) = PDD1(2)
      PHKK  (3,NHKK) = PDD1(3)
      PHKK  (4,NHKK) = PDD1(4)
      PHKK  (5,NHKK) = 0.0D0
C               Add position of parton in hadron
       CALL QINNUC(XXPP,YYPP)
      VHKK  (1,NHKK) = VHKK(1,IND)+XXPP
      VHKK  (2,NHKK) = VHKK(2,IND)+YYPP
      VHKK  (3,NHKK) = VHKK(3,IND)
      VHKK  (4,NHKK) = VHKK(4,IND)
*
      NHKK = NHKK+1
      ISTHKK(NHKK)   = 130+IDIFTP
      JMOHKK(1,NHKK) = 2*NHKK-11-JMOHKK(1,NHKK-3)
      JMOHKK(2,NHKK) = JMOHKK(1,NHKK-6)
      JDAHKK(1,NHKK) = NHKK+1
      JDAHKK(2,NHKK) = NHKK+1
      IDHKK (NHKK)   = IDHKK(JMOHKK(1,NHKK))
      PHKK  (1,NHKK) = PDQ2(1)
      PHKK  (2,NHKK) = PDQ2(2)
      PHKK  (3,NHKK) = PDQ2(3)
      PHKK  (4,NHKK) = PDQ2(4)
      PHKK  (5,NHKK) = 0.0D0
C               Add position of parton in hadron
       CALL QINNUC(XXPP,YYPP)
      VHKK  (1,NHKK) = VHKK(1,JMOHKK(1,NHKK-6))+XXPP
      VHKK  (2,NHKK) = VHKK(2,JMOHKK(1,NHKK-6))+YYPP
      VHKK  (3,NHKK) = VHKK(3,JMOHKK(1,NHKK-6))
      VHKK  (4,NHKK) = VHKK(4,JMOHKK(1,NHKK-6))
*
*                     chain 2
*
      NHKK = NHKK+1
      ISTHKK(NHKK)   = 199
      IDHKK (NHKK)   = 88888
      JMOHKK(1,NHKK) = NHKK-2
      JMOHKK(2,NHKK) = NHKK-1
      JDAHKK(1,NHKK) = 0
      JDAHKK(2,NHKK) = 0
      PHKK  (5,NHKK) = AMDCH2
      VHKK  (1,NHKK) = VHKK(1,NHKK-1)
      VHKK  (2,NHKK) = VHKK(2,NHKK-1)
      VHKK  (3,NHKK) = VHKK(3,NHKK-1)
      IF ((BETP.NE.0.0D0).AND.(BGAMP.NE.0.0D0))
     &VHKK  (4,NHKK) = VHKK(3,NHKK)/BETP-VHKK(3,NHKK-2)/BGAMP
*
*                     diffractive nucleon
*
      NHKK = NHKK+1
      ISTHKK(NHKK)   = 199
      IDHKK (NHKK)   = 88888
      JMOHKK(1,NHKK) = NHKK-14+2*IDIFTP
      JMOHKK(2,NHKK) = NHKK-13+2*IDIFTP
      JDAHKK(1,NHKK) = 0
      JDAHKK(2,NHKK) = 0
      PHKK  (1,NHKK) = PDFQ1(1)
      PHKK  (2,NHKK) = PDFQ1(2)
      PHKK  (3,NHKK) = PDFQ1(3)
      PHKK  (4,NHKK) = PDFQ1(4)
      PHKK  (5,NHKK) = AMDCH3
      VHKK  (1,NHKK) = VHKK(1,JMOHKK(1,NHKK))
      VHKK  (2,NHKK) = VHKK(2,JMOHKK(1,NHKK))
      VHKK  (3,NHKK) = VHKK(3,JMOHKK(1,NHKK))
      VHKK  (4,NHKK) = VHKK(4,JMOHKK(1,NHKK))
C     WRITE(6,*)' Diffr. Nucleon'
C    *,PHKK(3,NHKK),PHKK(4,NHKK),PHKK(5,NHKK)
*
*---------- S. Roesler 21-10-93
*      check energy-momentum conservation
      IF (IPEV.GE.2) THEN
         PX = PDQ1(1)+PDQ2(1)+PDD1(1)+PDD2(1)+PDFQ1(1)
         PY = PDQ1(2)+PDQ2(2)+PDD1(2)+PDD2(2)+PDFQ1(2)
         PZ = PDQ1(3)+PDQ2(3)+PDD1(3)+PDD2(3)+PDFQ1(3)
         EE = ECM-(PDQ1(4)+PDQ2(4)+PDD1(4)+PDD2(4)+PDFQ1(4))
         WRITE(LOUT,*)'VAHMSD: ENERGY-MOMENTUM-CHECK (PX,PY,PZ,E)'
         WRITE(LOUT,'(5F12.6)')PX,PY,PZ,EE,ECM
      ENDIF
*
      RETURN
*
 9999 CONTINUE
      NCREJ = NCREJ+1
      IF (MOD(NCREJ,2500).EQ.0) then
        IF (IPEV.GE.1)WRITE(LOUT,9900) NCREJ
 9900 FORMAT('REJECTION IN VAHMSD ',I10)
      endif
      IIREJ = 0
      IREJ  = 1
      RETURN
      END
*
*===diffpt===============================================================*
*
      SUBROUTINE DIFFPT(   ECH1,   PCH1, XDICH1,   XCH1,
     &                     ECH2,   PCH2, XDICH2,   XCH2,
     &                     ECH3,   PCH3,  ECH3I,  KCH3I,
     &                       EE,    EES,  IIREJ)
 
**************************************************************************
* Version November 1993                         by Stefan Roesler        *
*                                                  University of Leipzig *
* This subroutine is called by VAHMSD (HMSD), selects the transverse     *
* momenta of the chains and the diffractive nucleon.                     *
* The results are stored in the common-block ABRDIF.                     *
**************************************************************************
 
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      PARAMETER (LOUT=6,LLOOK=9)
      PARAMETER (NMXHKK= 49998)
      CHARACTER*8 ANAME
      COMMON /HKKEVT/ NHKK,NEVHKK,     ISTHKK(NMXHKK),  IDHKK(NMXHKK),
     &                JMOHKK(2,NMXHKK),JDAHKK(2,NMXHKK),PHKK(5,NMXHKK),
     &                VHKK(4,NMXHKK),  WHKK(4,NMXHKK)
      COMMON /DPRIN/  IPRI,IPEV,IPPA,IPCO,INIT,IPHKK,ITOPD,IPAUPR
      COMMON /DIFFRA/ ISINGD,IDIFTP,IOUDIF,IFLAGD
      COMMON /ABRDIF/ XDQ1,XDQ2,XDDQ1,XDDQ2,
     &                IKVQ1,IKVQ2,IKD1Q1,IKD2Q1,IKD1Q2,IKD2Q2,
     &                IDIFFP,IDIFAP,
     &                AMDCH1,AMDCH2,AMDCH3,GAMDC1,GAMDC2,GAMDC3,
     &                PGXVC1,PGYVC1,PGZVC1,PGXVC2,PGYVC2,PGZVC2,
     &                PGXVC3,PGYVC3,PGZVC3,NDCH1,NDCH2,NDCH3,
     &                IKDCH1,IKDCH2,IKDCH3,
     &                PDQ1(4),PDQ2(4),PDD1(4),PDD2(4),PDFQ1(4)
      COMMON /DPAR/   ANAME(210),AM(210),GA(210),TAU(210),ICH(210),
     &                IBAR(210),K1(210),K2(210)
      DATA NCPT /0/
*
      PCH3I = SIGN(SQRT((ECH3I-AM(KCH3I))*(ECH3I+AM(KCH3I))),PCH3)
*
*-------------------- select transverse momenta - diffractive particle
*
      TTTMIN = (ECH3-ECH3I)**2-(PCH3-PCH3I)**2
   10 CONTINUE
*
      XDIFF = XDICH1+XDICH2
      BTP0  = 3.7D0
      ALPH  = 0.24D0
      SLOPE = BTP0-2.0D0*ALPH*LOG(XDIFF)
      Y     = RNDM(V)
      TTT   = -LOG(1.0D0-Y)/SLOPE
      IF (IPEV.GE.2) THEN
         WRITE(LOUT,1009) SLOPE,TTT
 1009    FORMAT('VAHMSD/DIFFPT: SLOPE,TTT ',2E10.5)
      ENDIF
*
      IF (TTT.LE.ABS(TTTMIN)) GOTO 10
      TTT = -ABS(TTT)
      IF (IPEV.GE.2) WRITE(LOUT,1000) PCH3I,TTTMIN,TTT
 1000 FORMAT('VAHMSD/DIFFPT: PCH3I,TTTMIN,TTT ',3F10.5)
      PCH3F = ABS(TTT-(ECH3-ECH3I)**2+PCH3**2+PCH3I**2)/(2*PCH3I)
      IF ((PCH3**2).LE.(PCH3F**2)) THEN
         NCPT = NCPT+1
         IF(MOD(NCPT,5000).EQ.0) WRITE(LOUT,1001) NCPT
 1001    FORMAT('VAHMSD/DIFFPT: INEFFICIENT PT-SELECTION 1, NCPT=',I8)
         GOTO 10
      ENDIF
      P3XYF = SQRT(PCH3**2-PCH3F**2)
      CALL DSFECF(SFE,CFE)
      PXCH3F = P3XYF*CFE
      PYCH3F = P3XYF*SFE
*
*-------------------- select transverse momenta for partons of chain 1
*
      IF (NDCH1.EQ.-99) THEN
         EAQ2   = 0.0D0
         PTXVA2 = 0.0D0
         PTYVA2 = 0.0D0
         PLAQ2  = 0.0D0
         EQ1    = 0.0D0
         PTXDQ1 = 0.0D0
         PTYDQ1 = 0.0D0
         PLQ1   = 0.0D0
         PXCH1F = 0.0D0
         PYCH1F = 0.0D0
         PLCH1F = 0.0D0
         GOTO 11
      ENDIF
      PYCH1F = -ABS(PCH1/PCH3)*PYCH3F
      PXCH1F = -ABS(PYCH1F/PYCH3F)*PXCH3F
      TEMP   = PXCH1F**2+PYCH1F**2
      IF ((PCH1**2).LT.TEMP) THEN
         NCPT = NCPT+1
         IF(MOD(NCPT,5000).EQ.0) WRITE(LOUT,1002) NCPT
 1002    FORMAT('VAHMSD/DIFFPT: INEFFICIENT PT-SELECTION 2, NCPT=',I8)
         GOTO 10
      ENDIF
      PLCH1F = SIGN(SQRT(PCH1**2-TEMP),PCH1)
      EAQ2   = EES*XDICH1
      TEMP   = ABS(EAQ2/PCH1)
      PTXVA2 = -PXCH1F*TEMP
      PTYVA2 = -PYCH1F*TEMP
      PLAQ2  = -PLCH1F*TEMP
      EQ1    = EE*XCH1
      TEMP   = ABS(EQ1/PCH1)
      PTXDQ1 = PXCH1F*TEMP
      PTYDQ1 = PYCH1F*TEMP
      PLQ1   = PLCH1F*TEMP
*
*-------------------- select transverse momenta for partons of chain 2
*
   11 CONTINUE
      IF (NDCH2.EQ.-99) THEN
         EQ2    = 0.0D0
         PTXDQ2 = 0.0D0
         PTYDQ2 = 0.0D0
         PLQ2   = 0.0D0
         EAQ1   = 0.0D0
         PTXVA1 = 0.0D0
         PTYVA1 = 0.0D0
         PLAQ1  = 0.0D0
         PXCH2F = 0.0D0
         PYCH2F = 0.0D0
         PLCH2F = 0.0D0
         GOTO 12
      ENDIF
      PYCH2F = -ABS(PCH2/PCH3)*PYCH3F
      PXCH2F = -ABS(PYCH2F/PYCH3F)*PXCH3F
      TEMP   = PXCH2F**2+PYCH2F**2
      IF ((PCH2**2).LT.TEMP) THEN
         NCPT = NCPT+1
         IF(MOD(NCPT,5000).EQ.0) WRITE(LOUT,1003) NCPT
 1003    FORMAT('VAHMSD/DIFFPT: INEFFICIENT PT-SELECTION 3, NCPT=',I8)
         GOTO 10
      ENDIF
      PLCH2F = SIGN(SQRT(PCH2**2-TEMP),PCH2)
      EQ2    = EES*XDICH2
      TEMP   = ABS(EQ2/PCH2)
      PTXDQ2 = -PXCH2F*TEMP
      PTYDQ2 = -PYCH2F*TEMP
      PLQ2   = -PLCH2F*TEMP
      EAQ1   = EE*XCH2
      TEMP   = ABS(EAQ1/PCH2)
      PTXVA1 = PXCH2F*TEMP
      PTYVA1 = PYCH2F*TEMP
      PLAQ1  = PLCH2F*TEMP
*
   12 CONTINUE
      PTXCH3 = PXCH3F
      PTYCH3 = PYCH3F
      PCH3   = PCH3F
*---------- S. Roesler 11/4/93
*           calculate diffractive x-value
      IF (IPEV.GE.2) THEN
         TEMPX = PTXVA2+PTXDQ1+PTXDQ2+PTXVA1
         TEMPY = PTYVA2+PTYDQ1+PTYDQ2+PTYVA1
         TEMPZ = PLAQ2+PLQ1+PLQ2+PLAQ1
         TEMPE = EAQ1+EAQ2+EQ1+EQ2
	 TEMPM = SQRT(TEMPE**2-TEMPX**2-TEMPY**2-TEMPZ**2)
         TEMPP = TEMPM**2/((EES+EE)**2)
	 WRITE(*,*)'diffractive x-value before energy/momentum corr.',
     &              TEMPP
      ENDIF
*
*---------- S. Roesler 10/26/93
*
*           introduce off-shell partons in order to ensure
*           energy-momentum conservation
*
      DIFFX = PXCH3F+PTXVA2+PTXDQ1+PTXDQ2+PTXVA1
      DIFFY = PYCH3F+PTYVA2+PTYDQ1+PTYDQ2+PTYVA1
      DIFFZ = PCH3F+PLAQ2+PLQ1+PLQ2+PLAQ1
      IF (IPEV.GE.2) THEN
         WRITE(LOUT,1011) DIFFX,DIFFY,DIFFZ
 1011    FORMAT('VAHMSD/DIFFPT: DIFFX,DIFFY,DIFFZ ',3E15.5)
      ENDIF
*
      IF ((NDCH1.EQ.-99).OR.(NDCH1.EQ.1).OR.(NDCH1.EQ.-1)) THEN
*
         PTXDQ2 = PTXDQ2-DIFFX/2.0D0
         PTXVA1 = PTXVA1-DIFFX/2.0D0
*
         PTYDQ2 = PTYDQ2-DIFFY/2.0D0
         PTYVA1 = PTYVA1-DIFFY/2.0D0
*
         PLQ2   = PLQ2  -DIFFZ/2.0D0
         PLAQ1  = PLAQ1 -DIFFZ/2.0D0
*
      ELSEIF ((NDCH2.EQ.-99).OR.(NDCH2.EQ.1).OR.(NDCH2.EQ.-1)) THEN
*
         PTXVA2 = PTXVA2-DIFFX/2.0D0
         PTXDQ1 = PTXDQ1-DIFFX/2.0D0
*
         PTYVA2 = PTYVA2-DIFFY/2.0D0
         PTYDQ1 = PTYDQ1-DIFFY/2.0D0
*
         PLAQ2  = PLAQ2 -DIFFZ/2.0D0
         PLQ1   = PLQ1  -DIFFZ/2.0D0
*
      ELSE
*
         PTXVA2 = PTXVA2-DIFFX/4.0D0
         PTXDQ1 = PTXDQ1-DIFFX/4.0D0
         PTXDQ2 = PTXDQ2-DIFFX/4.0D0
         PTXVA1 = PTXVA1-DIFFX/4.0D0
*
         PTYVA2 = PTYVA2-DIFFY/4.0D0
         PTYDQ1 = PTYDQ1-DIFFY/4.0D0
         PTYDQ2 = PTYDQ2-DIFFY/4.0D0
         PTYVA1 = PTYVA1-DIFFY/4.0D0
*
         PLAQ2  = PLAQ2 -DIFFZ/4.0D0
         PLQ1   = PLQ1  -DIFFZ/4.0D0
         PLQ2   = PLQ2  -DIFFZ/4.0D0
         PLAQ1  = PLAQ1 -DIFFZ/4.0D0
*
      ENDIF
*---------- S. Roesler 11/4/93
*           calculate diffractive x-value
      IF (IPEV.GE.2) THEN
         TEMPX = PTXVA2+PTXDQ1+PTXDQ2+PTXVA1
         TEMPY = PTYVA2+PTYDQ1+PTYDQ2+PTYVA1
         TEMPZ = PLAQ2+PLQ1+PLQ2+PLAQ1
         TEMPE = EAQ1+EAQ2+EQ1+EQ2
	 TEMPM = SQRT(TEMPE**2-TEMPX**2-TEMPY**2-TEMPZ**2)
         TEMPP = TEMPM**2/((EES+EE)**2)
	 WRITE(*,*)'diffractive x-value after energy/momentum corr.',
     &              TEMPP
      ENDIF
*
*           recalculate chain masses...
*
      AMDCH1 = SQRT(ABS((EAQ2+EQ1)**2-(PTXVA2+PTXDQ1)**2
     &         -(PTYVA2+PTYDQ1)**2-(PLAQ2+PLQ1)**2)+1.0D-8)
      AMDCH2 = SQRT(ABS((EQ2+EAQ1)**2-(PTXDQ2+PTXVA1)**2
     &         -(PTYDQ2+PTYVA1)**2-(PLQ2+PLAQ1)**2)+1.0D-8)
*
      IF (IPEV.GE.2) THEN
         WRITE(LOUT,1012) AMDCH1,AMDCH2
 1012    FORMAT('VAHMSD/DIFFPT: AMDCH1,AMDCH2 ',2E10.5)
      ENDIF
*
*           ...and the Lorentz-parameter gamma
*
      GAMDC1 = (EAQ2+EQ1)/AMDCH1
      GAMDC2 = (EQ2+EAQ1)/AMDCH2
      IF (IPEV.GE.2) THEN
         WRITE(LOUT,1013) GAMDC1,GAMDC2
 1013    FORMAT('VAHMSD/DIFFPT: GAMDC1,GAMDC2 ',2E10.5)
      ENDIF
*
*-------------------- store results in common block /ABRDIF/
*
      PDQ1(1)  = PTXDQ1
      PDQ1(2)  = PTYDQ1
      PDQ1(3)  = PLQ1
      PDQ1(4)  = EQ1
      PDD1(1)  = PTXVA1
      PDD1(2)  = PTYVA1
      PDD1(3)  = PLAQ1
      PDD1(4)  = EAQ1
      PDFQ1(1) = PTXCH3
      PDFQ1(2) = PTYCH3
      PDFQ1(3) = PCH3
      PDFQ1(4) = ECH3
      PDQ2(1)  = PTXDQ2
      PDQ2(2)  = PTYDQ2
      PDQ2(3)  = PLQ2
      PDQ2(4)  = EQ2
      PDD2(1)  = PTXVA2
      PDD2(2)  = PTYVA2
      PDD2(3)  = PLAQ2
      PDD2(4)  = EAQ2
      IF (IPEV.GE.2) THEN
         WRITE(LOUT,1004)
 1004    FORMAT('VAHMSD/DIFFPT: PDQ1,PDD1,PDQ2,PDD2,PDFQ1 ')
         WRITE(LOUT,1005)
     &      (PDQ1(J),PDD1(J),PDQ2(J),PDD2(J),PDFQ1(J),J=1,4)
 1005    FORMAT(12X,5F10.5)
      ENDIF
      PGXVC1 = (PTXDQ1+PTXVA2)/AMDCH1
      PGYVC1 = (PTYDQ1+PTYVA2)/AMDCH1
      PGZVC1 = (PLQ1+PLAQ2)/AMDCH1
      PGXVC2 = (PTXVA1+PTXDQ2)/AMDCH2
      PGYVC2 = (PTYVA1+PTYDQ2)/AMDCH2
      PGZVC2 = (PLAQ1+PLQ2)/AMDCH2
      PGXVC3 = PTXCH3/AMDCH3
      PGYVC3 = PTYCH3/AMDCH3
      PGZVC3 = PCH3/AMDCH3
*
      PXCH1F = PTXDQ1+PTXVA2
      PYCH1F = PTYDQ1+PTYVA2
      PLCH1F = PLQ1+PLAQ2
      PXCH2F = PTXVA1+PTXDQ2
      PYCH2F = PTYVA1+PTYDQ2
      PLCH2F = PLAQ1+PLQ2
*
      IF (IPEV.GE.2) THEN
         WRITE(LOUT,1006) PGXVC1,PGYVC1,PGZVC1
 1006    FORMAT('VAHMSD/DIFFPT: PGXVC1,PGYVC1,PGZVC1 ',3F10.5)
         WRITE(LOUT,1007) PGXVC2,PGYVC2,PGZVC2
 1007    FORMAT('VAHMSD/DIFFPT: PGXVC2,PGYVC2,PGZVC2 ',3F10.5)
         WRITE(LOUT,1008) PGXVC3,PGYVC3,PGZVC3
 1008    FORMAT('VAHMSD/DIFFPT: PGXVC3,PGYVC3,PGZVC3 ',3F10.5)
      ENDIF
      IF ((NDCH1.EQ.-99).AND.(NDCH2.EQ.-99)) THEN
         WRITE(LOUT,*) 'REJECT IN DIFFPT: NO CHAINS CREATED'
         IIREJ = 1
         RETURN
      ENDIF
*
*-------------------- store results in common block /HKKEVT/
*
      PHKK(1,NHKK+9) = PXCH1F
      PHKK(2,NHKK+9) = PYCH1F
      PHKK(3,NHKK+9) = PLCH1F
      PHKK(4,NHKK+9) = ECH1
*
      PHKK(1,NHKK+12) = PXCH2F
      PHKK(2,NHKK+12) = PYCH2F
      PHKK(3,NHKK+12) = PLCH2F
      PHKK(4,NHKK+12) = ECH2
*
      RETURN
      END
*
*===diffch================================================================
*
      SUBROUTINE DIFFCH ( XSEA,  IFSEA,   XPAR, IFPARA, IFPARB,
     &                   XSEA2, IFSEA2, XPAR12, XPAR22,     EE,
     &                      RM,    ECH,    PCH,  GAMMA,   BETA,
     &                    NDCH,    ICH,    EES,   NUNO,  IIREJ,   IOPT)
 
**************************************************************************
* Version November 1993                         by Stefan Roesler        *
*                                                  University of Leipzig *
* This subroutine is called by VAHMSD (HMSD) and calculates the kine-    *
* matical parameters of chain IOPT from sampled x-values and flavors     *
* in CMS.                                                                *
**************************************************************************
 
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      PARAMETER (LOUT=6,LLOOK=9)
      CHARACTER*8 ANAME
      COMMON /DPRIN/  IPRI,IPEV,IPPA,IPCO,INIT,IPHKK,ITOPD,IPAUPR
      COMMON /DIFFRA/ ISINGD,IDIFTP,IOUDIF,IFLAGD
      COMMON /DPAR/   ANAME(210),AM(210),GA(210),TAU(210),IICH(210),
     &                IBAR(210),K1(210),K2(210)
      COMMON/DINPDA/IMPS(6,6),IMVE(6,6),IB08(6,21),IB10(6,21),IA08(6,21)
     &,IA10(6,21),A1,B1,B2,B3,LT,LE,BET,AS,B8,AME,DIQ,ISU
      DATA NCNOTH,NCWD /0,0/
*
      GOTO (1,2,3) IOPT
*
*-------------------- kinematical parameters of a q-aq (in any order) chain
*                     XSEA - XPAR, IFSEA - IFPAR
*
    1 CONTINUE
      IIREJ = 0
      IFQ   = IFPARA
      IFAQ  = IABS(IFSEA)
      IF (IFQ.LT.0) THEN
         IFQ  = IFSEA
         IFAQ = IABS(IFPARA)
      ENDIF
      IPS  = IMPS(IFAQ,IFQ)
      IV   = IMVE(IFAQ,IFQ)
      RMPS = AM(IPS)
      RMV  = AM(IV)
      RMBB = RMV+3.0D-1
      NDCH = 0
*
      IF ((XSEA.LE.0.0D0).OR.(XPAR.LE.0.0D0)) THEN
         IF (IPEV.GE.1)WRITE(LOUT,*) 
     *      'REJECTION IN DIFFCH: 1, XSEA,XPAR ',XSEA,XPAR
         IIREJ=1
         RETURN
      ENDIF
      RM = 2.0D0*SQRT(EES*XSEA*EE*XPAR)
      IF (IPEV.GE.2) THEN
         WRITE(LOUT,1000) 'XSEA, XSEA2, XPAR, XPAR12, RM, EE, EES'
         WRITE(LOUT,1001)  XSEA, XSEA2, XPAR, XPAR12, RM, EE, EES
      ENDIF
*
      IF (RM.LT.RMPS) THEN
*                                 produce nothing
         NDCH   = -99
         XSEA2  = XSEA2 +XSEA
         XPAR12 = XPAR12+XPAR
         IFSEA2 = IFPARA
         XSEA   = 0.0D0
         XPAR   = 0.0D0
         RM     = 1.0D-4
         ECH    = 0.0D0
         PCH    = 0.0D0
         GAMMA  = 1.0D0
         BETA   = 0.0D0
         NCNOTH = NCNOTH+1
         IF (MOD(NCNOTH,5000).EQ.0) then
           IF (IPEV.GE.1) WRITE(LOUT,1002) NCNOTH
 1002    FORMAT('VAHMSD/DIFFCH: PRODUCE NOTHING 1, NCNOTH=',I8)
         endif
         RETURN
*
      ELSE IF (RM.LT.RMV) THEN
*                                 produce RMPS
         RM     = RMPS
         NDCH   = -1
         ICH    = IPS
         XSQ    = RM/(2.0D0*SQRT(EE*EES))
         XSEAOL = XSEA
         XSEA   = XSQ**2/XPAR
         XPAR22 = XPAR22+XSEAOL-XSEA
*
      ELSE IF (RM.LT.RMBB) THEN
*                                 produce RMV
         RM     = RMV
         NDCH   = 1
         ICH    = IV
         XSQ    = RM/(2.0D0*SQRT(EE*EES))
         XSEAOL = XSEA
         XSEA   = XSQ**2/XPAR
         XPAR22 = XPAR22+XSEAOL-XSEA
      ENDIF
*
      IF (IDIFTP.EQ.1) THEN
         PCH = EES*XSEA-EE*XPAR
         IF (PCH.GE.0.0D0) THEN
            NCWD  = NCWD+1
            IF (MOD(NCWD,500).EQ.0)then
              IF (IPEV.GE.1)WRITE(LOUT,1003) NCWD
 1003       FORMAT('VAHMSD/DIFFCH: WRONG SIGN OF PCH (1), NCWD=',I8)
            endif
            IIREJ = 1
         ENDIF
      ELSE IF (IDIFTP.EQ.2) THEN
         PCH = EE*XPAR-EES*XSEA
         IF (PCH.LE.0.0D0) THEN
            NCWD  = NCWD+1
            IF (MOD(NCWD,500).EQ.0) then
              IF (IPEV.GE.1)WRITE(LOUT,1004) NCWD
 1004       FORMAT('VAHMSD/DIFFCH: WRONG SIGN OF PCH (2), NCWD=',I8)
            endif
            IIREJ = 1
         ENDIF
      ELSE
         WRITE(LOUT,*) 'ERROR IN VAHMSD/DIFFCH, IDIFTP=', IDIFTP
      ENDIF
      IF (IPEV.GE.2) THEN
         WRITE(LOUT,1000) 'EES,XSEA,EE,XPAR'
         WRITE(LOUT,1001)  EES,XSEA,EE,XPAR
      ENDIF
      ECH   = EES*XSEA+EE*XPAR
      GAMMA = ECH/RM
      BETA  = PCH/RM
      IF (IPEV.GE.2) THEN
         WRITE(LOUT,1000) 'RM,ECH,PCH,NDCH'
         WRITE(LOUT,1001)  RM,ECH,PCH
         WRITE(LOUT,'(I4)') NDCH
      ENDIF
 1000 FORMAT('VAHMSD/DIFFCH-CHAIN Q-AQ',A34)
 1001 FORMAT(10F10.5)
      RETURN
*
*-------------------- kinematical parameters of a q-qq or aq-aqaq (in any
*                     order) chain
*                     XSEA - XPAR, IFSEA - IFPARA/IFPARB
*
    2 CONTINUE
      IIREJ = 0
      CALL DBKLAS(IFSEA, IFPARA, IFPARB, I8, I10)
      RM8   = AM( I8)
      RM10  = AM(I10)
      RMBB  = RM10+3.0D-1
      NDCH  = 0
*
      IF ((XSEA.LE.0.0D0).OR.(XPAR.LE.0.0D0)) THEN
         IIREJ=1
         WRITE(LOUT,*) 'REJECTION IN DIFFCH: 3, XSEA,XPAR ',XSEA,XPAR
         RETURN
      ENDIF
      RM = 2.0D0*SQRT(EES*XSEA*EE*XPAR)
      IF (IPEV.GE.2) THEN
         WRITE(LOUT,2000) 'XSEA, XSEA2, XPAR, XPAR12, RM, EE, EES'
         WRITE(LOUT,2001)  XSEA, XSEA2, XPAR, XPAR12, RM, EE, EES
      ENDIF
*
      IF (RM.LT.RM10) THEN
*                                         reject
         IIREJ  = 1
         NCNOTH = NCNOTH+1
         IF (MOD(NCNOTH,20).EQ.0) then
           IF (IPEV.GE.1)WRITE(LOUT,2002) NCNOTH
 2002      FORMAT('VAHMSD/DIFFCH: PRODUCE NOTHING 2, NCNOTH=',I8)
         endif
         RETURN
      ELSE IF (RM.LT.RMBB) THEN
*                                         produce RM10
         NDCH   = 1
         RM     = RM10
         ICH    = I10
         XSQ    = RM/(2.0D0*SQRT(EE*EES))
         XSEAOL = XSEA
         XSEA   = XSQ**2/XPAR
         XPAR22 = XPAR22+XSEAOL-XSEA
      ENDIF
*
      IF (IDIFTP.EQ.1) THEN
         PCH = EES*XSEA-EE*XPAR
         IF (PCH.GE.0.0D0) THEN
            NCWD  = NCWD+1
            IF (MOD(NCWD,500).EQ.0)then
            IF (IPEV.GE.1) WRITE(LOUT,2003) NCWD
 2003       FORMAT('VAHMSD/DIFFCH: WRONG SIGN OF PCH (3), NCWD=',I8)
            endif
            IIREJ = 1
         ENDIF
      ELSE IF (IDIFTP.EQ.2) THEN
         PCH = EE*XPAR-EES*XSEA
         IF (PCH.LE.0.0D0) THEN
            NCWD  = NCWD+1
            IF (MOD(NCWD,500).EQ.0) then
              IF (IPEV.GE.1) WRITE(LOUT,2004) NCWD
 2004       FORMAT('VAHMSD/DIFFCH: WRONG SIGN OF PCH (4), NCWD=',I8)
            endif
            IIREJ = 1
         ENDIF
      ELSE
         WRITE(LOUT,*) 'ERROR IN VAHMSD/DIFFCH, IDIFTP=', IDIFTP
      ENDIF
      ECH   = EES*XSEA+EE*XPAR
      GAMMA = ECH/RM
      BETA  = PCH/RM
      IF (IPEV.GE.2) THEN
         WRITE(LOUT,2000) 'RM,ECH,PCH,NDCH'
         WRITE(LOUT,2001)  RM,ECH,PCH
         WRITE(LOUT,'(I4)') NDCH
      ENDIF
 2000 FORMAT('VAHMSD/DIFFCH-CHAIN Q-QQ',A34)
 2001 FORMAT(10F10.5)
      RETURN
*
*-------------------- kinematical parameters of a baryon/meson
*
    3 CONTINUE
      IIREJ = 0
      IF (IFPARB.EQ.99) THEN
         IF (IFSEA.LT.0) THEN
            IFAQ = IABS(IFSEA)
            IFQ  = IFPARA
         ELSE
            IFAQ = IABS(IFPARA)
            IFQ  = IFSEA
         ENDIF
         IM = IMPS(IFAQ,IFQ)
      ELSE
         CALL DBKLAS(IFSEA, IFPARA, IFPARB, IM, IDUM)
      ENDIF
      RM   = AM(IM)
      NDCH = -1
      IF ((XSEA.LE.0.0D0).OR.(XPAR.LE.0.0D0)) THEN
         IIREJ=1
         WRITE(LOUT,*) 'REJECTION IN DIFFCH: 5, XSEA,XPAR ',XSEA,XPAR
         RETURN
      ENDIF
      IF (IPEV.GE.2) THEN
         WRITE(LOUT,3000) 'XSEA, XPAR, RM'
         WRITE(LOUT,3001)  XSEA, XPAR, RM
      ENDIF
      ECH = EE*(XSEA+XPAR)
      IF (IDIFTP.EQ.1) THEN
         PCH = SQRT((ECH-RM)*(ECH+RM))
      ELSE IF (IDIFTP.EQ.2) THEN
         PCH = -SQRT((ECH-RM)*(ECH+RM))
      ELSE
         WRITE(LOUT,*) 'ERROR IN VAHMSD/DIFFCH, IDIFTP=', IDIFTP
      ENDIF
      GAMMA = ECH/RM
      BETA  = PCH/RM
      IF (IPEV.GE.2) THEN
         WRITE(LOUT,3000) 'ECH, PCH, GAMMA, BETA'
         WRITE(LOUT,3001)  ECH, PCH, GAMMA, BETA
      ENDIF
 3000 FORMAT('VAHMSD/DIFFCH-BARYON/MESON ',A27)
 3001 FORMAT(10F10.5)
      RETURN
      END
*
*===valmsd===============================================================*
*
      SUBROUTINE VALMSD(ITAPOI,ECM,KPROJ,KTARG,IREJ)
 
**************************************************************************
* Version November 1993                         by Stefan Roesler        *
*                                                  University of Leipzig *
* This subroutine selects flavors and 4-momenta of partons in low-mass   *
* single diffractive chains.                                             *
**************************************************************************
 
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      PARAMETER (LOUT=6,LLOOK=9)
      PARAMETER (NMXHKK= 49998)
      CHARACTER*8 ANAME
      COMMON /HKKEVT/ NHKK,NEVHKK,     ISTHKK(NMXHKK),  IDHKK(NMXHKK),
     &                JMOHKK(2,NMXHKK),JDAHKK(2,NMXHKK),PHKK(5,NMXHKK),
     &                VHKK(4,NMXHKK),  WHKK(4,NMXHKK)
      COMMON /DPRIN/  IPRI,IPEV,IPPA,IPCO,INIT,IPHKK,ITOPD,IPAUPR
      COMMON /DIFFRA/ ISINGD,IDIFTP,IOUDIF,IFLAGD
      COMMON /ABRDIF/ XDQ1,XDQ2,XDDQ1,XDDQ2,
     &                IKVQ1,IKVQ2,IKD1Q1,IKD2Q1,IKD1Q2,IKD2Q2,
     &                IDIFFP,IDIFAP,
     &                AMDCH1,AMDCH2,AMDCH3,GAMDC1,GAMDC2,GAMDC3,
     &                PGXVC1,PGYVC1,PGZVC1,PGXVC2,PGYVC2,PGZVC2,
     &                PGXVC3,PGYVC3,PGZVC3,NDCH1,NDCH2,NDCH3,
     &                IKDCH1,IKDCH2,IKDCH3,
     &                PDQ1(4),PDQ2(4),PDD1(4),PDD2(4),PDFQ1(4)
      COMMON /DPAR/   ANAME(210),AM(210),GA(210),TAU(210),ICH(210),
     &                IBAR(210),K1(210),K2(210)
      COMMON/DINPDA/IMPS(6,6),IMVE(6,6),IB08(6,21),IB10(6,21),IA08(6,21)
     &,IA10(6,21),A1,B1,B2,B3,LT,LE,BET,AS,B8,AME,DIQ,ISU
      COMMON /TRAFOP/ GAMP,BGAMP,BETP
      COMMON /ENERIN/ EPROJ,ETARG
      COMMON /SDFLAG/ ISD
      COMMON /OUTLEV/IOUTPO,IOUTPA,IOUXEV,IOUCOL
      COMMON /XDIDID/XDIDI
*
      DIMENSION MQUARK(3,30),IHKKQ(-6:6),IHKKQQ(-3:3,-3:3),
     &          IDX(-4:4)
      DATA IDX   /-4,-3,-1,-2,0,2,1,3,4/
      DATA IHKKQ /-6,-5,-4,-3,-1,-2,0,2,1,3,4,5,6/
      DATA IHKKQQ/-3301,-3103,-3203,0,   0,0,0,
     &            -3103,-1103,-2103,0,   0,   0,   0,
     &            -3203,-2103,-2203,0,   0,   0,   0,
     &                0,    0,    0,0,   0,   0,   0,
     &                0,    0,    0,0,2203,2103,3202,
     &                0,    0,    0,0,2103,1103,3103,
     &                0,    0,    0,0,3203,3103,3303/
*
*----------------------------------- quark content of hadrons:
*                                     1, 2, 3, 4  -   u, d, s, c
*                                    -1,-2,-3,-4  -  au,ad,as,ac
*
      DATA MQUARK/
     &   1,1,2,    -1,-1,-2,       0,0,0,       0,0,0,       0,0,0,
     &   0,0,0,       0,0,0,       1,2,2,    -1,-2,-2,       0,0,0,
     &   0,0,0,       0,0,0,      1,-2,0,      2,-1,0,      1,-3,0,
     &  3,-1,0,       1,2,3,    -1,-2,-3,       0,0,0,       2,2,3,
     &   1,1,3,       1,2,3,      1,-1,0,      2,-3,0,      3,-2,0,
     &  2,-2,0,      3,-3,0,       0,0,0,       0,0,0,       0,0,0/
      DATA UNON/2.0/
      DATA NCREJ, NCPT /0, 0/
*
      ISD   = 2
      IREJ  = 0
      IIREJ = 0
      IBPROJ = IBAR(KPROJ)
      IBTARG = IBAR(KTARG)
      EPROJ  = (AM(KPROJ)**2-AM(KTARG)**2+ECM**2)/(2.0D0*ECM)
      ETARG  = (AM(KTARG)**2-AM(KPROJ)**2+ECM**2)/(2.0D0*ECM)
      IF(IPEV.GE.2) WRITE(LOUT,1014)EPROJ,ETARG
 1014 FORMAT('VALMSD: EPROJ,ETARG',2F10.5)
      IF (IBTARG.LE.0) THEN
         WRITE(LOUT,1001) IBTARG
 1001    FORMAT('VALMSD: NO LMSD FOR TARGET WITH BARYON-CHARGE',I4)
         IIREJ = 1
         GOTO 9999
      ENDIF
      IQP1 = MQUARK(1,KPROJ)
      IQP2 = MQUARK(2,KPROJ)
      IQP3 = MQUARK(3,KPROJ)
      IQT1 = MQUARK(1,KTARG)
      IQT2 = MQUARK(2,KTARG)
      IQT3 = MQUARK(3,KTARG)
      IF(IPEV.GE.2) WRITE(LOUT,1002)
     &                IBPROJ,IBTARG,IQP1,IQP2,IQP3,IQT1,IQT2,IQT3
 1002 FORMAT('VALMSD: IBPROJ,IBTARG,IQP1,IQP2,IQP3,IQT1,IQT2,IQT3 ',8I4)
*
      IF (IBPROJ.NE.0) THEN
*
*-------------------- q-qq (aq-aqaq) - flavors of projectile (baryon)
*
         ISAM = 1.0D0+2.999D0*RNDM(V)
         GOTO (10,11,12) ISAM
   10    CONTINUE
         IQP    = IQP1
         IDIQP1 = IQP2
         IDIQP2 = IQP3
         GOTO 13
   11    CONTINUE
         IQP    = IQP2
         IDIQP1 = IQP1
         IDIQP2 = IQP3
         GOTO 13
   12    CONTINUE
         IQP    = IQP3
         IDIQP1 = IQP1
         IDIQP2 = IQP2
   13    CONTINUE
*
      ELSE IF (IBPROJ.EQ.0) THEN
*
*-------------------- q-aq - flavors of projectile (meson)
*
         ISAM = 1.0D0+1.999D0*RNDM(V)
         GOTO (14,15) ISAM
   14    CONTINUE
         IQP    = IQP1
         IDIQP1 = IQP2
         GOTO 16
   15    CONTINUE
         IQP    = IQP2
         IDIQP1 = IQP1
   16    CONTINUE
         IDIQP2 = 0
*
      ENDIF
*
*-------------------- q-qq - flavors of target (baryon)
*
      ISAM = 1.0D0+2.999D0*RNDM(V)
      GOTO (17,18,19) ISAM
   17 CONTINUE
      IQT    = IQT1
      IDIQT1 = IQT2
      IDIQT2 = IQT3
      GOTO 20
   18 CONTINUE
      IQT    = IQT2
      IDIQT1 = IQT1
      IDIQT2 = IQT3
      GOTO 20
   19 CONTINUE
      IQT    = IQT3
      IDIQT1 = IQT1
      IDIQT2 = IQT2
   20 CONTINUE
*
      IKVQ1  = IQP
      IKD1Q1 = IDIQP1
      IKD2Q1 = IDIQP2
*
      IKVQ2  = IQT
      IKD1Q2 = IDIQT1
      IKD2Q2 = IDIQT2
*
      IF (IPEV.GE.2) WRITE(LOUT,1003)
     &                 IKVQ1,IKD1Q1,IKD2Q1,IKVQ2,IKD1Q2,IKD2Q2
 1003 FORMAT('VALMSD: IKVQ1,IKD1Q1,IKD2Q1,IKVQ2,IKD1Q2,IKD2Q2 ',6I4)
*
*-------------------- IDIFTP = 1  target     (backward) hadron  excited
*                     IDIFTP = 2  projectile (forward)  hadron  excited
*
      IDIFTP = 1.0D0+1.999D0*RNDM(V)
*-------------------- S.Roesler 5/26/93
      IF ((ISINGD.EQ.3).OR.(ISINGD.EQ.7)) IDIFTP = 1
      IF ((ISINGD.EQ.4).OR.(ISINGD.EQ.8)) IDIFTP = 2
*
      IF (IPEV.GE.2) WRITE(LOUT,1004) IDIFTP
 1004 FORMAT('VALMSD: IDIFTP ',I4)
      IF ((IDIFTP.NE.1).AND.(IDIFTP.NE.2)) THEN
         IF (IPEV.GE.2) WRITE(LOUT,'(A19)') 'VALMSD-ERROR: IDIFTP'
         GOTO 9999
      ENDIF
*
*-------------------- diffractive mass
*
31    CONTINUE
      AMO = 1.5D0
      R   = RNDM(V)
      IF ((IBPROJ.EQ.0).AND.(IDIFTP.EQ.1))
     &               AMO = 1.5D0*R+2.83D0*(1.0D0-R)
      IF ((IBPROJ.EQ.0).AND.(IDIFTP.EQ.2)) AMO = 1.0D0
      SAM = 1.0D0
      IF (ECM.LE.300.0D0) SAM = 1.0D0-EXP(-((ECM/200.0D0)**4))
      R   = RNDM(V)*SAM
      AMAX= (1.0D0-SAM)*SQRT(0.1D0*ECM**2)+SAM*SQRT(400.0D0)
      AMU = R*SQRT(100.0D0)+(1.0D0-R)*AMAX
      IF (IBPROJ.EQ.0) THEN
C----------------- change mass-cuts
C        AMAX= (1.0D0-SAM)*SQRT(0.25D0*ECM**2)+SAM*SQRT(400.0D0)
         AMAX= (1.0D0-SAM)*SQRT(0.15D0*ECM**2)+SAM*SQRT(400.0D0)
         AMU = R*SQRT(100.0D0)+(1.0D0-R)*AMAX
      ENDIF
C---------------------------------------------------------------
C
C                                           j.r. test 2/94
C
C---------------------------------------------------------------
      AMU=2.D0*AMU
C---------------------------------------------------------------
      R   = RNDM(V)
      IF (ECM.LE.50.0D0) THEN
         AMDIFF = AMO*(AMU/AMO)**R
      ELSE
         A = 0.7D0
         IF (ECM.LE.300.0D0) A = 0.7D0*(1.0D0-EXP(-((ECM/100.0D0)**2)))
         AMDIFF = 1.0D0/((R/(AMU**A)+(1.0D0-R)/(AMO**A))
     &         **(1.0D0/A))
      ENDIF
      IF(AMDIFF.GT.0.5D0*ECM)GO TO 31
      IF (IOUXEV.GE.2) WRITE(LOUT,1005) AMDIFF
 1005 FORMAT('VALMSD: AMDIFF',E10.5)
       XDIDI=AMDIFF**2/ECM**2
      IF (IOUXEV.GE.2) WRITE(LOUT,*)'LM AMDIFF,XDIDI ',AMDIFF,XDIDI
*
*-------------------- kinematical parameters of
*                     diffractive projectile (IDIFTP = 1)
*                     or diffractive target  (IDIFTP = 2)
*
      IF (IDIFTP.EQ.1) THEN
         AMDCH3 = AM(KPROJ)
      ELSE IF (IDIFTP.EQ.2) THEN
         AMDCH3 = AM(KTARG)
      ENDIF
      ECH3 = (ECM**2+AMDCH3**2-AMDIFF**2)/(2.0D0*ECM)
      IF (ECH3.LE.AMDCH3) THEN
         NCMERR = NCMERR+1
         IF (MOD(NCMERR,2200).EQ.0)
     &      WRITE(LOUT,*) 'LMSD: INEFFICIENT SELECTION OF AMDIFF(1),
     &                        NCMERR = ',NCMERR
         GOTO 31
      ENDIF
*
      PCH3 = SQRT(ABS(ECH3-AMDCH3))*SQRT(ECH3+AMDCH3)
      IF (IDIFTP.EQ.2) PCH3 = -PCH3
      NDCH3  = -1
      GAMDC3 = ECH3/AMDCH3
      PGVC3  = PCH3/AMDCH3
      IF (IOUXEV.GE.2) WRITE(LOUT,1006) AMDCH3,ECH3,PCH3,GAMDC3,PGVC3
 1006 FORMAT('VALMSD: AMDCH3,ECH3,PCH3,GAMDC3,PGVC3',5E15.5)
*
   30 CONTINUE
      B33   = 8.0D0
      ES    = -2.0D0/(B33**2)*LOG(RNDM(V)*RNDM(V))
      HPS   = SQRT(ES*ES+2.0D0*ES*0.94D0)
      CALL DSFECF(SFE,CFE)
      PXCH3 = HPS*CFE
      PYCH3 = HPS*SFE
      PTCH3 = SQRT(PXCH3**2+PYCH3**2)
      IF (PTCH3.GT.ABS(PCH3)) THEN
         NCPT = NCPT+1
         IF (MOD(NCPT,500).EQ.0) WRITE(LOUT,1007) NCPT
 1007    FORMAT('VALMSD: INEFFICIENT PT-SELECTION 1, NCPT=',I8)
         GOTO 30
      ENDIF
      PLCH3 = SIGN(SQRT(ABS(PCH3-PTCH3))*SQRT(ABS(PCH3+PTCH3)),PCH3)
      IF (IOUXEV.GE.2) WRITE(LOUT,1008) ES,HPS,PXCH3,PYCH3,PLCH3
 1008 FORMAT('VALMSD: ES,HPS,PXCH3,PYCH3,PLCH3',5E15.5)
*
*-------------------- no chain 1
*
      NDCH1  = -99
      AMDCH1 = 0.0D0
      ECH1   = 0.0D0
      PCH1   = 0.0D0
      GAMDC1 = 1.0D0
      PGVC1  = 0.0D0
      PGXVC1 = 0.0D0
      PGYVC1 = 0.0D0
      PGZVC1 = 0.0D0
      DO 40 I=1,4
         PDD2(I) = 0.0D0
         PDQ1(I) = 0.0D0
   40 CONTINUE
*
*-------------------- kinematical parameters of
*                     excited target        (IDIFTP = 1)
*                     or excited projectile (IDIFTP = 2)
*
      AMDCH2 = AMDIFF
      ECH2   = (ECM**2+AMDCH2**2-AMDCH3**2)/(2.0D0*ECM)
      PCH2   = -SIGN(SQRT(ABS(ECH2-AMDCH2))*SQRT(ECH2+AMDCH2),PCH3)
      NDCH2  = 0
      GAMDC2 = ECH2/AMDCH2
      PGVC2  = PCH2/AMDCH2
*
*-------------------- (IDIFFP,IDIFAP in analogy to HMSD in VAHMSD)
*                     IDIFTP = 1 : IKD1Q2/IKD2Q2 - IDIFFP = IKVQ2
*                     IDIFTP = 2 : projectile - baryon
*                                  IKD1Q1/IKD2Q1 - IDIFFP = IKVQ1
*                                  projectile - antibaryon
*                                  IKD1Q1/IKD2Q1 - IDIFAP = IKVQ1
*                                  projectile - meson
*                                  IKD1Q1 > 0    - IDIFAP = IKVQ1
*                                  IKD1Q1 < 0    - IDIFFP = IKVQ1
*
      IF (IDIFTP.EQ.1) IDIFFP = IKVQ2
      IF (IDIFTP.EQ.2) THEN
         IF (IBPROJ.GT.0) IDIFFP = IKVQ1
         IF (IBPROJ.LT.0) IDIFAP = IKVQ1
         IF ((IBPROJ.EQ.0).AND.(IKD1Q1.GT.0)) IDIFAP = IKVQ1
         IF ((IBPROJ.EQ.0).AND.(IKD1Q1.LT.0)) IDIFFP = IKVQ1
      ENDIF
      IF (IOUXEV.GE.2) WRITE(LOUT,1009) AMDCH2,ECH2,PCH2,GAMDC2,PGVC2,
     &                                  IDIFFP,IDIFAP
 1009 FORMAT('VALMSD: AMDCH2,ECH2,PCH2,GAMDC2,PGVC2,IDIFFP,IDIFAP',
     &                                                  5E15.5,2I4)
      PXCH2 = -PXCH3
      PYCH2 = -PYCH3
      PTCH2 = SQRT(PXCH2**2+PYCH2**2)
      IF (PTCH2.GT.ABS(PCH2)) THEN
         NCPT = NCPT+1
         IF (MOD(NCPT,500).EQ.0) WRITE(LOUT,1010) NCPT
 1010    FORMAT('VALMSD: INEFFICIENT PT-SELECTION 2, NCPT=',I8)
         GOTO 30
      ENDIF
      PLCH2 = SIGN(SQRT(ABS(PCH2-PTCH2))*SQRT(ABS(PCH2+PTCH2)),PCH2)
      IF (IOUXEV.GE.2) WRITE(LOUT,1011) PXCH2,PYCH2,PLCH2
 1011 FORMAT('VALMSD: PXCH2,PYCH2,PLCH2',3E15.5)
      CC    = AMDCH2/(2.0D0*ECH2)
*--------------------------- S.R. 11/12/92
      IF (CC.GE.0.5D0) THEN
         NCMERR = NCMERR+1
         IF (MOD(NCMERR,200).EQ.0)
     &      WRITE(LOUT,*) 'LMSD: INEFFICIENT SELECTION OF AMDIFF(2),
     &                        NCMERR = ',NCMERR
         GOTO 31
      ENDIF
*
      XDIQ  = 0.5D0+SQRT(ABS((0.5D0-CC)*(0.5D0+CC)))
      XQ    = 1.0D0-XDIQ
      EDIQ  = ECH2*XDIQ
      EQ    = ECH2*XQ
      TEMP  = ABS(EDIQ/PCH2)
      PXDIQ = PXCH2*TEMP
      PYDIQ = PYCH2*TEMP
      PLDIQ = PLCH2*TEMP
      TEMP  = ABS(EQ/PCH2)
      PXQ   = -PXCH2*TEMP
      PYQ   = -PYCH2*TEMP
      PLQ   = -PLCH2*TEMP
*
*-------------------- store results in COMMON-block /ABRDIF/
*
      PDQ2(1)  = PXQ
      PDQ2(2)  = PYQ
      PDQ2(3)  = PLQ
      PDQ2(4)  = EQ
      PDD1(1)  = PXDIQ
      PDD1(2)  = PYDIQ
      PDD1(3)  = PLDIQ
      PDD1(4)  = EDIQ
      PDFQ1(1) = PXCH3
      PDFQ1(2) = PYCH3
      PDFQ1(3) = PLCH3
      PDFQ1(4) = ECH3
      PGXVC2   = PXCH2/AMDCH2
      PGYVC2   = PYCH2/AMDCH2
      PGZVC2   = PLCH2/AMDCH2
      PGXVC3   = PXCH3/AMDCH3
      PGYVC3   = PYCH3/AMDCH3
      PGZVC3   = PLCH3/AMDCH3
*
      IF (IPEV.GE.2) THEN
         WRITE(LOUT,*) 'VALMSD: PDQ1, PDD2, PDD1, PDQ2, PDFQ1'
         WRITE(LOUT,1012)
     &      (PDQ1(I),PDD2(I),PDD1(I),PDQ2(I),PDFQ1(I),I=1,4)
 1012    FORMAT(5E15.5)
         WRITE(LOUT,1013) 'PGXVC1,PGYVC1,PGZVC1,GAMDC1',
     &                     PGXVC1,PGYVC1,PGZVC1,GAMDC1
         WRITE(LOUT,1013) 'PGXVC2,PGYVC2,PGZVC2,GAMDC2',
     &                     PGXVC2,PGYVC2,PGZVC2,GAMDC2
         WRITE(LOUT,1013) 'PGXVC3,PGYVC3,PGZVC3,GAMDC3',
     &                     PGXVC3,PGYVC3,PGZVC3,GAMDC3
 1013    FORMAT(A27,4E15.5)
      ENDIF
*
*------------------- store results in common block /HKKEVT/
*
*                    partonen of projectile/target
*
      NHKK = NHKK + 1
      ISTHKK(NHKK) = 23-IDIFTP
      IF (IDIFTP.EQ.1) IDHKK(NHKK) = IHKKQ(IDX(IKVQ2))
      IF (IDIFTP.EQ.2) IDHKK(NHKK) = IHKKQ(IDX(IKVQ1))
      IF (IDIFTP.EQ.1) JMOHKK(1,NHKK) = ITAPOI
      IF (IDIFTP.EQ.2) JMOHKK(1,NHKK) = 1
      JMOHKK(2,NHKK) = 0
      JDAHKK(1,NHKK) = 0
      JDAHKK(2,NHKK) = 0
      PHKK(1,NHKK)   = 0.0D0
      PHKK(2,NHKK)   = 0.0D0
      PHKK(3,NHKK)   = XQ
      PHKK(4,NHKK)   = XQ
      PHKK(5,NHKK)   = 0.0D0
      VHKK  (1,NHKK) = VHKK(1,JMOHKK(1,NHKK))
      VHKK  (2,NHKK) = VHKK(2,JMOHKK(1,NHKK))
      VHKK  (3,NHKK) = VHKK(3,JMOHKK(1,NHKK))
      VHKK  (4,NHKK) = VHKK(4,JMOHKK(1,NHKK))
*
      NHKK = NHKK + 1
      ISTHKK(NHKK) = 23-IDIFTP
      IF (IDIFTP.EQ.1) IDHKK(NHKK) = IHKKQQ(IDX(IKD1Q2),IDX(IKD2Q2))
      IF (IDIFTP.EQ.2) IDHKK(NHKK) = IHKKQQ(IDX(IKD1Q1),IDX(IKD2Q1))
      IF (IDIFTP.EQ.1) JMOHKK(1,NHKK) = ITAPOI
      IF (IDIFTP.EQ.2) JMOHKK(1,NHKK) = 1
      JMOHKK(2,NHKK) = 0
      JDAHKK(1,NHKK) = 0
      JDAHKK(2,NHKK) = 0
      PHKK(1,NHKK)   = 0.0D0
      PHKK(2,NHKK)   = 0.0D0
      PHKK(3,NHKK)   = XDIQ
      PHKK(4,NHKK)   = XDIQ
      PHKK(5,NHKK)   = 0.0D0
      VHKK  (1,NHKK) = VHKK(1,JMOHKK(1,NHKK))
      VHKK  (2,NHKK) = VHKK(2,JMOHKK(1,NHKK))
      VHKK  (3,NHKK) = VHKK(3,JMOHKK(1,NHKK))
      VHKK  (4,NHKK) = VHKK(4,JMOHKK(1,NHKK))
*
*                    ends of chain 2
*
      NHKK = NHKK + 1
      ISTHKK(NHKK)   = 100+ISTHKK(NHKK-2)
      IDHKK(NHKK)    = IDHKK(NHKK-2)
      JMOHKK(1,NHKK) = NHKK-2
      JMOHKK(2,NHKK) = JMOHKK(1,NHKK-2)
      JDAHKK(1,NHKK) = NHKK+2
      JDAHKK(2,NHKK) = NHKK+2
      PHKK(1,NHKK)   = PDQ2(1)
      PHKK(2,NHKK)   = PDQ2(2)
      PHKK(3,NHKK)   = PDQ2(3)
      PHKK(4,NHKK)   = PDQ2(4)
      PHKK(5,NHKK)   = 0.0D0
C               Add position of parton in hadron
       CALL QINNUC(XXPP,YYPP)
      VHKK  (1,NHKK) = VHKK(1,JMOHKK(1,NHKK))+XXPP
      VHKK  (2,NHKK) = VHKK(2,JMOHKK(1,NHKK))+YYPP
      VHKK  (3,NHKK) = VHKK(3,JMOHKK(1,NHKK))
      VHKK  (4,NHKK) = VHKK(4,JMOHKK(1,NHKK))
*
      NHKK = NHKK + 1
      ISTHKK(NHKK)   = 100+ISTHKK(NHKK-2)
      IDHKK(NHKK)    = IDHKK(NHKK-2)
      JMOHKK(1,NHKK) = NHKK-2
      JMOHKK(2,NHKK) = JMOHKK(1,NHKK-2)
      JDAHKK(1,NHKK) = NHKK+1
      JDAHKK(2,NHKK) = NHKK+1
      PHKK(1,NHKK)   = PDD1(1)
      PHKK(2,NHKK)   = PDD1(2)
      PHKK(3,NHKK)   = PDD1(3)
      PHKK(4,NHKK)   = PDD1(4)
      PHKK(5,NHKK)   = 0.0D0
C               Add position of parton in hadron
       CALL QINNUC(XXPP,YYPP)
      VHKK  (1,NHKK) = VHKK(1,JMOHKK(1,NHKK))+XXPP
      VHKK  (2,NHKK) = VHKK(2,JMOHKK(1,NHKK))+YYPP
      VHKK  (3,NHKK) = VHKK(3,JMOHKK(1,NHKK))
      VHKK  (4,NHKK) = VHKK(4,JMOHKK(1,NHKK))
*
*                    chain 2
*
      NHKK = NHKK + 1
      ISTHKK(NHKK)   = 177
      IDHKK(NHKK)    = 88888
      JMOHKK(1,NHKK) = NHKK-2
      JMOHKK(2,NHKK) = NHKK-1
      JDAHKK(1,NHKK) = 0
      JDAHKK(2,NHKK) = 0
      PHKK(1,NHKK)   = PXCH2
      PHKK(2,NHKK)   = PYCH2
      PHKK(3,NHKK)   = PLCH2
      PHKK(4,NHKK)   = ECH2
      PHKK(5,NHKK)   = AMDCH2
      VHKK  (1,NHKK) = VHKK(1,NHKK-1)
      VHKK  (2,NHKK) = VHKK(2,NHKK-1)
      VHKK  (3,NHKK) = VHKK(3,NHKK-1)
      IF ((BETP.NE.0.0D0).AND.(BGAMP.NE.0.0D0))
     &VHKK  (4,NHKK) = VHKK(3,NHKK)/BETP-VHKK(3,NHKK-2)/BGAMP
*
*                    diffractive nucleon
*
      NHKK = NHKK + 1
      ISTHKK(NHKK)   = 177
      IDHKK(NHKK)    = 88888
      IF (IDIFTP.EQ.2) JMOHKK(1,NHKK) = ITAPOI
      IF (IDIFTP.EQ.1) JMOHKK(1,NHKK) = 1
      JMOHKK(2,NHKK) = 0
      JDAHKK(1,NHKK) = 0
      JDAHKK(2,NHKK) = 0
      PHKK(1,NHKK)   = PDFQ1(1)
      PHKK(2,NHKK)   = PDFQ1(2)
      PHKK(3,NHKK)   = PDFQ1(3)
      PHKK(4,NHKK)   = PDFQ1(4)
C     WRITE(6,*)' Diffr. Nucleon'
C    *,PHKK(3,NHKK),PHKK(4,NHKK),PHKK(5,NHKK)
      PHKK(5,NHKK)   = AMDCH3
      VHKK  (1,NHKK) = VHKK(1,JMOHKK(1,NHKK))
      VHKK  (2,NHKK) = VHKK(2,JMOHKK(1,NHKK))
      VHKK  (3,NHKK) = VHKK(3,JMOHKK(1,NHKK))
      VHKK  (4,NHKK) = VHKK(4,JMOHKK(1,NHKK))
*
*
*---------- S. Roesler 21-10-93
*      check energy-momentum conservation
      IF (IPEV.GE.2) THEN
         PX = PDQ1(1)+PDQ2(1)+PDD1(1)+PDD2(1)+PDFQ1(1)
         PY = PDQ1(2)+PDQ2(2)+PDD1(2)+PDD2(2)+PDFQ1(2)
         PZ = PDQ1(3)+PDQ2(3)+PDD1(3)+PDD2(3)+PDFQ1(3)
         EE = ECM-(PDQ1(4)+PDQ2(4)+PDD1(4)+PDD2(4)+PDFQ1(4))
         WRITE(LOUT,*)'VALMSD: ENERGY-MOMENTUM-CHECK (PX,PY,PZ,E)'
         WRITE(LOUT,'(5F12.6)')PX,PY,PZ,EE,ECM
      ENDIF
*
      RETURN
 9999 CONTINUE
      NCREJ = NCREJ+1
      IF (MOD(NCREJ,500).EQ.0) WRITE(LOUT,9900) NCREJ
 9900 FORMAT('REJECTION IN VALMSD ',I10)
      IIREJ = 0
      IREJ  = 1
      RETURN
      END
*
*===valmdd===============================================================*
*
      SUBROUTINE VALMDD(ITAPOI,ECM,KPROJ,KTARG,IREJ)

C                   Low mass double diffraction J.R. Feb/Mar 94
 
**************************************************************************
* Version November 1993                         by Stefan Roesler        *
*                                                  University of Leipzig *
* This subroutine selects flavors and 4-momenta of partons in low-mass   *
* single diffractive chains.                                             *
**************************************************************************
 
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      PARAMETER (LOUT=6,LLOOK=9)
      PARAMETER (NMXHKK= 49998)
      CHARACTER*8 ANAME
      COMMON /HKKEVT/ NHKK,NEVHKK,     ISTHKK(NMXHKK),  IDHKK(NMXHKK),
     &                JMOHKK(2,NMXHKK),JDAHKK(2,NMXHKK),PHKK(5,NMXHKK),
     &                VHKK(4,NMXHKK),  WHKK(4,NMXHKK)
      COMMON /DPRIN/  IPRI,IPEV,IPPA,IPCO,INIT,IPHKK,ITOPD,IPAUPR
      COMMON /DIFFRA/ ISINGD,IDIFTP,IOUDIF,IFLAGD
      COMMON /ABRDIF/ XDQ1,XDQ2,XDDQ1,XDDQ2,
     &                IKVQ1,IKVQ2,IKD1Q1,IKD2Q1,IKD1Q2,IKD2Q2,
     &                IDIFFP,IDIFAP,
     &                AMDCH1,AMDCH2,AMDCH3,GAMDC1,GAMDC2,GAMDC3,
     &                PGXVC1,PGYVC1,PGZVC1,PGXVC2,PGYVC2,PGZVC2,
     &                PGXVC3,PGYVC3,PGZVC3,NDCH1,NDCH2,NDCH3,
     &                IKDCH1,IKDCH2,IKDCH3,
     &                PDQ1(4),PDQ2(4),PDD1(4),PDD2(4),PDFQ1(4)
      COMMON /DPAR/   ANAME(210),AM(210),GA(210),TAU(210),ICH(210),
     &                IBAR(210),K1(210),K2(210)
      COMMON/DINPDA/IMPS(6,6),IMVE(6,6),IB08(6,21),IB10(6,21),IA08(6,21)
     &,IA10(6,21),A1,B1,B2,B3,LT,LE,BET,AS,B8,AME,DIQ,ISU
      COMMON /TRAFOP/ GAMP,BGAMP,BETP
      COMMON /ENERIN/ EPROJ,ETARG
      COMMON /SDFLAG/ ISD
      COMMON/XXLMDD/IJLMDD,KDLMDD 
      COMMON /OUTLEV/IOUTPO,IOUTPA,IOUXEV,IOUCOL
*
      DIMENSION MQUARK(3,30),IHKKQ(-6:6),IHKKQQ(-3:3,-3:3),
     &          IDX(-4:4)
      DATA IDX   /-4,-3,-1,-2,0,2,1,3,4/
      DATA IHKKQ /-6,-5,-4,-3,-1,-2,0,2,1,3,4,5,6/
      DATA IHKKQQ/-3301,-3103,-3203,0,   0,0,0,
     &            -3103,-1103,-2103,0,   0,   0,   0,
     &            -3203,-2103,-2203,0,   0,   0,   0,
     &                0,    0,    0,0,   0,   0,   0,
     &                0,    0,    0,0,2203,2103,3202,
     &                0,    0,    0,0,2103,1103,3103,
     &                0,    0,    0,0,3203,3103,3303/
*
*----------------------------------- quark content of hadrons:
*                                     1, 2, 3, 4  -   u, d, s, c
*                                    -1,-2,-3,-4  -  au,ad,as,ac
*
      DATA MQUARK/
     &   1,1,2,    -1,-1,-2,       0,0,0,       0,0,0,       0,0,0,
     &   0,0,0,       0,0,0,       1,2,2,    -1,-2,-2,       0,0,0,
     &   0,0,0,       0,0,0,      1,-2,0,      2,-1,0,      1,-3,0,
     &  3,-1,0,       1,2,3,    -1,-2,-3,       0,0,0,       2,2,3,
     &   1,1,3,       1,2,3,      1,-1,0,      2,-3,0,      3,-2,0,
     &  2,-2,0,      3,-3,0,       0,0,0,       0,0,0,       0,0,0/
      DATA UNON/2.0/
      DATA NCREJ, NCPT /0, 0/
*
      IJLMDD= 1
      ISD   = 2
      IREJ  = 0
      IIREJ = 0
      IBPROJ = IBAR(KPROJ)
      IBTARG = IBAR(KTARG)
      EPROJ  = (AM(KPROJ)**2-AM(KTARG)**2+ECM**2)/(2.0D0*ECM)
      ETARG  = (AM(KTARG)**2-AM(KPROJ)**2+ECM**2)/(2.0D0*ECM)
      IF(IPEV.GE.2) WRITE(LOUT,1014)EPROJ,ETARG
 1014 FORMAT('VALMSD: EPROJ,ETARG',2F10.5)
      IF (IBTARG.LE.0) THEN
         WRITE(LOUT,1001) IBTARG
 1001    FORMAT('VALMSD: NO HMSD FOR TARGET WITH BARYON-CHARGE',I4)
         IIREJ = 1
         GOTO 9999
      ENDIF
      IQP1 = MQUARK(1,KPROJ)
      IQP2 = MQUARK(2,KPROJ)
      IQP3 = MQUARK(3,KPROJ)
      IQT1 = MQUARK(1,KTARG)
      IQT2 = MQUARK(2,KTARG)
      IQT3 = MQUARK(3,KTARG)
      IF(IPEV.GE.2) WRITE(LOUT,1002)
     &                IBPROJ,IBTARG,IQP1,IQP2,IQP3,IQT1,IQT2,IQT3
 1002 FORMAT('VALMSD: IBPROJ,IBTARG,IQP1,IQP2,IQP3,IQT1,IQT2,IQT3 ',8I4)
*
      IF (IBPROJ.NE.0) THEN
*
*-------------------- q-qq (aq-aqaq) - flavors of projectile (baryon)
*
         ISAM = 1.0D0+2.999D0*RNDM(V)
         GOTO (10,11,12) ISAM
   10    CONTINUE
         IQP    = IQP1
         IDIQP1 = IQP2
         IDIQP2 = IQP3
         GOTO 13
   11    CONTINUE
         IQP    = IQP2
         IDIQP1 = IQP1
         IDIQP2 = IQP3
         GOTO 13
   12    CONTINUE
         IQP    = IQP3
         IDIQP1 = IQP1
         IDIQP2 = IQP2
   13    CONTINUE
*
      ELSE IF (IBPROJ.EQ.0) THEN
*
*-------------------- q-aq - flavors of projectile (meson)
*
         ISAM = 1.0D0+1.999D0*RNDM(V)
         GOTO (14,15) ISAM
   14    CONTINUE
         IQP    = IQP1
         IDIQP1 = IQP2
         GOTO 16
   15    CONTINUE
         IQP    = IQP2
         IDIQP1 = IQP1
   16    CONTINUE
         IDIQP2 = 0
*
      ENDIF
*
*-------------------- q-qq - flavors of target (baryon)
*
      ISAM = 1.0D0+2.999D0*RNDM(V)
      GOTO (17,18,19) ISAM
   17 CONTINUE
      IQT    = IQT1
      IDIQT1 = IQT2
      IDIQT2 = IQT3
      GOTO 20
   18 CONTINUE
      IQT    = IQT2
      IDIQT1 = IQT1
      IDIQT2 = IQT3
      GOTO 20
   19 CONTINUE
      IQT    = IQT3
      IDIQT1 = IQT1
      IDIQT2 = IQT2
   20 CONTINUE
*
      IKVQ1  = IQP
      IKD1Q1 = IDIQP1
      IKD2Q1 = IDIQP2
*
      IKVQ2  = IQT
      IKD1Q2 = IDIQT1
      IKD2Q2 = IDIQT2
*
      IF (IPEV.GE.2) WRITE(LOUT,1003)
     &                 IKVQ1,IKD1Q1,IKD2Q1,IKVQ2,IKD1Q2,IKD2Q2
 1003 FORMAT('VALMSD: IKVQ1,IKD1Q1,IKD2Q1,IKVQ2,IKD1Q2,IKD2Q2 ',6I4)
*
*-------------------- IDIFTP = 1  target     (backward) hadron  excited
*                     IDIFTP = 2  projectile (forward)  hadron  excited
*
      IDIFTP = 1.0D0+1.999D0*RNDM(V)
*-------------------- S.Roesler 5/26/93
      IF ((ISINGD.EQ.3).OR.(ISINGD.EQ.7)) IDIFTP = 1
      IF ((ISINGD.EQ.4).OR.(ISINGD.EQ.8)) IDIFTP = 2
*
      IF (IPEV.GE.2) WRITE(LOUT,1004) IDIFTP
 1004 FORMAT('VALMSD: IDIFTP ',I4)
      IF ((IDIFTP.NE.1).AND.(IDIFTP.NE.2)) THEN
         IF (IPEV.GE.2) WRITE(LOUT,'(A19)') 'VALMSD-ERROR: IDIFTP'
         GOTO 9999
      ENDIF
*
*-------------------- diffractive mass
*
31    CONTINUE
      AMO = 1.5D0
C------------------------------------------------------------
C
C                             first simple test j.r. 2/94
C
C-----------------------------------------------------------
C     AMO = 4.0D0
C-----------------------------------------------------------
      R   = RNDM(V)
      IF ((IBPROJ.EQ.0).AND.(IDIFTP.EQ.1))
     &               AMO = 1.5D0*R+2.83D0*(1.0D0-R)
      IF ((IBPROJ.EQ.0).AND.(IDIFTP.EQ.2)) AMO = 1.0D0
      SAM = 1.0D0
      IF (ECM.LE.300.0D0) SAM = 1.0D0-EXP(-((ECM/200.0D0)**4))
      R   = RNDM(V)*SAM
      AMAX= (1.0D0-SAM)*SQRT(0.1D0*ECM**2)+SAM*SQRT(400.0D0)
      AMU = R*SQRT(100.0D0)+(1.0D0-R)*AMAX
      IF (IBPROJ.EQ.0) THEN
C----------------- change mass-cuts
C        AMAX= (1.0D0-SAM)*SQRT(0.25D0*ECM**2)+SAM*SQRT(400.0D0)
         AMAX= (1.0D0-SAM)*SQRT(0.15D0*ECM**2)+SAM*SQRT(400.0D0)
         AMU = R*SQRT(100.0D0)+(1.0D0-R)*AMAX
      ENDIF
C---------------------------------------------------------------
C
C                                           j.r. test 2/94
C
C---------------------------------------------------------------
      AMU=2.D0*AMU
C---------------------------------------------------------------
      R   = RNDM(V)
      IF (ECM.LE.50.0D0) THEN
         AMDIFF = AMO*(AMU/AMO)**R
      ELSE
         A = 0.7D0
         IF (ECM.LE.300.0D0) A = 0.7D0*(1.0D0-EXP(-((ECM/100.0D0)**2)))
         AMDIFF = 1.0D0/((R/(AMU**A)+(1.0D0-R)/(AMO**A))
     &         **(1.0D0/A))
      ENDIF
      IF(AMDIFF.GT.0.5D0*ECM)GO TO 31
      IF (IOUXEV.GE.2) WRITE(LOUT,1005) AMDIFF
 1005 FORMAT('VALMSD: AMDIFF',E10.5)
*
*-------------------- kinematical parameters of
*                     diffractive projectile (IDIFTP = 1)
*                     or diffractive target  (IDIFTP = 2)
*
      IF (IDIFTP.EQ.1) THEN
         AMDCH3 = AM(KPROJ)
	 IF(KPROJ.EQ.1)THEN
	   KDLMDD = 61
           AMDCH3 = AM(61)
C                          19.4.99	   
	   KDLMDD = 54
           AMDCH3 = AM(54)
	 ELSEIF(KPROJ.EQ.2)THEN
C                          19.4.99	   
	   KDLMDD = 68
           AMDCH3 = AM(68)
	 ELSEIF(KPROJ.EQ.8)THEN
	   AMDCH3 = AM(62)
	   KDLMDD = 62
C                          19.4.99	   
	   AMDCH3 = AM(55)
	   KDLMDD = 55
	 ELSEIF(KPROJ.EQ.13)THEN
	   AMDCH3 = AM(186)
	   KDLMDD = 186
	 ELSEIF(KPROJ.EQ.14)THEN
	   AMDCH3 = AM(188)
	   KDLMDD = 188
	 ELSEIF(KPROJ.EQ.15)THEN
	   AMDCH3 = AM(190)
	   KDLMDD = 190
	 ELSEIF(KPROJ.EQ.16)THEN
	   AMDCH3 = AM(191)
	   KDLMDD = 191
	 ELSEIF(KPROJ.EQ.23)THEN
	   AMDCH3 = AM(187)
	   KDLMDD = 187
	 ELSEIF(KPROJ.EQ.24)THEN
	   AMDCH3 = AM(192)
	   KDLMDD = 192
	 ELSEIF(KPROJ.EQ.25)THEN
	   AMDCH3 = AM(193)
	   KDLMDD = 193
	 ENDIF
      ELSE IF (IDIFTP.EQ.2) THEN
         AMDCH3 = AM(KTARG)
	 IF(KTARG.EQ.1)THEN
	   KDLMDD = 61
           AMDCH3 = AM(61)
C                          19.4.99	   
	   KDLMDD = 54
           AMDCH3 = AM(54)
	 ELSEIF(KTARG.EQ.2)THEN
C                          19.4.99	   
	   KDLMDD = 68
           AMDCH3 = AM(68)
	 ELSEIF(KTARG.EQ.8)THEN
	   AMDCH3 = AM(62)
	   KDLMDD = 62
C                          19.4.99	   
	   AMDCH3 = AM(55)
	   KDLMDD = 55
	 ELSEIF(KTARG.EQ.13)THEN
	   AMDCH3 = AM(186)
	   KDLMDD = 186
	 ELSEIF(KTARG.EQ.14)THEN
	   AMDCH3 = AM(188)
	   KDLMDD = 188
	 ELSEIF(KTARG.EQ.15)THEN
	   AMDCH3 = AM(190)
	   KDLMDD = 190
	 ELSEIF(KTARG.EQ.16)THEN
	   AMDCH3 = AM(191)
	   KDLMDD = 191
	 ELSEIF(KTARG.EQ.23)THEN
	   AMDCH3 = AM(187)
	   KDLMDD = 187
	 ELSEIF(KTARG.EQ.24)THEN
	   AMDCH3 = AM(192)
	   KDLMDD = 192
	 ELSEIF(KTARG.EQ.25)THEN
	   AMDCH3 = AM(193)
	   KDLMDD = 193
	 ENDIF
      ENDIF
      ECH3 = (ECM**2+AMDCH3**2-AMDIFF**2)/(2.0D0*ECM)
      IF (ECH3.LE.AMDCH3) THEN
         NCMERR = NCMERR+1
         IF (MOD(NCMERR,2200).EQ.0)
     &      WRITE(LOUT,*) 'LMSD: INEFFICIENT SELECTION OF AMDIFF(1),
     &                        NCMERR = ',NCMERR
         GOTO 31
      ENDIF
*
      PCH3 = SQRT(ABS(ECH3-AMDCH3))*SQRT(ECH3+AMDCH3)
      IF (IDIFTP.EQ.2) PCH3 = -PCH3
      NDCH3  = -1
      GAMDC3 = ECH3/AMDCH3
      PGVC3  = PCH3/AMDCH3
      IF (IOUXEV.GE.2) WRITE(LOUT,1006) AMDCH3,ECH3,PCH3,GAMDC3,PGVC3
 1006 FORMAT('VALMSD: AMDCH3,ECH3,PCH3,GAMDC3,PGVC3',5E10.5)
*
   30 CONTINUE
      B33   = 8.0D0
      ES    = -2.0D0/(B33**2)*LOG(RNDM(V)*RNDM(V))
      HPS   = SQRT(ES*ES+2.0D0*ES*0.94D0)
      CALL DSFECF(SFE,CFE)
      PXCH3 = HPS*CFE
      PYCH3 = HPS*SFE
      PTCH3 = SQRT(PXCH3**2+PYCH3**2)
      IF (PTCH3.GT.ABS(PCH3)) THEN
         NCPT = NCPT+1
         IF (MOD(NCPT,500).EQ.0) WRITE(LOUT,1007) NCPT
 1007    FORMAT('VALMSD: INEFFICIENT PT-SELECTION 1, NCPT=',I8)
         GOTO 30
      ENDIF
      PLCH3 = SIGN(SQRT(ABS(PCH3-PTCH3))*SQRT(ABS(PCH3+PTCH3)),PCH3)
      IF (IOUXEV.GE.2) WRITE(LOUT,1008) ES,HPS,PXCH3,PYCH3,PLCH3
 1008 FORMAT('VALMSD: ES,HPS,PXCH3,PYCH3,PLCH3',5E10.5)
*
*-------------------- no chain 1
*
      NDCH1  = -99
      AMDCH1 = 0.0D0
      ECH1   = 0.0D0
      PCH1   = 0.0D0
      GAMDC1 = 1.0D0
      PGVC1  = 0.0D0
      PGXVC1 = 0.0D0
      PGYVC1 = 0.0D0
      PGZVC1 = 0.0D0
      DO 40 I=1,4
         PDD2(I) = 0.0D0
         PDQ1(I) = 0.0D0
   40 CONTINUE
*
*-------------------- kinematical parameters of
*                     excited target        (IDIFTP = 1)
*                     or excited projectile (IDIFTP = 2)
*
      AMDCH2 = AMDIFF
      ECH2   = (ECM**2+AMDCH2**2-AMDCH3**2)/(2.0D0*ECM)
      PCH2   = -SIGN(SQRT(ABS(ECH2-AMDCH2))*SQRT(ECH2+AMDCH2),PCH3)
      NDCH2  = 0
      GAMDC2 = ECH2/AMDCH2
      PGVC2  = PCH2/AMDCH2
*
*-------------------- (IDIFFP,IDIFAP in analogy to HMSD in VAHMSD)
*                     IDIFTP = 1 : IKD1Q2/IKD2Q2 - IDIFFP = IKVQ2
*                     IDIFTP = 2 : projectile - baryon
*                                  IKD1Q1/IKD2Q1 - IDIFFP = IKVQ1
*                                  projectile - antibaryon
*                                  IKD1Q1/IKD2Q1 - IDIFAP = IKVQ1
*                                  projectile - meson
*                                  IKD1Q1 > 0    - IDIFAP = IKVQ1
*                                  IKD1Q1 < 0    - IDIFFP = IKVQ1
*
      IF (IDIFTP.EQ.1) IDIFFP = IKVQ2
      IF (IDIFTP.EQ.2) THEN
         IF (IBPROJ.GT.0) IDIFFP = IKVQ1
         IF (IBPROJ.LT.0) IDIFAP = IKVQ1
         IF ((IBPROJ.EQ.0).AND.(IKD1Q1.GT.0)) IDIFAP = IKVQ1
         IF ((IBPROJ.EQ.0).AND.(IKD1Q1.LT.0)) IDIFFP = IKVQ1
      ENDIF
      IF (IOUXEV.GE.2) WRITE(LOUT,1009) AMDCH2,ECH2,PCH2,GAMDC2,PGVC2,
     &                                  IDIFFP,IDIFAP
 1009 FORMAT('VALMSD: AMDCH2,ECH2,PCH2,GAMDC2,PGVC2,IDIFFP,IDIFAP',
     &                                                  5E10.5,2I4)
      PXCH2 = -PXCH3
      PYCH2 = -PYCH3
      PTCH2 = SQRT(PXCH2**2+PYCH2**2)
      IF (PTCH2.GT.ABS(PCH2)) THEN
         NCPT = NCPT+1
         IF (MOD(NCPT,500).EQ.0) WRITE(LOUT,1010) NCPT
 1010    FORMAT('VALMSD: INEFFICIENT PT-SELECTION 2, NCPT=',I8)
         GOTO 30
      ENDIF
      PLCH2 = SIGN(SQRT(ABS(PCH2-PTCH2))*SQRT(ABS(PCH2+PTCH2)),PCH2)
      IF (IOUXEV.GE.2) WRITE(LOUT,1011) PXCH2,PYCH2,PLCH2
 1011 FORMAT('VALMSD: PXCH2,PYCH2,PLCH2',3E10.5)
      CC    = AMDCH2/(2.0D0*ECH2)
*--------------------------- S.R. 11/12/92
      IF (CC.GE.0.5D0) THEN
         NCMERR = NCMERR+1
         IF (MOD(NCMERR,200).EQ.0)
     &      WRITE(LOUT,*) 'LMSD: INEFFICIENT SELECTION OF AMDIFF(2),
     &                        NCMERR = ',NCMERR
         GOTO 31
      ENDIF
*
      XDIQ  = 0.5D0+SQRT(ABS((0.5D0-CC)*(0.5D0+CC)))
      XQ    = 1.0D0-XDIQ
      EDIQ  = ECH2*XDIQ
      EQ    = ECH2*XQ
      TEMP  = ABS(EDIQ/PCH2)
      PXDIQ = PXCH2*TEMP
      PYDIQ = PYCH2*TEMP
      PLDIQ = PLCH2*TEMP
      TEMP  = ABS(EQ/PCH2)
      PXQ   = -PXCH2*TEMP
      PYQ   = -PYCH2*TEMP
      PLQ   = -PLCH2*TEMP
*
*-------------------- store results in COMMON-block /ABRDIF/
*
      PDQ2(1)  = PXQ
      PDQ2(2)  = PYQ
      PDQ2(3)  = PLQ
      PDQ2(4)  = EQ
      PDD1(1)  = PXDIQ
      PDD1(2)  = PYDIQ
      PDD1(3)  = PLDIQ
      PDD1(4)  = EDIQ
      PDFQ1(1) = PXCH3
      PDFQ1(2) = PYCH3
      PDFQ1(3) = PLCH3
      PDFQ1(4) = ECH3
      PGXVC2   = PXCH2/AMDCH2
      PGYVC2   = PYCH2/AMDCH2
      PGZVC2   = PLCH2/AMDCH2
      PGXVC3   = PXCH3/AMDCH3
      PGYVC3   = PYCH3/AMDCH3
      PGZVC3   = PLCH3/AMDCH3
*
      IF (IPEV.GE.2) THEN
         WRITE(LOUT,*) 'VALMSD: PDQ1, PDD2, PDD1, PDQ2, PDFQ1'
         WRITE(LOUT,1012)
     &      (PDQ1(I),PDD2(I),PDD1(I),PDQ2(I),PDFQ1(I),I=1,4)
 1012    FORMAT(5F10.5)
         WRITE(LOUT,1013) 'PGXVC1,PGYVC1,PGZVC1,GAMDC1',
     &                     PGXVC1,PGYVC1,PGZVC1,GAMDC1
         WRITE(LOUT,1013) 'PGXVC2,PGYVC2,PGZVC2,GAMDC2',
     &                     PGXVC2,PGYVC2,PGZVC2,GAMDC2
         WRITE(LOUT,1013) 'PGXVC3,PGYVC3,PGZVC3,GAMDC3',
     &                     PGXVC3,PGYVC3,PGZVC3,GAMDC3
 1013    FORMAT(A27,4F10.5)
      ENDIF
*
*------------------- store results in common block /HKKEVT/
*
*                    partonen of projectile/target
*
      NHKK = NHKK + 1
      ISTHKK(NHKK) = 23-IDIFTP
      IF (IDIFTP.EQ.1) IDHKK(NHKK) = IHKKQ(IDX(IKVQ2))
      IF (IDIFTP.EQ.2) IDHKK(NHKK) = IHKKQ(IDX(IKVQ1))
      IF (IDIFTP.EQ.1) JMOHKK(1,NHKK) = ITAPOI
      IF (IDIFTP.EQ.2) JMOHKK(1,NHKK) = 1
      JMOHKK(2,NHKK) = 0
      JDAHKK(1,NHKK) = 0
      JDAHKK(2,NHKK) = 0
      PHKK(1,NHKK)   = 0.0D0
      PHKK(2,NHKK)   = 0.0D0
      PHKK(3,NHKK)   = XQ
      PHKK(4,NHKK)   = XQ
      PHKK(5,NHKK)   = 0.0D0
      VHKK  (1,NHKK) = VHKK(1,JMOHKK(1,NHKK))
      VHKK  (2,NHKK) = VHKK(2,JMOHKK(1,NHKK))
      VHKK  (3,NHKK) = VHKK(3,JMOHKK(1,NHKK))
      VHKK  (4,NHKK) = VHKK(4,JMOHKK(1,NHKK))
*
      NHKK = NHKK + 1
      ISTHKK(NHKK) = 23-IDIFTP
      IF (IDIFTP.EQ.1) IDHKK(NHKK) = IHKKQQ(IDX(IKD1Q2),IDX(IKD2Q2))
      IF (IDIFTP.EQ.2) IDHKK(NHKK) = IHKKQQ(IDX(IKD1Q1),IDX(IKD2Q1))
      IF (IDIFTP.EQ.1) JMOHKK(1,NHKK) = ITAPOI
      IF (IDIFTP.EQ.2) JMOHKK(1,NHKK) = 1
      JMOHKK(2,NHKK) = 0
      JDAHKK(1,NHKK) = 0
      JDAHKK(2,NHKK) = 0
      PHKK(1,NHKK)   = 0.0D0
      PHKK(2,NHKK)   = 0.0D0
      PHKK(3,NHKK)   = XDIQ
      PHKK(4,NHKK)   = XDIQ
      PHKK(5,NHKK)   = 0.0D0
      VHKK  (1,NHKK) = VHKK(1,JMOHKK(1,NHKK))
      VHKK  (2,NHKK) = VHKK(2,JMOHKK(1,NHKK))
      VHKK  (3,NHKK) = VHKK(3,JMOHKK(1,NHKK))
      VHKK  (4,NHKK) = VHKK(4,JMOHKK(1,NHKK))
*
*                    ends of chain 2
*
      NHKK = NHKK + 1
      ISTHKK(NHKK)   = 100+ISTHKK(NHKK-2)
      IDHKK(NHKK)    = IDHKK(NHKK-2)
      JMOHKK(1,NHKK) = NHKK-2
      JMOHKK(2,NHKK) = JMOHKK(1,NHKK-2)
      JDAHKK(1,NHKK) = NHKK+2
      JDAHKK(2,NHKK) = NHKK+2
      PHKK(1,NHKK)   = PDQ2(1)
      PHKK(2,NHKK)   = PDQ2(2)
      PHKK(3,NHKK)   = PDQ2(3)
      PHKK(4,NHKK)   = PDQ2(4)
      PHKK(5,NHKK)   = 0.0D0
C               Add position of parton in hadron
       CALL QINNUC(XXPP,YYPP)
      VHKK  (1,NHKK) = VHKK(1,JMOHKK(1,NHKK))+XXPP
      VHKK  (2,NHKK) = VHKK(2,JMOHKK(1,NHKK))+YYPP
      VHKK  (3,NHKK) = VHKK(3,JMOHKK(1,NHKK))
      VHKK  (4,NHKK) = VHKK(4,JMOHKK(1,NHKK))
*
      NHKK = NHKK + 1
      ISTHKK(NHKK)   = 100+ISTHKK(NHKK-2)
      IDHKK(NHKK)    = IDHKK(NHKK-2)
      JMOHKK(1,NHKK) = NHKK-2
      JMOHKK(2,NHKK) = JMOHKK(1,NHKK-2)
      JDAHKK(1,NHKK) = NHKK+1
      JDAHKK(2,NHKK) = NHKK+1
      PHKK(1,NHKK)   = PDD1(1)
      PHKK(2,NHKK)   = PDD1(2)
      PHKK(3,NHKK)   = PDD1(3)
      PHKK(4,NHKK)   = PDD1(4)
      PHKK(5,NHKK)   = 0.0D0
C               Add position of parton in hadron
       CALL QINNUC(XXPP,YYPP)
      VHKK  (1,NHKK) = VHKK(1,JMOHKK(1,NHKK))+XXPP
      VHKK  (2,NHKK) = VHKK(2,JMOHKK(1,NHKK))+YYPP
      VHKK  (3,NHKK) = VHKK(3,JMOHKK(1,NHKK))
      VHKK  (4,NHKK) = VHKK(4,JMOHKK(1,NHKK))
*
*                    chain 2
*
      NHKK = NHKK + 1
      ISTHKK(NHKK)   = 188
      IDHKK(NHKK)    = 88888
      JMOHKK(1,NHKK) = NHKK-2
      JMOHKK(2,NHKK) = NHKK-1
      JDAHKK(1,NHKK) = 0
      JDAHKK(2,NHKK) = 0
      PHKK(1,NHKK)   = PXCH2
      PHKK(2,NHKK)   = PYCH2
      PHKK(3,NHKK)   = PLCH2
      PHKK(4,NHKK)   = ECH2
      PHKK(5,NHKK)   = AMDCH2
      VHKK  (1,NHKK) = VHKK(1,NHKK-1)
      VHKK  (2,NHKK) = VHKK(2,NHKK-1)
      VHKK  (3,NHKK) = VHKK(3,NHKK-1)
      IF ((BETP.NE.0.0D0).AND.(BGAMP.NE.0.0D0))
     &VHKK  (4,NHKK) = VHKK(3,NHKK)/BETP-VHKK(3,NHKK-2)/BGAMP
*
*                    diffractive nucleon
*
      NHKK = NHKK + 1
      ISTHKK(NHKK)   = 188
      IDHKK(NHKK)    = 88888
      IF (IDIFTP.EQ.2) JMOHKK(1,NHKK) = ITAPOI
      IF (IDIFTP.EQ.1) JMOHKK(1,NHKK) = 1
      JMOHKK(2,NHKK) = 0
      JDAHKK(1,NHKK) = 0
      JDAHKK(2,NHKK) = 0
      PHKK(1,NHKK)   = PDFQ1(1)
      PHKK(2,NHKK)   = PDFQ1(2)
      PHKK(3,NHKK)   = PDFQ1(3)
      PHKK(4,NHKK)   = PDFQ1(4)
      PHKK(5,NHKK)   = AMDCH3
      VHKK  (1,NHKK) = VHKK(1,JMOHKK(1,NHKK))
      VHKK  (2,NHKK) = VHKK(2,JMOHKK(1,NHKK))
      VHKK  (3,NHKK) = VHKK(3,JMOHKK(1,NHKK))
      VHKK  (4,NHKK) = VHKK(4,JMOHKK(1,NHKK))
*
*
*---------- S. Roesler 21-10-93
*      check energy-momentum conservation
      IF (IPEV.GE.2) THEN
         PX = PDQ1(1)+PDQ2(1)+PDD1(1)+PDD2(1)+PDFQ1(1)
         PY = PDQ1(2)+PDQ2(2)+PDD1(2)+PDD2(2)+PDFQ1(2)
         PZ = PDQ1(3)+PDQ2(3)+PDD1(3)+PDD2(3)+PDFQ1(3)
         EE = ECM-(PDQ1(4)+PDQ2(4)+PDD1(4)+PDD2(4)+PDFQ1(4))
         WRITE(LOUT,*)'VALMSD: ENERGY-MOMENTUM-CHECK (PX,PY,PZ,E)'
         WRITE(LOUT,'(5F12.6)')PX,PY,PZ,EE,ECM
      ENDIF
*
      RETURN
 9999 CONTINUE
      NCREJ = NCREJ+1
      IF (MOD(NCREJ,500).EQ.0) WRITE(LOUT,9900) NCREJ
 9900 FORMAT('REJECTION IN VALMSD ',I10)
      IIREJ = 0
      IREJ  = 1
      RETURN
      END
*
*===hadrdi===============================================================*
*
      SUBROUTINE HADRDI(NAUX,IJPROJ,IJTAR,NHKKH1)
 
**************************************************************************
* Version November 1993                         by Stefan Roesler        *
*                                                  University of Leipzig *
* This subroutine prepares the hadronisation of diffractive chains       *
* (single-diffractive component), calls HADJET and stores the results    *
* in common block /HKKEVT/.                                              *
**************************************************************************
 
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      PARAMETER (LOUT=6,LLOOK=9)
      PARAMETER (NMXHKK= 49998,INTMX=2488,NAUMAX=897,NFIMAX=249)
      CHARACTER*8 ANAME,ANC,ANF
      COMMON /HKKEVT/ NHKK,NEVHKK,     ISTHKK(NMXHKK),  IDHKK(NMXHKK),
     &                JMOHKK(2,NMXHKK),JDAHKK(2,NMXHKK),PHKK(5,NMXHKK),
     &                VHKK(4,NMXHKK),  WHKK(4,NMXHKK)
      COMMON /DPRIN/  IPRI,IPEV,IPPA,IPCO,INIT,IPHKK,ITOPD,IPAUPR
      COMMON /DPAR/   ANAME(210),AAM(210),GA(210),TAU(210),IICH(210),
     &                IIBAR(210),K1(210),K2(210)
      COMMON /DIFFRA/ ISINGD,IDIFTP,IOUDIF,IFLAGD
      COMMON /DIFPAR/ PXC(902),  PYC(902),PZC(902),
     &                HEC(902),  AMC(902),ICHC(902),
     &                IBARC(902),ANC(902),NRC(902)
      COMMON /DFINPA/ ANF(NFIMAX),PXF(NFIMAX),PYF(NFIMAX),
     &                PZF(NFIMAX),HEF(NFIMAX),AMF(NFIMAX),
     &                ICHF(NFIMAX),IBARF(NFIMAX),NREF(NFIMAX)
      COMMON /DFINPZ/IORMO(NFIMAX),IDAUG1(NFIMAX),IDAUG2(NFIMAX),
     * ISTATH(NFIMAX)
      COMMON /ABRDIF/ XDQ1,XDQ2,XDDQ1,XDDQ2,
     &                IKVQ1,IKVQ2,IKD1Q1,IKD2Q1,IKD1Q2,IKD2Q2,
     &                IDIFFP,IDIFAP,
     &                AMDCH1,AMDCH2,AMDCH3,GAMDC1,GAMDC2,GAMDC3,
     &                PGXVC1,PGYVC1,PGZVC1,PGXVC2,PGYVC2,PGZVC2,
     &                PGXVC3,PGYVC3,PGZVC3,NDCH1,NDCH2,NDCH3,
     &                IKDCH1,IKDCH2,IKDCH3,
     &                PDQ1(4),PDQ2(4),PDD1(4),PDD2(4),PDFQ1(4)
      COMMON /DINPDA/ IMPS(6,6),IMVE(6,6),IB08(6,21),IB10(6,21),
     &                IA08(6,21),IA10(6,21),
     &                A1,B1,B2,B3,LT,LE,BET,AS,B8,AME,DIQ,ISU
      COMMON /ENERIN/ EPROJ,ETARG
      COMMON /DIFOUT/ AMCHDI,TTT,NNAUX,KPROJ,KTARG
      COMMON /SDFLAG/ ISD
      COMMON/XXLMDD/IJLMDD,KDLMDD 
C                                   modified DPMJET
       COMMON /BUFUEH/ ANNVV,ANNSS,ANNSV,ANNVS,ANNCC,
     *                 ANNDV,ANNVD,ANNDS,ANNSD,
     *                 ANNHH,ANNZZ,
     *                 PTVV,PTSS,PTSV,PTVS,PTCC,PTDV,PTVD,PTDS,PTSD,
     *                 PTHH,PTZZ,
     *                 EEVV,EESS,EESV,EEVS,EECC,EEDV,EEVD,EEDS,EESD,
     *                 EEHH,EEZZ
     *                ,ANNDI,PTDI,EEDI
     *                ,ANNZD,ANNDZ,PTZD,PTDZ,EEZD,EEDZ
C---------------------
*
      DIMENSION POJ1(4),PAT1(4),POJ2(4),PAT2(4)
*
      NHKKH1 = NHKK
      NAUX   = 0
      NHAD   = 0
      PXDI   = 0.0D0
      PYDI   = 0.0D0
      PLDI   = 0.0D0
      EDI    = 0.0D0
      IMOH2  = NHKK-1
      IMOH3  = NHKK
      IF (ISD.EQ.1) IMOH1 = NHKK-4
      IBPROJ = IIBAR(IJPROJ)
      IBTAR  = IIBAR(IJTAR)
      KPROJ  = IJPROJ
      KTARG  = IJTAR
*
      IF (IPEV.GE.2) WRITE(LOUT,1100) ISD
 1100 FORMAT('HADRDI: ISD ',I3)
*
      NUNUC1 = 3
      NUNUC2 = 3
      IF ((IBPROJ.NE.0).AND.(IDIFTP.EQ.2)) NUNUC2 = 6
      IF ((IBTAR .NE.0).AND.(IDIFTP.EQ.1)) NUNUC2 = 4
      IF (IDIFTP.EQ.2) THEN
         DO 10 J=1,4
            POJ1(J) = PDQ1(J)
            PAT1(J) = PDD2(J)
            POJ2(J) = PDD1(J)
            PAT2(J) = PDQ2(J)
   10    CONTINUE
      ELSE
         DO 11 J=1,4
            POJ1(J) = PDD2(J)
            PAT1(J) = PDQ1(J)
            POJ2(J) = PDQ2(J)
            PAT2(J) = PDD1(J)
   11    CONTINUE
      ENDIF
      IF (IDIFTP.EQ.1) THEN
         IFB11 = IDIFAP
         IFB12 = IKVQ2
         IFB21 = IDIFFP
         IFB22 = IKD1Q2
         IFB23 = IKD2Q2
      ELSE IF ((IDIFTP.EQ.2).AND.(IKVQ1.GT.0)) THEN
         IFB11 = IKVQ1
         IFB12 = IDIFAP
         IFB21 = IKD1Q1
         IFB22 = IKD2Q1
         IFB23 = IDIFFP
      ELSE IF ((IDIFTP.EQ.2).AND.(IKVQ1.LE.0)) THEN
         IFB11 = IKVQ1
         IFB12 = IDIFFP
         IFB21 = IKD1Q1
         IFB22 = IKD2Q1
         IFB23 = IDIFAP
      ENDIF
      IF ((IFB22.EQ.0).AND.(IFB23.NE.0)) THEN
         IFB22 = IFB23
         IFB23 = 0
      ENDIF
      IF (IFB11.LT.0) IFB11 = IABS(IFB11)+6
      IF (IFB12.LT.0) IFB12 = IABS(IFB12)+6
      IF (IFB21.LT.0) IFB21 = IABS(IFB21)+6
      IF (IFB22.LT.0) IFB22 = IABS(IFB22)+6
      IF (IFB23.LT.0) IFB23 = IABS(IFB23)+6
*
*-------------------------- chain 1
*
C        WRITE(LOUT,1001) (POJ1(I),I=1,4)
C        WRITE(LOUT,1002) (PAT1(I),I=1,4)
      IF (IPEV.GE.2) THEN
         WRITE(LOUT,1000) NHAD,IKDCH1,NUNUC1,NDCH1,IFB11,IFB12,
     &                                             IFB13,IFB14
         WRITE(LOUT,1001) (POJ1(I),I=1,4)
         WRITE(LOUT,1002) (PAT1(I),I=1,4)
         WRITE(LOUT,1003) GAMDC1,PGXVC1,PGYVC1,PGZVC1,AMDCH1
 1000    FORMAT('HADRDI: NHAD,IKDCH1,NUNUC1,NDCH1,IFB11,IFB12',
     &                  ', IFB13,IFB14 ',8I4)
 1001    FORMAT('HADRDI: POJ1 ',4E15.5)
 1002    FORMAT('HADRDI: PAT1 ',4E15.5)
 1003    FORMAT('HADRDI: GAMDC1,PGXVC1,PGYVC1,PGZVC1,AMDCH1',5F10.5)
      ENDIF
      CALL HADJET(NHAD,AMDCH1,POJ1,PAT1,GAMDC1,PGXVC1,
     &            PGYVC1,PGZVC1,IFB11,IFB12,IFB13,IFB14,
     &            IKDCH1,IKDCH1,NUNUC1,NDCH1,7)
*
      NHKKBE = NHKK+1
      IF (NHAD.EQ.0) GOTO 13
      DO 12 J=1,NHAD
         IF (NHKK.EQ.NMXHKK) THEN
            WRITE(LOUT,1004) NHKK
 1004       FORMAT('HADRDI: NHKK.EQ.NMXHKK',I10)
            GOTO 9999
         ENDIF
         NHKK   = NHKK+1
         NAUX   = NAUX+1
         IF(IBARF(J).EQ.500)GO TO 776
         ECHECK = SQRT(PXF(J)**2+PYF(J)**2+PZF(J)**2+AMF(J)**2)
         IF (ABS(ECHECK-HEF(J)).GT.0.5D-2) THEN
            WRITE(LOUT,1005) NHKK,ECHECK,HEF(J),AMF(J)
 1005       FORMAT('HADRDI: CHAIN 1  CORRECT INCONSISTENT ENERGY',
     &              I10,3F10.5)
            HEF(J) = ECHECK
         ENDIF
  776    CONTINUE
         ANNDI=ANNDI+1
         EEDI=EEDI+HEF(J)
         PTDI=PTDI+SQRT(PXF(J)**2+PYF(J)**2)
         PXC  (NAUX) = PXF  (J)
         PYC  (NAUX) = PYF  (J)
         PZC  (NAUX) = PZF  (J)
         HEC  (NAUX) = HEF  (J)
         AMC  (NAUX) = AMF  (J)
         ICHC (NAUX) = ICHF (J)
         IBARC(NAUX) = IBARF(J)
         ANC  (NAUX) = ANF  (J)
         NRC  (NAUX) = NREF (J)
         PXDI   = PXDI+PXF(J)
         PYDI   = PYDI+PYF(J)
         PLDI   = PLDI+PZF(J)
         EDI    = EDI +HEF(J)
         EDIFF  = EDIFF+HEF(J)
         PTDIFF = PTDIFF+SQRT(PXF(J)**2+PYF(J)**2)
         ISTHKK(NHKK)   = 1
         IF(IBARF(J).EQ.500)ISTHKK(NHKK)=2
         IDHKK (NHKK)   = MPDGHA(NREF(J))
	 IF(IORMO(J).EQ.999)THEN
           JMOHKK(1,NHKK) = IMOH1
	 ELSE
	   JMOHKK(1,NHKK)=NHKKBE+IORMO(J)-1
	 ENDIF
         JMOHKK(2,NHKK) = 0
         JDAHKK(1,NHKK) = 0
         JDAHKK(2,NHKK) = 0
         PHKK(1,NHKK)   = PXF(J)
         PHKK(2,NHKK)   = PYF(J)
         PHKK(3,NHKK)   = PZF(J)
         PHKK(4,NHKK)   = HEF(J)
         PHKK(5,NHKK)   = AMF(J)
         IMOHKK         = JMOHKK(1,NHKK)
         VHKK(1,NHKK)   = VHKK(1,IMOHKK)
         VHKK(2,NHKK)   = VHKK(2,IMOHKK)
         VHKK(3,NHKK)   = VHKK(3,IMOHKK)
         VHKK(4,NHKK)   = VHKK(4,IMOHKK)
         IF (IPHKK.GE.1) THEN
            WRITE(LOUT,1006) NHKK,ISTHKK(NHKK),IDHKK(NHKK),
     &                       JMOHKK(1,NHKK),JMOHKK(2,NHKK),
     &                       JDAHKK(1,NHKK),JDAHKK(2,NHKK)
            WRITE(LOUT,1007) (PHKK(K,NHKK),K=1,5)
 1006       FORMAT('HADRDI: NHKK,ISTHKK,IDHKK,JMOHKK,JDAHKK',7I6)
 1007       FORMAT('HADRDI: PHKK ',5F10.5)
         ENDIF
   12 CONTINUE
   13 CONTINUE
      IF ((NHAD.GT.0).AND.(ISD.EQ.1)) THEN
         JDAHKK(1,IMOH1) = NHKKBE
         JDAHKK(2,IMOH1) = NHKK
      ENDIF
*
*------------------------ chain 2
*
      NHAD = 0
C        WRITE(LOUT,1009) (POJ2(I),I=1,4)
C        WRITE(LOUT,1010) (PAT2(I),I=1,4)
      IF (IPEV.GE.2) THEN
         WRITE(LOUT,1008) NHAD,IKDCH2,NUNUC2,NDCH2,IFB21,IFB22,
     &                                             IFB23,IFB24
         WRITE(LOUT,1009) (POJ2(I),I=1,4)
         WRITE(LOUT,1010) (PAT2(I),I=1,4)
         WRITE(LOUT,1011) GAMDC2,PGXVC2,PGYVC2,PGZVC2,AMDCH2
 1008    FORMAT('HADRDI: NHAD,IKDCH2,NUNUC2,NDCH2,IFB21,IFB22,
     &                   IFB23,IFB24 ',8I4)
 1009    FORMAT('HADRDI: POJ2 ',4E15.5)
 1010    FORMAT('HADRDI: PAT2 ',4E15.5)
 1011    FORMAT('HADRDI: GAMDC2,PGXVC2,PGYVC2,PGZVC2,AMDCH2',5F10.5)
      ENDIF
      CALL HADJET(NHAD,AMDCH2,POJ2,PAT2,GAMDC2,PGXVC2,
     &            PGYVC2,PGZVC2,IFB21,IFB22,IFB23,IFB24,
     &            IKDCH2,IKDCH2,NUNUC2,NDCH2,8)
*
      NHKKBE = NHKK+1
      IF (NHAD.EQ.0) GOTO 15
      DO 14 J=1,NHAD
         IF (NHKK.EQ.NMXHKK) THEN
            WRITE(LOUT,1012) NHKK
 1012       FORMAT('HADRDI: NHKK.EQ.NMXHKK',I10)
            GOTO 9999
         ENDIF
         NHKK   = NHKK+1
         NAUX   = NAUX+1
         IF(IBARF(J).EQ.500)GO TO 775
         ECHECK = SQRT(PXF(J)**2+PYF(J)**2+PZF(J)**2+AMF(J)**2)
         IF (ABS(ECHECK-HEF(J)).GT.0.5D-2) THEN
            WRITE(LOUT,1013) NHKK,ECHECK,HEF(J),AMF(J)
 1013       FORMAT('HADRDI: CHAIN 2  CORRECT INCONSISTENT ENERGY',
     &              I10,3F10.5)
            HEF(J) = ECHECK
         ENDIF
  775    CONTINUE
         ANNDI=ANNDI+1
         EEDI=EEDI+HEF(J)
         PTDI=PTDI+SQRT(PXF(J)**2+PYF(J)**2)
         PXC  (NAUX) = PXF  (J)
         PYC  (NAUX) = PYF  (J)
         PZC  (NAUX) = PZF  (J)
         HEC  (NAUX) = HEF  (J)
         AMC  (NAUX) = AMF  (J)
         ICHC (NAUX) = ICHF (J)
         IBARC(NAUX) = IBARF(J)
         ANC  (NAUX) = ANF  (J)
         NRC  (NAUX) = NREF (J)
         PXDI   = PXDI+PXF(J)
         PYDI   = PYDI+PYF(J)
         PLDI   = PLDI+PZF(J)
         EDI    = EDI +HEF(J)
         EDIFF  = EDIFF+HEF(J)
         PTDIFF = PTDIFF+SQRT(PXF(J)**2+PYF(J)**2)
         ISTHKK(NHKK)   = 1
         IF(IBARF(J).EQ.500)ISTHKK(NHKK)=2
         IDHKK (NHKK)   = MPDGHA(NREF(J))
	 IF(IORMO(J).EQ.999)THEN
           JMOHKK(1,NHKK) = IMOH2
	 ELSE
	   JMOHKK(1,NHKK)=NHKKBE+IORMO(J)-1
	 ENDIF
         JMOHKK(2,NHKK) = 0
         JDAHKK(1,NHKK) = 0
         JDAHKK(2,NHKK) = 0
         PHKK(1,NHKK)   = PXF(J)
         PHKK(2,NHKK)   = PYF(J)
         PHKK(3,NHKK)   = PZF(J)
         PHKK(4,NHKK)   = HEF(J)
         PHKK(5,NHKK)   = AMF(J)
         IMOHKK         = JMOHKK(1,NHKK)
         VHKK(1,NHKK)   = VHKK(1,IMOHKK)
         VHKK(2,NHKK)   = VHKK(2,IMOHKK)
         VHKK(3,NHKK)   = VHKK(3,IMOHKK)
         VHKK(4,NHKK)   = VHKK(4,IMOHKK)
         IF (IPHKK.GE.2) THEN
            WRITE(LOUT,1014) NHKK,ISTHKK(NHKK),IDHKK(NHKK),
     &                       JMOHKK(1,NHKK),JMOHKK(2,NHKK),
     &                       JDAHKK(1,NHKK),JDAHKK(2,NHKK)
            WRITE(LOUT,1015) (PHKK(K,NHKK),K=1,5)
 1014       FORMAT('HADRDI: NHKK,ISTHKK,IDHKK,JMOHKK,JDAHKK',7I6)
 1015       FORMAT('HADRDI: PHKK ',5F10.5)
         ENDIF
   14 CONTINUE
   15 CONTINUE
      IF (NHAD.GT.0) THEN
         JDAHKK(1,IMOH2) = NHKKBE
         JDAHKK(2,IMOH2) = NHKK
      ENDIF
*
*----------------------------- diffractive nucleon/antinucleon
*
      NAUX = NAUX+1
      IF (IDIFTP.EQ.1) THEN
	IF(IJLMDD.EQ.1)THEN
         AMC  (NAUX) = AAM  (KDLMDD)
         ICHC (NAUX) = IICH (KDLMDD)
         IBARC(NAUX) = IIBAR(KDLMDD)
         ANC  (NAUX) = ANAME(KDLMDD)
         NRC  (NAUX) =KDLMDD 
	ELSEIF(IJLMDD.EQ.0)THEN
         AMC  (NAUX) = AAM  (IJPROJ)
         ICHC (NAUX) = IICH (IJPROJ)
         IBARC(NAUX) = IIBAR(IJPROJ)
         ANC  (NAUX) = ANAME(IJPROJ)
         NRC  (NAUX) = IJPROJ
        ENDIF
      ELSEIF (IDIFTP.EQ.2) THEN
	IF(IJLMDD.EQ.1)THEN
         AMC  (NAUX) = AAM  (KDLMDD)
         ICHC (NAUX) = IICH (KDLMDD)
         IBARC(NAUX) = IIBAR(KDLMDD)
         ANC  (NAUX) = ANAME(KDLMDD)
         NRC  (NAUX) =KDLMDD 
	ELSEIF(IJLMDD.EQ.0)THEN
         AMC  (NAUX) = AAM  (IJTAR)
         ICHC (NAUX) = IICH (IJTAR)
         IBARC(NAUX) = IIBAR(IJTAR)
         ANC  (NAUX) = ANAME(IJTAR)
         NRC  (NAUX) = IJTAR
        ENDIF
      ENDIF
      PXC(NAUX) = PDFQ1(1)
      PYC(NAUX) = PDFQ1(2)
      PZC(NAUX) = PDFQ1(3)
      HEC(NAUX) = PDFQ1(4)
         ANNDI=ANNDI+1
         EEDI=EEDI+HEC(NAUX)
         PTDI=PTDI+SQRT(PXC(NAUX)**2+PYC(NAUX)**2)
      NHKK = NHKK+1
      ISTHKK(NHKK)   = 1
C        IF(IBARF(J).EQ.500)ISTHKK(NHKK)=2
      IDHKK (NHKK)   = MPDGHA(NRC(NAUX))
	 IF(IORMO(J).EQ.999)THEN
           JMOHKK(1,NHKK) = IMOH3
	 ELSE
	   JMOHKK(1,NHKK)=NHKKBE+IORMO(J)-1
	 ENDIF
      JMOHKK(2,NHKK) = 0
      JDAHKK(1,NHKK) = 0
*---------- S. Roesler 5-11-93
*           the following line is just to get the leading particle
*           detected
      JDAHKK(2,NHKK) = 1000
*
      PHKK(1,NHKK)   = PXC(NAUX)
      PHKK(2,NHKK)   = PYC(NAUX)
      PHKK(3,NHKK)   = PZC(NAUX)
      PHKK(4,NHKK)   = HEC(NAUX)
      PHKK(5,NHKK)   = AMC(NAUX)
      JDAHKK(1,IMOH3)= NHKK
      IMOHKK         = JMOHKK(1,NHKK)
      VHKK(1,NHKK)   = VHKK(1,IMOHKK)
      VHKK(2,NHKK)   = VHKK(2,IMOHKK)
      VHKK(3,NHKK)   = VHKK(3,IMOHKK)
      VHKK(4,NHKK)   = VHKK(4,IMOHKK)
      IF (IPHKK.GE.2) THEN
         WRITE(LOUT,1016) NHKK,ISTHKK(NHKK),IDHKK(NHKK),
     &                    JMOHKK(1,NHKK),JMOHKK(2,NHKK),
     &                    JDAHKK(1,NHKK),JDAHKK(2,NHKK)
         WRITE(LOUT,1017) (PHKK(K,NHKK),K=1,5)
 1016    FORMAT('HADRDI: NHKK,ISTHKK,IDHKK,JMOHKK,JDAHKK',7I6)
 1017    FORMAT('HADRDI: PHKK ',5F10.5)
      ENDIF
      IF (IPEV.GE.2) THEN
         DO 16 I=1,NAUX
            WRITE(LOUT,*) 'HADRDI: DIFFRACTIVE JET-HADRONS'
            WRITE(LOUT,1018)I,PXC(I),PYC(I),PZC(I),HEC(I),AMC(I),
     &                      ICHC(I),IBARC(I),NRC(I),ANC(I)
 1018       FORMAT(I5,5F12.4,3I5,A10)
   16    CONTINUE
      ENDIF
*
      NNAUX  = NAUX
      AMCHDI = SQRT(EDI**2-PXDI**2-PYDI**2-PLDI**2)
      IF (IDIFTP.EQ.1) TTT=2*AAM(IJPROJ)**2-2.*(EPROJ*HEC(NAUX)
     &                    -SQRT(EPROJ**2-AAM(IJPROJ)**2)*PZC(NAUX))
      IF (IDIFTP.EQ.2) TTT=2*AAM(IJTAR)**2-2.*(ETARG*HEC(NAUX)
     &                    +SQRT(ETARG**2-AAM(IJTAR)**2)*PZC(NAUX))
      IF (IPEV.GE.2) THEN
         WRITE(LOUT,1019) AMCHDI,TTT
 1019    FORMAT('HADRDI: AMCHDI,TTT ',2F10.5)
      ENDIF
 9999 CONTINUE
      RETURN
      END
*
*===diadif===============================================================*
*
      SUBROUTINE DIADIF(IOP,NHKKH1)
 
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      PARAMETER (LOUT=6,LLOOK=9)
      PARAMETER (NMXHKK= 49998)
      CHARACTER*8 ANAME,ANC
      COMMON /HKKEVT/ NHKK,NEVHKK,     ISTHKK(NMXHKK),  IDHKK(NMXHKK),
     &                JMOHKK(2,NMXHKK),JDAHKK(2,NMXHKK),PHKK(5,NMXHKK),
     &                VHKK(4,NMXHKK),  WHKK(4,NMXHKK)
      COMMON /DPRIN/  IPRI,IPEV,IPPA,IPCO,INIT,IPHKK,ITOPD,IPAUPR
      COMMON /DPAR/   ANAME(210),AAM(210),GA(210),TAU(210),IICH(210),
     &                IIBAR(210),K1(210),K2(210)
      COMMON /DIFPAR/ PXC(902),  PYC(902),PZC(902),
     &                HEC(902),  AMC(902),ICHC(902),
     &                IBARC(902),ANC(902),NRC(902)
      COMMON /ENERIN/ EPROJ,ETARG
      COMMON /NNCMS/  DGAMCM,DBGCM,ECM,DPCM,DEPROJ,DPPROJ
      COMMON /DHISTO/ XYL(51,10),YYL(51,10),YYLPS(51,10),XXFL(51,10),
     &                YXFL(51,10),TDTDM(40,24),DSDTDM(40,24),
     &                AMDM(24,40),DSDM(24,40),AVE(30),AVMULT(30),
     &                YXFLCH(51),YXFLPI(51)
      COMMON /DIFOUT/ AMCH,TT,NHAD,KPROJ,KTARG
      COMMON /DIFFRA/ ISINGD,IDIFTP,IOUDIF,IFLAGD
      COMMON /NUCC/   IT,ITZ,IP,IPZ,IJPROJ,IBPROJ,IJTARG,IBTARG
      COMMON /EVFLAG/ NUMEV
      DIMENSION INDX(28),PX(902),PY(902),PZ(902),HE(902),AM(902),
     &          ICH(902),NR(902)
C     DATA INDX /1,8,10,10,10,10,7,2,7,10,10,7,3,4,5,6,
C    &          11,12,7,13,14,15,16,17,18,7,7,7/
      DATA INDX/ 1,8,10,10,10,   10,7,2,7,10,
     &           10,7,3,4,5,      6,7,7,7,7,
     &            7,7,7,7,7,      7,7,7/
*
      GOTO (1,2,3) IOP
*
    1 CONTINUE
      NCEV = 0
      DXFL = 0.04D0
      DT   = 0.1D0
      DDM  = 10.0D0
      DY   = 0.499999D0
      NEVT = 0
      NCH  = 0
      NPI  = 0
      NHAD = 0
C     KPROJ= 0
C     KTARG= 0
      AMCH = 0.0D0
      TT   = 0.0D0
*
      DO 10 J=1,51
         YXFLCH(J) = 0.0D0
         YXFLPI(J) = 0.0D0
         DO 11 I=1,10
            XXFL(J,I) = J*DXFL-1.0D0
            YXFL(J,I) = 1.0D-18
            XYL(J,I)  = (J-24)*DY-DY/2.0D0
            YYL(J,I)  = 1.0D-18
            YYLPS(J,I)= 1.0D-18
   11    CONTINUE
   10 CONTINUE
      DO 12 I=1,40
         DO 13 J=1,24
            TDTDM(I,J) = I*DT
            DSDTDM(I,J)= 1.0D-8
            AMDM(J,I)  = (J*DDM-DDM/2.0D0)**2
            DSDM(J,I)  = 1.0D-8
            AMDM(J,I)  = LOG10(AMDM(J,I))
   13    CONTINUE
   12 CONTINUE
      DO 14 I=1,30
         AVE(I)    = 1.0D-18
         AVMULT(I) = 1.0D-18
   14 CONTINUE
      RETURN
*
    2 CONTINUE
      NCEV = NCEV+1
      IF (MOD(NCEV,2000).EQ.0) WRITE(LOUT,*) NCEV
      J = 0
C     IF (IFLAGD.EQ.1) RETURN
      DO 21 I=NHKKH1+1,NHKK
         IF ((ISTHKK(I).EQ.1).AND.(JMOHKK(2,I).NE.100).AND.
     &       (JDAHKK(1,I).EQ.0)) THEN
            J = J+1
            PX(J) = PHKK(1,I)
            PY(J) = PHKK(2,I)
            PZ(J) = PHKK(3,I)
            HE(J) = PHKK(4,I)
            AM(J) = PHKK(5,I)
            NR(J) = MCIHAD(IDHKK(I))
            ICH(J)= IICH(NR(J))
         ENDIF
   21 CONTINUE
      IHAD = J
      IF (IPEV.GE.2) THEN
         WRITE(LOUT,*) 'DIADIF: PX,PY,PZ,HE,AM,NR,ICH'
         DO 22 I=1,IHAD
            WRITE(LOUT,*) PX(I),PY(I),PZ(I),HE(I),AM(I),NR(I),ICH(I)
 1000       FORMAT(5F12.5,2I4)
   22    CONTINUE
      ENDIF
C     IF (IDIFTP.EQ.1) THEN
C        P0 = SQRT(ETARG**2-AAM(KTARG)**2)
C     ELSE IF (IDIFTP.EQ.2) THEN
C        P0 = SQRT(EPROJ**2-AAM(KPROJ)**2)
C     ENDIF
      EPCM = (AAM(IJPROJ)**2-AAM(1)**2+ECM**2)/(2.0D0*ECM)
      P0   = SQRT((EPCM-AAM(IJPROJ))*(EPCM+AAM(IJPROJ)))
      NEVT = NEVT+1
      AVMULT(30) = AVMULT(30)+IHAD
      DO 20 I=1,IHAD
         NRE = NR(I)
         IF (NRE.GT.25) NRE = 28
         IF (NRE.LT. 1) NRE = 28
         NI = INDX(NRE)
         IF (NRE.EQ.28) NI = 8
         AVE(NRE) = AVE(NRE)+HE(I)
         AVE(30)  = AVE(30) +HE(I)
         IF (NI.NE.6) AVE(29) = AVE(29)+HE(I)
         AVMULT(NRE) = AVMULT(NRE)+1.0D0
         IF (NI.NE.6) AVMULT(29) = AVMULT(29)+1.0D0
         IF (ICH(I).NE.0) AVE(27) = AVE(27)+HE(I)
         IF (ICH(I).NE.0) AVMULT(27) = AVMULT(27)+1.0D0
C        XFL = PZ(I)/PO
         XFL  = PZ(I)/P0
         XFLE = HE(I)/P0
C        IF ((ICH(I).NE.0).AND.(XFL.GT.-0.84D0).AND.(XFL.LT.-0.44D0))
C    &      WRITE(LOUT,*)'WRONG EVENT',NUMEV
         IXFL = XFL/DXFL+26
C        IF (XFL.LT.0.0D0) WRITE(LLOOK,'(2F15.5,I3)')XFL,PZ(I),IXFL
         IF (IXFL.LT.1 ) IXFL=1
         IF (IXFL.GT.50) IXFL=50
         XXXFL = ABS(XFL)
         IF (NRE.EQ.14) THEN
            NPI = NPI+1
            YXFLPI(IXFL) = YXFLPI(IXFL)+XFLE
         ENDIF
         IF ((ICH(I).GT.0).AND.(NRE.NE.1)) THEN
            NCH = NCH+1
            YXFLCH(IXFL) = YXFLCH(IXFL)+XFLE
         ENDIF
         IF (ICH(I).NE.0) YXFL(IXFL,9) = YXFL(IXFL,9)+XXXFL
         YXFL(IXFL,NI) = YXFL(IXFL,NI)+XXXFL
         YXFL(IXFL,10) = YXFL(IXFL,10)+XXXFL
         PTT = PX(I)**2+PY(I)**2
         AMT = SQRT(PTT+AM(I)**2)
         YL = 0.5D0*LOG(ABS((HE(I)+PZ(I)+1.D-10)
     &        /(HE(I)-PZ(I)+1.D-10)))
         YLPS = LOG(ABS((PZ(I)+SQRT(PZ(I)**2+PTT))
     &        /SQRT(PTT+1.D-6)+1.D-18))
         IYLPS = (YLPS+25.0D0*DY)/DY
         IF (IYLPS.LT.1)  IYLPS = 1
         IF (IYLPS.GT.51) IYLPS = 51
         YYLPS(IYLPS,NI) = YYLPS(IYLPS,NI)+1.0D0
         YYLPS(IYLPS,10) = YYLPS(IYLPS,10)+1.0D0
         IF (ICH(I).NE.0) YYLPS(IYLPS,9) = YYLPS(IYLPS,9)+1.0D0
         IYL = (YL+25.0D0*DY)/DY
         IF (IYL.LT.1)  IYL = 1
         IF (IYL.GT.51) IYL = 51
         IF (ICH(I).NE.0) YYL(IYL,9) = YYL(IYL,9)+1.0D0
         YYL(IYL,NI) = YYL(IYL,NI)+1.0D0
         YYL(IYL,10) = YYL(IYL,10)+1.0D0
   20 CONTINUE
      KPL = (AMCH+DDM+DDM/2.0D0)/DDM
      IF (KPL.GT.24) KPL=24
      IF (KPL.LT.1)  KPL=1
      ITT = 10.0D0*ABS(TT)+1
      IF (ITT.GT.40) ITT = 40
C     DSDTDM(ITT,KPL) = DSDTDM(ITT,KPL)+1.0D0/AMCH
      RETURN
*
    3 CONTINUE
      DO 30 J=1,51
         IF(NCH.NE.0) YXFLCH(J) = YXFLCH(J)/(NCH*DXFL)
         IF(NPI.NE.0) YXFLPI(J) = YXFLPI(J)/(NPI*DXFL)
         DO 31 I=1,10
            YXFL(J,I) = LOG10(ABS(YXFL(J,I) /(NEVT*DXFL))+1.0D-8)
            YYL(J,I)  = YYL(J,I) /(NEVT*DY)
            YYLPS(J,I)= YYLPS(J,I)/(NEVT*DY)
   31    CONTINUE
   30 CONTINUE
      DO 32 I=1,30
         AVMULT(I) = AVMULT(I)/NEVT
         AVE( I)   = AVE(I)   /NEVT
   32 CONTINUE
      DO 33 I=1,40
         DO 34 J=1,24
            DSDTDM(I,J) = DSDTDM(I,J)/NEVT
            DSDTDM(I,J) = LOG10(DSDTDM(I,J))
            DSDM(J,I)   = DSDTDM(I,J)
   34    CONTINUE
   33 CONTINUE
      WRITE(LOUT,*)'NAME,AVE,AVMULT'
      DO 105 I=1,30
         WRITE(LOUT,210) ANAME(I),AVE(I),AVMULT(I)
  210    FORMAT(' ',A8,2F15.5)
  105 CONTINUE
      WRITE(LOUT,100)
  100 FORMAT('1 RAPIDITY DISTRIBUTION')
      DO 110 J=1,50
         WRITE(LOUT,200) XYL(J,1),(YYL(J,I),I=1,10)
c        WRITE(LOUT,200) XYL(J,1),(YYL(J,I),I=11,20)
  200    FORMAT (F10.2,10E11.3)
  110 CONTINUE
      CALL PLOT(XYL,YYL,510,10,51,-25.D0*DY,DY,0.D0,0.03D0)
      WRITE(LOUT,101)
  101 FORMAT('1 PSEUDORAPIDITY DISTRIBUTION')
      CALL PLOT(XYL,YYLPS,510,10,51,-25.D0*DY,DY,0.D0,0.03D0)
      WRITE(LOUT,102)
  102 FORMAT ('1  LONG MOMENTUM (SCALED) DISTRIBUTION (LOG)')
      CALL PLOT(XXFL,YXFL,510,10,51,-1.D0,DXFL,-3.5D0,0.05D0)
      WRITE(LOUT,103)
  103 FORMAT ('1DISTRIBUTION DS/DTDM AS FUNCTION OF T ')
      CALL PLOT(TDTDM,DSDTDM,960,24,40,0.D0,0.04D0,-5.D0,0.05D0)
      WRITE(LOUT,104)
  104 FORMAT ('1DISTRIBUTION DS/DTDM AS FUNCTION OF M**2 ')
      CALL PLOT(AMDM,DSDM,960,40,24,2.D0,0.1D0,-5.D0,0.05D0)
      IF (IJPROJ.EQ.13) SIG = 66.0D0
      IF (IJPROJ.EQ.14) SIG = 66.0D0
      IF (IJPROJ.EQ.15) SIG = 54.9D0
      IF (IJPROJ.EQ.1)  SIG = 95.0D0
      SIGCH = 84.8
      SIGPIM=0.23D0
C     OPEN(19,FILE='FEYNDI.OUT')
      WRITE(LOUT,*)'FEYNMAN-DISTRIBUTION FOR PION-'
      DO 35 I=1,51
         WRITE(LOUT,'(2F15.5)')
     &   DXFL*(I-1)-1,SIG*YXFLPI(I)
         WRITE(LOUT,'(2F15.5)')
     &   DXFL*I-1,SIG*YXFLPI(I)
   35 CONTINUE
      WRITE(LOUT,*)'FEYNMAN-DISTRIBUTION FOR CHARGED PARTICLES'
      DO 36 I=1,51
         WRITE(LOUT,'(2F15.5)')
     &   DXFL*(I-1)-1,SIGCH*YXFLCH(I)
         WRITE(LOUT,'(2F15.5)')
     &   DXFL*I-1,SIGCH*YXFLCH(I)
   36 CONTINUE
C     CLOSE(19)
      RETURN
      END
*
*===sihndi===============================================================*
*
      SUBROUTINE SIHNDI(ECM,KPROJ,KTARG,SIGDIF,SIGDIH)
 
**********************************************************************
*   Single diffractive hadron-nucleon cross sections                 *
*                                              S.Roesler 14/1/93     *
*                                                                    *
*   The cross sections are calculated from extrapolated single       *
*   diffractive antiproton-proton cross sections (DTUJET92) using    *
*   scaling relations between total and single diffractive cross     *
*   sections.                                                        *
**********************************************************************
 
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      CHARACTER*8  ANAME
      COMMON /DPAR/ ANAME(210),AM(210),GA(210),TAU(210),IICH(210),
     &              IIBAR(210),K1(210),K2(210)
*
      CSD1   =   4.201483727
      CSD4   = -0.4763103556E-02
      CSD5   =  0.4324148297
*
      CHMSD1 =  0.8519297242
      CHMSD4 = -0.1443076599E-01
      CHMSD5 =  0.4014954567
*
      EPN = (ECM**2 - AM(KPROJ)**2 - AM(KTARG)**2)/(2.0D0*AM(KTARG))
      PPN = SQRT((EPN-AM(KPROJ))*(EPN+AM(KPROJ)))
*
      SDIAPP = CSD1+CSD4*LOG(PPN)**2+CSD5*LOG(PPN)
      SHMSD  = CHMSD1+CHMSD4*LOG(PPN)**2+CHMSD5*LOG(PPN)
      FRAC   = SHMSD/SDIAPP
*
      GOTO( 10, 20,999,999,999,999,999, 10, 20,999,
     &     999, 20, 20, 20, 20, 20, 10, 20, 20, 10,
     &      10, 10, 20, 20, 20) KPROJ
*
   10 CONTINUE
*---------------------------- p - p , n - p , sigma0+- - p ,
*                             Lambda - p
      CSD1   =  6.004476070
      CSD4   = -0.1257784606E-03
      CSD5   =  0.2447335720
      SIGDIF = CSD1+CSD4*LOG(PPN)**2+CSD5*LOG(PPN)
C     Replace SIGDIF with dpmjet result SIPPSD(ECM)
      SIGDIF=SIPPSD(ECM)
      SIGDIH = FRAC*SIGDIF
      RETURN
*
   20 CONTINUE
*
      KPSCAL = 2
      KTSCAL = 1
      F      = SDIAPP/DSHNTO(KPSCAL,KTSCAL,ECM)
C     F      = SDIAPP/DSHNEL(KPSCAL,KTSCAL,ECM)
      KT     = 1
      SIGDIF = DSHNTO(KPROJ,KT,ECM)*F
C     SIGDIF = DSHNEL(KPROJ,KT,ECM)*F
      SIGDIH = FRAC*SIGDIF
      RETURN
*
  999 CONTINUE
*-------------------------- leptons..
      SIGDIF = 1.E-10
      SIGDIH = 1.E-10
      RETURN
      END
*
*===dshnto===============================================================*
*
      DOUBLE PRECISION FUNCTION DSHNTO(KPROJ,KTARG,UMO)
 
**********************************************************************
*   Total hadron-nucleon cross sections         S.Roesler 12/1/93    *
*                                                                    *
*   Fits from Rev. of Part. Prop.(1992) are used in the momentum     *
*   ranges given there. Cross sections for momenta below them are    *
*   calculated as in an earlier version of this function :           *
*               SIG(el) + SIG(inel) = SIHNEL + SIHNIN .              *
*   Total antiproton-proton cross sections calculated with DTUJET92  *
*   parametrize the cross sections at higher enrgies.                *
**********************************************************************
 
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      CHARACTER*8  ANAME
      COMMON /DPAR/ ANAME(210),AAM(210),GA(210),TAU(210),IICH(210),
     &              IIBAR(210),K1(210),K2(210)
      COMMON /STRUFU/ISTRUM,ISTRUT
      DIMENSION SQS(20),SIIV(20),SQS22(40),SIIV22(40)
      DATA SQS /20.,50.,100.,200.,500.,1000.,1500.,2000.,3000.,
     *4000.,6000.,8000.,10000.,15000.,20000.,30000.,40000.,
     *60000.,80000.,100000/
      DATA SIIV /41.6,44.6,47.9,52.3,60.,67.2,71.4,75.,79.,82.4,
     *87.2,90.4,93.2,97.3,100.7,104.7,107.9,111.7,114.7,117.2/
      DATA SQS22 /
     *53.,69.,91.,119.,156.,205.,268.,351.,460.,603.,
     *790.,1036.,1357.,1778.,2329.,
     *3053.,3999.,5239.,6865.,8994.,
     *11785.,15441.,20232.,26509.,34733.,
     *45509.,59627.,78126.,102365.,134123.,
     *175734.,230255.,301690.,395288.,517925.,
     *678609.,889144.,1164997.,1526432.,2000000.
     */
      DATA SIIV22 /
     *44.3,45.3,46.5,47.8,49.3,51.0,53.0,55.3,57.9,60.9,
     *64.3,68.0,72.0,76.3,80.8,85.4,90.0,94.7,99.3,103.9,
     *108.4,112.8,117.2,121.4,125.6,
     *129.8,133.9,138.0,142.0,146.1,
     *150.2,154.3,158.5,162.7,166.9, 
     *171.2,175.6,180.0,184.6,189.1
     */
*
      F1 = 1.0D0
      CA = 0.0D0
      CB = 0.0D0
      CC = 0.0D0
      CD = 0.0D0
      CN = 0.0D0
*
      A1 = 0.0D0
      A2 = 0.0D0
      A3 = 1.0D0
      A4 = 0.0D0
      A5 = 0.0D0
      A6 = 0.0D0
*
      PARAM1  =   34.94235992
      PARAM4  =  0.2104312854
      PARAM5  = -0.4509592056E-01
*
      IPIO  = 0
      SPIO1 = 0.0D0
      SPIO2 = 0.0D0
*
      UMO2   = UMO**2
      EPN = (UMO**2-AAM(KPROJ)**2-AAM(KTARG)**2)/(2.0D0*AAM(KTARG))
      PO  = SQRT((EPN-AAM(KPROJ))*(EPN+AAM(KPROJ)))
*
    1 CONTINUE
*
      IF (KTARG.EQ.8) THEN
           GOTO( 30, 40,999,999,999,999,999, 10, 20,999,
     &          999,140, 70, 60,150,160,100, 20,140, 10,
     &           10, 10,110,130,120) KPROJ
      ELSE
           GOTO( 10, 20,999,999,999,999,999, 30, 40,999,
     &          999, 50, 60, 70, 80, 90,100, 20, 50, 10,
     &           10, 10,110,120,130) KPROJ
      ENDIF
*
   10 CONTINUE
*---------------------------- p - p , sigma0+- - p
      IF (PO.LE.3.0D0) THEN
         GOTO 500
      ELSE IF ((PO.GT.3.0D0).AND.(UMO.LE.100.0D0)) THEN
         CA = 48.0D0
         CC = 0.522D0
         CD = -4.51D0
         GOTO 600
      ELSE
         GOTO 700
      ENDIF
*
   20 CONTINUE
*---------------------------- pbar - p , Lambdabar - p
      IF (PO.LE.5.0D0) THEN
         GOTO 500
      ELSE IF ((PO.GT.5.0D0).AND.(UMO.LE.200.0D0)) THEN
         CA = 38.4D0
         CB = 77.6
         CC = 0.26D0
         CD = -1.2D0
         CN = -0.64D0
         GOTO 600
      ELSE
         GOTO 700
      ENDIF
*
   30 CONTINUE
*---------------------------- n - p
      IF (PO.LE.3.0D0) THEN
         GOTO 500
      ELSE IF ((PO.GT.3.0D0).AND.(PO.LE.370.0D0)) THEN
         CA = 47.3D0
         CC = 0.513D0
         CD = -4.27D0
         GOTO 600
      ELSE IF ((PO.GT.370.0D0).AND.(UMO.LE.110.0D0)) THEN
         A1 = 38.5D0
         A2 = 0.46D0
         A3 = 125.0D0
         A4 = 15.0D0
         GOTO 800
      ELSE
         GOTO 700
      ENDIF
*
   40 CONTINUE
*---------------------------- nbar - p
      IF (PO.LE.1.1D0) THEN
         GOTO 500
      ELSE IF ((PO.GT.1.1D0).AND.(PO.LE.280.0D0)) THEN
         CB = 133.6D0
         CC = -1.22D0
         CD = 13.7D0
         CN = -0.7D0
         GOTO 600
      ELSE IF ((PO.GT.280.0D0).AND.(UMO.LE.110.0D0)) THEN
         A1 = 38.5D0
         A2 = 0.46D0
         A3 = 125.0D0
         A4 = 15.0D0
         A5 = 77.43D0
         A6 = -0.6D0
         GOTO 800
      ELSE
         GOTO 700
      ENDIF
*
   50 CONTINUE
*---------------------------- Klong - p , Kshort - p
      R = RNDM(V)
      IF (R.LE.0.5D0) THEN
*                             K+ - p
         GOTO 80
      ELSE
*                             K- - p
         GOTO 90
      ENDIF
*
   60 CONTINUE
*---------------------------- pi+ - p
      IF (PO.LE.4.0D0) THEN
         GOTO 500
      ELSE IF ((PO.GT.4.0D0).AND.(PO.LE.340.0D0)) THEN
         CA = 16.4D0
         CB = 19.3D0
         CC = 0.19D0
         CN = -0.42D0
         GOTO 600
      ELSE IF ((PO.GT.340.0D0).AND.(UMO.LE.47.0D0)) THEN
         A1 = 24.0D0
         A2 = 0.6D0
         A3 = 160.0D0
         A5 = -7.9D0
         A6 = -0.46D0
         GOTO 800
      ELSE
         F1 = 2.0D0/3.0D0
         GOTO 10
      ENDIF
*
   70 CONTINUE
*---------------------------- pi- - p
      IF (PO.LE.2.5D0) THEN
         GOTO 500
      ELSE IF ((PO.GT.2.5D0).AND.(PO.LE.370.0D0)) THEN
         CA = 33.0D0
         CB = 14.0D0
         CC = 0.456D0
         CD = -4.03D0
         CN = -1.36D0
         GOTO 600
      ELSE IF ((PO.GT.370.0D0).AND.(UMO.LE.47.0D0)) THEN
         A1 = 24.0D0
         A2 = 0.6D0
         A3 = 160.0D0
         GOTO 800
      ELSE
         F1 = 2.0D0/3.0D0
         GOTO 10
      ENDIF
*
   80 CONTINUE
*---------------------------- K+ - p
      IF (PO.LE.2.0D0) THEN
         GOTO 500
      ELSE IF ((PO.GT.2.0D0).AND.(PO.LE.310.0D0)) THEN
         CA = 18.1D0
         CC = 0.26D0
         CD = -1.0D0
         GOTO 600
      ELSE IF ((PO.GT.310.0D0).AND.(UMO.LE.110.0D0)) THEN
         A1 = 20.3D0
         A2 = 0.59D0
         A3 = 140.0D0
         A5 = -30.13D0
         A6 = -0.58D0
         GOTO 800
      ELSE
         F1 = 2.0D0/3.0D0
         GOTO 10
      ENDIF
*
   90 CONTINUE
*---------------------------- K- - p
      IF (PO.LE.3.0D0) THEN
         GOTO 500
      ELSE IF ((PO.GT.3.0D0).AND.(PO.LE.310.0D0)) THEN
         CA = 32.1D0
         CC = 0.66D0
         CD = -5.6D0
         GOTO 600
      ELSE IF ((PO.GT.310.0D0).AND.(UMO.LE.110.0D0)) THEN
         A1 = 20.3D0
         A2 = 0.59D0
         A3 = 140.0D0
         GOTO 800
      ELSE
         F1 = 2.0D0/3.0D0
         GOTO 10
      ENDIF
*
  100 CONTINUE
*---------------------------- Lambda - p
      IF (PO.LE.0.6D0) THEN
         GOTO 500
      ELSE IF ((PO.GT.0.6D0).AND.(PO.LE.21.0D0)) THEN
         CA = 30.4D0
         CD = 1.6D0
         GOTO 600
      ELSE
         GOTO 10
      ENDIF
*
  110 CONTINUE
*---------------------------- pi0 - p
*                             1/2(pi+p + pi-p)
      IPIO  = 1
      KPROJ = 13
      GOTO 1
*
  120 CONTINUE
*---------------------------- K0 - p
      IF (PO.LE.2.0D0) THEN
         GOTO 500
      ELSE IF ((PO.GT.2.0D0).AND.(PO.LE.310.0D0)) THEN
*                             K+ - n
         CA = 18.7D0
         CC = 0.21D0
         CD = -0.89D0
         GOTO 600
      ELSE
         GOTO 80
      ENDIF
*
  130 CONTINUE
*---------------------------- K0bar - p
      IF (PO.LE.1.8D0) THEN
         GOTO 500
      ELSE IF ((PO.GT.1.8D0).AND.(PO.LE.310.0D0)) THEN
*                             K- - n
         CA = 25.2D0
         CC = 0.38D0
         CD = -2.9D0
         GOTO 600
      ELSE
         GOTO 90
      ENDIF
*
  140 CONTINUE
*---------------------------- Klong - n , Kshort - n
      R = RNDM(V)
      IF (R.LE.0.5D0) THEN
*                             K+ - n
         GOTO 150
      ELSE
*                             K- - n
         GOTO 160
      ENDIF
*
  150 CONTINUE
*---------------------------- K+ - n
      IF (PO.LE.2.0D0) THEN
         GOTO 500
      ELSE IF ((PO.GT.2.0D0).AND.(PO.LE.310.0D0)) THEN
         CA = 18.7D0
         CC = 0.21D0
         CD = -0.89D0
         GOTO 600
      ELSE
         GOTO 90
      ENDIF
*
  160 CONTINUE
*---------------------------- K- - n
      IF (PO.LE.1.8D0) THEN
         GOTO 500
      ELSE IF ((PO.GT.1.8D0).AND.(PO.LE.310.0D0)) THEN
         CA = 25.2D0
         CC = 0.38D0
         CD = -2.9D0
         GOTO 600
      ELSE
         GOTO 80
      ENDIF
*
  500 CONTINUE
      CALL SIHNEL(KPROJ,KTARG,PO,SEL)
      CALL SIHNIN(KPROJ,KTARG,PO,SIN)
      STOT = SEL + SIN
      GOTO 900
*
  600 CONTINUE
      STOT = F1*(CA+CB*PO**CN+CC*(LOG(PO))**2+CD*LOG(PO))
      GOTO 900
*
  700 CONTINUE
      IF(ISTRUM.EQ.14.AND.ISTRUT.EQ.2)THEN
	DO 701 I=1,20
	  IF(UMO.LE.SQS(I))GO TO 702
  701   CONTINUE
	I=20
  702   CONTINUE
	IF ((I.EQ.20).AND.(UMO.GT.SQS(20)))THEN
	  TEPP=SIIV(20)+(LOG(UMO)-LOG(SQS(20)))*(SIIV(20)-SIIV(19))/
     *         (LOG(SQS(20))-LOG(SQS(19)))
          STOT=F1*TEPP
	ELSE
	  TEPP=SIIV(I-1)+(UMO-SQS(I-1))*(SIIV(I)-SIIV(I-1))/
     *         (SQS(I)-SQS(I-1))
          STOT=F1*TEPP
	ENDIF
      ELSEIF(ISTRUM.EQ.22.AND.ISTRUT.EQ.2)THEN
	DO 711 I=1,40
	  IF(UMO.LE.SQS22(I))GO TO 712
  711   CONTINUE
	I=40
  712   CONTINUE
	IF ((I.EQ.40).AND.(UMO.GT.SQS22(40)))THEN
	  TEPP=SIIV22(40)+(LOG(UMO)-LOG(SQS22(40)))*
     *	  (SIIV22(40)-SIIV22(39))/
     *         (LOG(SQS22(40))-LOG(SQS22(39)))
          STOT=F1*TEPP
	ELSE
	  TEPP=SIIV22(I-1)+(UMO-SQS22(I-1))*(SIIV22(I)-SIIV22(I-1))/
     *         (SQS22(I)-SQS22(I-1))
          STOT=F1*TEPP
	ENDIF
      ELSE
        STOT = F1*(PARAM1+PARAM4*LOG(PO)**2+PARAM5*LOG(PO))
      ENDIF
      GOTO 900
*
  800 CONTINUE
      STOT = F1*(A1+A2*(LOG(UMO2/A3))**2+A4/UMO2+A5*UMO2**A6)
*
  900 CONTINUE
      IF ((IPIO.EQ.1).AND.(KPROJ.EQ.13)) THEN
         SPIO1 = STOT
         KPROJ = 14
         GOTO 1
      ENDIF
      IF ((IPIO.EQ.1).AND.(KPROJ.EQ.14)) THEN
         SPIO2 = STOT
         STOT = 0.5D0*(SPIO1+SPIO2)
      ENDIF
      DSHNTO = STOT
      RETURN
*
  999 CONTINUE
*-------------------------- leptons..
      DSHNTO = 1.E-10
      RETURN
      END
*
*===dshnel===============================================================*
*
      DOUBLE PRECISION FUNCTION DSHNEL(KPROJ,KTARG,UMO)
 
**********************************************************************
*   Elastic hadron-nucleon cross sections         S.Roesler 13/1/93  *
*                                                                    *
*   SIHNEL is called for c.m. energies below 50 GeV. Otherwise       *
*   a parametrisation of antiproton-proton elastic cross sections    *
*   obtained from DTUJET92 is used.                                  *
**********************************************************************
 
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      CHARACTER*8  ANAME
      COMMON /DPAR/ ANAME(210),AAM(210),GA(210),TAU(210),IICH(210),
     &              IIBAR(210),K1(210),K2(210)
*
      F1 = 1.0D0
      CA = 0.0D0
      CB = 0.0D0
      CC = 0.0D0
      CD = 0.0D0
      CN = 0.0D0
*
      IPIO  = 0
      SPIO1 = 0.0D0
      SPIO2 = 0.0D0
*
      PARAM1  =   7.789333344
      PARAM4  =  0.7488331199E-01
      PARAM5  = -0.6963931322
*
      UMO2   = UMO**2
      EPN = (UMO**2-AAM(KPROJ)**2-AAM(KTARG)**2)/(2.0D0*AAM(KTARG))
      PO  = SQRT((EPN-AAM(KPROJ))*(EPN+AAM(KPROJ)))
*
    1 CONTINUE
*
      GOTO( 10, 10,999,999,999,999,999, 10, 10,999,
     &     999, 30, 20, 20, 20, 20, 10, 10, 30, 10,
     &      10, 10, 40, 20, 20) KPROJ
*
   10 CONTINUE
      IF (UMO.LE.50.0D0) THEN
         CALL SIHNEL(KPROJ,KTARG,PO,SEL)
         GOTO 900
      ELSE
         F1 = 1.0D0
         GOTO 500
      ENDIF
*
   20 CONTINUE
      IF (UMO.LE.50.0D0) THEN
         CALL SIHNEL(KPROJ,KTARG,PO,SEL)
         GOTO 900
      ELSE
         F1 = 2.0D0/3.0D0
         GOTO 500
      ENDIF
*
   30 CONTINUE
*---------------------------- Klong - p , Kshort - p
      R = RNDM(V)
      IF (R.LE.0.5D0) THEN
*                             K+ - p
         KPROJ = 15
      ELSE
*                             K- - p
         KPROJ = 16
      ENDIF
      GOTO 1
*
   40 CONTINUE
*---------------------------- pi0 - p
*                             1/2(pi+p + pi-p)
      IPIO  = 1
      KPROJ = 13
      GOTO 1
*
  500 CONTINUE
      SEL = F1*(PARAM1+PARAM4*LOG(PO)**2+PARAM5*LOG(PO))
*
  900 CONTINUE
      IF ((IPIO.EQ.1).AND.(KPROJ.EQ.13)) THEN
         SPIO1 = SEL
         KPROJ = 14
         GOTO 1
      ENDIF
      IF ((IPIO.EQ.1).AND.(KPROJ.EQ.14)) THEN
         SPIO2 = SEL
         SEL = 0.5D0*(SPIO1+SPIO2)
      ENDIF
      DSHNEL = SEL
      RETURN
*
  999 CONTINUE
*-------------------------- leptons..
      DSHNEL = 1.E-10
      RETURN
      END
C------- name of the file ----------------------------------------------
C                          DTULAP.FOR
C
C Modified for initializations for NESTEP values of energy C.Forti-Apr 97
C______________________________________________________________________
C
C        originally: JTDTU.FOR program
C        connection between DTU and JT ( hard scattering )
*
C        first parameters are taken from DTU and set to the own
C        parameter-commons of JT, then JT will be initialized
C
C______________________________________________________________________
*     revision 3.92:  adjust COMMONS,
*     caraful: DTU90 was based on a older version of DTULAP
*  ********************************************************************
      SUBROUTINE JTDTU(IOPT)
*
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      PARAMETER ( MAXPRO = 8 , MLINE = 1000 , MSCAHD = 250 )
      COMMON /HAPARA/ ECM,PTINI(4),Q0SQR,ALASQR,BQCD,NPD,NF,NHA,NHB
      COMMON /HAENVI/ NINDEP
      COMMON /HAOUTL/ NOUTL,NOUTER,NOUTCO
      COMMON /HAPADI/ NPDM
      COMMON /HAQQAP/ AQQAL,AQQPD,NQQAL,NQQPD
      COMMON /OUTLEV/IOUTPO,IOUTPA,IOUXEV,IOUCOL
*
      CHARACTER*80 TITLE
      CHARACTER*80 TITLE0
      CHARACTER*8 PROJTY,TARGTY
      CHARACTER*8 PROJTY0,TARGTY0
      COMMON /USERLA1/TITLE,PROJTY,TARGTY
      COMMON /USERLA2/CMENER,SDFRAC,PTLAR,ISTRUF ,ISINGD,IDUBLD
      COMMON /USER1/TITLE0,PROJTY0,TARGTY0
      COMMON /USER2/CMENER0,SDFRAC0,PTLAR0,ISTRUF0,ISINGD0,IDUBLD0
      COMMON /COLLAP/S,IJPROJ,IJTAR,PTTHR,PTTHR2,IOPHRD,IJPRLU,IJTALU
      COMMON/COLLIS/ S0, IJPROJ0, IJTAR0, PTTHR0, PTTHR20, IOPHRD0,
     *               IJPRLU0, IJTALU0
C     COMMON /USER/TITLE,PROJTY,TARGTY,CMENER,ISTRUF
C    &            ,ISINGD,IDUBLD,SDFRAC,PTLAR
C     COMMON /USER1/TITLE,PROJTY,TARGTY
C     COMMON /USER2/CMENER,SDFRAC,PTLAR,ISTRUF,ISINGD,IDUBLD
*
C
C repl.      COMMON /COLLIS/ECMDTU,S,IJPROJ,IJTAR,PTTHR,IOPHRD,
C     *IJPRLU,IJTALU,PTTHR2
C     COMMON/COLLIS/S,IJPROJ,IJTAR,PTTHR,PTTHR2,IOPHRD,IJPRLU,IJTALU
C repl.      COMMON /COLLIS/ECMDTU,S,IJPROJ,IJTAR,PTTHR,IOPHRD,IJPRLU,IJTALU,PTTHR2
      COMMON /STRUFU/ISTRUM,ISTRUT
      COMMON /PTLARG/XSMAX
      COMMON /HAXSUM/XSHMX
C     COMMON /POMENE/POEN(20),POEN1(20),POEN2(20),NESTEP
      COMMON /POMENE/POEN(28),POEN1(28),POEN2(28),NESTEP
C     COMMON /LAPENE/PTTHRZ(20),PTTHZ2(20),INDENE
      COMMON /LAPENE/PTTHRZ(28),PTTHZ2(28),INDENE
C
C                              Fill COLLAP COMMON Block
      S      = S0
      IJPROJ = IJPROJ0
      IJTAR  = IJTAR0
      PTTHR  = PTTHR0
      IOPHRD = IOPHRD0
      IJPRLU = IJPRLU0
      IJTALU = IJTALU0
      PTTHR2 = PTTHR20
C                              Fill USERLA COMMON Block
      TITLE  = TITLE0
      PROJTY = PROJTY0
      TARGTY = TARGTY0
      CMENER = CMENER0
      ISTRUF = ISTRUF0
      ISINGD = ISINGD0
      IDUBLD = IDUBLD0
      SDFRAC = SDFRAC0
      PTLAR  = PTLAR0
C                               define NESTEP values of PTTHRZ 
      DO 101 III=1,NESTEP
	PTTHRZ(III)=3.
	PTTHZ2(III)=3.
        IF(ISTRUT.EQ.1)THEN
          PTTHRZ(III)=2.1+0.15*(LOG10(POEN(III)/50.))**3
          PTTHZ2(III)=PTTHRZ(III)
        ELSEIF(ISTRUT.EQ.2)THEN
          PTTHRZ(III)=2.5+0.12*(LOG10(POEN(III)/50.))**3
          PTTHZ2(III)=PTTHRZ(III)
        ENDIF
  101 CONTINUE
      INDENE=1
C
C===read default values
C
      CALL HASTRT
C
C===read parameters from DTU
C
C  max. # of flavors
      NF = 4
C  partondistributions
      NPD  = ISTRUF
      NPDM = ISTRUM
C  correct scale for CTEQ PDFs
      IF((ISTRUF.GE.16).OR.(ISTRUF.LE.20)) THEN
        AQQAL = 1.D0
        AQQPD = 1.D0
      ENDIF
C  hadron a
      NHA  = IJPROJ
      IF ( IJPROJ.EQ.2 ) NHA =-1
C  hadron b
      NHB  = IJTAR
      IF ( IJTAR .EQ.2 ) NHB =-1
C  output level
      NOUTL = IOUTPA
C  cms-energy ( GeV )
C repl    ECM=ECMDTU
C                                  LOOP over NESTEP Energies
      DO 201 INDENE=1,NESTEP
C       ECM = CMENER
        ECM = POEN(INDENE)
C                  pt-cut ( GeV )
C       PTINI(1) = PTTHR
C       PTINI(2) = PTTHR2
        PTINI(1) = PTTHRZ(INDENE)
        PTINI(2) = PTTHZ2(INDENE)
        PTINI(3) = 0.0
        PTINI(4) = 0.0
C                 maximum sum of hard x
        XSHMX    = XSMAX
C
C is program called from DTU ( NINDEP=0 ) or independent ( NINDEP=1 )
        NINDEP   = IOPT
C     ECM = CMENER
C  pt-cut ( GeV )
C     PTINI(1) = PTTHR
C     PTINI(2) = PTTHR2
C     PTINI(3) = 0.0
C     PTINI(4) = 0.0
C  maximum sum of hard x
C     XSHMX    = XSMAX
C  is program called from DTU ( NINDEP=0 ) or independent ( NINDEP=1 )
C     NINDEP   = IOPT
C
C===initialize JT
C
        CALL HISINII
        IF ( IOPT.EQ.0 ) CALL HARINI
  201 CONTINUE	
      RETURN
      END
C
C******************************************************************************
      SUBROUTINE SELHRD(MHARD,IJPVAL,IJTVAL,PTTHRE)
C
C   select the initial parton x-fractions and flavors and the final flavors
C           for an event with mhard hard or semihard scatterings
C
C   IJPVAL,IJTVAL =0 valence quarks of projectile or target not involved
C                                                     in hard scattering
C   IJPVAL,IJTVAL =1 valence quarks of projectile or target  involved
C                                                     in hard scattering
C
C the results are in COMMON /ABRHRD/
C               XH1(I),XH2(I):     x-values of initial partons
C               IJHI1(I),IJHI2(I): flavor of initial parton
C                                  0            gluon
C                                  1,2          valence u,d quarks
C                                  11,12,13,14  sea udsc-quarks
C                                  negative     anti s or v quarks
C               IJHF1(I),IJHF2(I): flavor of final state partons
C               PHARD1(I,J),PHARD2(I,J): final part. momentum and energy
C                                J=1   PX
C                                 =2   PY
C                                 =3   PZ
C                                 =4   ENERGY  (massless partons)
C-----------------------------------------------------------------------
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      PARAMETER ( MAXPRO = 8 , MLINE = 1000 , MSCAHD = 250 )
*
      CHARACTER*80 TITLE
      CHARACTER*80 TITLE0
      CHARACTER*8 PROJTY,TARGTY
      CHARACTER*8 PROJTY0,TARGTY0
      COMMON /USERLA1/TITLE,PROJTY,TARGTY
      COMMON /USERLA2/CMENER,SDFRAC,PTLAR,ISTRUF ,ISINGD,IDUBLD
      COMMON /USER1/TITLE0,PROJTY0,TARGTY0
      COMMON /USER2/CMENER0,SDFRAC0,PTLAR0,ISTRUF0,ISINGD0,IDUBLD0
      COMMON /COLLAP/S,IJPROJ,IJTAR,PTTHR,PTTHR2,IOPHRD,IJPRLU,IJTALU
      COMMON/COLLIS/ S0, IJPROJ0, IJTAR0, PTTHR0, PTTHR20, IOPHRD0,
     *               IJPRLU0, IJTALU0
*
C     COMMON /USER/TITLE,PROJTY,TARGTY,CMENER,ISTRUF
C    &            ,ISINGD,IDUBLD,SDFRAC,PTLAR
C     COMMON /USER1/TITLE,PROJTY,TARGTY
C     COMMON /USER2/CMENER,SDFRAC,PTLAR,ISTRUF,ISINGD,IDUBLD
C     COMMON/COLLIS/S,IJPROJ,IJTAR,PTTHR,PTTHR2,IOPHRD,IJPRLU,IJTALU
      COMMON /ABRHRD/XH1(MSCAHD),XH2(MSCAHD),IJHI1(MSCAHD),
     *IJHI2(MSCAHD),IJHF1(MSCAHD),IJHF2(MSCAHD),PHARD1(MSCAHD,4),
     *PHARD2(MSCAHD,4)
      COMMON /OUTLEV/IOUTPO,IOUTPA,IOUXEV,IOUCOL
      COMMON /HAPARA/ ECM,PTINI(4),Q0SQR,ALASQR,BQCD,NPD,NF,NHA,NHB
      COMMON /HAOUTL/ NOUTL,NOUTER,NOUTCO
      COMMON /HAEVTR/ LINE,LIN,LREC1(MLINE),LREC2(MLINE),PREC(0:3,MLINE)
      COMMON /HARSLT/ LSCAHD,LSC1HD,
     &                ETAHD(MSCAHD,2) ,PTHD(MSCAHD),
     &                XHD(MSCAHD,2)   ,VHD(MSCAHD) ,X0HD(MSCAHD,2),
     &                NINHD(MSCAHD,2) ,NOUTHD(MSCAHD,2),
     &                N0INHD(MSCAHD,2),NBRAHD(MSCAHD,2),NPROHD(MSCAHD)
C     COMMON /POMENE/POEN(20),POEN1(20),POEN2(20),NESTEP
      COMMON /POMENE/POEN(28),POEN1(28),POEN2(28),NESTEP
      COMMON /LAPENE/PTTHRZ(28),PTTHZ2(28),INDENE
      DATA X1SU/0./ , X2SU/0./
C
C                                 Calculate energy index INDENE
      CMENER=CMENER0
      ECM=CMENER
      INDENE=1
      DO 1120 II=1,NESTEP
	IF(CMENER0.GE.POEN1(II).AND.CMENER0.LT.POEN2(II))THEN
          INDENE=II
	  GO TO 1122
        ENDIF
 1120 CONTINUE
 1122 CONTINUE
C     INDENE=1
      PTINI(1) = PTTHRZ(INDENE)
      PTINI(2) = PTTHZ2(INDENE)
C
      IJPVAL =0
      IJTVAL =0
      IF (IOUTPA.GE.3) WRITE(6,221)
     *                  MHARD,IJPVAL,IJTVAL
  221 FORMAT (' SELHRD  ',3I10)
C  call of hard scattering routines
      CALL HAREVT(MHARD,PTTHR2)
C      WRITE(6,*)'SELHRD:CMENER,MHARD,PTTHR2,INDENE,PTINI(1),PTINI(2)',
C    * CMENER,MHARD,PTTHR2,INDENE,PTINI(1),PTINI(2)
C  select information from event-record
C   number of hard scatterings reached
      MHARD = LSCAHD
C   initial partons
      DO 10 N=1,LSCAHD
C    X-values
        XH1(N) = XHD(N,1)
        XH2(N) = XHD(N,2)
        X1SU = X1SU + XH1(N)
        X2SU = X2SU + XH2(N)
        IF( IOUTPA.GT. 6 )WRITE(6,*)N,X1SU,X2SU,XH1(N),XH2(N)
C    flavors
        III      = NINHD(N,1)
        IIIA     = ABS(III)
        IF ( IIIA.GT. 0 .AND. IIIA.LT.10 ) III    = SIGN(IIIA+10,III)
        IF ( IIIA.GE.10                  ) III    = SIGN(IIIA-10,III)
        IF ( IIIA.GE.10                  ) IJPVAL = 1
        IJHI1(N) = III
        III      = NINHD(N,2)
        IIIA     = ABS(III)
        IF ( IIIA.GT. 0 .AND. IIIA.LT.10 ) III    = SIGN(IIIA+10,III)
        IF ( IIIA.GE.10                  ) III    = SIGN(IIIA-10,III)
        IF ( IIIA.GE.10                  ) IJTVAL = 1
        IJHI2(N) = III
10      CONTINUE
C   final partons
      DO 30 N=1,LSCAHD
        I3     = 4*N-1
        I4     = 4*N
C    flavors
        IJHF1(N) = NOUTHD(N,1)
        IJHF2(N) = NOUTHD(N,2)
C    four momentum
        DO 20 J=1,3
          PHARD1(N,J) = PREC(J,I3)
20        PHARD2(N,J) = PREC(J,I4)
        PHARD1(N,4)   = PREC(0,I3)
        PHARD2(N,4)   = PREC(0,I4)
30    CONTINUE
C
C   output ( optional )
C
      IF (IOUTPA.GE.3)WRITE (6,101)
  101 FORMAT(' SELHRD OUTPUT FOR INITIAL STATE SCATTERED PARTONS')
      DO 102 I=1,LSCAHD
        IF (IOUTPA.GE.3)
     *    WRITE (6,103)I,IJPVAL,IJTVAL,IJHI1(I),IJHI2(I),XH1(I),XH2(I)
  103   FORMAT (' I,IJPVAL,IJTVAL,IJHI1,IJHI2,XH1,XH2= ',5I5,2F12.6)
  102 CONTINUE
      IF (IOUTPA.GE.3)WRITE (6,301)
  301 FORMAT(' SELHRD OUTPUT FOR FINAL STATE SCATTERED PARTONS')
      DO 302 I=1,LSCAHD
        IF (IOUTPA.GE.3)
     *    WRITE (6,303)I,IJHF1(I),IJHF2(I),(PHARD1(I,III),III=1,4)
        IF (IOUTPA.GE.3)
     *    WRITE (6,303)I,IJHF1(I),IJHF2(I),(PHARD2(I,III),III=1,4)
  303   FORMAT (' I,IJHI1,IJHI2,PHARD1 OR PHARD2 ',3I5,4F16.6)
  302 CONTINUE
      RETURN
      END
*
C______________________________________________________________________
C
C        originally:  JTWORK.FOR
C        procedures to simulate a single event
C
C
C     ( this procedures work independent to procedures in other blocks
C       if initialization was done )
C
C______________________________________________________________________
*
*  ********************************************************************
      SUBROUTINE HAREVT(MHARD,PT1IN)
*
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      PARAMETER ( MAXPRO = 8 , MLINE = 1000 , MSCAHD = 250 )
      COMMON /HAPARA/ ECM,PTINI(4),Q0SQR,ALASQR,BQCD,NPD,NF,NHA,NHB
      COMMON /HAENVI/ NINDEP
      COMMON /HAEVNT/ PT1,PT2,NHARD,NTRY,IHARD,ITRY,IREJEV

      PT1    = MAX(PT1IN,PTINI(1))
      PT2    = PTINI(1)
      NHARD  = MHARD
      IHARD  = 0
C     NTRY   = 5
      NTRY   = 200
C      NTRY   = 1000
      ITRY   = 0
      IREJEV = 0
      CALL HAMULT
      CALL HAOUTP
      IF ( NINDEP.EQ.1 ) CALL HISFIL2
      RETURN
      END
C_______________________________________________________________________
C===========================================================================
C
C       THE FOLLOWING 5 SUBROUTINES ARE REWRITTEN BY
C        BY I.KAWRAKOW  IN ORDER TO BE ABLE 
C         TO PRODUCE GREAT NUMBER OF HARD POMERONS (>100) IN A 
C          SHORT TIME
C                                          VERSION IK.1 - 01.93
C--------------------------------------------------------------------     
      SUBROUTINE HAMULT
C--------------------------------------------------------------------
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      PARAMETER ( MAXPRO = 8 , MLINE = 1000 , MSCAHD = 250 )
      PARAMETER ( TINY= 1.D-30, ONE=1.D0, ZSMALL=1.D-3 )
      COMMON /HAPARA/ ECM,PTINI(4),Q0SQR,ALASQR,BQCD,NPD,NF,NHA,NHB
      COMMON /HAPDCO/ NPDCOR
      COMMON /HAOUTL/ NOUTL,NOUTER,NOUTCO
      COMMON /HAEVNT/ PT1,PT2,NHARD,NTRY,IHARD,ITRY,IREJEV
      COMMON /HASCA / PTWANT,A,ALN,Z1MAX,Z1DIF,Z2MAX,Z2DIF,
     &                PT,ETAC,ETAD,X1,X2,V,U,W,W1,AXX,WEIGHT,MSPR,IREJSC
      COMMON /HAXIK / XREST,YREST,ZMAX,AXXMAX,WEMAX
      COMMON /HAEVTR/ LINE,LIN,LREC1(MLINE),LREC2(MLINE),PREC(0:3,MLINE)
      COMMON /HAXSUM/XSHMX
      INTEGER MXSECT
C     COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4,20),XSECT(5,-1:MAXPRO,20),
C    &                MXSECT(0:2,-1:MAXPRO,20)
      COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4,28),XSECT(5,-1:MAXPRO,28),
     &                MXSECT(0:2,-1:MAXPRO,28)
C     COMMON /LAPENE/PTTHRZ(20),PTTHZ2(20),INDENE
      COMMON /LAPENE/PTTHRZ(28),PTTHZ2(28),INDENE
C     COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4),XSECT(5,-1:MAXPRO),
C    &                MXSECT(0:2,-1:MAXPRO)
      COMMON /HARSLT/ LSCAHD,LSC1HD,
     &                ETAHD(MSCAHD,2) ,PTHD(MSCAHD),
     &                XHD(MSCAHD,2)   ,VHD(MSCAHD) ,X0HD(MSCAHD,2),
     &                NINHD(MSCAHD,2) ,NOUTHD(MSCAHD,2),
     &                N0INHD(MSCAHD,2),NBRAHD(MSCAHD,2),NPROHD(MSCAHD)
      ITYPE(L)      = MOD(LREC1(L),100)-50

      LINE   = 0
      LSCAHD = 0
C     WRITE(6,*)' hamult:ECM',ECM
      AA     = (2.*PT2/ECM)**2
      SA     = SQRT(AA)      
C
C  loop until event is accepted or too many attempts ( more then NTRY )
C
5     ITRY   = 0
20    ITRY   = ITRY+1
      IF(ITRY.GT.NTRY) GOTO 301
      LINE   = 0
      XREST    = XSHMX-NHARD*SA
      YREST    = XSHMX-NHARD*SA
      IF(XREST*YREST.LT.AA) THEN
C       WRITE(6,*) ' ****************** HAMULT ****************** '
C       WRITE(6,*) ' IT IS NOT POSSIBLE TO PRODUCE ',NHARD,' POMERONS '
        NHARD=0
        RETURN
C       STOP
      ENDIF	
      ZMAX=XREST*YREST
C     WRITE(6,*)' hamult:ZMAX',ZMAX      
      AXXMAX=AA/ZMAX
      WEMAX =SQRT(1-AXXMAX)
      X1S    = 0.0
      X2S    = 0.0
      IHARD  = 0
      PTWANT = PT1
10    CONTINUE
        A        = (2.*PTWANT/ECM)**2
        SA       = SQRT(A)
        I = 5
50      I = I-1
        IF ( PT1.LT.PTINI(I) .AND. I.GT.1 ) GOTO 50
        DO 60 M=-1,MAXPRO
C           XSECT(1,M) = XSECTA(1,M,I)
C           XSECT(2,M) = XSECTA(2,M,I)
            XSECT(1,M,INDENE) = XSECTA(1,M,I,INDENE)
            XSECT(2,M,INDENE) = XSECTA(2,M,I,INDENE)
60     CONTINUE
       CALL HARSCA
       X1S   = X1S+X1
       X2S   = X2S+X2
       xrest=xrest-x1+sa
       yrest=yrest-x2+sa
       zmax=xrest*yrest
       IHARD=IHARD+1
       LSCAHD         = IHARD
       XHD(IHARD,1)   = X1
       XHD(IHARD,2)   = X2
       VHD(IHARD)     = V
       ETAHD(IHARD,1) = ETAC
       ETAHD(IHARD,2) = ETAD
       PTHD(IHARD)    = PT
       NPROHD(IHARD)  = MSPR
C      WRITE(6,*)'hamult:a',A       
       if(zmax/a-one.lt.ZSMALL) THEN
C        CALL XCHECK(X1S,X2S,LINMAX)
         IF(IHARD.GE.1)then
           CALL XCHECK(X1S,X2S,LINMAX)
c dh 21.12.2000   begin
           if (IHARD.EQ.0) then
             NHARD=0
             RETURN
           endif
         endif
c dh  21.12.2000   end
	 IF(IHARD.EQ.0) WRITE(6,*)' HAMULT: IHARD=0'
	 GOTO 10 
       ENDIF	 
       AXXMAX=A/ZMAX
       WEMAX=SQRT(1.-AXXMAX)
       PTWANT   = PT2
       IF(IHARD.LT.NHARD) GOTO 10
C-------------------------------------------------- NOW THE REQUIRED NUMBER
C                                              OF POMERTONS IS CREATED       
      IF ( NPDCOR.EQ.1     .AND.
     &     IHARD .GT.1     .AND.
     &     (1.-X1S)*(1.-X2S).LT.RNDM(AI)*(1.-AA*IHARD)**2 ) GOTO 5
 301  CONTINUE 
C
C  end of loop
C
C  check choice of valence quarks
      DO 120 K=1,2
        IVAL  = 0
        DO 110 I=1,IHARD
          IND = 4*(I-1)+K
          IT  = ITYPE(IND)
          IF ( ABS(IT).GT.10 .AND. IVAL.EQ.0 ) THEN
            IVAL       = 1
          ELSEIF ( ABS(IT).GT.10 .AND. IVAL.EQ.1 ) THEN
            IT         = SIGN(ABS(IT)-10,IT)
            LREC1(IND) = (LREC1(IND)/100)*100+50+IT
          ENDIF
C  fill COMMON HARSLT
          NINHD(I,K)   = IT
          NOUTHD(I,K)  = ITYPE(IND+2)
110     CONTINUE
120   CONTINUE
C
C  information if HAMULT is not able to produce the required # of scatt.
C
      IF ( IHARD.NE.NHARD .AND. NOUTER.EQ.1 ) THEN
        WRITE(6,1010) NHARD,IHARD
1010    FORMAT(' ###### HAMULT : CANNOT PRODUCE',I3,' HARD SCATT.',
     &         '; ONLY',I3,' ARE PRODUCED !!!')
      ENDIF
      RETURN
      END

C______________________________________________________________________
      SUBROUTINE RECCHK( LINMAX,X,IOPT )
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      PARAMETER ( MAXPRO = 8 , MLINE = 1000 , MSCAHD = 250 )
      COMMON /HAPARA/ ECM,PTINI(4),Q0SQR,ALASQR,BQCD,NPD,NF,NHA,NHB
      COMMON /HAPDCO/ NPDCOR
      COMMON /HAOUTL/ NOUTL,NOUTER,NOUTCO
      COMMON /HAEVNT/ PT1,PT2,NHARD,NTRY,IHARD,ITRY,IREJEV
      COMMON /HASCA / PTWANT,A,ALN,Z1MAX,Z1DIF,Z2MAX,Z2DIF,
     &                PT,ETAC,ETAD,X1,X2,V,U,W,W1,AXX,WEIGHT,MSPR,IREJSC
      COMMON /HAEVTR/ LINE,LIN,LREC1(MLINE),LREC2(MLINE),PREC(0:3,MLINE)
      INTEGER MXSECT
C     COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4,20),XSECT(5,-1:MAXPRO,20),
C    &                MXSECT(0:2,-1:MAXPRO,20)
      COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4,28),XSECT(5,-1:MAXPRO,28),
     &                MXSECT(0:2,-1:MAXPRO,28)
C     COMMON /LAPENE/PTTHRZ(20),PTTHZ2(20),INDENE
      COMMON /LAPENE/PTTHRZ(28),PTTHZ2(28),INDENE
C     COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4),XSECT(5,-1:MAXPRO),
C    &                MXSECT(0:2,-1:MAXPRO)
      COMMON /HARSLT/ LSCAHD,LSC1HD,
     &                ETAHD(MSCAHD,2) ,PTHD(MSCAHD),
     &                XHD(MSCAHD,2)   ,VHD(MSCAHD) ,X0HD(MSCAHD,2),
     &                NINHD(MSCAHD,2) ,NOUTHD(MSCAHD,2),
     &                N0INHD(MSCAHD,2),NBRAHD(MSCAHD,2),NPROHD(MSCAHD)
C
      IF( IOPT.EQ.0 ) THEN
        LSTART = LINMAX + 1
        DO 1 L = LSTART,LINE
             LP = L - 4
          PREC(1,LP) = PREC(1,L)
          PREC(2,LP) = PREC(2,L)
          PREC(3,LP) = PREC(3,L)
          PREC(0,LP) = PREC(0,L)
          LREC1( LP) = LREC1( L)
          LREC2( LP) = LREC2( L)
   1    CONTINUE
        LINE = LINE - 4
        RETURN
      ELSEIF( IOPT.EQ.1 ) THEN
        QTEST = 0.5*ECM*X
        DO 2 L=1,LINE
          PTEST = PREC(0,L)
          IF( PTEST.EQ.QTEST ) THEN
            LINMAX = L
            RETURN
          ENDIF
   2    CONTINUE
        WRITE(6,*)'  RECCHK: NO NEW LINMAX FOUND - LINMAX=',LINMAX
        RETURN
      ENDIF
      WRITE(6,*)'  RECCHK: IOPT OUT OF RANGE - 0 OR 1 - IOPT=',IOPT
      RETURN
      END
C______________________________________________________________________
      SUBROUTINE XCHECK( X1S, X2S, LINMAX )
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      PARAMETER ( MAXPRO = 8 , MLINE = 1000 , MSCAHD = 250 )
      COMMON /HAPARA/ ECM,PTINI(4),Q0SQR,ALASQR,BQCD,NPD,NF,NHA,NHB
      COMMON /HAPDCO/ NPDCOR
      COMMON /HAOUTL/ NOUTL,NOUTER,NOUTCO
      COMMON /HAEVNT/ PT1,PT2,NHARD,NTRY,IHARD,ITRY,IREJEV
      COMMON /HASCA / PTWANT,A,ALN,Z1MAX,Z1DIF,Z2MAX,Z2DIF,
     &                PT,ETAC,ETAD,X1,X2,V,U,W,W1,AXX,WEIGHT,MSPR,IREJSC
      COMMON /HAXIK / XREST,YREST,ZMAX,AXXMAX,WEMAX
      COMMON /HAEVTR/ LINE,LIN,LREC1(MLINE),LREC2(MLINE),PREC(0:3,MLINE)
      COMMON /HAXSUM/XSHMX
      INTEGER MXSECT
C     COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4,20),XSECT(5,-1:MAXPRO,20),
C    &                MXSECT(0:2,-1:MAXPRO,20)
      COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4,28),XSECT(5,-1:MAXPRO,28),
     &                MXSECT(0:2,-1:MAXPRO,28)
C     COMMON /LAPENE/PTTHRZ(20),PTTHZ2(20),INDENE
      COMMON /LAPENE/PTTHRZ(28),PTTHZ2(28),INDENE
C     COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4),XSECT(5,-1:MAXPRO),
C    &                MXSECT(0:2,-1:MAXPRO)
      COMMON /HARSLT/ LSCAHD,LSC1HD,
     &                ETAHD(MSCAHD,2) ,PTHD(MSCAHD),
     &                XHD(MSCAHD,2)   ,VHD(MSCAHD) ,X0HD(MSCAHD,2),
     &                NINHD(MSCAHD,2) ,NOUTHD(MSCAHD,2),
     &                N0INHD(MSCAHD,2),NBRAHD(MSCAHD,2),NPROHD(MSCAHD)
      PARAMETER (ONE=1D0, ZSMALL=1D-3)
C
50    CONTINUE
      IF(IHARD.LT.1) THEN
        WRITE(6,*) '  ERROR IN XCHECK : IHARD < 1 ',IHARD
*       STOP
c dh 21.12.2000
        RETURN
      ENDIF	
C-------------------------------------- FIND PROCESS WITH THE MAX. X
      IMAX=0
      XMAX=0.
      DO 10 I=1,IHARD
        IF(XHD(I,1).GT.XMAX) THEN
	  IMAX=I
	  XMAX=XHD(I,1)
	ENDIF
	IF(XHD(I,2).GT.XMAX) THEN
	  IMAX=I
	  XMAX=XHD(I,2)
	ENDIF
10    CONTINUE
C--------------------------------------- REJECT THIS PROCESS
      X1S=X1S-XHD(IMAX,1)
      X2S=X2S-XHD(IMAX,2)
      XREST=XREST+XHD(IMAX,1)-SQRT(A)
      YREST=YREST+XHD(IMAX,2)-SQRT(A)
      ZMAX=XREST*YREST	    
      AXXMAX=A/ZMAX
      WEMAX=SQRT(1.-AXXMAX)
      MH=0
      DO 20 I=1,IHARD
        IF(I.NE.IMAX) THEN
	  MH=MH+1
          XHD(MH,1)   = XHD(I,1)
          XHD(MH,2)   = XHD(I,2)
          VHD(MH)     = VHD(I)
          ETAHD(MH,1) = ETAHD(I,1)
          ETAHD(MH,2) = ETAHD(I,2)
          PTHD(MH)    = PTHD(I)
          NPROHD(MH)  = NPROHD(I)
	ENDIF
20    CONTINUE	  
      CALL RECCHK( 4*IMAX,XHD1,0)
      IHARD=IHARD-1
      LSCAHD=IHARD
      IF(ZMAX/A-ONE.LT.ZSMALL) GOTO 50
      RETURN
      END
C_______________________________________________________
      SUBROUTINE HAX1X2
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      COMMON /HAEVNT/ PT1,PT2,NHARD,NTRY,IHARD,ITRY,IREJEV
      COMMON /HASCA / PTWANT,A,ALN,Z1MAX,Z1DIF,Z2MAX,Z2DIF,
     &                PT,ETAC,ETAD,X1,X2,V,U,W,W1,AXX,WEIGHT,MSPR,IREJSC
C      COMMON /HAXIK / XREST,YREST,ZMAX
      COMMON /HAXIK / XREST,YREST,ZMAX,AXXMAX,WEMAX
      PARAMETER ( TINY= 1.D-30, ONE=1.D0 ,TINY6=1.D-06)

      SA=SQRT(A)
12    continue
c--------------------------------- sample z=x*y
      z=a*Exp(rndm(1.D0)*Log(zmax/a))
      xm=xrest
      ym=yrest
      if(xm.lt.yrest) then
        xm=yrest
        ym=xrest
      endif   
      ww=Log(xm**2/z)/Log(xm**2/a)
      if(rndm(1.1D0).gt.ww) goto 12
c--------------------------------- sample u=x+y
      umin=Sqrt(4.*z)
      umax=xm+z/xm
      cc=umax**2-4.*z
      if(cc.lt.0.) cc=0.
      ICOUN=0
13    continue
      ICOUN=ICOUN+1
      c=Exp(rndm(2.D0)*Log((umax+Sqrt(cc))/umin))
      uu=umin*(c**2+1.)/2./c
      if(ICOUN.LT.50.AND.uu.gt.2.*ym.and.uu.lt.ym+z/ym) goto 13
c------------------------------------- x,y from u,z
      c=uu**2-4.*z
      if(c.lt.0.)  c=0.
      c=sqrt(c)
      xtemp=(uu+c)/2.
      ytemp=(uu-c)/2.
      if(xrest.ge.yrest) then
         x=xtemp
         y=ytemp
         if(xrest.eq.yrest) then
           if(rndm(3.D0).gt.0.5) then
             x=ytemp
             y=xtemp
           endif
         endif
      else
         x=ytemp
         y=xtemp
      endif
      X1=X
      X2=Y
      AXX  = A/(X1*X2)
      W    = SQRT(MAX(TINY,ONE-AXX))
      W1   = AXX/(1.+W)
      RETURN
      END
C______________________________________________________________________
      SUBROUTINE HARKIN
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      PARAMETER ( MAXPRO = 8 , MLINE = 1000 , MSCAHD = 250 )
      PARAMETER ( TINY= 1.D-30, ONE=1.D0 ,TINY6=1.D-06)
      COMMON /HAPARA/ ECM,PTINI(4),Q0SQR,ALASQR,BQCD,NPD,NF,NHA,NHB
      COMMON /HAEVNT/ PT1,PT2,NHARD,NTRY,IHARD,ITRY,IREJEV
      COMMON /HASCA / PTWANT,A,ALN,Z1MAX,Z1DIF,Z2MAX,Z2DIF,
     &                PT,ETAC,ETAD,X1,X2,V,U,W,W1,AXX,WEIGHT,MSPR,IREJSC
      DIMENSION RM(-1:MAXPRO)
      COMMON /HAXIK / XREST,YREST,ZMAX,AXXMAX,WEMAX
      DATA RM / 3.31, 0.0,
     &          3.80, 0.65, 2.00, 0.65, 0.89, 0.45, 0.445, 0.89 /
      M    = MSPR
      IF     ( M.EQ.1 ) THEN
10      CALL HAX1X2
        V  =-0.5*W1/(W1+RNDM(AI)*W)
        U  =-1.-V
        R  = (1.+W)*2.25*(V*V*(3.-U*V-V/(U*U))-U)
        RMAX=RM(1)*WEMAX*(1.+WEMAX)
        WIK=R*W/RMAX
        IF(WIK.GT.1.D0) WRITE(6,*) ' HARKIN : WIK > 1 : ',M,R
C        IF ( R*W.LT.RM(1)*RNDM(AI) ) GOTO 10
        IF(WIK.LT.RNDM(AI)) GOTO 10
        IF ( RNDM(AJ).LE.0.5D0 ) V = U
      ELSEIF ( M.EQ.2 .OR. M.EQ.4 ) THEN
20      CALL HAX1X2
        WL = LOG(W1)
        V  =-EXP(-0.6931472+RNDM(AI)*WL)
        U  =-1.-V
        R  = (U*U+V*V)*((16./27.)/U-(4./3.)*V)*(WL/W)*AXX
        IF ( R*W.LT.RM(M)*RNDM(AI) ) GOTO 20
        IF ( RNDM(AJ).LE.0.5D0 ) V = U
      ELSEIF ( M.EQ.3 ) THEN
30      CALL HAX1X2
        V  =-0.5*W1/(W1+RNDM(AI)*W)
        U  =-1.-V
        R  = (1.+W)*(1.+U*U)*(1.-(4./9.)*V*V/U)
        RMAX=RM(3)*WEMAX*(1.+WEMAX)
        WIK=R*W/RMAX
        IF(WIK.GT.1.D0) WRITE(6,*) ' HARKIN : WIK > 1 : ',M,R
C        IF ( R*W.LT.RM(3)*RNDM(AI) ) GOTO 30
        IF(WIK.LT.RNDM(AI)) GOTO 30
      ELSEIF ( M.EQ.5 ) THEN
50      CALL HAX1X2
        V  =-0.5*AXX/(W1+2.*RNDM(AI)*W)
        U  =-1.-V
        R  = (4./9.)*(1.+U*U+V*V*(U*U+V*V))-(8./27.)*U*U*V
        RMAX=RM(5)*WEMAX
        WIK=R*W/RMAX
        IF(WIK.GT.1.D0) WRITE(6,*) ' HARKIN : WIK > 1 : ',M,R
C        IF ( R*W.LT.RM(5)*RNDM(AI) ) GOTO 50
        IF(WIK.LT.RNDM(AI)) GOTO 50
      ELSEIF ( M.EQ.6 ) THEN
60      CALL HAX1X2
        V  =-0.5*(1.+W)+RNDM(AI)*W
        U  =-1.-V
        R  = (4./9.)*(U*U+V*V)*AXX
        IF ( R*W.LT.RM(6)*RNDM(AI) ) GOTO 60
      ELSEIF ( M.EQ.7 ) THEN
70      CALL HAX1X2
        V  =-0.5*W1/(W1+RNDM(AI)*W)
        U  =-1.-V
        R  = (1.+W)*((2./9.)*(1.+U*U+(1.+V*V)*V*V/(U*U))-(4./27.)*V/U)
        RMAX=RM(7)*WEMAX*(1.+WEMAX)
        WIK=R*W/RMAX
        IF(WIK.GT.1.D0) WRITE(6,*) ' HARKIN : WIK > 1 : ',M,R
C        IF ( R*W.LT.RM(7)*RNDM(AI) ) GOTO 70
        IF(WIK.LT.RNDM(AI)) GOTO 70
        IF ( RNDM(AJ).LE.0.5D0 ) V = U
      ELSEIF ( M.EQ.8 ) THEN
80      CALL HAX1X2
        V  =-0.5*AXX/(W1+2.*RNDM(AI)*W)
        U  =-1.-V
        R  = (4./9.)*(1.+U*U)
        RMAX=RM(8)*WEMAX
        WIK=R*W/RMAX
        IF(WIK.GT.1.D0) WRITE(6,*) ' HARKIN : WIK > 1 : ',M,R
C        IF ( R*W.LT.RM(8)*RNDM(AI) ) GOTO 80
        IF(WIK.LT.RNDM(AI)) GOTO 80
      ELSEIF ( M.EQ.-1 ) THEN
90      CALL HAX1X2
        WL = LOG(W1)
        V  =-EXP(-0.6931472+RNDM(AI)*WL)
        U  =-1.-V
        R  = (1.+V*V)*(V/(U*U)-(4./9.))*(WL/W)*AXX
        IF ( R*W.LT.RM(-1)*RNDM(AI) ) GOTO 90
      ENDIF
C      PARAMETER ( TINY= 1.D-30, ONE=1.D0 ,TINY6 =1.D-06)
      V    = MAX(MIN(      V,-TINY6 ),-1.+TINY6 )
      U    = MAX(MIN(-1.E0-V,-TINY6 ),-1.+TINY6 )
      PT   = SQRT(U*V*X1*X2)*ECM
      ETAC = 0.5*LOG((U*X1)/(V*X2))
      ETAD = 0.5*LOG((V*X1)/(U*X2))
      RETURN
      END
C-------------------------------------------- END OF CHANGES BY IK 01.93
C===========================================================================      
C_______________________________________________________________________

      SUBROUTINE HACHEK(IOPT)
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      COMMON /HACUTS/ PTL,PTU,ETACL,ETACU,ETADL,ETADU
      COMMON /HASCA / PTWANT,A,ALN,Z1MAX,Z1DIF,Z2MAX,Z2DIF,
     &                PT,ETAC,ETAD,X1,X2,V,U,W,W1,AXX,WEIGHT,MSPR,IREJSC

      IOPT = 1
      IF (  PT  .LT.PTL    .OR.  PT  .GT.PTU
     & .OR. ETAC.LT.ETACL  .OR.  ETAC.GT.ETACU
     & .OR. ETAD.LT.ETADL  .OR.  ETAD.GT.ETADU ) IOPT = 0
      RETURN
      END
C______________________________________________________________________
      SUBROUTINE HAFDIS(PDS,PDA,PDB,FDISTR)
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      PARAMETER ( MAXPRO = 8 , MLINE = 1000 , MSCAHD = 250 )
      PARAMETER ( TINY= 1.D-30, ONE=1.D0 ,TINY6=1.D-06)
      COMMON /HAPARA/ ECM,PTINI(4),Q0SQR,ALASQR,BQCD,NPD,NF,NHA,NHB
      COMMON /HAQQAP/ AQQAL,AQQPD,NQQAL,NQQPD
      COMMON /HAEVNT/ PT1,PT2,NHARD,NTRY,IHARD,ITRY,IREJEV
      COMMON /HASCA / PTWANT,A,ALN,Z1MAX,Z1DIF,Z2MAX,Z2DIF,
     &                PT,ETAC,ETAD,X1,X2,V,U,W,W1,AXX,WEIGHT,MSPR,IREJSC
      DIMENSION PDA(-6:6),PDB(-6:6)
      INTEGER MXSECT
C     COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4,20),XSECT(5,-1:MAXPRO,20),
C    &                MXSECT(0:2,-1:MAXPRO,20)
      COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4,28),XSECT(5,-1:MAXPRO,28),
     &                MXSECT(0:2,-1:MAXPRO,28)
C     COMMON /LAPENE/PTTHRZ(20),PTTHZ2(20),INDENE
      COMMON /LAPENE/PTTHRZ(28),PTTHZ2(28),INDENE
C     COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4),XSECT(5,-1:MAXPRO),
C    &                MXSECT(0:2,-1:MAXPRO)

      FDISTR = 0.0
C  set hard scale  QQ  for alpha and partondistr.
      IF     ( NQQAL.EQ.1 ) THEN
        QQAL = AQQAL*PT*PT
      ELSEIF ( NQQAL.EQ.2 ) THEN
        QQAL = AQQAL*X1*X2*ECM*ECM
      ELSEIF ( NQQAL.EQ.3 ) THEN
        QQAL = AQQAL*X1*X2*ECM*ECM*(U*V)**(1./3.)
      ELSEIF ( NQQAL.EQ.4 ) THEN
        QQAL = AQQAL*X1*X2*ECM*ECM*U*V/(1.+V*V+U*U)
      ENDIF
      IF     ( NQQPD.EQ.1 ) THEN
        QQPD = AQQPD*PT*PT
      ELSEIF ( NQQPD.EQ.2 ) THEN
        QQPD = AQQPD*X1*X2*ECM*ECM
      ELSEIF ( NQQPD.EQ.3 ) THEN
        QQPD = AQQPD*X1*X2*ECM*ECM*(U*V)**(1./3.)
      ELSEIF ( NQQPD.EQ.4 ) THEN
        QQPD = AQQPD*X1*X2*ECM*ECM*U*V/(1.+V*V+U*U)
      ENDIF
      ALPHA = BQCD/LOG(MAX(QQAL/ALASQR,1.1*ONE))
      F  = XSECT(1,MSPR,INDENE)*ALPHA**2
C     F  = XSECT(1,MSPR)*ALPHA**2
C calculate partondistributions
      CALL JTPDIS(X1,QQPD,NHA,MSPR,PDA)
      CALL JTPDIS(X2,QQPD,NHB,MSPR,PDB)
C calculate full distribution FDISTR
      IF ( MSPR.EQ.1  .OR.  MSPR.EQ.4 ) THEN
        PDS   = PDA(0)*PDB(0)
      ELSE
        S2    = 0.0
        S3    = 0.0
        S4    = 0.0
        S5    = 0.0
        DO 10 I=1,NF
          S2  = S2+PDA(I)*PDB(-I)+PDA(-I)*PDB( I)
          S3  = S3+PDA(I)*PDB( I)+PDA(-I)*PDB(-I)
          S4  = S4+PDA(I)+PDA(-I)
          S5  = S5+PDB(I)+PDB(-I)
10        CONTINUE
        IF     ( MSPR.EQ.2  .OR.  MSPR.EQ.5  .OR.  MSPR.EQ.6 ) THEN
          PDS = S2
        ELSEIF ( MSPR.EQ.3  .OR.  MSPR.EQ.-1 ) THEN
          PDS = PDA(0)*S5+PDB(0)*S4
        ELSEIF ( MSPR.EQ.7 ) THEN
          PDS = S3
        ELSEIF ( MSPR.EQ.8 ) THEN
          PDS = S4*S5-(S2+S3)
        ENDIF
      ENDIF
      FDISTR  = F*PDS
      RETURN
      END
C______________________________________________________________________
      SUBROUTINE HARSCA
C  HARSCA determines the type of hard subprocess, the partons taking
C  part in subprocess and the kinematic variables
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      PARAMETER ( MAXPRO = 8 , MLINE = 1000 , MSCAHD = 250 )
      COMMON /HAPARA/ ECM,PTINI(4),Q0SQR,ALASQR,BQCD,NPD,NF,NHA,NHB
      COMMON /HAOUTL/ NOUTL,NOUTER,NOUTCO
      COMMON /HAEVNT/ PT1,PT2,NHARD,NTRY,IHARD,ITRY,IREJEV
      COMMON /HASCA / PTWANT,A,ALN,Z1MAX,Z1DIF,Z2MAX,Z2DIF,
     &                PT,ETAC,ETAD,X1,X2,V,U,W,W1,AXX,WEIGHT,MSPR,IREJSC
      DIMENSION PDA(-6:6),PDB(-6:6)
      COMMON /HAEVTR/ LINE,LIN,LREC1(MLINE),LREC2(MLINE),PREC(0:3,MLINE)
      INTEGER MXSECT
C     COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4,20),XSECT(5,-1:MAXPRO,20),
C    &                MXSECT(0:2,-1:MAXPRO,20)
      COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4,28),XSECT(5,-1:MAXPRO,28),
     &                MXSECT(0:2,-1:MAXPRO,28)
C     COMMON /LAPENE/PTTHRZ(20),PTTHZ2(20),INDENE
      COMMON /LAPENE/PTTHRZ(28),PTTHZ2(28),INDENE
C     COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4),XSECT(5,-1:MAXPRO),
C    &                MXSECT(0:2,-1:MAXPRO)

C     MXSECT(0,0) = 0
C     XSECT(2,0)  = 0.0
      MXSECT(0,0,INDENE) = 0
      XSECT(2,0,INDENE)  = 0.0      
      
      DO 15 M=-1,MAXPRO
         IF ( MXSECT(0,M,INDENE).EQ.1 )
     &  XSECT(2,0,INDENE) = XSECT(2,0,INDENE)+XSECT(2,M,INDENE)
C       IF ( MXSECT(0,M).EQ.1 ) XSECT(2,0) = XSECT(2,0)+XSECT(2,M)
15    CONTINUE
C
C -------------------------------------------I
C  begin of iteration loop                   I
C                                            I
      IREJSC = 0
10    CONTINUE
      IREJSC = IREJSC+1
      IREJEV = IREJEV+1
C  find subprocess
      B      = RNDM(AI)*XSECT(2,0,INDENE)
C     B      = RNDM(AI)*XSECT(2,0)
      MSPR   =-2
      SUM    = 0.0
20    MSPR   = MSPR+1
      IF ( MXSECT(0,MSPR,INDENE).EQ.1 ) SUM = SUM+XSECT(2,MSPR,INDENE)
C     IF ( MXSECT(0,MSPR).EQ.1 ) SUM = SUM+XSECT(2,MSPR)
      IF ( SUM.LT.B  .AND. MSPR.LT.MAXPRO ) GOTO 20
C  find kin. variables X1,X2 and V
      CALL HARKIN
C  check kin. cuts eventually given by user
      CALL HACHEK(IOPT)
      IF ( IOPT.EQ.0 ) GOTO 10
C  calculate remaining distribution
      CALL HAFDIS(PDS,PDA,PDB,F)
C  actualize counter for cross-section calculation
      IF( F .LE. 1.D-15 ) F=0.
C     XSECT (3,MSPR) = XSECT (3,MSPR)+F
C     XSECT (4,MSPR) = XSECT (4,MSPR)+F*F
C     MXSECT(1,MSPR) = MXSECT(1,MSPR)+1
      XSECT (3,MSPR,INDENE) = XSECT (3,MSPR,INDENE)+F
      XSECT (4,MSPR,INDENE) = XSECT (4,MSPR,INDENE)+F*F
      MXSECT(1,MSPR,INDENE) = MXSECT(1,MSPR,INDENE)+1
C
C  check F against FMAX
C
      WEIGHT = F/XSECT(2,MSPR,INDENE)
C     WEIGHT = F/XSECT(2,MSPR)
      IF ( WEIGHT.LT.RNDM(AI) ) GOTO 10
C-------------------------------------------------------------------
C      IF(WEIGHT.GT.1.D0) WRITE(6,1234)F,XSECT(2,MSPR,INDENE),WEIGHT
C1234  FORMAT(' HARSCA: MONTE-CARLO WEIGHT FUNCTION H/HMAX GT 1 !',/
C    * '  H = SUM OVER A,B FOR PROCESS M OF:',/
C    * '  E(M)*ALPHAS**2*XA*FA(XA,Q**2)*XB*FB(XB,Q**2)',/
C    * '  F(=H),XSECT(2,MSPR,INDENE)(=HMAX), WEIGHT = H/HMAX',3E12.5)
C-------------------------------------------------------------------
C                                            I
C  end of iteration loop                     I
C -------------------------------------------I
C
C  the event is accepted now
C
C  actualize counter for accepted events
      MXSECT(2,MSPR,INDENE) = MXSECT(2,MSPR,INDENE)+1
C     MXSECT(2,MSPR) = MXSECT(2,MSPR)+1
      IF ( MSPR.EQ.-1 ) MSPR = 3
C  find initial partons
      SUM    = 0.0
      SCHECK = RNDM(AI)*PDS
      IF     ( MSPR.EQ.1  .OR.  MSPR.EQ.4 ) THEN
        IA = 0
        IB = 0
      ELSEIF ( MSPR.EQ.2  .OR.  MSPR.EQ.5  .OR.  MSPR.EQ.6 ) THEN
        DO 610 IA=-NF,NF
          IF ( IA.EQ.0 ) GOTO 610
          SUM  = SUM+PDA(IA)*PDB(-IA)
          IF ( SUM.GE.SCHECK ) GOTO 620
610       CONTINUE
620     IB =-IA
      ELSEIF ( MSPR.EQ.3 ) THEN
        IB     = 0
        DO 630 IA=-NF,NF
          IF ( IA.EQ.0 ) GOTO 630
          SUM  = SUM+PDA(0)*PDB(IA)
          IF ( SUM.GE.SCHECK ) GOTO 640
          SUM  = SUM+PDA(IA)*PDB(0)
          IF ( SUM.GE.SCHECK ) GOTO 650
630       CONTINUE
640     IB     = IA
        IA     = 0
650     CONTINUE
      ELSEIF ( MSPR.EQ.7 ) THEN
        DO 660 IA=-NF,NF
          IF ( IA.EQ.0 ) GOTO 660
          SUM  = SUM+PDA(IA)*PDB(IA)
          IF ( SUM.GE.SCHECK ) GOTO 670
660       CONTINUE
670     IB     = IA
      ELSEIF ( MSPR.EQ.8 ) THEN
        DO 690 IA=-NF,NF
          IF ( IA.EQ.0 ) GOTO 690
          DO 680 IB=-NF,NF
            IF ( ABS(IB).EQ.ABS(IA)  .OR.  IB.EQ.0 ) GOTO 680
            SUM = SUM+PDA(IA)*PDB(IB)
            IF ( SUM.GE.SCHECK ) GOTO 700
680         CONTINUE
690       CONTINUE
700     CONTINUE
      ENDIF
C  find final partons
      IC = IA
      ID = IB
      IF     ( MSPR.EQ.2 ) THEN
        IC = 0
        ID = 0
      ELSEIF ( MSPR.EQ.4 ) THEN
        IC = INT(FLOAT(NF+NF)*RNDM(AI))+1
        IF ( IC.GT.NF ) IC = NF-IC
        ID =-IC
      ELSEIF ( MSPR.EQ.6 ) THEN
        IC = INT(FLOAT(NF+NF-2)*RNDM(AI))+1
        IF ( IC.GT.NF-1 ) IC = NF-1-IC
        IF ( ABS(IC).EQ.ABS(IA) ) IC = SIGN(NF,IC)
        ID =-IC
      ENDIF
C
30    A1     = RNDM(AI)
      A2     = RNDM(AI)
      IF ( ((A1*A1)+(A2*A2)).GT.1.0D0 ) GOTO 30
      COSPHI = ((A1*A1)-(A2*A2))/((A1*A1)+(A2*A2))
      SINPHI = SIGN(((A1*A2)+(A1*A2))/((A1*A1)+(A2*A2)),RNDM(AI)-0.5D0)
C
      IF ( RNDM(AI)*PDA(IA).GT.PDA(-IA) ) IA = SIGN(ABS(IA)+10,IA)
      IF ( RNDM(AJ)*PDB(IB).GT.PDB(-IB) ) IB = SIGN(ABS(IB)+10,IB)
C  fill event record
      LINE          = LINE+1
      PREC(1,LINE)  = 0.0
      PREC(2,LINE)  = 0.0
      PREC(3,LINE)  = 0.5*ECM*X1
      PREC(0,LINE)  = PREC(3,LINE)
      LREC1(LINE)   = IA+50+100*MSPR
      LREC2(LINE)   = 01000
      LINE          = LINE+1
      PREC(1,LINE)  = 0.0
      PREC(2,LINE)  = 0.0
      PREC(3,LINE)  =-0.5*ECM*X2
      PREC(0,LINE)  =-PREC(3,LINE)
      LREC1(LINE)   = IB+50
      LREC2(LINE)   = 01000
      LINE          = LINE+1
      PREC(1,LINE)  = PT*COSPHI
      PREC(2,LINE)  = PT*SINPHI
      PREC(3,LINE)  =-0.5*ECM*(U*X1-V*X2)
      PREC(0,LINE)  =-0.5*ECM*(U*X1+V*X2)
      LREC1(LINE)   = IC+50
      LREC2(LINE)   = 11000
      LINE          = LINE+1
      PREC(1,LINE)  =-PT*COSPHI
      PREC(2,LINE)  =-PT*SINPHI
      PREC(3,LINE)  =-0.5*ECM*(V*X1-U*X2)
      PREC(0,LINE)  =-0.5*ECM*(V*X1+U*X2)
      LREC1(LINE)   = ID+50
      LREC2(LINE)   = 11000
      RETURN
      END
C_______________________________________________________________________
      SUBROUTINE HAOUTP
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      PARAMETER ( MAXPRO = 8 , MLINE = 1000 , MSCAHD = 250 )
      COMMON /HAOUTL/ NOUTL,NOUTER,NOUTCO
      COMMON /HAEVNT/ PT1,PT2,NHARD,NTRY,IHARD,ITRY,IREJEV
      COMMON /HAEVTR/ LINE,LIN,LREC1(MLINE),LREC2(MLINE),PREC(0:3,MLINE)
      COMMON /HARSLT/ LSCAHD,LSC1HD,
     &                ETAHD(MSCAHD,2) ,PTHD(MSCAHD),
     &                XHD(MSCAHD,2)   ,VHD(MSCAHD) ,X0HD(MSCAHD,2),
     &                NINHD(MSCAHD,2) ,NOUTHD(MSCAHD,2),
     &                N0INHD(MSCAHD,2),NBRAHD(MSCAHD,2),NPROHD(MSCAHD)

C  output of data for hard scattering
      IF ( NOUTL.GE.4 ) THEN
      WRITE(6,1010) NHARD,IHARD,IREJEV
1010  FORMAT(' ===HARD EVENT===    NHARD,NTRUE,REJECTIONS ',3I5,/
     &'  IA IB IC ID     XA         XB         PT       YC       YD',
     &'       PHI')
      DO 10 N=1,LSCAHD
        PHI = ATAN2(PREC(1,4*N-1),PREC(2,4*N-1))
        WRITE(6,1020) NINHD(N,1),NINHD(N,2),NOUTHD(N,1),NOUTHD(N,2),
     &             XHD(N,1),XHD(N,2),PTHD(N),ETAHD(N,1),ETAHD(N,2),PHI
1020    FORMAT(1X,4I3,2F11.7,4F9.3)
10    CONTINUE
      ENDIF
      IF ( NOUTL.GE.6 ) THEN
C  output of eventrecord
        WRITE(6,1030)
1030    FORMAT('   EVENTRECORD')
        DO 20 L=1,LINE
          WRITE(6,1040) LREC1(L),LREC2(L),(PREC(I,L),I=0,3)
20      CONTINUE
1040    FORMAT(2I12,4(1PE12.4))
        WRITE(6,1050)
1050    FORMAT(/)
      ENDIF
      RETURN
      END
C_____________________________________________________________________
C
C        original title: JTPADI.FOR
C_______________________________________________________________________
*
*  ********************************************************************
      SUBROUTINE JTPDIS(X,QQ,IHATYP,MSPR,PD)
*
*             Parton distributios
*       NPD=ISTRUF (elsewhere) 
*
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      COMMON /HAPARA/ ECM,PTINI(4),Q0SQR,ALASQR,BQCD,NPD,NF,NHA,NHB
      DIMENSION PD(-6:6)
      DATA ISET / 0 /
      DO 10 I=-6,6
10      PD(I) = 0.0
C  SET MAXFL - THE MAX. NUMBER OF FLAVORS TO CALCULATE
      MAXFL = NF
      IF ( MSPR.EQ.1 .OR. MSPR.EQ.4 ) MAXFL = 0
C------------------------------------------------------
C  CALL ROUTINES CALCULATING THE DISTRIBUTIONS
C  EHLQ 1/2, MRS 1/2/3, GRV, HMRS 1/2, KMRS 1/2/3/4,
C  WHERE HMRS 1/2, KMRS 1/2/3/4 CORRESP. TO HKMRS 1-6
C------------------------------------------------------
      IF     ( NPD.EQ.1 .OR.  NPD.EQ.2 ) THEN
C       CALL PDEHLQ(X,QQ,MAXFL,PD)
        WRITE(6,*) ' unsupported PDF number: ',NPD
      ELSEIF ( NPD.GE.3 .AND. NPD.LE.5 ) THEN
C       CALL PDMRS(X,QQ,MAXFL,PD)
        WRITE(6,*) ' unsupported PDF number: ',NPD
      ELSEIF(NPD.EQ.6)THEN
C       CALL PDGRV(X,QQ,PD)
        WRITE(6,*) ' unsupported PDF number: ',NPD
      ELSEIF(NPD.EQ.7)THEN
C       CALL PHKMRS(X,QQ,PD,1)
        WRITE(6,*) ' unsupported PDF number: ',NPD
      ELSEIF(NPD.EQ.8)THEN
C       CALL PHKMRS(X,QQ,PD,2)
        WRITE(6,*) ' unsupported PDF number: ',NPD
      ELSEIF(NPD.EQ.9)THEN
C       CALL PHKMRS(X,QQ,PD,3)
        WRITE(6,*) ' unsupported PDF number: ',NPD
      ELSEIF(NPD.EQ.10)THEN
C       CALL PHKMRS(X,QQ,PD,4)
        WRITE(6,*) ' unsupported PDF number: ',NPD
      ELSEIF(NPD.EQ.11)THEN
C       CALL PHKMRS(X,QQ,PD,5)
        WRITE(6,*) ' unsupported PDF number: ',NPD
      ELSEIF(NPD.EQ.12)THEN
C       CALL PHKMRS(X,QQ,PD,6)
        WRITE(6,*) ' unsupported PDF number: ',NPD
* updates of April 92, April 93
      ELSEIF((NPD.GE.13).AND.(NPD.LE.20)) THEN
C       CALL PHKMRS(X,QQ,PD,NPD-6)
        WRITE(6,*) ' unsupported PDF number: ',NPD
      ELSEIF((NPD.GE.21).AND.(NPD.LE.23)) THEN
        CALL PHKMRS(X,QQ,PD,NPD-6)
      ELSE
        WRITE(6,*) ' unsupported PDF number: ',NPD
        STOP
      ENDIF
      DO 20 I=-MAXFL,MAXFL
        IF ( PD(I).LT.1.D-15 ) PD(I) = 0.0
20      CONTINUE
C  IF ANTIPROTON CHANGE QUARK <---> ANTIQUARK
      IF ( IHATYP.EQ.-1 ) THEN
        DO 50 I=1,6
          TTTT   = PD(-I)
          PD(-I) = PD(I)
50        PD( I) = TTTT
      ENDIF
      RETURN
      END

C_______________________________________________________________________
      SUBROUTINE PHKMRS(XQ,QQ,PD,MODE)
C***************************************************************C
C                                                               C
C     ORIGINAL NAME: MRSEB( ... )                               C
C                                                               C
C     -----  VARIABLE QUARKS AND GLUONS AT SMALL X ----         C
C                                                               C
C     NEW VERSIONS !!!! JANUARY 1990  (AS DESCRIBED IN          C
C     "PARTON DISTRIBUTIONS ... " P.N. HARRIMAN, A.D. MARTIN,   C
C     R.G. ROBERTS AND W.J. STIRLING PREPRINT DTP-90-04 )       C
C                                                               C
C     NEW VERSIONS !!!! JULY 1990                               C
C     "........................ " J. KWIECINSKI, A.D. MARTIN,   C
C     R.G. ROBERTS AND W.J. STIRLING PREPRINT DTP-90-46 )       C
C      
C****************************************************************
C   All modes 1-14 dropped in dpmjet-II.4.2
C***************************************************************
C  MODE 1 CORRESPONDS TO  HARRIMAN,                             C
C  MARTIN, ROBERTS, STIRLING (EMC FIT)    WITH LAMBDA= 100 MEV  C
C  ORIGINAL: STRC27     NOW: PHMRS1                            C
C                                                               C
C  MODE 2 CORRESPONDS TO  HARRIMAN,                             C
C  MARTIN, ROBERTS, STIRLING (BCDMS FIT)  WITH LAMBDA= 190 MEV  C
C  WITH SMALL X BEHAVIOUR DETERMINED FROM FIT  "HB FIT"         C
C  ORIGINAL: STRC28     NOW: PHMRS2                            C
C                                                               C
C  MODE 3 CORRESPONDS TO  KWIECINSKI,                           C
C  MARTIN, ROBERTS, STIRLING (BCDMS FIT)  WITH LAMBDA= 190 MEV  C
C  AND XG,XQ --> CONSTANT AS X--> 0 AT Q0**2   "B0 FIT"         C
C  ORIGINAL: STRC38     NOW: PKMRS1                            C
C                                                               C
C  MODE 4 CORRESPONDS TO  KWIECINSKI,                           C
C  MARTIN, ROBERTS, STIRLING (BCDMS FIT)  WITH LAMBDA= 190 MEV  C
C  AND XG,XQ --> X**-1/2 AS X--> 0 AT Q0**2    "B- FIT"         C
C  ORIGINAL: STRC48     NOW: PKMRS2                            C
C                                                               C
C  MODE 5 CORRESPONDS TO  KWIECINSKI,                           C
C  MARTIN, ROBERTS, STIRLING (BCDMS FIT)  WITH LAMBDA= 190 MEV  C
C  AND XG,XQ --> X**-1/2 AS X--> 0 AT Q0**2    "B-(5) FIT"      C
C  I.E. WITH WEAK (R=5 GEV-1) SHADOWING INCLUDED              C
C  ORIGINAL: STRC58     NOW: PKMRS3                            C
C                                                               C
C  MODE 6 CORRESPONDS TO  KWIECINSKI,                           C
C  MARTIN, ROBERTS, STIRLING (BCDMS FIT)  WITH LAMBDA= 190 MEV  C
C  AND XG,XQ --> X**-1/2 AS X--> 0 AT Q0**2    "B-(2) FIT"      C
C  I.E. WITH STRONG  (R=2 GEV-1) SHADOWING INCLUDED           C
C  ORIGINAL: STRC68     NOW: PKMRS4                            C
C                                                               C
C****************************************************************
C   All modes 1-14 dropped in dpmjet-II.4.2
C***************************************************************
C                                                               C
C                         -*-                                   C
C                                                               C
C    (NOTE THAT X TIMES THE PARTON DISTRIBUTION FUNCTION        C
C    IS RETURNED I.E. G(X) = GLU/X ETC, AND THAT "SEA"          C
C    IS THE LIGHT QUARK SEA I.E. UBAR(X)=DBAR(X)                C
C    = SEA/X FOR A PROTON.  IF IN DOUBT, CHECK THE              C
C    MOMENTUM SUM RULE! NOTE ALSO THAT SCALE=Q**2 IN GEV**2)    C
C                                                               C
C                         -*-                                   C
C                                                               C
C***************************************************************C
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
C      REAL XQ,QQ,PD
C     to get the same as outside
C     in the D IMPLICIT DOUBLE PRECISION(A-H,O-Z) world
      REAL
     & *8
     & XQ,QQ,PD
      DIMENSION PD(-6:6)
      DIMENSION PDFF(-6:2)
      X=DBLE( XQ )
      SCALE=DBLE( QQ )
C-------------------------------------------------------------------
C****************************************************************
C   All modes 1-14 dropped in dpmjet-II.4.2
C***************************************************************
C****************************************************************
C   All modes 1-14 dropped in dpmjet-II.4.2
C***************************************************************
C--------------------------------------------------------------------
C     updates Oct 98 replace DOR94LO by PO_GRV98LO (R.Engel)
      IF((MODE.EQ.15)) THEN
         SCALE2=SCALE
C        CALL DOR94LO(X,SCALE2,UV, DV, DEL, UDB, SB, GL)
         CALL PO_GRV98LO(ISET,X,SCALE2,UV,DV,US,DS,SS,GL)
         CB = 0.D0
         BB = 0.D0
         PD(-5) = BB
         PD(-4) = CB
         PD(-3) = SS
         PD(-2) = US
         PD(-1) = DS
         PD(0)  = GL
         PD(1) = DV+DS
         PD(2)  = UV+US
         PD(3)  = SS
         PD(4)  = PD(-4)
         PD(5)  = PD(-5)
         XQ= X
         QQ= SCALE
C        WRITE(6,*)' PD ',PD
         RETURN
      ENDIF
C     updates Oct 98 replace DOR94LO by PO_GRV98LO (R.Engel)
      IF((MODE.EQ.16)) THEN
         SCALE2=SCALE
C        CALL DOR94LO(X,SCALE2,UV, DV, DEL, UDB, SB, GL)
         CALL PO_GRV98LO(ISET,X,SCALE2,UV,DV,US,DS,SS,GL)
         CB = 0.D0
         BB = 0.D0
         PD(-5) = BB
         PD(-4) = CB
         PD(-3) = SS
         PD(-2) = US
         PD(-1) = DS
         PD(0)  = GL
         PD(1) = DV+DS
         PD(2)  = UV+US
         PD(3)  = SS
         PD(4)  = PD(-4)
         PD(5)  = PD(-5)
         XQ= X
         QQ= SCALE
C        WRITE(6,*)' PD ',PD
         RETURN
      ENDIF
C--------------------------------------------------------------------
C     updates Feb. 97
      IF((MODE.EQ.17)) THEN
      CALL structm(x,SCALE,Upv,Dnv,Usea,Dsea,Str,Chm,Bot,Top,Glu)
      PD(0)=  GLU
      PD(1)=  USEA+UPV
      PD(2)=  DSEA+DNV
      PD(3)=  STR
      PD(4)=  CHM
      PD(5)=  BOT
      PD(-5)= BOT
      PD(-4)= CHM
      PD(-3)= STR
      PD(-2)= DSEA
      PD(-1)= USEA 
      XQ= X
      QQ= SCALE 
        RETURN
      ENDIF
C--------------------------------------------------------------------
C--------------------------------------------------------------------
      PD(0)=  GLU
      PD(1)=  SEA+UPV
      PD(2)=  SEA+DNV
      PD(3)=  STR
      PD(4)=  CHM
      PD(5)=  BOT
      PD(-5)= BOT
      PD(-4)= CHM
      PD(-3)= STR
      PD(-2)= SEA
      PD(-1)= SEA
      XQ= X
      QQ= SCALE
C--------------------------------------------------------------------
      RETURN
      END
C
C*********************************************************************
C-----original seperate file with the name------------------------------------------------------------------
C                            DTULPTPE.FOR
C
C------------------------------------------------------------------------
C_______________________________________________________________________
C
C   PROGRAM FOR SIMULATION OF HARD SCATTERING OF HADRONIC PARTICLES
C
C     AUTHOR       K.HAHN            LEIPZIG   GDR
C_______________________________________________________________________
      SUBROUTINE LAPTAB
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      PARAMETER ( MAXPRO = 8 , MLINE = 1000 , MSCAHD = 250 )
      COMMON /HACONS/ PI,PI2,PI4,GEVTMB
      COMMON /HAPARA/ ECM,PTINI(4),Q0SQR,ALASQR,BQCD,NPD,NF,NHA,NHB
      COMMON /HAPADI/ NPDM
      COMMON /HAPDCO/ NPDCOR
      COMMON /HAQQAP/ AQQAL,AQQPD,NQQAL,NQQPD
      COMMON /HAENVI/ NINDEP
      COMMON /HAOUTL/ NOUTL,NOUTER,NOUTCO
      COMMON /HACUTS/ PTL,PTU,ETACL,ETACU,ETADL,ETADU
      COMMON /HAGAUP/ NGAUP1,NGAUP2,NGAUET,NGAUIN
      COMMON /HAEVTR/ LINE,LIN,LREC1(MLINE),LREC2(MLINE),PREC(0:3,MLINE)
      COMMON /HARSLT/ LSCAHD,LSC1HD,
     &                ETAHD(MSCAHD,2) ,PTHD(MSCAHD),
     &                XHD(MSCAHD,2)   ,VHD(MSCAHD) ,X0HD(MSCAHD,2),
     &                NINHD(MSCAHD,2) ,NOUTHD(MSCAHD,2),
     &                N0INHD(MSCAHD,2),NBRAHD(MSCAHD,2),NPROHD(MSCAHD)
      INTEGER MXSECT
C     COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4,28),XSECT(5,-1:MAXPRO,28),
C    &                MXSECT(0:2,-1:MAXPRO,28)
      COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4,28),XSECT(5,-1:MAXPRO,28),
     &                MXSECT(0:2,-1:MAXPRO,28)
C     COMMON /LAPENE/PTTHRZ(20),PTTHZ2(20),INDENE
      COMMON /LAPENE/PTTHRZ(28),PTTHZ2(28),INDENE
C     COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4),XSECT(5,-1:MAXPRO),
C    &                MXSECT(0:2,-1:MAXPRO)
      CHARACTER*8  CW
      CHARACTER*79 COMMNT
      CHARACTER*70 INP
      DIMENSION   WHAT(6)
C======================================================================
C  THE AVAILABLE CODE WORDS ARE
C
C        END     , COMMENT , ENERGYPT, PARDISTR, CUTS
C        INTPOINT, FLAVOR  , PARTICLE, OUTPUT  , INIT    ,
C        TESTINCL, TESTMC  , SUBPRON , SUBPROFF, HISOUT  ,
C        HISINI  , HARDSCAL, USER    , PARDISCO
C_______________________________________________________________________
      WRITE(6,2000)
2000  FORMAT('1***************************************************'
     & ,/,   ' MONTE-CARLO GENERATION OF HARD HADRONIC SCATTERINGS'
     & ,/,   ' ***************************************************',/)
      CALL JTDTU(1)
C  read a control card
10    CONTINUE
      READ (5,1010) INP
      IF ( INP(1:1).EQ.'-' ) GOTO 10
      WRITE(6,1011) INP
      READ(INP,1012,ERR=99) CW,WHAT
      GOTO 15
99    WRITE(6,1013)
      GOTO 10
1010  FORMAT(A70)
1011  FORMAT(' *********.* CONTROL.CARD*****.',4(9X,'.'),/,1X,A70,/)
1012  FORMAT(A8,2X,6E10.0)
1013  FORMAT('     CARD IS INCORRECT, IGNORE AND TRY NEXT CARD',/)
15    CONTINUE
C======================================================================
C======================================================================
      IF     ( CW.EQ.'END     ' ) THEN
C
C       STOPS THE PROGRAM
C_______________________________________________________________________
        WRITE(6,1030)
1030    FORMAT(' ******** END OF PROGRAM EXECUTION ********')
        RETURN
C======================================================================
      ELSEIF ( CW.EQ.'COMMENT ' ) THEN
C
C       TO INCLUDE COMMENTS IN PROGRAM OUTPUT
C  WHAT(1) - # OF CARDS FOLLOWING THE CONTROLCARD AND
C            CONTAINING THE COMMENT
C_______________________________________________________________________
        N = MAX(1,INT(WHAT(1)))
        DO 20 I=1,N
          READ(5,1040) COMMNT
20        WRITE(6,1050) COMMNT
1040    FORMAT(A79)
1050    FORMAT(1X,A79)
C======================================================================
      ELSEIF ( CW.EQ.'ENERGYPT' ) THEN
C
C       READ CMS-ENERGY AND MIN. TRANSVERSE MOMENTUM FOR JETS
C  WHAT(1) - CMS-ENERGY   ( IN GEV )       DEFAULT  540.
C  WHAT(2) - MIN. PT      ( IN GEV )       DEFAULT    2.
C  WHAT(3) - MIN. PT      ( IN GEV )       DEFAULT    2.
C  WHAT(4) - MIN. PT      ( IN GEV )       DEFAULT    2.
C  WHAT(5) - MIN. PT      ( IN GEV )       DEFAULT    2.
C
C_______________________________________________________________________
        IF ( WHAT(1).GT.0.0D0 ) ECM = WHAT(1)
        DO 22 I=1,4
          PTINI(I) = WHAT(I+1)
22      CONTINUE
C======================================================================
      ELSEIF ( CW.EQ.'PARDISTR' ) THEN
C
C       DEFINE THE PARTON DISTRIBUTION SET
C  WHAT(1) - NPD                               DEFAULT  3.
C       NPD = 1,2     : EICHTEN,HINCHLIFFE,LANE,QUIGG
C           = 3,4,5   : MARTIN,ROBERTS,STIRLING
C           = 6       : GLUECK,REYA,VOGT
C           = 7,8     : HARRIMAN,MARTIN,ROBERTS,STIRLING
C           = 9 - 12  : KWIECINSKI,MARTIN,ROBERTS,STIRLING
C
C  WHAT(2) - NPDM                              DEFAULT  0.
C       NPDM = 0,1    : CORRECTS THE PARTON DISTRIBUTION IN CASE
C                       OF NPD = 10 TO THE 1/SQRT(X) BEHAVIOUR
C                       FOR X < XMIN=1.E-05 IF NPDM = 1 AND NOT
C                       IF NPDM = 0 ( M STANDS FOR MODIFICATION )
C_______________________________________________________________________
        IPD      = INT(WHAT(1))
        IPDM     = INT(WHAT(2))
        NPD      = 3
        NPDM     = 0
*       IF ( IPD.GE.1 .AND. IPD.LE.12 ) NPD = IPD
        IF ( IPD.GE.1 .AND. IPD.LE.15 ) NPD = IPD
        IF ( IPDM.EQ.1 ) NPDM = IPDM
C======================================================================
      ELSEIF ( CW.EQ.'CUTS    ' ) THEN
C
C       set kinematic cuts on partonlevel
C  WHAT(1) - PTL     min. pt for parton               DEFAULT  0.0
C  WHAT(2) - PTU     max. pt for parton               DEFAULT  1.E+30
C  WHAT(3) - ETACL   min. rapidity for parton c       DEFAULT -1.E+30
C  WHAT(4) - ETACU   max. rapidity for parton c       DEFAULT  1.E+30
C  WHAT(5) - ETADL   min. rapidity for parton d       DEFAULT -1.E+30
C  WHAT(6) - ETADU   max. rapidity for parton d       DEFAULT  1.E+30
C
C    this cuts are additional cuts which not affect the pt-cut given
C    in the ENERGYPT card;
C    this cuts are checked during event generation and events violating
C    the cuts are rejected;
C    the defaults are such that there is really no cutting;
C_______________________________________________________________________
        PTL     = WHAT(1)
        PTU     = WHAT(2)
        ETACL   = WHAT(3)
        ETACU   = WHAT(4)
        ETADL   = WHAT(5)
        ETADU   = WHAT(6)
        IF ( PTU  .LE.PTL   ) PTU   = PTL  +1.0
        IF ( ETACU.LE.ETACL ) ETACU = ETACL+1.0
        IF ( ETADU.LE.ETADL ) ETADU = ETADL+1.0
C======================================================================
      ELSEIF ( CW.EQ.'INTPOINT' ) THEN
C
C       define number of integration points
C  WHAT(1) - NGAUP1                            DEFAULT  8.
C  WHAT(2) - NGAUP2                            DEFAULT  8.
C  WHAT(3) - NGAUET                            DEFAULT  8.
C  WHAT(4) - NGAUIN                            DEFAULT  8.
C
C    NGAUP1,NGAUP2,NGAUET : used in inclusive x-section calculation;
C                           first, second pt-integration and
C                           eta-integration respectivly
C    NGAUIN               : used in initialization ( SUBROUTINE HABINT )
C
C       max. value allowed for integration is   32 ! - For NGAUP1,P2,ET
C       max. value allowed for integration is 1000 ! - For NGAUIN.
C                                                    (4.6.91)
C_______________________________________________________________________
      IF ( WHAT(1).GE.1.D0.AND.WHAT(1).LE.32.D0) NGAUP1 = INT(WHAT(1))
      IF ( WHAT(2).GE.1.D0.AND. WHAT(2).LE.32.D0) NGAUP2 = INT(WHAT(2))
      IF ( WHAT(3).GE.1.D0.AND. WHAT(3).LE.32.D0) NGAUET = INT(WHAT(3))
      IF(WHAT(4).GE.1.D0.AND. WHAT(3).LE.1000.D0) NGAUIN = INT(WHAT(4))
C======================================================================
      ELSEIF ( CW.EQ.'FLAVOR  ' ) THEN
C       DEFINES ACTIVE FLAVORS
C  WHAT(1) - # OF FLAVORS                 DEFAULT  4
C_______________________________________________________________________
        NFF     = INT(WHAT(1))
        IF ( NFF.GE.0  .AND.  NFF .LE.6 ) NF = NFF
C======================================================================
      ELSEIF ( CW.EQ.'PARTICLE' ) THEN
C
C       TARGET AND BEAM PARTICLES
C  WHAT(1) - BEAM    ( POSITIVE Z-DIRECTION )    DEFAULT  1
C  WHAT(2) - TARGET                              DEFAULT  1
C     1 : PROTON
C    -1 : ANTIPROTON
C_______________________________________________________________________
        IHA = INT(WHAT(1))
        IF ( ABS(IHA).EQ.1 ) NHA = IHA
        IHB = INT(WHAT(2))
        IF ( ABS(IHB).EQ.1 ) NHB = IHB
C======================================================================
      ELSEIF ( CW.EQ.'OUTPUT  ' ) THEN
C
C       set output level
C  WHAT(1) - NOUTL    output level  0....                    DEFAULT  1.
C  WHAT(2) - NOUTER   error messages ( 0 - no  ; 1 - yes )   DEFAULT  1.
C_______________________________________________________________________
        IF ( WHAT(1).GE.0.D0 )                NOUTL  = INT(WHAT(1))
        IF ( WHAT(2).EQ.0.D0.OR.WHAT(2).EQ.1.D0)NOUTER = INT(WHAT(2))
        IF ( WHAT(3).GE.0.D0 )                 NOUTCO = INT(WHAT(3))
C======================================================================
      ELSEIF ( CW.EQ.'INIT    ' ) THEN
C
C       DEMANDS A NEW INITIALIZATION
C_______________________________________________________________________
        CALL HARINI
C======================================================================
      ELSEIF ( CW.EQ.'TESTINCL' ) THEN
C
C       TEST OF INCLUSIVE JET PRODUCTION
C         PLOT OF PARTONDISTRIBUTIONS USED ( GLUONS )
C         PLOT OF DIFFERENTIAL JET CROSS SECTIONS
C
C_______________________________________________________________________
        DO 35 I=1,6
          J   = INT(WHAT(I))
          IF ( J.GE.1 .AND. J.LE.4 ) CALL HATEST(J)
35        CONTINUE
C======================================================================
      ELSEIF ( CW.EQ.'TESTMC  ' ) THEN
C
C       TEST OF MONTE-CARLO JET PRODUCTION
C         PLOT OF DIFFERENTIAL JET CROSS SECTIONS
C  WHAT(1) - # OF EVENTS TO PRODUCE IN TEST       DEFAULT  100
C  WHAT(2) - # OF HARD SCATTERINGS AT HARD EVENT
C  WHAT(3) - MIN. PT FOR FIRST HARD SCATTERING
C
C_______________________________________________________________________
        NEVT = INT(WHAT(1))
        IF ( NEVT.LE.0 ) NEVT = 100
        NHARD = MAX(1,INT(WHAT(2)))
        PT1   = WHAT(3)
        CALL TIMDAT
        DO 36 I=1,NEVT
          MHARD = NHARD
          CALL HAREVT(MHARD,PT1)
36      CONTINUE
        CALL TIMDAT
C======================================================================
      ELSEIF ( CW.EQ.'SUBPRON ' ) THEN
C
C   SWITCH SUBPROCESSES ON
C
C______________________________________________________________________
        DO 40 I=1,6
          M = INT(WHAT(I))
          IF ( M.GE.1  .AND.  M.LE.MAXPRO ) MXSECT(0,M,INDENE) = 1
C         IF ( M.GE.1  .AND.  M.LE.MAXPRO ) MXSECT(0,M) = 1
40        CONTINUE
        MXSECT(0,-1,INDENE) = MXSECT(0,3,INDENE)
C       MXSECT(0,-1) = MXSECT(0,3)
C======================================================================
      ELSEIF ( CW.EQ.'SUBPROFF' ) THEN
C
C   SWITCH SUBPROCESSES OFF
C
C_______________________________________________________________________
        DO 50 I=1,6
          M = INT(WHAT(I))
          IF ( M.GE.1  .AND.  M.LE.MAXPRO ) MXSECT(0,M,INDENE) = 0
C         IF ( M.GE.1  .AND.  M.LE.MAXPRO ) MXSECT(0,M) = 0
50        CONTINUE
        MXSECT(0,-1,INDENE) = MXSECT(0,3,INDENE)
C       MXSECT(0,-1) = MXSECT(0,3)
C======================================================================
      ELSEIF ( CW.EQ.'HISOUT  ' ) THEN
C
C   OUTPUT OF MC RESULTS
C    WHAT()- 1   : TOTAL CROSS SECTION
C    WHAT()- 2   : PT-DISTR.
C    WHAT()- 3   : PT-DISTR.
C    WHAT()- 4   : PT-DISTR.
C    WHAT()- 5   : RAPIDITY-DISTR.
C    WHAT()- 6   : RAPIDITY-DISTR.
C
C_______________________________________________________________________
        DO 60 I=1,6
          J   = INT(WHAT(I))
          IF ( J.GE.1 .AND. J.LE.6 ) CALL HISOUTT(J)
60        CONTINUE
C======================================================================
      ELSEIF ( CW.EQ.'HISINI  ' ) THEN
C
C   INITIALIZE THE HISTOGRAMS FOR MC TESTING
C_______________________________________________________________________
        CALL HISINII
C======================================================================
      ELSEIF ( CW.EQ.'HARDSCAL' ) THEN
C
C   define hard scale
C     WHAT(1) - NQQAL  : definition of hard scale in coupling constant
C     WHAT(2) - AQQAL  : factor multiplied to hard scale in coupling
C     WHAT(3) - NQQPD  : definition of hard scale in parton distr.
C     WHAT(4) - AQQPD  : factor multiplied to hard scale in parton distr.
C        the possible NQQAL(PD) are
C           1 :  QQ = AQQAL(PD) * PT**2
C           2 :  QQ = AQQAL(PD) * SP
C           3 :  QQ = AQQAL(PD) * (SP*TP*UP)**(1./3.)
C           4 :  QQ = AQQAL(PD) * (SP*TP*UP)/(SP**2+TP**2+UP**2)
C
C      DEFAULT is NQQAL = NQQPD = 1 and AQQAL = AQQPD = 1./4.
C_______________________________________________________________________
        IF ( WHAT(1).GE.1.D0.AND.WHAT(1).LE.4.D0)NQQAL = INT(WHAT(1))
        IF ( WHAT(2).GT.0.D0 )                   AQQAL =     WHAT(2)
        IF ( WHAT(3).GE.1.D0.AND.WHAT(3).LE.4.D0)NQQPD = INT(WHAT(3))
        IF ( WHAT(4).GT.0.D0 )                   AQQPD =     WHAT(4)
C    C======================================================================
C          ELSEIF ( CW.EQ.'USER    ' ) THEN
C    C
C    C_______________________________________________________________________
C            WRITE(6,9050)
C    9050    FORMAT(' -----> GIVE CONTROL TO USER ROUTINE')
C            CALL HAUSER(WHAT)
C            WRITE(6,9060)
C    9060    FORMAT(' -----> CONTROL COMES BACK FROM USER ROUTINE')
C======================================================================
      ELSEIF ( CW.EQ.'PARDISCO' ) THEN
C
C   define partoncorrelationfunction
C     WHAT(1) - NPDCOR : =0 no correlations, =1 correlations
C
C      DEFAULT is NPDCOR = 0
C_______________________________________________________________________
        IF ( WHAT(1).EQ.0.D0.OR.WHAT(1).EQ.1.D0)NPDCOR = INT(WHAT(1))
C======================================================================
      ELSE
        WRITE(6,9999)
9999    FORMAT(' ##### UNKNOWN CODEWORD;  CARD IS IGNORED ###',/)
      ENDIF
      GOTO 10
      END
C
C-----originally seperate file with the name ---------------------------
C                             JTINCL.FOR
C
C______________________________________________________________________
C
C  PROCEDURES FOR CALCULATION OF INCLUSIVE CROSS SECTIONS
C
C______________________________________________________________________
C______________________________________________________________________
      SUBROUTINE CSJ2M(PT,ETAC,ETAD,DSIGMM)
C    CALCULATION OF DIFFERENTIAL CROSS SECTION DSIG/(DETAC*DETAD*DPT)
C    FOR DIFFERENT SUBPROCESSES
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      PARAMETER ( MAXPRO = 8 , MLINE = 1000 , MSCAHD = 250 )
      PARAMETER ( TINY= 1.D-30, ONEP1=1.1D0 ,TINY6=1.D-06)
      COMMON /HACONS/ PI,PI2,PI4,GEVTMB
      COMMON /HAPARA/ ECM,PTINI(4),Q0SQR,ALASQR,BQCD,NPD,NF,NHA,NHB
      COMMON /HAQQAP/ AQQAL,AQQPD,NQQAL,NQQPD
      DOUBLE PRECISION EC,ED,XA,XB,SP,TP,UP,TT,UU,
     *       FACTOR,DSIGM(0:MAXPRO)
      DIMENSION DSIGMM(0:MAXPRO),PDA(-6:6),PDB(-6:6)

      DO 10 I=0,MAXPRO
        DSIGM(I) = 0.0
10      CONTINUE
      EC     = EXP(ETAC)
      ED     = EXP(ETAD)
C  KINETICS
      XA     = PT*(EC+ED)/ECM
      XB     = XA/(EC*ED)
      IF ( XA.GE.1.D0 .OR. XB.GE.1.D0 ) RETURN
      SP     = XA*XB*ECM*ECM
      UP     =-ECM*PT*EC*XB
      UP     = UP/SP
      TP     =-(1.+UP)
      UU     = UP*UP
      TT     = TP*TP
C  set hard scale  QQ  for alpha and partondistr.
      IF     ( NQQAL.EQ.1 ) THEN
        QQAL = AQQAL*PT*PT
      ELSEIF ( NQQAL.EQ.2 ) THEN
        QQAL = AQQAL*SP
      ELSEIF ( NQQAL.EQ.3 ) THEN
        QQAL = AQQAL*SP*(UP*TP)**(1./3.)
      ELSEIF ( NQQAL.EQ.4 ) THEN
        QQAL = AQQAL*SP*UP*TP/(1.+TT+UU)
      ENDIF
      IF     ( NQQPD.EQ.1 ) THEN
        QQPD = AQQPD*PT*PT
      ELSEIF ( NQQPD.EQ.2 ) THEN
        QQPD = AQQPD*SP
      ELSEIF ( NQQPD.EQ.3 ) THEN
        QQPD = AQQPD*SP*(UP*TP)**(1./3.)
      ELSEIF ( NQQPD.EQ.4 ) THEN
        QQPD = AQQPD*SP*UP*TP/(1.+TT+UU)
      ENDIF
C      PARAMETER ( TINY= 1.D-30, ONEP1=1.1D0 ,TINY6=1.D-06)
      ALPHA  = BQCD/LOG(MAX(QQAL/ALASQR,ONEP1))
      FACTOR = PI2*GEVTMB*PT*(ALPHA/SP)**2
C   PARTONDISTRIBUTIONS  ( MULTIPLIED BY X )
      X1 = XA
      X2 = XB
      CALL JTPDIS(X1,QQPD,NHA,0,PDA)
      CALL JTPDIS(X2,QQPD,NHB,0,PDB)
      S1    = PDA(0)*PDB(0)
      S2    = 0.0
      S3    = 0.0
      S4    = 0.0
      S5    = 0.0
      DO 20 I=1,NF
        S2  = S2+PDA(I)*PDB(-I)+PDA(-I)*PDB( I)
        S3  = S3+PDA(I)*PDB( I)+PDA(-I)*PDB(-I)
        S4  = S4+PDA(I)+PDA(-I)
        S5  = S5+PDB(I)+PDB(-I)
20    CONTINUE
C   CROSS-SECTIONS ( INCLUDING MATRIX ELEMENTS, SYMMETRY-FACTORS AND
C                                FACTORS FOR FINALSTATE-SUMMATION )
      DSIGM(1) = 2.25*(3.-((UP*TP)+UP/TT+TP/UU))
      DSIGM(6) = (4./9.)*(UU+TT)
      DSIGM(8) = (4./9.)*(1.+UU)/TT
      DSIGM(2) = (16./27.)*(UU+TT)/(UP*TP)-3.*DSIGM(6)
      DSIGM(3) = ((1.+UU)/TT)-(4./9.)*(1.+UU)/UP
      DSIGM(4) = (9./32.)*DSIGM(2)
      DSIGM(5) = DSIGM(6)+DSIGM(8)-(8./27.)*UU/TP
      DSIGM(7) = 0.5*(DSIGM(8)+(4./9.)*(1.+TT)/UU-(8./27.)/(UP*TP))

      DSIGM(1) = FACTOR*DSIGM(1)*S1
      DSIGM(2) = FACTOR*DSIGM(2)*S2
      DSIGM(3) = FACTOR*DSIGM(3)*(PDA(0)*S5+PDB(0)*S4)
      DSIGM(4) = FACTOR*DSIGM(4)*S1*NF
      DSIGM(5) = FACTOR*DSIGM(5)*S2
      DSIGM(6) = FACTOR*DSIGM(6)*S2*MAX(0,(NF-1))
      DSIGM(7) = FACTOR*DSIGM(7)*S3
      DSIGM(8) = FACTOR*DSIGM(8)*(S4*S5-(S2+S3))
C   sum over processes
      DO 40 M=1,MAXPRO
        DSIGM(0) = DSIGM(0)+DSIGM(M)
40    CONTINUE
      DO 50 M=0,MAXPRO
        DSIGMM(M) = DSIGM(M)
50    CONTINUE
      RETURN
      END
C______________________________________________________________________
      SUBROUTINE CSJ1M(PT,ETAC,DSIGM)
C  ONE JET CROSS SECTION
C   ( CSJ2M INTEGRATED OVER ETAD )
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      PARAMETER ( MAXPRO = 8 , MLINE = 1000 , MSCAHD = 250 )
C     PARAMETER ( TINY= 1.D-30 )
C     CHANGED 14.10.92 AFTER COMPARISON WITH THE ORIGINAL
C     VERSION OF DTULAP FROM 1.D-30 BACK TO THE ORIGINAL 1.D-20
      PARAMETER ( TINY= 1.D-20 )
      COMMON /HAPARA/ ECM,PTINI(4),Q0SQR,ALASQR,BQCD,NPD,NF,NHA,NHB
      COMMON /HAGAUP/ NGAUP1,NGAUP2,NGAUET,NGAUIN
      DIMENSION DSIGM(0:MAXPRO),DSIG1(0:MAXPRO)
      DIMENSION ABSZ(32),WEIG(32)

      DO 10 M=0,MAXPRO
        DSIGM(M) = 0.0
10    CONTINUE
      EC  = EXP(ETAC)
      ARG = ECM/PT
      IF  ( ARG.LE.EC .OR. ARG.LE.1./EC ) RETURN
      EDU = LOG(ARG-EC)
      EDL =-LOG(ARG-1./EC)
      NPOINT = NGAUET
      CALL GSET(EDL,EDU,NPOINT,ABSZ,WEIG)
      DO 30 I=1,NPOINT
        CALL CSJ2M(PT,ETAC,ABSZ(I),DSIG1)
        DO 20 M=0,MAXPRO
C         PCTRL= DSIG1(M)/1.E-20
          PCTRL= DSIG1(M)/TINY
          PCTRL= ABS( PCTRL )
          IF( PCTRL.GE.1.D0 ) THEN
            DSIGM(M) = DSIGM(M)+WEIG(I)*DSIG1(M)
          ENDIF
20      CONTINUE
30    CONTINUE
      RETURN
      END
C______________________________________________________________________
      SUBROUTINE CSJ1MI(PT,DSIGM)
C  ONE JET CROSS SECTION
C   ( CSJ2M INTEGRATED OVER ETAD AND ETAC )
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      PARAMETER ( MAXPRO = 8 , MLINE = 1000 , MSCAHD = 250 )
      COMMON /HAPARA/ ECM,PTINI(4),Q0SQR,ALASQR,BQCD,NPD,NF,NHA,NHB
      COMMON /HAGAUP/ NGAUP1,NGAUP2,NGAUET,NGAUIN
      DIMENSION DSIGM(0:MAXPRO),DSIG1(0:MAXPRO)
      DIMENSION ABSZ(32),WEIG(32)

      DO 10 M=0,MAXPRO
        DSIGM(M) = 0.0
10    CONTINUE
      AMT = 2.*PT/ECM
      IF ( AMT.GE.1.D0 ) RETURN
      ECU = LOG((SQRT(1.-AMT*AMT)+1.)/AMT)
      ECL =-ECU
      NPOINT = NGAUET
      CALL GSET(ECL,ECU,NPOINT,ABSZ,WEIG)
      DO 30 I=1,NPOINT
        CALL CSJ1M(PT,ABSZ(I),DSIG1)
        DO 20 M=0,MAXPRO
          DSIGM(M) = DSIGM(M)+WEIG(I)*DSIG1(M)
20      CONTINUE
30    CONTINUE
      RETURN
      END
C______________________________________________________________________
      SUBROUTINE CSHARM(DSIGM)
C
C  TOTAL HARD CROSS SECTION
C   ( CSJ2M INTEGRATED OVER PT, ETAD AND ETAC )
C
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      PARAMETER ( MAXPRO = 8 , MLINE = 1000 , MSCAHD = 250 )
      COMMON /HAPARA/ ECM,PTINI(4),Q0SQR,ALASQR,BQCD,NPD,NF,NHA,NHB
      COMMON /HAGAUP/ NGAUP1,NGAUP2,NGAUET,NGAUIN
      COMMON /XSECPT/ PTCUT,SIGS,DSIGH
      DIMENSION DSIGM(0:MAXPRO),DSIG1(0:MAXPRO)
      DIMENSION ABSZ(32),WEIG(32)
      DATA FAC / 3.0 /

      DO 10 M=0,MAXPRO
        DSIGM(M) = 0.0
10    CONTINUE
      IF ( PTINI(1).GE.ECM/2.D0 ) RETURN
      PTMIN  = PTINI(1)
      PTCUT  = PTMIN
      PTMAX  = MIN(FAC*PTMIN,ECM/2.D0)
      NPOINT = NGAUP1
      CALL CSJ1MI(PTMIN,DSIG1)
      SIG1   = DSIG1(0)
C     WRITE(6,1000) SIG1
 1000 FORMAT(1X,' d sigma/ p_t d p_t ',E12.5)
      DSIGH  = SIG1
      PTMXX  = 0.95*PTMAX
      CALL CSJ1MI(PTMXX,DSIG1)
      EX     = LOG(SIG1/(DSIG1(0)+1.D-30))/LOG(FAC)
      EX1    = 1.0-EX
      DO 50 K=1,2
        IF ( PTMIN.GE.PTMAX ) GOTO 40
        RL   = PTMIN**EX1
        RU   = PTMAX**EX1
        CALL GSET(RL,RU,NPOINT,ABSZ,WEIG)
        DO 30 I=1,NPOINT
          R  = ABSZ(I)
          PT = R**(1.0/EX1)
          CALL CSJ1MI(PT,DSIG1)
          F  = WEIG(I)*PT/(R*EX1)
          DO 20 M=0,MAXPRO
            DSIGM(M) = DSIGM(M)+F*DSIG1(M)
20        CONTINUE
30      CONTINUE
40      PTMIN  = PTMAX
        PTMAX  = ECM/2.0D0
        NPOINT = NGAUP2
50    CONTINUE
      RETURN
      END
C-------originally seperate file ----------------------------------------
C                        JTHIST.FOR
C
C________________________________________________________________________

CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
C    PROCEDURES TO PRINT OUT HISTOGRAMS AND INCLUSICE TESTCALCULATIONS
C     ( AND TO INITIALIZE AND FILL HISTOGRAMS ALSO )
C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C______________________________________________________________________
      SUBROUTINE HISOUTT(IOUT)
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      PARAMETER ( MAXPRO = 8 , MLINE = 1000 , MSCAHD = 250 )
      PARAMETER ( TINY= 1.D-30, ONE=1.D0 ,TINY6=1.D-06,ZERO=0.D0)
      COMMON /HAPARA/ ECM,PTINI(4),Q0SQR,ALASQR,BQCD,NPD,NF,NHA,NHB
      INTEGER MXSECT
C     COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4,20),XSECT(5,-1:MAXPRO,20),
C    &                MXSECT(0:2,-1:MAXPRO,20)
      COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4,28),XSECT(5,-1:MAXPRO,28),
     &                MXSECT(0:2,-1:MAXPRO,28)
C     COMMON /LAPENE/PTTHRZ(20),PTTHZ2(20),INDENE
      COMMON /LAPENE/PTTHRZ(28),PTTHZ2(28),INDENE
C     COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4),XSECT(5,-1:MAXPRO),
C    &                MXSECT(0:2,-1:MAXPRO)
      CHARACTER*18 PROC
      CHARACTER*11 PDSET,PARTIC
      COMMON /PEPROC/ PROC(0:MAXPRO),PDSET(23),PARTIC(-1:1)
C  LENGTH OF HISTO : 15000  REAL*4
      COMMON /HISTO / PT10,DPT1,ETA10,DETA1,PT20,DPT2,ETA20,DETA2,
     &                X(50,-5:5),AB(50,-5:5),HPE(50,-5:5),HEP(50,5),
     &                HPM(50,8),HEM(50,8),HP(50),HE(50),
     &                SIG(MAXPRO),STDEV(MAXPRO),
     &                FILL(12176)
C
      XSMIN =-6.
      XSSTEP= 0.1
      DO 5 J=-5,5
        DO 5 I=1,50
5         X(I,J)  =-100.
      XSECT (2,0,INDENE) = XSECT (2,-1,INDENE)
      MXSECT(1,0,INDENE) = MXSECT(1,-1,INDENE)
      MXSECT(2,0,INDENE) = MXSECT(2,-1,INDENE)
C     XSECT (2,0) = XSECT (2,-1)
C     MXSECT(1,0) = MXSECT(1,-1)
C     MXSECT(2,0) = MXSECT(2,-1)
      DO 7 M=1,MAXPRO
        MXSECT(1,0,INDENE) = MXSECT(1,0,INDENE)+MXSECT(1,M,INDENE)
        MXSECT(2,0,INDENE) = MXSECT(2,0,INDENE)+MXSECT(2,M,INDENE)
7       XSECT (2,0,INDENE) = XSECT(2,0,INDENE)+XSECT(2,M,INDENE)
C       MXSECT(1,0) = MXSECT(1,0)+MXSECT(1,M)
C       MXSECT(2,0) = MXSECT(2,0)+MXSECT(2,M)
C7       XSECT (2,0) = XSECT(2,0)+XSECT(2,M)
      WRITE(6,1010) IOUT
1010  FORMAT(1X,20('=='),' HISTO-OUTPUT ',I2,1X,10('=='),/)
      IF ( IOUT.EQ.1 ) THEN
        WRITE(6,1040)
1040    FORMAT('      PROCESS',15X,'EVENTS',22X,'HARD CROSS SECTION',/,
     &         25X,'TOTAL  ACCEPT.',10X,'MONTE-CARLO',11X,'INCLUSIVE')
        SIGSUM = 0.0
        STDEVS = 0.0
        DO 20 M=1,MAXPRO
          SIG(M)   = 0.0
          STDEV(M) = 0.0
          IF ( MXSECT(1,M,INDENE).GT.0 ) THEN
            SIG(M)   = XSECT(3,M,INDENE)/MXSECT(1,M,INDENE)
            STDEV(M) = SQRT(MAX(ZERO,XSECT(4,M,INDENE)-
     *       XSECT(3,M,INDENE)*SIG(M)))/MXSECT(1,M,INDENE)
C         IF ( MXSECT(1,M).GT.0 ) THEN
C           SIG(M)   = XSECT(3,M)/MXSECT(1,M)
C           STDEV(M) = SQRT(MAX(ZERO,XSECT(4,M)-XSECT(3,M)*SIG(M)))/
C    &                                                     MXSECT(1,M)
          ENDIF
          IF ( M.EQ.3 .AND. MXSECT(1,-1,INDENE).GT.0 ) THEN
            SIGG     = XSECT(3,-1,INDENE)/MXSECT(1,-1,INDENE)
C         IF ( M.EQ.3 .AND. MXSECT(1,-1).GT.0 ) THEN
C           SIGG     = XSECT(3,-1)/MXSECT(1,-1)
            SIG(3)   = SIG(3)+SIGG
            STDEV(3) = STDEV(3)
     *       +SQRT(MAX(ZERO,XSECT(4,-1,INDENE)-
     *       XSECT(3,-1,INDENE)*SIGG))/MXSECT(1,-1,INDENE)
C    &       +SQRT(MAX(ZERO,XSECT(4,-1)-XSECT(3,-1)*SIGG))/MXSECT(1,-1)
          ENDIF
          SIGSUM = SIGSUM+SIG(M)
          STDEVS = STDEVS+STDEV(M)
20      CONTINUE
        MXSECT(1,3,INDENE) = MXSECT(1,3,INDENE)+MXSECT(1,-1,INDENE)
        MXSECT(2,3,INDENE) = MXSECT(2,3,INDENE)+MXSECT(2,-1,INDENE)
        WRITE(6,1050) PROC(0),(MXSECT(L,0,INDENE),L=0,2),
     &                SIGSUM,STDEVS,XSECT(5,0,INDENE)
C       MXSECT(1,3) = MXSECT(1,3)+MXSECT(1,-1)
C       MXSECT(2,3) = MXSECT(2,3)+MXSECT(2,-1)
C       WRITE(6,1050) PROC(0),(MXSECT(L,0),L=0,2),
C    &                SIGSUM,STDEVS,XSECT(5,0)
        DO 25 M=1,MAXPRO
          IF ( MXSECT(0,M,INDENE).EQ.1 ) WRITE(6,1050) PROC(M),
     &     (MXSECT(L,M,INDENE),L=0,2),SIG(M),STDEV(M),XSECT(5,M,INDENE)
C         IF ( MXSECT(0,M).EQ.1 ) WRITE(6,1050) PROC(M),
C    &              (MXSECT(L,M),L=0,2),SIG(M),STDEV(M),XSECT(5,M)
25        CONTINUE
1050      FORMAT(A19,I3,2I8,E14.4,' +- ',E10.4,E14.4)
        MXSECT(1,3,INDENE) = MXSECT(1,3,INDENE)-MXSECT(1,-1,INDENE)
        MXSECT(2,3,INDENE) = MXSECT(2,3,INDENE)-MXSECT(2,-1,INDENE)
C       MXSECT(1,3) = MXSECT(1,3)-MXSECT(1,-1)
C       MXSECT(2,3) = MXSECT(2,3)-MXSECT(2,-1)
      ELSEIF ( IOUT.EQ.2 ) THEN
        FAC = XSECT(2,0,INDENE)/(DPT1*MXSECT(1,0,INDENE))
C       FAC = XSECT(2,0)/(DPT1*MXSECT(1,0))
        DO 30 I=1,50
          AB(I,1) = PT10+(I-1)*DPT1
          IF ( HP(I).GT.1.D-35 ) X(I,1) = LOG10(FAC*HP(I))
30        CONTINUE
        WRITE(6,1060)
1060    FORMAT('  JET CROSS SECTION  PT-DISTRIBUTION',/)
        CALL PLOT(AB(1,1),X(1,1),50,1,50,PT10,DPT1,XSMIN,XSSTEP)
      ELSEIF ( IOUT.EQ.3 ) THEN
        FAC = XSECT(2,0,INDENE)/(DPT1*MXSECT(1,0,INDENE))
C       FAC = XSECT(2,0)/(DPT1*MXSECT(1,0))
        DO 50 I=1,50
          PT = PT10+(I-1)*DPT1
          DO 40 J=1,8
            AB(I,J-6)  = PT
            IF ( HPM(I,J).GT.1.D-35 ) X(I,J-6) = LOG10(FAC*HPM(I,J))
40          CONTINUE
50        CONTINUE
        WRITE(6,1070)
1070    FORMAT('  JET CROSS SECTION  PT-DISTRIBUTION',/,
     &         '                     FOR THE DIFF. SUBPROCESSES',/)
        CALL PLOT(AB,X,400,8,50,PT10,DPT1,XSMIN,XSSTEP)
      ELSEIF ( IOUT.EQ.4 ) THEN
        FAC = XSECT(2,0,INDENE)/(DPT1*DETA1*MXSECT(1,0,INDENE))
C       FAC = XSECT(2,0)/(DPT1*DETA1*MXSECT(1,0))
        DO 70 I=1,50
          PT = PT10+(I-1)*DPT1
          DO 60 J=-5,5
            AB(I,J)  = PT
            IF ( HPE(I,J).GT.1.D-35 ) X(I,J) = LOG10(FAC*HPE(I,J))
60          CONTINUE
70        CONTINUE
        WRITE(6,1080) ETA10,-ETA10
1080    FORMAT('  JET CROSS SECTION  PT-DISTRIBUTION',/,
     &         '                     RAP.=',F5.2,'...',F4.2,/)
        CALL PLOT(AB,X,550,11,50,PT10,DPT1,XSMIN,XSSTEP)
      ELSEIF ( IOUT.EQ.5 ) THEN
        FAC = XSECT(2,0,INDENE)/(DETA2*DPT2*MXSECT(1,0,INDENE))
C       FAC = XSECT(2,0)/(DETA2*DPT2*MXSECT(1,0))
        DO 80 I=1,50
          ETA = ETA20+(I-1)*DETA2
          DO 75 J=1,5
            AB(I,J) = ETA
            IF ( HEP(I,J).GT.1.D-35 ) X(I,J) = LOG10(FAC*HEP(I,J))
75          CONTINUE
80        CONTINUE
        WRITE(6,1090) PT20,PT20+4.*DPT2
1090    FORMAT('  JET CROSS SECTION   RAP.-DISTRIBUTION',/,
     &         '                      PT=',F6.2,'...',F6.2,/)
        CALL PLOT(AB(1,1),X(1,1),250,5,50,ETA20,DETA2,XSMIN,XSSTEP)
      ELSEIF ( IOUT.EQ.6 ) THEN
        FAC = XSECT(2,0,INDENE)/(DETA2*MXSECT(1,0,INDENE))
C       FAC = XSECT(2,0)/(DETA2*MXSECT(1,0))
        DO 100 I=1,50
          ETA = ETA20+(I-1)*DETA2
          DO 90 J=1,8
            AB(I,J-6)  = ETA
            IF ( HEM(I,J).GT.1.D-35 ) X(I,J-6) = LOG10(FAC*HEM(I,J))
90          CONTINUE
100       CONTINUE
        WRITE(6,1100)
1100    FORMAT('  JET CROSS SECTION  RAP.-DISTRIBUTION',/,
     &         '                     FOR THE DIFF. SUBPROCESSES',/)
        CALL PLOT(AB,X,400,8,50,ETA20,DETA2,XSMIN,XSSTEP)
      ENDIF
      WRITE(6,1110)
1110  FORMAT(/)
      RETURN
      END

C______________________________________________________________________
      SUBROUTINE HISINII
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      PARAMETER ( MAXPRO = 8 , MLINE = 1000 , MSCAHD = 250 )
C  LENGTH OF HISTO : 15000  REAL*4
      COMMON /HISTO / PT10,DPT1,ETA10,DETA1,PT20,DPT2,ETA20,DETA2,
     &                X(50,-5:5),AB(50,-5:5),HPE(50,-5:5),HEP(50,5),
     &                HPM(50,8),HEM(50,8),HP(50),HE(50),
     &                FILL(12192)
C
C  INITIALIZE HISTOGRAMS
      DPT1    = 1.
      DETA1   = 1.
      DPT2    = 2.
      DETA2   = 0.2
      PT10    = 1.
      ETA10   =-5.*DETA1
      PT20    = 2.
      ETA20   =-25.*DETA2
      DO 40 I=1,50
        HP(I)      = 0.0
        HE(I)      = 0.0
        DO 10 J=-5,5
10        HPE(I,J) = 0.0
        DO 20 J=1,5
20        HEP(I,J) = 0.0
        DO 30 J=1,8
          HPM(I,J) = 0.0
30        HEM(I,J) = 0.0
40      CONTINUE
      RETURN
      END
C______________________________________________________________________
      SUBROUTINE HISFIL2
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      PARAMETER ( MAXPRO = 8 , MLINE = 1000 , MSCAHD = 250 )
      COMMON /HAEVTR/ LINE,LIN,LREC1(MLINE),LREC2(MLINE),PREC(0:3,MLINE)
      COMMON /HARSLT/ LSCAHD,LSC1HD,
     &                ETAHD(MSCAHD,2) ,PTHD(MSCAHD),
     &                XHD(MSCAHD,2)   ,VHD(MSCAHD) ,X0HD(MSCAHD,2),
     &                NINHD(MSCAHD,2) ,NOUTHD(MSCAHD,2),
     &                N0INHD(MSCAHD,2),NBRAHD(MSCAHD,2),NPROHD(MSCAHD)
C  LENGTH OF HISTO : 15000  REAL*4
      COMMON /HISTO / PT10,DPT1,ETA10,DETA1,PT20,DPT2,ETA20,DETA2,
     &                X(50,-5:5),AB(50,-5:5),HPE(50,-5:5),HEP(50,5),
     &                HPM(50,8),HEM(50,8),HP(50),HE(50),
     &                FILL(12192)
C
C  fill histogram
      DO 20 N=1,LSCAHD
        MSPR   = NPROHD(N)
        DO 10 K=1,2
          IPT1   = INT((PTHD(N)-PT10)/DPT1)+1
          IETA1  = INT((ETAHD(N,K)-ETA10)/DETA1+0.5)-5
          IPT2   = INT((PTHD(N)-PT20)/DPT2)+1
          IETA2  = INT((ETAHD(N,K)-ETA20)/DETA2+0.5)
          IF ( IPT1.GE. 1 .AND. IPT1.LE.50 ) THEN
            HPM(IPT1,MSPR)  = HPM(IPT1,MSPR)+1.
            HP(IPT1)        = HP(IPT1)+1.
            IF ( ABS(IETA1).LE.5 ) HPE(IPT1,IETA1) = HPE(IPT1,IETA1)+1.
          ENDIF
          IF ( IETA2.GE. 1 .AND. IETA2.LE.50 ) THEN
            HEM(IETA2,MSPR) = HEM(IETA2,MSPR)+1.
            HE(IETA2)       = HE(IETA2)+1.
            IF ( IPT2.GE.1 .AND. IPT2.LE.5 ) HEP(IETA2,IPT2) =
     &                                              HEP(IETA2,IPT2)+1.
          ENDIF
10      CONTINUE
20    CONTINUE
      RETURN
      END
C_______________________________________________________________________
      SUBROUTINE HATEST(IOUT)
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      PARAMETER ( MAXPRO = 8 , MLINE = 1000 , MSCAHD = 250 )
      COMMON /HAPARA/ ECM,PTINI(4),Q0SQR,ALASQR,BQCD,NPD,NF,NHA,NHB
      CHARACTER*18 PROC
      CHARACTER*11 PDSET,PARTIC
      COMMON /PEPROC/ PROC(0:MAXPRO),PDSET(23),PARTIC(-1:1)
C  LENGTH OF HISTO : 15000  REAL*4
      COMMON /HISTO / VVV(50),XS(50,6),AB(50,6),DSIG(0:MAXPRO),PD(-6:6),
     &                FILL(14328)
      IF ( IOUT.EQ.1 ) THEN
        CALL CSHARM(DSIG)
        WRITE(6,1010) ECM,PTINI(1),(PROC(M),DSIG(M),M=0,MAXPRO)
1010    FORMAT('  HARD CROSS SECTIONS FOR SINGLE PROCESSES',/,
     &   '  AT CM-ENERGY=',E8.1,' AND PTMIN=',F5.1,/,9(A25,E14.6,/))
      ELSEIF ( IOUT.EQ.2 ) THEN
C  PLOT PARTON DISTRIBUTIONS
        PDMIN  = 0.0
        PDSTEP = 0.04
        YMAX   = 5.0
        DY     = YMAX/50.
        QQ     = 10.0
        DO 10 J=1,50
          Y         = FLOAT(J-1)*DY
          VVV(J)    = 10.0**(-Y)
          DO 10 I=1,5
            XS(J,I) =-1.E+30
            AB(J,I) = Y
10          CONTINUE
        QQ   = 1.0
        DO 20 I=1,5
          QQ = QQ*10.
          DO 20 J=1,50
            CALL JTPDIS(VVV(J),QQ,1,1,PD)
            IF ( PD(0).GT.1.D-30 ) XS(J,I) = LOG10(PD(0))
20          CONTINUE
        WRITE(6,1020)
1020    FORMAT('   GLUONDISTRIBUTION OVER LOG10(X)  ( Q**2=10**I;',
     &                '   I=1...5 )')
        CALL PLOT(AB,XS,250,5,50,YMAX,-DY,PDMIN,PDSTEP)
      ELSEIF ( IOUT.EQ.3 ) THEN
        QQMIN  = 1.0
        QQSTEP = 0.1
        DO 30 I=1,50
          B         = FLOAT(I-1)*QQSTEP+QQMIN
          VVV(I)    = 10.0**B
          DO 30 J=1,5
            XS(I,J) = -1.D+30
            AB(I,J) = B
30        CONTINUE
        X   = 1.0
        DO 40 I=1,50
          X = 1.0
          DO 40 J=1,4
            X = X*0.1D0
            CALL JTPDIS(X,VVV(I),1,1,PD)
            IF ( PD(0).GT.1.D-30 ) XS(I,J) = LOG10(PD(0))
40          CONTINUE
        WRITE(6,1030)
1030    FORMAT('   GLUONDISTRIBUTION OVER LOG10(Q**2)  ( X=10**(-I)'
     &              ,';  I=1...4')
        CALL PLOT(AB,XS,200,4,50,QQMIN,QQSTEP,PDMIN,PDSTEP)
      ELSEIF ( IOUT.EQ.4 ) THEN
C  PLOT DIFFERENTIAL ONE JET CROSS SECTION
        XSMIN  =-6.
        XSSTEP = 0.1
        PTMIN  = 1.0
        PTSTEP = 1.0
        DO 50 I=1,50
          PT        = (I-1)*PTSTEP+PTMIN
          XS(I,1)   =-35.0
          DO 50 J=1,6
50          AB(I,J) = PT
C       DO 60 J=1,6
C         ETAC  = (J-1)*0.5
          ETAC = 0.0
          DO 60 I=1,50
            PT = AB(I,1)
            CALL CSJ1M(PT,ETAC,DSIG)
            IF ( DSIG(0).GT.1.D-30 ) XS(I,1) = LOG10(DSIG(0))
60          CONTINUE
        WRITE(6,1040)
1040    FORMAT('  DIFFERENTIAL HARD CROSS SECTION OVER PT , RAP.=0.')
        CALL PLOT(AB,XS,50,1,50,PTMIN,PTSTEP,XSMIN,XSSTEP)
      ENDIF
      RETURN
      END
C-----------------------------------------------------------------------
C
C                                JTINIT.FOR
C
C---------------------------------------------------------------------
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
C     PROCEDURES TO INITIALIZE PROGRAM
C      ( NONE OF THIS PROCEDURES IS USED DURING EVENT SIMULATION,
C        BEFORE DEMANDING EVENT SIMULATION SUBROUTINES
C        HASTRT, HARINI AND HISINI MUST BE CALLED )
C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C_______________________________________________________________________
      SUBROUTINE HARINI
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      PARAMETER ( MAXPRO = 8 , MLINE = 1000 , MSCAHD = 250 )
      COMMON /HACONS/ PI,PI2,PI4,GEVTMB
      COMMON /HAPARA/ ECM,PTINI(4),Q0SQR,ALASQR,BQCD,NPD,NF,NHA,NHB
      COMMON /HAPDCO/ NPDCOR
      COMMON /HAQQAP/ AQQAL,AQQPD,NQQAL,NQQPD
      COMMON /HAOUTL/ NOUTL,NOUTER,NOUTCO
      INTEGER MXSECT
C     COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4,20),XSECT(5,-1:MAXPRO,20),
C    &                MXSECT(0:2,-1:MAXPRO,20)
      COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4,28),XSECT(5,-1:MAXPRO,28),
     &                MXSECT(0:2,-1:MAXPRO,28)
C     COMMON /LAPENE/PTTHRZ(20),PTTHZ2(20),INDENE
      COMMON /LAPENE/PTTHRZ(28),PTTHZ2(28),INDENE
C     COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4),XSECT(5,-1:MAXPRO),
C    &                MXSECT(0:2,-1:MAXPRO)
      CHARACTER*18 PROC
      CHARACTER*11 PDSET,PARTIC
      COMMON /PEPROC/ PROC(0:MAXPRO),PDSET(23),PARTIC(-1:1)
      DIMENSION DSIG(0:MAXPRO),ALAM(23),Q0S(23)
      DATA ALAM / 0.20D0, 0.29D0, 0.107D0, 0.250D0, 0.178D0, 0.25D0,
     *            0.10D0, 0.19D0, 0.190D0, 0.190D0, 0.190D0, 0.19D0,
     *            0.215D0,0.215D0,0.215D0,
     *            0.231D0,0.231D0,0.322D0, 0.247D0,
     *            0.168D0,0.2D0,0.2D0,0.202D0 /
      DATA Q0S  / 5.0D0 , 5.0D0 , 5.0D0  , 5.0D0  , 5.0D0 , 0.2D0,
     *            5.0D0 , 5.0D0 , 5.0D0  , 5.0D0  , 5.0D0 , 5.0D0,
     *            5.0D0 , 5.0D0 , 5.0D0  , 4.0D0  , 4.0D0 , 4.0D0,
     *            4.0D0 , 4.0D0 ,  0.4D0 ,0.4D0 ,1.60D0     /
C
        WRITE(6,*)' HARINI:NPD=',NPD
	IF ( NOUTL.GE.1 )CALL TIMDAT
        ALASQR = ALAM(NPD)**2
        Q0SQR  = Q0S(NPD)
        BQCD   = PI4/(11.-(2./3.)*NF)
C  check and sort the min. pt values in PTINI(1..4)
        INI = 0
        DO 30 I=1,4
          IF ( PTINI(I).LE..5D0.OR.PTINI(I).GE.ECM*.5D0)PTINI(I)=1.D+30
          IF ( PTINI(I).NE.1.D+30 ) INI = INI+1
30      CONTINUE
        DO 50 I=1,3
          DO 40 J=I+1,4
            IF ( PTINI(J).LT.PTINI(I) ) THEN
              TTT      = PTINI(J)
              PTINI(J) = PTINI(I)
              PTINI(I) = TTT
            ENDIF
40        CONTINUE
50      CONTINUE
C  calculate constant weights
        DO 10 M=-1,MAXPRO
           XSECT (3,M,INDENE) = 0.0
           XSECT (4,M,INDENE) = 0.0
           MXSECT(1,M,INDENE) = 0
           MXSECT(2,M,INDENE) = 0
C         XSECT (3,M) = 0.0
C         XSECT (4,M) = 0.0
C         MXSECT(1,M) = 0
C         MXSECT(2,M) = 0
10      CONTINUE
        DO 20     I = 1,4
          DO 20   M =-1,MAXPRO
            DO 20 J = 1,2
              XSECTA(J,M,I,INDENE) = 0.0
C             XSECTA(J,M,I) = 0.0
20      CONTINUE
        DO 70 I=INI,1,-1
          CALL HABINT(I)
          IF ( NOUTL.GE.10 ) WRITE(6,1060) PTINI(I)
1060      FORMAT(' NORMALIZATION FOR PTMIN=',F10.4,' CALCULATED')
          CALL HAMAXI(I)
          IF ( NOUTL.GE.10 ) WRITE(6,1070) PTINI(I)
1070      FORMAT(' MAXIMA FOR PTMIN=',F10.4,' CALCULATED')
          XSECTA(1,0,I,INDENE)   = PTINI(I)
C         XSECTA(1,0,I)   = PTINI(I)
          DO 60 M=-1,MAXPRO
            XSECTA(1,M,I,INDENE) = XSECT(1,M,INDENE)
	    XSECTA(2,M,I,INDENE) = XSECT(2,M,INDENE)
C           XSECTA(1,M,I) = XSECT(1,M)
C           XSECTA(2,M,I) = XSECT(2,M)
60        CONTINUE
70      CONTINUE
C  calculate inclusive cross-sections
        CALL CSHARM(DSIG)
        DO 80 M=0,MAXPRO
          XSECT(5,M,INDENE) = DSIG(M)
C         XSECT(5,M) = DSIG(M)
80      CONTINUE
C
C  print results of initialization
C
        IF ( NOUTL.GE.10 ) WRITE(6,'(/,1X,70(1H*))')
        WRITE(6,1057) PTINI(1),PDSET(NPD),SQRT(ALASQR),Q0SQR
1057    FORMAT(/,
     &         ' --- parameters of the hard scattering program ---',/,
     &         '       MIN. PT       :',F15.1,/,
     &         '       PARTON-DISTR. :',A15,/,
     &         '       LAMBDA        :',F15.3,/,
     &         '       Q0**2         :',F15.3,/)
      IF ( NOUTL.GE.1 ) THEN
        WRITE(6,1050) PARTIC(NHA),PARTIC(NHB),ECM,PTINI(1),PDSET(NPD),
     &                SQRT(ALASQR),Q0SQR,NPDCOR,NQQAL,AQQAL,NQQPD,AQQPD
1050    FORMAT(/,1X,70('*'),/,
     &         '  HARD SCATTERING PROGRAM IS INITIALIZED FOR',/,
     &         '    PROJECTILE    :',A15,/,
     &         '    TARGET        :',A15,/,
     &         '    CM-ENERGY     :',F15.1,/,
     &         '    MIN. PT       :',F15.1,/,
     &         '    PARTON-DISTR. :',A15,/,
     &         '    LAMBDA        :',F15.3,/,
     &         '    Q0**2         :',F15.3,/,
     &         '    NPDCOR        :',I15,/,
     &         '    NQQAL         :',I15,/,
     &         '    AQQAL         :',F15.3,/,
     &         '    NQQPD         :',I15,/,
     &         '    AQQPD         :',F15.3,/)
         CALL TIMDAT
      ENDIF
      RETURN
      END
C_______________________________________________________________________
      SUBROUTINE HABINT(IND)
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      PARAMETER ( MAXPRO = 8 , MLINE = 1000 , MSCAHD = 250 )
      PARAMETER ( MXABWT = 1000 )
      PARAMETER ( ZERO=0.D0, ONE=1.D0)
      COMMON /HACONS/ PI,PI2,PI4,GEVTMB
      COMMON /HAPARA/ ECM,PTINI(4),Q0SQR,ALASQR,BQCD,NPD,NF,NHA,NHB
      COMMON /HAGAUP/ NGAUP1,NGAUP2,NGAUET,NGAUIN
      INTEGER MXSECT
C     COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4,20),XSECT(5,-1:MAXPRO,20),
C    &                MXSECT(0:2,-1:MAXPRO,20)
      COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4,28),XSECT(5,-1:MAXPRO,28),
     &                MXSECT(0:2,-1:MAXPRO,28)
C     COMMON /LAPENE/PTTHRZ(20),PTTHZ2(20),INDENE
      COMMON /LAPENE/PTTHRZ(28),PTTHZ2(28),INDENE
C     COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4),XSECT(5,-1:MAXPRO),
C    &                MXSECT(0:2,-1:MAXPRO)
      DIMENSION       ABSZ(MXABWT),WEIG(MXABWT)
      DIMENSION S(-1:MAXPRO),S1(-1:MAXPRO),S2(-1:MAXPRO),F124(-1:MAXPRO)
      DATA F124 / 1.,0.,4.,2.,2.,2.,4.,1.,4.,4. /

      A      = (2.*PTINI(IND)/ECM)**2
      ALN    = LOG(A)
      HLN    = LOG(0.5)
      NPOINT = NGAUIN
      CALL GSET(ZERO,ONE,NPOINT,ABSZ,WEIG)
      DO 10 M=-1,MAXPRO
        S1(M) = 0.0
10    CONTINUE
      DO 80 I1=1,NPOINT
        Z1   = ABSZ(I1)
        X1   = EXP(ALN*Z1)
        DO 20 M=-1,MAXPRO
          S2(M) = 0.0
20      CONTINUE
        DO 60 I2=1,NPOINT
          Z2 = (1.-Z1)*ABSZ(I2)
          X2 = EXP(ALN*Z2)
          FAXX = A/(X1*X2)
          W    = SQRT(1.-FAXX)
          W1   = FAXX/(1.+W)
          WLOG = LOG(W1)
          FWW  = FAXX*WLOG/W
          DO 30 M=-1,MAXPRO
            S(M) = 0.0
30        CONTINUE
          DO 40 I=1,NPOINT
            Z   = ABSZ(I)
            VA  =-0.5*W1/(W1+Z*W)
            UA  =-1.-VA
            VB  =-0.5*FAXX/(W1+2.*W*Z)
            UB  =-1.-VB
            VC  =-EXP(HLN+Z*WLOG)
            UC  =-1.-VC
            VE  =-0.5*(1.+W)+Z*W
            UE  =-1.-VE
            S(1)  = S(1)+(1.+W)*2.25*(VA*VA*(3.-UA*VA-VA/(UA*UA))-UA)*
     &           WEIG(I)
            S(2)  = S(2)+(VC*VC+UC*UC)*((16./27.)/UC-(4./3.)*VC)*FWW*
     &            WEIG(I)
            S(3)  = S(3)+(1.+W)*(1.+UA*UA)*(1.-(4./9.)*VA*VA/UA)*WEIG(I)
            S(5)  = S(5)+((4./9.)*(1.+UB*UB+(UB*UB+VB*VB)*VB*VB)-
     &            (8./27.)*UA*UA*VA)*WEIG(I)
            S(6)  = S(6)+(4./9.)*(UE*UE+VE*VE)*FAXX*WEIG(I)
            S(7)  = S(7)+(1.+W)*((2./9.)*(1.+UA*UA+(1.+VA*VA)*VA*VA/
     &            (UA*UA))-(4./27.)*VA/UA)*WEIG(I)
            S(8)  = S(8)+(4./9.)*(1.+UB*UB)*WEIG(I)
            S(-1) = S(-1)+(1.+VC*VC)*(VC/(UC*UC)-(4./9.))*FWW*WEIG(I)
40        CONTINUE
          S(4)    = S(2)*(9./32.)
          DO 50 M=-1,MAXPRO
            S2(M) = S2(M)+S(M)*WEIG(I2)*W
50        CONTINUE
60      CONTINUE
        DO 70 M=-1,MAXPRO
          S1(M) = S1(M)+S2(M)*(1.-Z1)*WEIG(I1)
70      CONTINUE
80    CONTINUE
      FFF    = PI*GEVTMB*ALN*ALN/(A*ECM*ECM)
      DO 90 M=-1,MAXPRO
        XSECT(1,M,INDENE) = FFF*F124(M)*S1(M)
C       XSECT(1,M) = FFF*F124(M)*S1(M)
90    CONTINUE
      XSECT(1,4,INDENE) = XSECT(1,4,INDENE)*NF
      XSECT(1,6,INDENE) = XSECT(1,6,INDENE)*MAX(0,NF-1)
C     XSECT(1,4) = XSECT(1,4)*NF
C     XSECT(1,6) = XSECT(1,6)*MAX(0,NF-1)
      RETURN
      END
C______________________________________________________________________
      SUBROUTINE HAMAXI(IND)
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      PARAMETER ( MAXPRO = 8 , MLINE = 1000 , MSCAHD = 250 )
      PARAMETER ( NKM = 5 )
      PARAMETER ( TINY= 1.D-30 )
      COMMON /HAPARA/ ECM,PTINI(4),Q0SQR,ALASQR,BQCD,NPD,NF,NHA,NHB
      INTEGER MXSECT
C     COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4,20),XSECT(5,-1:MAXPRO,20),
C    &                MXSECT(0:2,-1:MAXPRO,20)
      COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4,28),XSECT(5,-1:MAXPRO,28),
     &                MXSECT(0:2,-1:MAXPRO,28)
C     COMMON /LAPENE/PTTHRZ(20),PTTHZ2(20),INDENE
      COMMON /LAPENE/PTTHRZ(28),PTTHZ2(28),INDENE
C     COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4),XSECT(5,-1:MAXPRO),
C    &                MXSECT(0:2,-1:MAXPRO)
      DIMENSION Z(3),D(3),FF(NKM)

      DO 40 NKON=1,NKM
        Z(1) = 0.99
        Z(2) = 0.5
        Z(3) = 0.0
        D(1) =-1.0
        D(2) = 2.0
        D(3) = 2.5
        IT   = 0
        CALL HAFDI1(NKON,Z,F2,IND)
10        IT   = IT+1
          FOLD = F2
          DO 30 I=1,3
            D(I) = D(I)/5.
            Z(I)   = Z(I)+D(I)
            CALL HAFDI1(NKON,Z,F3,IND)
            IF ( F2.GT.F3 ) Z(I) = Z(I)-D(I)
            IF ( F2.GT.F3 ) D(I) =-D(I)
20            F1   = MIN(F2,F3)
              F2   = MAX(F2,F3)
              Z(I) = Z(I)+D(I)
              CALL HAFDI1(NKON,Z,F3,IND)
              IF ( F3.GT.F2 ) GOTO 20
            ZZ     = Z(I)-D(I)
            Z(I)   = ZZ+0.5*D(I)*(F3-F1)/MAX(TINY,F2+F2-F1-F3)
            IF ( ABS(ZZ-Z(I)).GT.D(I)*0.1D0)CALL HAFDI1(NKON,Z,F1,IND)
            IF ( F1.LE.F2 ) Z(I) = ZZ
            F2     = MAX(F1,F2)
30        CONTINUE
          IF ( ABS(FOLD-F2)/F2.GT.0.002D0.OR. IT.LT.3 ) GOTO 10
        FF(NKON) = F2
40    CONTINUE
      XSECT(2,1,INDENE) = FF(1)*XSECT(1,1,INDENE)
      XSECT(2,2,INDENE) = FF(2)*XSECT(1,2,INDENE)
      XSECT(2,3,INDENE) = FF(4)*XSECT(1,3,INDENE)
      XSECT(2,4,INDENE) = FF(1)*XSECT(1,4,INDENE)
      XSECT(2,5,INDENE) = FF(2)*XSECT(1,5,INDENE)
      XSECT(2,6,INDENE) = FF(2)*XSECT(1,6,INDENE)
      XSECT(2,7,INDENE) = FF(3)*XSECT(1,7,INDENE)
      XSECT(2,8,INDENE) = FF(5)*XSECT(1,8,INDENE)
      XSECT(2,-1,INDENE)= FF(4)*XSECT(1,-1,INDENE)
      RETURN
      END
C______________________________________________________________________
      SUBROUTINE HAFDI1(NKON,Z,FDIS,IND)
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      PARAMETER ( MAXPRO = 8 , MLINE = 1000 , MSCAHD = 250 )
      PARAMETER ( NKM = 5 )
      PARAMETER ( TINY= 1.D-30, ONE=1.D0 ,TINY6=1.D-06,ZERO=0.D0)
      COMMON /HAPARA/ ECM,PTINI(4),Q0SQR,ALASQR,BQCD,NPD,NF,NHA,NHB
      COMMON /HAQQAP/ AQQAL,AQQPD,NQQAL,NQQPD
      DIMENSION F(NKM),PDA(-6:6),PDB(-6:6),Z(3)

      FDIS = 0.0
C check input values
      IF ( Z(1).LE.0.0D0  .OR.  Z(1).GE.1.0D0 ) RETURN
      IF ( Z(2).LE.0.0D0  .OR.  Z(2).GE.1.0D0 ) RETURN
      IF ( Z(3).LT.0.0D0  .OR.  Z(3).GT.1.0D0 ) RETURN
      A     = (2.*PTINI(IND)/ECM)**2
      ALN   = LOG(A)
      Y1  = EXP(ALN*Z(1))
      Y2  =-(1.-Y1)+2.*(1.-Y1)*Z(2)
      X1  = 0.5*(Y2+SQRT(Y2*Y2+4.*Y1))
      X2  = X1-Y2
      W   = SQRT(MAX(TINY,1.-A/Y1))
      V   =-0.5+W*(Z(3)-0.5)
      U   =-(1.+V)
      PT  = MAX(PTINI(IND),SQRT(U*V*Y1*ECM*ECM))
C  set hard scale  QQ  for alpha and partondistr.
      IF     ( NQQAL.EQ.1 ) THEN
        QQAL = AQQAL*PT*PT
      ELSEIF ( NQQAL.EQ.2 ) THEN
        QQAL = AQQAL*Y1*ECM*ECM
      ELSEIF ( NQQAL.EQ.3 ) THEN
        QQAL = AQQAL*Y1*ECM*ECM*(U*V)**(1./3.)
      ELSEIF ( NQQAL.EQ.4 ) THEN
        QQAL = AQQAL*Y1*ECM*ECM*U*V/(1.+V*V+U*U)
      ENDIF
      IF     ( NQQPD.EQ.1 ) THEN
        QQPD = AQQPD*PT*PT
      ELSEIF ( NQQPD.EQ.2 ) THEN
        QQPD = AQQPD*Y1*ECM*ECM
      ELSEIF ( NQQPD.EQ.3 ) THEN
        QQPD = AQQPD*Y1*ECM*ECM*(U*V)**(1./3.)
      ELSEIF ( NQQPD.EQ.4 ) THEN
        QQPD = AQQPD*Y1*ECM*ECM*U*V/(1.+V*V+U*U)
      ENDIF
      FACTOR = (BQCD/LOG(MAX(QQAL/ALASQR,1.1*ONE)))**2
C calculate partondistributions
      CALL JTPDIS(X1,QQPD,NHA,0,PDA)
      CALL JTPDIS(X2,QQPD,NHB,0,PDB)
C calculate full distribution FDIS
      DO 10 N=1,NKM
        F(N) = 0.0
10    CONTINUE
      DO 20 I=1,NF
        F(2) = F(2)+PDA(I)*PDB(-I)+PDA(-I)*PDB( I)
        F(3) = F(3)+PDA(I)*PDB( I)+PDA(-I)*PDB(-I)
        F(4) = F(4)+PDA(I)+PDA(-I)
        F(5) = F(5)+PDB(I)+PDB(-I)
20    CONTINUE
      F(1)   = PDA(0)*PDB(0)
      T      = PDA(0)*F(5)+PDB(0)*F(4)
      F(5)   = F(4)*F(5)-(F(2)+F(3))
      F(4)   = T
      FDIS   = MAX(ZERO,F(NKON)*FACTOR)
      RETURN
      END
C______________________________________________________________________
      SUBROUTINE HASTRT
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      PARAMETER ( MAXPRO = 8 , MLINE = 1000 , MSCAHD = 250 )
      COMMON /HACONS/ PI,PI2,PI4,GEVTMB
      COMMON /HAPARA/ ECM,PTINI(4),Q0SQR,ALASQR,BQCD,NPD,NF,NHA,NHB
      COMMON /HAPADI/ NPDM
      COMMON /HAPDCO/ NPDCOR
      COMMON /HAQQAP/ AQQAL,AQQPD,NQQAL,NQQPD
      COMMON /HAOUTL/ NOUTL,NOUTER,NOUTCO
      COMMON /HACUTS/ PTL,PTU,ETACL,ETACU,ETADL,ETADU
      COMMON /HAGAUP/ NGAUP1,NGAUP2,NGAUET,NGAUIN
      COMMON /HAEVTR/ LINE,LIN,LREC1(MLINE),LREC2(MLINE),PREC(0:3,MLINE)
      INTEGER MXSECT
C     COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4,20),XSECT(5,-1:MAXPRO,20),
C    &                MXSECT(0:2,-1:MAXPRO,20)
      COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4,28),XSECT(5,-1:MAXPRO,28),
     &                MXSECT(0:2,-1:MAXPRO,28)
C     COMMON /LAPENE/PTTHRZ(20),PTTHZ2(20),INDENE
      COMMON /LAPENE/PTTHRZ(28),PTTHZ2(28),INDENE
C     COMMON /HAXSEC/ XSECTA(2,-1:MAXPRO,4),XSECT(5,-1:MAXPRO),
C    &                MXSECT(0:2,-1:MAXPRO)
      COMMON /HAXSUM/XSHMX
C  initialize COMMON /HAXSUM/
      XSHMX    = 1.
C  initialize COMMON /HACONS/
      PI       = 3.1415927
      PI2      = 2.*PI
      PI4      = 4.*PI
      GEVTMB   = 0.389365
C  initialize COMMON /HAPARA/
      ECM      = 1800.
      PTINI(1) = 2.0
      PTINI(2) = 0.0
      PTINI(3) = 0.0
      PTINI(4) = 0.0
      Q0SQR    = 5.0
      ALASQR   = 0.107**2
      NF       = 4
      BQCD     = PI4/(11.0-(2./3.)*NF)
      NPD      = 3
      NHA      = 1
      NHB      =-1
C  initialize COMMON /HAPADI/
      NPDM     = 0
C  initialize COMMON /HAPDCO/
      NPDCOR   = 0
C  initialize COMMON /HAQQAP/
      NQQAL    = 1
      AQQAL    = 0.25
      NQQPD    = 1
      AQQPD    = 0.25
C  initialize COMMON /HAOUTL/
      NOUTL    = 1
      NOUTER   = 1
      NOUTCO   = 0
C  initialize COMMON /HAGAUP/
      NGAUP1   = 8
      NGAUP2   = 8
      NGAUET   = 8
      NGAUIN   = 8
C  initialize COMMON /HACUTS/
      PTL      = 0.E+00
      PTU      = 1.E+30
      ETACL    =-1.E+30
      ETACU    = 1.E+30
      ETADL    =-1.E+30
      ETADU    = 1.E+30
C  initialize COMMON /HAEVTR/
      LINE       = 0
      LIN        = 0
      DO 20 L = 1,MLINE
        LREC1(L) = 0
        LREC2(L) = 0
        DO 10 I=0,3
          PREC(I,L) = 0.0
10      CONTINUE
20    CONTINUE
C  initialize COMMON /HAXSEC/
      DO 40 M=-1,MAXPRO
        DO 30 I=1,5
          XSECT(I,M,INDENE) = 0.0
C         XSECT(I,M) = 0.0
30      CONTINUE
        MXSECT(1,M,INDENE)  = 0
        MXSECT(2,M,INDENE)  = 0
        MXSECT(0,M,INDENE)  = 1
40    CONTINUE
      RETURN
      END
C----------------------------------------------------------------------
      BLOCK DATA JTDATA
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      PARAMETER ( MAXPRO = 8 , MLINE = 1000 , MSCAHD = 250 )
      CHARACTER*18 PROC
      CHARACTER*11 PDSET,PARTIC
      COMMON /PEPROC/ PROC(0:MAXPRO),PDSET(23),PARTIC(-1:1)

      DATA PROC   /  'SUM OVER PROCESSES', 'G  +G  --> G  +G  ',
     &               'Q  +QB --> G  +G  ', 'G  +Q  --> G  +Q  ',
     &               'G  +G  --> Q  +QB ', 'Q  +QB --> Q  +QB ',
     &               'Q  +QB --> QS +QBS', 'Q  +Q  --> Q  +Q  ',
     &               'Q  +QS --> Q  +QS '                       /
      DATA PDSET  / ' EHLQ SET 1',' EHLQ SET 2',' MRS  SET 1',
     &              ' MRS  SET 2',' MRS  SET 3',' GRV LO    ',
     &              ' HMRS SET 1',' HMRS SET 2',' KMRS SET 1',
     &              ' KMRS SET 2',' KMRS SET 3',' KMRS SET 4',
     &              ' MRS(S0)   ',' MRS(D0)   ',' MRS(D-)   ',
     &              ' CTEQ 1M   ',' CTEQ 1MS  ',' CTEQ 1ML  ',
     &              ' CTEQ 1D   ',' CTEQ 1L   ',' GRV94LO1  ' ,
     &              ' GRV98LO   ',' CTEQ96    '/
      DATA PARTIC / ' ANTIPROTON','           ','     PROTON'   /
      END
C***********************************************************************
C
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
*                                                                 *
*    G R V  -  P R O T O N  - P A R A M E T R I Z A T I O N S     *
*                                                                 *
*                         1994 UPDATE                             *
*                                                                 *
*                 FOR A DETAILED EXPLANATION SEE                  *
*                   M. GLUECK, E.REYA, A.VOGT :                   *
*                   DO-TH 94/24  =  DESY 94-206                   *
*                    (TO APPEAR IN Z. PHYS. C)                    *
*                                                                 *
*   THE PARAMETRIZATIONS ARE FITTED TO THE EVOLVED PARTONS FOR    *
*        Q**2 / GEV**2  BETWEEN   0.4   AND  1.E6                 *
*             X         BETWEEN  1.E-5  AND   1.                  *
*   LARGE-X REGIONS, WHERE THE DISTRIBUTION UNDER CONSIDERATION   *
*   IS NEGLIGIBLY SMALL, WERE EXCLUDED FROM THE FIT.              *
*                                                                 *
*   HEAVY QUARK THRESHOLDS  Q(H) = M(H)  IN THE BETA FUNCTION :   *
*                   M(C)  =  1.5,  M(B)  =  4.5                   *
*   CORRESPONDING LAMBDA(F) VALUES IN GEV FOR  Q**2 > M(H)**2 :   *
*      LO :   LAMBDA(3)  =  0.232,   LAMBDA(4)  =  0.200,         *
*             LAMBDA(5)  =  0.153,                                *
*      NLO :  LAMBDA(3)  =  0.248,   LAMBDA(4)  =  0.200,         *
*             LAMBDA(5)  =  0.131.                                *
*   THE NUMBER OF ACTIVE QUARK FLAVOURS IS  NF = 3  EVERYWHERE    *
*   EXCEPT IN THE BETA FUNCTION, I.E. THE HEAVY QUARKS C,B,...    *
*   ARE NOT PRESENT AS PARTONS IN THE Q2-EVOLUTION.               *
*   IF NEEDED, HEAVY QUARK DENSITIES CAN BE TAKEN FROM THE 1991   *
*   GRV PARAMETRIZATION.                                          *
*                                                                 *
*   NLO DISTRIBUTIONS ARE GIVEN IN MS-BAR FACTORIZATION SCHEME    *
*   (SUBROUTINE GRV94HO) AS WELL AS IN THE DIS SCHEME (GRV94DI),  *
*   THE LEADING ORDER PARAMETRIZATION IS PROVIDED BY "GRV94LO".   *
*                                                                 *
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
*
*...INPUT PARAMETERS :
*
*    X   = MOMENTUM FRACTION
*    Q2  = SCALE Q**2 IN GEV**2
*
*...OUTPUT (ALWAYS X TIMES THE DISTRIBUTION) :
*
*    UV  = U(VAL) = U - U(BAR)
*    DV  = D(VAL) = D - D(BAR)
*    DEL = D(BAR) - U(BAR)
*    UDB = U(BAR) + D(BAR)
*    SB  = S = S(BAR)
*    GL  = GLUON
*
*...LO PARAMETRIZATION :
*
       SUBROUTINE DOR94LO (X, Q2, UV, DV, DEL, UDB, SB, GL)
       IMPLICIT DOUBLE PRECISION (A - Z)
      SAVE
       MU2  = 0.23
       LAM2 = 0.2322 * 0.2322
       S  = LOG (LOG(Q2/LAM2) / LOG(MU2/LAM2))
       DS = SQRT (S)
       S2 = S * S
       S3 = S2 * S
*...UV :
       NU  =  2.284 + 0.802 * S + 0.055 * S2
       AKU =  0.590 - 0.024 * S
       BKU =  0.131 + 0.063 * S
       AU  = -0.449 - 0.138 * S - 0.076 * S2
       BU  =  0.213 + 2.669 * S - 0.728 * S2
       CU  =  8.854 - 9.135 * S + 1.979 * S2
       DU  =  2.997 + 0.753 * S - 0.076 * S2
       UV  = DOR94FV (X, NU, AKU, BKU, AU, BU, CU, DU)
*...DV :
       ND  =  0.371 + 0.083 * S + 0.039 * S2
       AKD =  0.376
       BKD =  0.486 + 0.062 * S
       AD  = -0.509 + 3.310 * S - 1.248 * S2
       BD  =  12.41 - 10.52 * S + 2.267 * S2
       CD  =  6.373 - 6.208 * S + 1.418 * S2
       DD  =  3.691 + 0.799 * S - 0.071 * S2
       DV  = DOR94FV (X, ND, AKD, BKD, AD, BD, CD, DD)
*...DEL :
       NE  =  0.082 + 0.014 * S + 0.008 * S2
       AKE =  0.409 - 0.005 * S
       BKE =  0.799 + 0.071 * S
       AE  = -38.07 + 36.13 * S - 0.656 * S2
       BE  =  90.31 - 74.15 * S + 7.645 * S2
       CE  =  0.0
       DE  =  7.486 + 1.217 * S - 0.159 * S2
       DEL = DOR94FV (X, NE, AKE, BKE, AE, BE, CE, DE)
*...UDB :
       ALX =  1.451
       BEX =  0.271
       AKX =  0.410 - 0.232 * S
       BKX =  0.534 - 0.457 * S
       AGX =  0.890 - 0.140 * S
       BGX = -0.981
       CX  =  0.320 + 0.683 * S
       DX  =  4.752 + 1.164 * S + 0.286 * S2
       EX  =  4.119 + 1.713 * S
       ESX =  0.682 + 2.978 * S
       UDB=DOR94FW(X, S, ALX, BEX, AKX, BKX, AGX, BGX, CX, DX, EX, ESX)
*...SB :
       ALS =  0.914
       BES =  0.577
       AKS =  1.798 - 0.596 * S
       AS  = -5.548 + 3.669 * DS - 0.616 * S
       BS  =  18.92 - 16.73 * DS + 5.168 * S
       DST =  6.379 - 0.350 * S  + 0.142 * S2
       EST =  3.981 + 1.638 * S
       ESS =  6.402
       SB  = DOR94FS (X, S, ALS, BES, AKS, AS, BS, DST, EST, ESS)
*...GL :
       ALG =  0.524
       BEG =  1.088
       AKG =  1.742 - 0.930 * S
       BKG =        - 0.399 * S2
       AG  =  7.486 - 2.185 * S
       BG  =  16.69 - 22.74 * S  + 5.779 * S2
       CG  = -25.59 + 29.71 * S  - 7.296 * S2
       DG  =  2.792 + 2.215 * S  + 0.422 * S2 - 0.104 * S3
       EG  =  0.807 + 2.005 * S
       ESG =  3.841 + 0.316 * S
       GL =DOR94FW(X, S, ALG, BEG, AKG, BKG, AG, BG, CG, DG, EG, ESG)
       RETURN
       END
*
*...NLO PARAMETRIZATION (MS(BAR)) :
*
       SUBROUTINE DOR94HO (X, Q2, UV, DV, DEL, UDB, SB, GL)
       IMPLICIT DOUBLE PRECISION (A - Z)
      SAVE
       MU2  = 0.34
       LAM2 = 0.248 * 0.248
       S  = LOG (LOG(Q2/LAM2) / LOG(MU2/LAM2))
       DS = SQRT (S)
       S2 = S * S
       S3 = S2 * S
*...UV :
       NU  =  1.304 + 0.863 * S
       AKU =  0.558 - 0.020 * S
       BKU =          0.183 * S
       AU  = -0.113 + 0.283 * S - 0.321 * S2
       BU  =  6.843 - 5.089 * S + 2.647 * S2 - 0.527 * S3
       CU  =  7.771 - 10.09 * S + 2.630 * S2
       DU  =  3.315 + 1.145 * S - 0.583 * S2 + 0.154 * S3
       UV  = DOR94FV (X, NU, AKU, BKU, AU, BU, CU, DU)
*...DV :
       ND  =  0.102 - 0.017 * S + 0.005 * S2
       AKD =  0.270 - 0.019 * S
       BKD =  0.260
       AD  =  2.393 + 6.228 * S - 0.881 * S2
       BD  =  46.06 + 4.673 * S - 14.98 * S2 + 1.331 * S3
       CD  =  17.83 - 53.47 * S + 21.24 * S2
       DD  =  4.081 + 0.976 * S - 0.485 * S2 + 0.152 * S3
       DV  = DOR94FV (X, ND, AKD, BKD, AD, BD, CD, DD)
*...DEL :
       NE  =  0.070 + 0.042 * S - 0.011 * S2 + 0.004 * S3
       AKE =  0.409 - 0.007 * S
       BKE =  0.782 + 0.082 * S
       AE  = -29.65 + 26.49 * S + 5.429 * S2
       BE  =  90.20 - 74.97 * S + 4.526 * S2
       CE  =  0.0
       DE  =  8.122 + 2.120 * S - 1.088 * S2 + 0.231 * S3
       DEL = DOR94FV (X, NE, AKE, BKE, AE, BE, CE, DE)
*...UDB :
       ALX =  0.877
       BEX =  0.561
       AKX =  0.275
       BKX =  0.0
       AGX =  0.997
       BGX =  3.210 - 1.866 * S
       CX  =  7.300
       DX  =  9.010 + 0.896 * DS + 0.222 * S2
       EX  =  3.077 + 1.446 * S
       ESX =  3.173 - 2.445 * DS + 2.207 * S
       UDB=DOR94FW(X, S, ALX, BEX, AKX, BKX, AGX, BGX, CX, DX, EX, ESX)
*...SB :
       ALS =  0.756
       BES =  0.216
       AKS =  1.690 + 0.650 * DS - 0.922 * S
       AS  = -4.329 + 1.131 * S
       BS  =  9.568 - 1.744 * S
       DST =  9.377 + 1.088 * DS - 1.320 * S + 0.130 * S2
       EST =  3.031 + 1.639 * S
       ESS =  5.837 + 0.815 * S
       SB  = DOR94FS (X, S, ALS, BES, AKS, AS, BS, DST, EST, ESS)
*...GL :
       ALG =  1.014
       BEG =  1.738
       AKG =  1.724 + 0.157 * S
       BKG =  0.800 + 1.016 * S
       AG  =  7.517 - 2.547 * S
       BG  =  34.09 - 52.21 * DS + 17.47 * S
       CG  =  4.039 + 1.491 * S
       DG  =  3.404 + 0.830 * S
       EG  = -1.112 + 3.438 * S  - 0.302 * S2
       ESG =  3.256 - 0.436 * S
       GL =DOR94FW(X, S, ALG, BEG, AKG, BKG, AG, BG, CG, DG, EG, ESG)
       RETURN
       END
*
*...NLO PARAMETRIZATION (DIS) :
*
       SUBROUTINE DOR94DI (X, Q2, UV, DV, DEL, UDB, SB, GL)
       IMPLICIT DOUBLE PRECISION (A - Z)
      SAVE
       MU2  = 0.34
       LAM2 = 0.248 * 0.248
       S  = LOG (LOG(Q2/LAM2) / LOG(MU2/LAM2))
       DS = SQRT (S)
       S2 = S * S
       S3 = S2 * S
*...UV :
       NU  =  2.484 + 0.116 * S + 0.093 * S2
       AKU =  0.563 - 0.025 * S
       BKU =  0.054 + 0.154 * S
       AU  = -0.326 - 0.058 * S - 0.135 * S2
       BU  = -3.322 + 8.259 * S - 3.119 * S2 + 0.291 * S3
       CU  =  11.52 - 12.99 * S + 3.161 * S2
       DU  =  2.808 + 1.400 * S - 0.557 * S2 + 0.119 * S3
       UV  = DOR94FV (X, NU, AKU, BKU, AU, BU, CU, DU)
*...DV :
       ND  =  0.156 - 0.017 * S
       AKD =  0.299 - 0.022 * S
       BKD =  0.259 - 0.015 * S
       AD  =  3.445 + 1.278 * S + 0.326 * S2
       BD  = -6.934 + 37.45 * S - 18.95 * S2 + 1.463 * S3
       CD  =  55.45 - 69.92 * S + 20.78 * S2
       DD  =  3.577 + 1.441 * S - 0.683 * S2 + 0.179 * S3
       DV  = DOR94FV (X, ND, AKD, BKD, AD, BD, CD, DD)
*...DEL :
       NE  =  0.099 + 0.019 * S + 0.002 * S2
       AKE =  0.419 - 0.013 * S
       BKE =  1.064 - 0.038 * S
       AE  = -44.00 + 98.70 * S - 14.79 * S2
       BE  =  28.59 - 40.94 * S - 13.66 * S2 + 2.523 * S3
       CE  =  84.57 - 108.8 * S + 31.52 * S2
       DE  =  7.469 + 2.480 * S - 0.866 * S2
       DEL = DOR94FV (X, NE, AKE, BKE, AE, BE, CE, DE)
*...UDB :
       ALX =  1.215
       BEX =  0.466
       AKX =  0.326 + 0.150 * S
       BKX =  0.956 + 0.405 * S
       AGX =  0.272
       BGX =  3.794 - 2.359 * DS
       CX  =  2.014
       DX  =  7.941 + 0.534 * DS - 0.940 * S + 0.410 * S2
       EX  =  3.049 + 1.597 * S
       ESX =  4.396 - 4.594 * DS + 3.268 * S
       UDB=DOR94FW(X, S, ALX, BEX, AKX, BKX, AGX, BGX, CX, DX, EX, ESX)
*...SB :
       ALS =  0.175
       BES =  0.344
       AKS =  1.415 - 0.641 * DS
       AS  =  0.580 - 9.763 * DS + 6.795 * S  - 0.558 * S2
       BS  =  5.617 + 5.709 * DS - 3.972 * S
       DST =  13.78 - 9.581 * S  + 5.370 * S2 - 0.996 * S3
       EST =  4.546 + 0.372 * S2
       ESS =  5.053 - 1.070 * S  + 0.805 * S2
       SB  = DOR94FS (X, S, ALS, BES, AKS, AS, BS, DST, EST, ESS)
*...GL :
       ALG =  1.258
       BEG =  1.846
       AKG =  2.423
       BKG =  2.427 + 1.311 * S  - 0.153 * S2
       AG  =  25.09 - 7.935 * S
       BG  = -14.84 - 124.3 * DS + 72.18 * S
       CG  =  590.3 - 173.8 * S
       DG  =  5.196 + 1.857 * S
       EG  = -1.648 + 3.988 * S  - 0.432 * S2
       ESG =  3.232 - 0.542 * S
       GL = DOR94FW(X, S, ALG, BEG, AKG, BKG, AG, BG, CG, DG, EG, ESG)
       RETURN
       END
*
*...FUNCTIONAL FORMS OF THE PARAMETRIZATIONS :
*
       FUNCTION DOR94FV (X, N, AK, BK, A, B, C, D)
       IMPLICIT DOUBLE PRECISION (A - Z)
      SAVE
       DX = SQRT (X)
       DOR94FV=N * X**AK * (1.+ A*X**BK + X * (B + C*DX)) * (1.- X)**D
       RETURN
       END
*
       FUNCTION DOR94FW (X, S, AL, BE, AK, BK, A, B, C, D, E, ES)
       IMPLICIT DOUBLE PRECISION (A - Z)
      SAVE
       LX = LOG (1./X)
       DOR94FW = (X**AK * (A + X * (B + X*C)) * LX**BK + S**AL
     1      * DEXP (-E + SQRT (ES * S**BE * LX))) * (1.- X)**D
       RETURN
       END
*
       FUNCTION DOR94FS (X, S, AL, BE, AK, AG, B, D, E, ES)
       IMPLICIT DOUBLE PRECISION (A - Z)
      SAVE
       DX = SQRT (X)
       LX = LOG (1./X)
       DOR94FS = S**AL / LX**AK * (1.+ AG*DX + B*X) * (1.- X)**D
     1       * DEXP (-E + SQRT (ES * S**BE * LX))
       RETURN
       END
*

C---------------- end of file -----------------------------------------
C---------------------------------------------------------------------
C                   dtcpomqj.f    (July 1993)
C-----------------------------------------------------------------------
************************************************************************
*
      SUBROUTINE SIGSHD(ECM)
*     May 1991
*     input:
*     hard cross sections (see DATA statements)
*     ECM (independent of CMENER in /USER/)
*     output:
*     bar cross sections for soft (SIGSOF) hard (SIGHAR) and diffractive
*     (SIGTRP) SCATTERING
*
*- - -  - - -  - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
*
*     version determined by ISIG
C*********************************************************************
C    ISIG=1-9 dropped since dpmjet-II.4.2
C*********************************************************************
*     ISIG=1  Capella,Tran Thanh Van,Kwiecinski,PRL 58(1987)2015
*     ISIG=2  Capella,Tran Thanh Van,Kwiecinski,PRL 58(1987)2015 CHG.SIG
*     ISIG=3  ALL SUBPROCESSES HARD CROSS SECTIONS PTHR CHANGING WITH ECM
*     ISIG=4  ALL SUBPROCESSES HARD CROSS SECTIONS PTHR=3 GEV/C   MRS1
*     ISIG=5  ALL SUBPROCESSES HARD CROSS SECTIONS PTHR=2 GEV/C   MRS1
*     ISIG=6  ALL SUBPROCESSES HARD CROSS SECTIONS PTHR=1.3 GEV/C MRS1
*     ISIG=7  all subprocesses hard cross sections PTHR=2GEV/C    MRS1
*     ISIG=8  program written by Patrick and Maire
*     ISIG=9  ALL SUBPROCESSES HARD CROSS SECTIONS PTHR=1.0 GEV/C MRS1
C*********************************************************************
C    ISIG=1-9 dropped since dpmjet-II.4.2
C*********************************************************************
*     ISIG=10  Version ISIG=4 including different sets
*              of structure functions
*
*-----------------------------------------------------------------------
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
*     CONVERSION FACTOR GEV**-2 TO MILLIBARNS
      PARAMETER (CONV=.38935D0)
      PARAMETER (PI=3.141592654D0,
     &           THREE=3.D0,
     &           TWO =2.D0,
     &           EPS=1.D-8)
      PARAMETER (THOUSA = 1000.D0)
*
* *** /OUTLEV/ controls output level for POMDI and parton X distribution
      COMMON /OUTLEV/IOUTPO,IOUTPA,IOUXEV,IOUCOL
*
* *** /POMPAR/*/SIGMA/*/POMTYP/ used only in SIGMAPOM-routines (->POMDI)
      COMMON /POMTYP/IPIM,ICON,ISIG,LMAX,MMAX,NMAX,DIFEL,DIFNU
      COMMON/POMPAR/ALFA,ALFAP,A,C,AK
      COMMON /SIGMA/SIGSOF,BS,ZSOF,SIGHAR,BH,ZHAR,SIGTRP,BT,ZTRP,
     *              SIGLOO,ZLOO
*
      CHARACTER*80 TITLE
      CHARACTER*8 PROJTY,TARGTY
C     COMMON /USER/TITLE,PROJTY,TARGTY,CMENER,ISTRUF
C    &            ,ISINGD,IDUBLD,SDFRAC,PTLAR
      COMMON /USER1/TITLE,PROJTY,TARGTY
      COMMON /USER2/CMENER,SDFRAC,PTLAR,ISTRUF,ISINGD,IDUBLD
*
      COMMON /STRUFU/ISTRUM,ISTRUT
      COMMON /ALALA/ALALAM
C     COMMON/COLLIS/S,IJPROJ,IJTAR,PTTHR,PTTHR2,IOPHRD,IJPRLU,IJTALU
C                             Prevent initialization energy
C                             to pollute s in /COLLIS/
      COMMON /COLLPO/S,PTTHR,PTTHR2
C     COMMON /COLLIS/SPO,IJPROJ,IJTAR,PTTPO,IOPHRD,IJPRLU,IJTALU,
C    *               PTTPO2
      COMMON/COLLIS/SPO,IJPROJ,IJTAR,PTTPO,PTTPO2,IOPHRD,IJPRLU,IJTALU
      COMMON /HAQQAP/ AQQAL,AQQPD,NQQAL,NQQPD
*
      DIMENSION SQS(13)
      DIMENSION SQSJ(17)
      DIMENSION XSQSJ(21),XXHHJ4(21)
*
*
*
*     used in ISIG=3,5,6,7,9
      DATA XSQSJ/0.005,0.01,0.02,0.035,0.053,
     * 0.1,0.2,0.35,0.54,1.,2.,5.,
     *10.,20.,40.,100.,200.,400.,1000.,2000.,4000./
*
*     used in ISIG 10,40
      DATA SQS/1.,2.,3.,4.,5.,10.,20.,30.,40.,100.,200.,500.,1000./
*
      PI4=4.*PI
      S=ECM**2
***********************************************************************
*----------------------------------------------------------------------
*
* **  select option used
*
      GO TO (10,20,30,40,50,60,70,80,90,100),ISIG
*
   10 CONTINUE
      WRITE(6,*)' This value of ISIG no longer available ISIG=',ISIG
*----------------------------------------------------------------------
*     nach:  Capella, Tran Thanh Van, Kwiecinski, PRL 58(1987)2015
*     as used in Ranft et al. SSC 149 Eq. 4,5
*
   20 CONTINUE
      WRITE(6,*)' This value of ISIG no longer available ISIG=',ISIG
*----------------------------------------------------------------------
*     nach:  Capella,Tran Thanh Van,Kwiecinski,PRL 58(1987)2015 CHG.SIG
*
   30 CONTINUE
      WRITE(6,*)' This value of ISIG no longer available ISIG=',ISIG
*----------------------------------------------------------------------
*     nach:  all subprocesses hard cross sections LIKE 70
C            PTHR RISING WITH ECM
*            NEW SIGTRP RISING LIKE LOG(S)   A.CAPELLA 30.3.90
C            ONLY FOR USE WITH PRBLM2!!!!!!!!!!!!!!!!
   40 CONTINUE
      WRITE(6,*)' This value of ISIG no longer available ISIG=',ISIG
*----------------------------------------------------------------------
*     nach:  all subprocesses hard cross sections LIKE 70
C            PTHR RISING WITH ECM  ptthr=3gev
*            NEW SIGTRP RISING LIKE LOG(S)   A.CAPELLA 30.3.90
C            ONLY FOR USE WITH PRBLM2!!!!!!!!!!!!!!!!
   50 CONTINUE
      WRITE(6,*)' This value of ISIG no longer available ISIG=',ISIG
*----------------------------------------------------------------------
*     nach:  all subprocesses hard cross sections LIKE 70
C            PTHR RISING WITH ECM    ptthr=2 gev
*            NEW SIGTRP RISING LIKE LOG(S)   A.CAPELLA 30.3.90
C            ONLY FOR USE WITH PRBLM2!!!!!!!!!!!!!!!!
   60 CONTINUE
      WRITE(6,*)' This value of ISIG no longer available ISIG=',ISIG
*----------------------------------------------------------------------
*     nach:  all subprocesses hard cross sections LIKE 70
C            PTHR RISING WITH ECM    ptthr=1.3 GEV
*            NEW SIGTRP RISING LIKE LOG(S)   A.CAPELLA 30.3.90
C            ONLY FOR USE WITH PRBLM2!!!!!!!!!!!!!!!!
   70 CONTINUE
      WRITE(6,*)' This value of ISIG no longer available ISIG=',ISIG
*----------------------------------------------------------------------
*     nach:  all subprocesses hard cross sections
*
   80 CONTINUE
      WRITE(6,*)' This value of ISIG no longer available ISIG=',ISIG
*----------------------------------------------------------------------
*     nach:  Patrick Maires program
   90 CONTINUE
      WRITE(6,*)' This value of ISIG no longer available ISIG=',ISIG
*----------------------------------------------------------------------
*     nach:  all subprocesses hard cross sections LIKE 70
C            PTHR RISING WITH ECM    ptthr=1.0 GEV
*            NEW SIGTRP RISING LIKE LOG(S)   A.CAPELLA 30.3.90
C            ONLY FOR USE WITH PRBLM2!!!!!!!!!!!!!!!!
      RETURN
  100 CONTINUE
*----------------------------------------------------------------------
*     nach:  all subprocesses hard cross sections LIKE 70
C            PTHR RISING WITH ECM
*            NEW SIGTRP RISING LIKE LOG(S)   A.CAPELLA 30.3.90
C            ONLY FOR USE WITH PRBLM2!!!!!!!!!!!!!!!!
C                                            INTRODUCED 18.12.90
C                                            BY DIETER PERTERMANN
C     modified 11-06-92 (R.Engel)
C
C  default parameter set
      ALFA=1.076
      ALFAP=0.24
      A=40.8
      BH=3.51
      BHOO=BH
      BSOO=BH
      AK=1.5
C     ALALAM --> ALAM (see PRBLM2 and POMDI)
      ALALAM=0.0
C                       begin fixed ptthr=3GeV
C--------------------------------------------------------------------
      IF(ABS(PTTHR-THREE).LT.EPS) THEN
        WRITE(6,*)' PTTHR=3. not available in dpmjet25'
          WRITE(6,*) ' WARNING: no model parameter set available'
          WRITE(6,*) ' for this combination of PTCUT and ISTRUF'
          WRITE(6,*) ' (initialization using default values)'
          ALFA = 1.078
          A    = 42.6
          ALALAM=0.740 
          AQQAL=1.D0
          AQQPD=1.D0
          ALFAP= 0.24
          AK=2.0
      ENDIF
C                       end fixed ptthr=3GeV
C                       begin fixed ptthr=2GeV
      IF(ABS(PTTHR-TWO).LT.EPS) THEN
        WRITE(6,*)' PTTHR=2. not available in dpmjet25'
          WRITE(6,*) ' WARNING: no model parameter set available'
          WRITE(6,*) ' for this combination of PTCUT and ISTRUF'
          WRITE(6,*) ' (initialization using default values)'
          ALFA = 1.042
          A    = 64.54
          ALALAM=0.6402
          AQQAL=1.D0
          AQQPD=1.D0
          ALFAP= 0.24
          AK=2.0
      ENDIF
C\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
C                       end fixed ptthr=2GeV
C-----------------------------------------------------------
C-----------------------------------------------------------
C-----------------------------------------------------------
C     begin  ptthr= PTTHR=2.1+0.15*(LOG10(ECM/50.))**3
C-----------------------------------------------------------
      IF(ISTRUT.EQ.1) THEN
        WRITE(6,*)' ISTRUT=1 (PTTHR=2.1+0.15*(LOG10(ECM/50.))**3)',
     *	'not available in dpmjet25'
        PTTHR=2.1+0.15*(LOG10(ECM/50.))**3
        PTTHR2=PTTHR
          WRITE(6,*) ' WARNING: no model parameter set available'
          WRITE(6,*) ' for this combination of PTCUT and ISTRUF'
          WRITE(6,*) ' (initialization using default values)'
          ALFA = 1.042
          A    = 64.54
          ALALAM=0.6402
          AQQAL=1.D0
          AQQPD=1.D0
          ALFAP= 0.24
          AK=2.0
      ENDIF
C     end   PTTHR=2.1+0.15*(LOG10(ECM/50.))**3
C\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
      BHOO=BH
      BSOO=BH
C\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
C-----------------------------------------------------------
C-----------------------------------------------------------
C-----------------------------------------------------------
C    begin  PTTHR=2.5+0.12*(LOG10(ECM/50.))**3
C-----------------------------------------------------------
      IF(ISTRUT.EQ.2) THEN
        PTTHR=2.5+0.12*(LOG10(ECM/50.))**3
        PTTHR2=PTTHR
        IF( ISTRUF.EQ.9 ) THEN
        WRITE(6,*)' ISTRUT=2 (PTTHR=2.5+0.12*(LOG10(ECM/50.))**3)',
     *	'and ISTRUF= ',ISTRUF ,' not available in dpmjet25'
ctp060123         GO TO 778
        ELSEIF( ISTRUF.EQ.10 ) THEN
        WRITE(6,*)' ISTRUT=2 (PTTHR=2.5+0.12*(LOG10(ECM/50.))**3)',
     *	'and ISTRUF= ',ISTRUF ,' not available in dpmjet25'
ctp060123         GO TO 778
        ELSEIF( ISTRUF.EQ.11 ) THEN
        WRITE(6,*)' ISTRUT=2 (PTTHR=2.5+0.12*(LOG10(ECM/50.))**3)',
     *	'and ISTRUF= ',ISTRUF ,' not available in dpmjet25'
ctp060123         GO TO 778
        ELSEIF( ISTRUF.EQ.12 ) THEN
        WRITE(6,*)' ISTRUT=2 (PTTHR=2.5+0.12*(LOG10(ECM/50.))**3)',
     *	'and ISTRUF= ',ISTRUF ,' not available in dpmjet25'
ctp060123         GO TO 778
        ELSEIF( ISTRUF.EQ.13 ) THEN
        WRITE(6,*)' ISTRUT=2 (PTTHR=2.5+0.12*(LOG10(ECM/50.))**3)',
     *	'and ISTRUF= ',ISTRUF ,' not available in dpmjet25'
ctp060123         GO TO 778
        ELSEIF( ISTRUF.EQ.14 ) THEN
        WRITE(6,*)' ISTRUT=2 (PTTHR=2.5+0.12*(LOG10(ECM/50.))**3)',
     *	'and ISTRUF= ',ISTRUF ,' not available in dpmjet25'
ctp060123         GO TO 778
        ELSEIF( ISTRUF.EQ.15 ) THEN
        WRITE(6,*)' ISTRUT=2 (PTTHR=2.5+0.12*(LOG10(ECM/50.))**3)',
     *	'and ISTRUF= ',ISTRUF ,' not available in dpmjet25'
C  CETQ PDFs with other scale
ctp060123         GO TO 778
        ELSEIF( ISTRUF.EQ.16 ) THEN
        WRITE(6,*)' ISTRUT=2 (PTTHR=2.5+0.12*(LOG10(ECM/50.))**3)',
     *	'and ISTRUF= ',ISTRUF ,' not available in dpmjet25'
          AK=2.0
ctp060123         GO TO 778
        ELSEIF( ISTRUF.EQ.17 ) THEN
        WRITE(6,*)' ISTRUT=2 (PTTHR=2.5+0.12*(LOG10(ECM/50.))**3)',
     *	'and ISTRUF= ',ISTRUF ,' not available in dpmjet25'
ctp060123         GO TO 778
        ELSEIF( ISTRUF.EQ.18 ) THEN
        WRITE(6,*)' ISTRUT=2 (PTTHR=2.5+0.12*(LOG10(ECM/50.))**3)',
     *	'and ISTRUF= ',ISTRUF ,' not available in dpmjet25'
ctp060123         GO TO 778
        ELSEIF( ISTRUF.EQ.19 ) THEN
        WRITE(6,*)' ISTRUT=2 (PTTHR=2.5+0.12*(LOG10(ECM/50.))**3)',
     *	'and ISTRUF= ',ISTRUF ,' not available in dpmjet25'
ctp060123         GO TO 778
        ELSEIF( ISTRUF.EQ.20 ) THEN
        WRITE(6,*)' ISTRUT=2 (PTTHR=2.5+0.12*(LOG10(ECM/50.))**3)',
     *	'and ISTRUF= ',ISTRUF ,' not available in dpmjet25'
ctp060123         GO TO 778
C              GRV94LO AK=1. only for ISTRUT = 2
	ELSEIF( ISTRUF.EQ.21 ) THEN
          ALFA = 1.0733
          ALFAP= 0.171
          A    = 47.84
          ALALAM=0.621
          BSOO=1.58
          BHOO=3.54
          AK=1.000
          GO TO 778
C              GRV94LO AK=2. only for ISTRUT = 2
	ELSEIF( ISTRUF.EQ.22 ) THEN
          ALFA = 1.0513
          ALFAP= 0.3246
          A    = 55.16
          ALALAM=0.5846
          BSOO=1.114
          BHOO=1.703
          AK=2.000
          GO TO 778
C              CTEQ96 AK=2. only for ISTRUT = 2
	ELSEIF( ISTRUF.EQ.23 ) THEN
          ALFA = 1.0448
          ALFAP= 0.372
          A    = 57.51
          ALALAM=0.566
          BSOO=0.97
          BHOO=1.47
          AK=2.000
          GO TO 778
ctp060123           ELSE
        ENDIF
ctp060123 778      CONTINUE	
          WRITE(6,*) ' WARNING: no model parameter set available'
          WRITE(6,*) ' for this combination of PTCUT and ISTRUF'
          WRITE(6,*) ' (initialization using default values)'
          ALFA = 1.042
          A    = 64.54
          ALALAM=0.6402
          AQQAL=1.D0
          AQQPD=1.D0
          ALFAP= 0.24
          AK=2.0
ctp060123         ENDIF
 778    CONTINUE	
        BHOO = BHOO/CONV
        BSOO = BSOO/CONV
      ENDIF
C    end  PTTHR=2.5+0.12*(LOG10(ECM/50.))**3
C\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
C  slopes in GeV**-2
      BS=BSOO+ALFAP*LOG(S)
      BH=BHOO
*     BS=BSOO+ALFAP*LOG(S)
C  change units to mb
      BH=BH*CONV
      BS=BS*CONV
      BT=BS
C\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
C     BT=BS/2.
      C=40.
C                                 CHANGED 13.1.90 BY J.R.
C     C=1.8
C\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
C     C=1.E-8
*     parametrizations of input cross sections
      SIGSOF=A*S**(ALFA-1.)
* *** hard X-section
*     read interpolation data for different
*     sets of structure functions:
*
      CALL RDXSEC(XXHHJ4)
      IF(ISTRUF.EQ.21)AK=2.
      SIGHAR=1.E-8
      IF (S.GT.2450.D0)
     *               SIGHAR=AK*0.1*(S-2450.)**0.35
      IF(ECM.GE.THOUSA*XSQSJ(2)) THEN
        DO 1031 I=1,20
          III=I+1
          IF(ECM.LT.XSQSJ(III)*THOUSA.AND.
     *       ECM.GE.THOUSA*XSQSJ(I))THEN
            DSQ=ECM-THOUSA*XSQSJ(I)
            DDSQ=THOUSA*(XSQSJ(III)-XSQSJ(I))
            DHS=(XXHHJ4(III)-XXHHJ4(I))
            SIGHAR=AK*(XXHHJ4(I)+DHS*DSQ/DDSQ)*0.5
          ENDIF
 1031   CONTINUE
      ENDIF
C
C *** trippel pomeron X-section
C
C                                  VERSION A.CAPELLA 30.3.90
      GCA=SQRT(A)
      G3CA=GCA**3
      GACA=0.42
C     BSDOCA=1.372
      BSDOCA=BSOO*CONV
C     ALSCA=.0925
      ALSCA=ALFAP*CONV
      ALNS=LOG(S)
      BSDCA=BSDOCA+2.*ALSCA*ALNS
      SIGTRP=G3CA*GACA*LOG(S/10.)/(8.*3.14*BSDCA)
      IF (SIGTRP.LT.0.D0)SIGTRP=0.01
C
      BDDCA=2.*ALSCA*ALNS
      ALO1SQ=(LOG(S/400.))**2
      ALO2SQ=(LOG(25./S))**2
      ALO3SQ=(LOG(5./20.))**2
      SIGLOO=A*GACA**2*(ALO1SQ+ALO2SQ-2.*ALO3SQ)/(32.*3.14*BDDCA)
C
      ZSOF=SIGSOF/(PI4*BS)
      ZHAR=SIGHAR/(PI4*BH)
      ZTRP=SIGTRP/(PI4*BT)
      ZLOO=SIGLOO/(PI4*BT)
C 
C     WRITE(6,'(2(/1X,A))') 'SELECTED PARAMETERS:',
C    &                     '===================='
C     WRITE(6,'(1X,A,E12.3)')   '  ALFA   ',ALFA
C     WRITE(6,'(1X,A,E12.3)')   '  ALFAP  ',ALFAP
C     WRITE(6,'(1X,A,E12.3)')   '  A      ',A
C     WRITE(6,'(1X,A,2E12.3)')  '  BS,BSOO',BS,BSOO*CONV
C     WRITE(6,'(1X,A,2E12.3)')  '  BH,BHOO',BH,BHOO*CONV
C     WRITE(6,'(1X,A,E12.3)')   '  GACA   ',GACA
C     WRITE(6,'(1X,A,E12.3,/)') '  AK     ',AK
C
      RETURN
      END
*
*
************************************************************************
************************************************************************
*
      SUBROUTINE RDXSEC(XSEC)
C
C     18.12.90, Dieter Pertermann
C     15.03.93, 27.05.93 modified (R. Engel)
C
C     RDXSEC READS DATA FOR INTERPOLATION
C     OF THE TOTAL CROSS SECTIONS FOR DIFFERENT
C     SETS OF STRUCTURE FUNCTIONS. THE CHOICE
C     OF THE CORRESPONDIG DATA SET IS CONTROLED
C     BY THE OVERALL STRUCTURE FUNCTION PARAMETER
C     ISTRUF.
C
C     CMENER taken out but no action necessary as not in SUB
C
C     modified 11-05-92 (R.Engel)
*
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      CHARACTER*80 TITLE
      CHARACTER*8 PROJTY,TARGTY
C     COMMON /USER/TITLE,PROJTY,TARGTY,CMENER,ISTRUF
C    &            ,ISINGD,IDUBLD,SDFRAC,PTLAR
      COMMON /USER1/TITLE,PROJTY,TARGTY
      COMMON /USER2/CMENER,SDFRAC,PTLAR,ISTRUF,ISINGD,IDUBLD
*
C     COMMON/COLLIS/S,IJPROJ,IJTAR,PTTHR,PTTHR2,IOPHRD,IJPRLU,IJTALU
*
      COMMON /COLLPO/S,PTTHR,PTTHR2
C     COMMON /COLLIS/SPO,IJPROJ,IJTAR,PTTPO,IOPHRD,IJPRLU,IJTALU,
C    *               PTTPO2
      COMMON/COLLIS/SPO,IJPROJ,IJTAR,PTTPO,PTTPO2,IOPHRD,IJPRLU,IJTALU
      COMMON /STRUFU/ISTRUM,ISTRUT
C
      DIMENSION XSEC(21)
      DIMENSION XS21(189)
C
      PARAMETER(EPSIL=1.D-9,
     &          THREE=3.D0,
     &          TWO=2.D0)
C
      DATA XS21  /
     &   0.000000E+00,0.137854E-04, .02, .13, .37, 1.32,
     &   3.88, 8.02, 13.15, 24.32, 43.43, 79.69, 113.13,
     &   147.5, 180.47, 221.01, 250.37,
     &   279.4, 320.1, 349.6, 381.6,
*  total X-section ,  cteq1M  PTTHR=x GEV/C
     &       .000000E+00, .494767E-05, .02, .14, .41, 
     &    1.48, 4.17, 7.92, 11.90, 19.03, 28.59, 42.36,
     &   52.78, 62.86, 72.65, 85.61, 95.97,
     &   96.,  96.,  96.,  96.,
*  total X-section ,  cteq1MS PTTHR=x GEV/C
     &      0.000000E+00,
     &      0.517461E-05, .02, .14, .42, 1.49, 4.14, 
     &    7.87, 11.93, 19.58, 30.67, 48.39, 63.08, 
     &    78.1, 93.28, 114.33, 132.24,
     &   133.,  133.,  133.,  133.,
*  total X-section ,  cteq1ML PTTHR=x GEV/C
     &      0.000000E+00,
     &      0.717097E-05, .03, .19, .54, 1.91, 5.33, 10.11,
     &     16.16, 24.21, 36.41, 54.21, 67.92, 81.44,
     &     94.81,112.9, 127.63,
     &    128.,  128.,  128.,  128.,   
*  total X-section ,  cteq1D  PTTHR=x GEV/C
     &      0.000000E+00,
     &      0.761464E-05, .02, .17, .47, 1.56, 4.19, 
     &     7.76, 11.48, 18.11, 26.97, 39.82, 49.86, 59.35, 
     &     68.88, 81.65, 91.94,
     &    92.,  92.,  92.,  92.,
*  total X-section ,  cteq1L  PTTHR=x GEV/C
     &       .000000E+00,
     &       .620779E-05, .02, .12, .34, 1.19, 3.27, 
     &      6.16, 9.27, 14.99, 23.2, 36.85, 49.45, 
     &      64.43, 82.38, 112.06, 140.36,
     &    141.,  141.,  141.,  141.,
*  total X-section ,  GRV94LO  AK=1. PTTHR=x GEV/C
     &       .000000E+00,
     &       .620779E-05, .01, .05, .14, 0.55, 1.87, 
     &      4.29,  7.49, 14.81, 27.8, 55.99, 77.49, 
     &     105.98,138.48, 189.33, 236.37,
     &    294.,  395.,  496.,  629.,
*  total X-section ,  GRV94LO AK=2. PTTHR=x GEV/C
     &       .000000E+00,
     &       .620779E-05, .01, .10, .31, 1.16, 3.76, 
     &      8.31, 14.16, 27.11, 49.3, 90.93,129.77, 
     &     174.16,223.83, 300.20, 370.00,
     &    455.,  600.,  746.,  936.,
*  total X-section ,  CTEC96 AK=2. PTTHR=x GEV/C
     &       .000000E+00,
     &       .620779E-05, .01, .08, .27, 1.17, 4.15, 
     &      9.60, 16.75, 32.88, 61.1,125.98,169.87, 
     &     233.75,308.22, 426.95, 537.90,
     &    673.,  898., 1112., 1379./
*******************************************************************
*
      IF( ABS(PTTHR-THREE).LT.EPSIL )     THEN
          WRITE(6,*) ' ERROR RDXSEC: invalid pdf No. ',ISTRUF
          STOP
      ELSEIF( ABS(PTTHR-TWO).LT.EPSIL ) THEN
          WRITE(6,*) ' ERROR RDXSEC: invalid pdf No. ',ISTRUF
          STOP
      ELSEIF( ISTRUT.EQ.1 ) THEN
          WRITE(6,*) ' ERROR RDXSEC: invalid pdf No. ',ISTRUF
          STOP
      ELSEIF( ISTRUT.EQ.2 ) THEN
        IF( (ISTRUF.GE.9).AND.(ISTRUF.LE.20) ) THEN
          WRITE(6,*) ' ERROR RDXSEC: invalid pdf No. ',ISTRUF
          STOP
        ELSEIF( (ISTRUF.GE.21).AND.(ISTRUF.LE.23) ) THEN
          DO 311 I=1,21
            NXS = 21*(ISTRUF-15)+I
            XSEC(I)=XS21(NXS)
  311    CONTINUE
        ELSE
          WRITE(6,*) ' ERROR RDXSEC: invalid pdf No. ',ISTRUF
          STOP
        ENDIF
      ELSE
        WRITE(6,*) ' ERROR RDXSEC: PTCUT ',PTTHR,' not supported ***'
        STOP
      ENDIF
C
      RETURN
      END
*
*
************************************************************************
*
       BLOCK DATA POMEN
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
C      COMMON /POMENE/POEN(20),POEN1(20),POEN2(20)
       COMMON /POMENE/POEN(28),POEN1(28),POEN2(28),NESTEP
       DATA POEN/20.D0,50.D0,100.D0,200.D0,500.D0,
     *  1000.D0,1500.D0,
     * 2000.D0,3000.D0,4000.D0,6000.D0,8000.D0,10000.D0,
     *15000.D0,20000.D0,30000.D0,40000.D0,60000.D0,
     *80000.D0,100000.D0,150000.D0,200000.D0,300000.D0
     *,400000.D0,600000.D0,800000.D0,1000000.D0,2000000.D0/
       DATA POEN1/5.D0,30.D0,70.D0,150.D0,300.D0,
     *  700.D0,1200.D0,1700.D0,      
     * 2500.D0,3500.D0,5000.D0,7000.D0,9000.D0,
     *12000.D0,17000.D0,25000.D0,35000.D0,50000.D0,
     *70000.D0,90000.D0,120000.D0,170000.D0,250000.D0,
     *250000.D0,500000.D0,700000.D0,900000.D0,1500000.D0/
       DATA POEN2/30.D0,70.D0,150.D0,300.D0,
     *  700.D0,1200.D0,1700.D0,2500.D0,
     * 3500.D0,5000.D0,7000.D0,9000.D0,12000.D0,
     *17000.D0,25000.D0,35000.D0,50000.D0,70000.D0,
     *90000.D0,120000.D0,170000.D0,250000.D0,350000.D0,
     *500000.D0,700000.D0,900000.D0,1500000.D0,3000000.D0/
       DATA NESTEP/28/
       END
************************************************************************
************************************************************************
************************************************************************
*
      SUBROUTINE PRBLM2(ECM)
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
C
C   Routine to call QRBLM2 for NESTEP energies
*                                   j.r.3/94
C-----------------------------------------------------------------------
C$
C$  If IPOMTA=1 file INIDAT already exists : the content of commons
C$  POMENE and POLMN1 will be read in (Logic unit is IUNIT=37)
C$  If IPOMTA=0 file INIDAT does not exist : the content of COMMON
C$  POMENE will be taken from BLOCKDATA POMEN or, when interfaced to
C$  HEMAS, directly from hemas input file INPFIL. Then, the content of 
C$  POMENE and POLMN1 will be written in INIDAT (Logic unit is IUNIT=37)
C$  C.Forti 18-nov-94  
C$
C     COMMON /POMENE/POEN(20),POEN1(20),POEN2(20),NESTEP
       COMMON /POMENE/POEN(28),POEN1(28),POEN2(28),NESTEP
      COMMON /POMTAB/IPOMTA
C$
      PARAMETER (MXPA25=30,MXPA26=MXPA25+1,MXPA13=13)
      PARAMETER (MXPA50=250,MXPA51=MXPA50+1)
      PARAMETER (MXPU50=100,MXPU51=MXPU50+1)
* *** /POLMN/ arrays having to do with cut soft and hard Pomerons
      COMMON /POLMN/PLMN(0:MXPA25,0:MXPA50,0:MXPA13),
     *              PLMNCU(0:MXPA25,0:MXPA50,0:MXPA13)
      COMMON /POLMN1/ PLMNEE(0:MXPA25,0:MXPU50,0:MXPA13,28)
      DATA IUNIT/37/
C
      CHARACTER*80 INIDAT
      LOGICAL LDATA
C
C$  Statement : setenv INIDAT /nfs/hpmac1/macro02/dpmjet/POMTAB_06.DAT 
C$  in the job file is required
C
      CALL GETENV('INIDAT',INIDAT)
C     OPEN(IUNIT,FILE=INIDAT,STATUS='UNKNOWN',ERR=99)
CDH  read POMTAB.DAT if available, else calculate and write it
      INQUIRE(FILE='pomtab.dat',EXIST=LDATA)
        OPEN(UNIT=IUNIT,FILE='pomtab.dat'
     *  ,STATUS='UNKNOWN',ERR=99)
C
*DH   IF (IPOMTA.EQ.0) THEN
      IF ( .NOT.LDATA ) THEN
        DO 1 II=1,NESTEP
          ENERGY = POEN(II)
          CALL QRBLM2(ENERGY)
          DO 10 JJ=0,MXPA25  
	    DO 10 KK=0,MXPU50
	      DO 10 LL=0,MXPA13
	        PLMNEE(JJ,KK,LL,II)=PLMNCU(JJ,KK,LL)
   10     CONTINUE
    1   CONTINUE
C
        WRITE(IUNIT,7102) NESTEP   
        DO 31 II=1,NESTEP
          WRITE(IUNIT,7101) POEN(II), POEN1(II), POEN2(II)
          WRITE(IUNIT,101)(((PLMNEE(JJ,KK,LL,II),LL=0,MXPA13),
     *                  KK=0,MXPU50),JJ=0,MXPA25)
   31   CONTINUE    
 7102   FORMAT(I13)
 7101   FORMAT(3E13.5)
  101   FORMAT(8E13.5)    
C$ 
*DH   ELSEIF (IPOMTA.EQ.1)THEN
      ELSE
        READ(IUNIT,7102) NESTEP   
        DO 11 II=1,NESTEP
          READ(IUNIT,7101) POEN(II), POEN1(II), POEN2(II)
          READ(IUNIT,101)(((PLMNEE(JJ,KK,LL,II),LL=0,MXPA13),
     *                  KK=0,MXPU50),JJ=0,MXPA25)
   11   CONTINUE    
      ENDIF
      CLOSE(IUNIT)
      RETURN
   99 CONTINUE
      WRITE(6,'(A)')'Error in PRBLM2 : file pomtab.dat ERROR'
      CLOSE(IUNIT)
      STOP   
      END

************************************************************************
*
      SUBROUTINE QRBLM2(ECM)
*     *     input:
*        ECM
*     output:
*        PLMN, PLMNCUmmulative, AVSOFN, AVHRDN,SIGDD/D/QEL/EL, PSOFT
*
*- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
*
*        Probabilities for L soft cut, M hard cut pomerons
*           and N someplace cut trippel pomerons
*
*         Aurenche Maire's  version of PRBLM
*         modified from A.M. to include calculation of x-sections
*         modified to get:
*      version with high mass diffraction (Y's and PHI's)
*              and on both sides 2 kanal low mass diffraction
* ***                                     OPTION 21.2.90 FB
*----------------------------------------------------------------------
*
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      PARAMETER ( ZERO=0.D0, ONE=1.D0)
      PARAMETER (CONV=0.38935D0)
      PARAMETER (PI=3.141592654D0)
      PARAMETER (MXPA25=30,MXPA26=MXPA25+1,MXPA13=13)
*     PARAMETRIZATION FOR PTMIN= 3. GEV
      PARAMETER (MXPA50=250,MXPA51=MXPA50+1)
*     PARAMETRIZATION FOR PTMIN= 2. GEV
C     PARAMETER (MXPA50=350,MXPA51=MXPA50+1)
      PARAMETER (MXPA96=96)
C     PARAMETER (MXPA96=480)
      LOGICAL LSQRT
C      PARAMETER (MXLMN=5,LSQRT=.false.)
      PARAMETER (MXLMN=5,LSQRT=.TRUE.)
      DOUBLE PRECISION DTINY
C     PARAMETER (TINY = 1.2D-38,DTINY=1.D-70,TIN=1.D-22,TINEXP = -300.D0)
C     PARAMETER (TINY = 1.2D-38,DTINY=1.D-300,TIN=1.D-22,TINEXP =
C    -700.D0)
      PARAMETER (TINY=1.2D-38,DTINY=1.D-70,TIN=1.D-22,TINEXP=-700.D0)
C      PARAMETER (TINY = 1.D-38,DTINY=tiny,TIN=1.D-22,TINEXP = -300.D0)
*     in older version used:
      PARAMETER (TINYEX  = -48.D0)
* --- -- - - - - - - - - - -- - - - - - - - - - - - - - - - - - - - -
* *** /POLMN/ arrays having to do with cut soft and hard Pomerons
      COMMON /POLMN/PLMN(0:MXPA25,0:MXPA50,0:MXPA13),
     *              PLMNCU(0:MXPA25,0:MXPA50,0:MXPA13)
      COMMON /POLMN0/PDIFR,PHARD,PSOFT,ALFAH,BETAH,
     *              SIGTOT,SIGQEL,SIGEL,SIGINE,SIGHIN,SIGD,SIGDD
* *** /POMPAR/*/SIGMA/*/POMTYP/ used only in SIGMAPOM-routines (->POMDI)
*      (LMAX,MMAX,NMAX (max number of soft/hard/trippel pomerons)
      COMMON /POMTYP/IPIM,ICON,ISIG,LMAX,MMAX,NMAX,DIFEL,DIFNU
      COMMON /SIGMA/SIGSOF,BS,ZSOF,SIGHAR,BH,ZHAR,SIGTRP,BT,ZTRP,
     *              SIGLOO,ZLOO
      COMMON/POMPAR/ALFA,ALFAP,A,C,AK
      COMMON /SINGDI/SILMSD,SIGDI
* *** /OUTLEV/ controls output level for POMDI and parton X distribution
      COMMON /OUTLEV/IOUTPO,IOUTPA,IOUXEV,IOUCOL
      COMMON /ALALA/ALALAM
      CHARACTER*80 TITLE
      CHARACTER*8 PROJTY,TARGTY
C     COMMON /USER/TITLE,PROJTY,TARGTY,CMENER,ISTRUF
C    &            ,ISINGD,IDUBLD,SDFRAC,PTLAR
      COMMON /USER1/TITLE,PROJTY,TARGTY
      COMMON /USER2/CMENER,SDFRAC,PTLAR,ISTRUF,ISINGD,IDUBLD
* --- -- - - - - - - - - - -- - - - - - - - - - - - - - - - - - - - -
      DOUBLE PRECISION SIG,SIGP,SIGM,SIGN,SIGO
      DIMENSION SIG(0:MXPA25,0:MXPA50,0:MXPA13),
     &SIGP(0:MXPA25,0:MXPA50,0:MXPA13),SIGM(0:MXPA25,0:MXPA50,0:MXPA13),
     &SIGN(0:MXPA25,0:MXPA50,0:MXPA13),SIGO(0:MXPA25,0:MXPA50,0:MXPA13)
      DIMENSION XPNT(MXPA96),WGHT(MXPA96),
     &SSOFT(0:MXPA25),SHARD(0:MXPA50),STRPL(0:MXPA25)
C       - - required MXPA25 > NMAX - -
      DIMENSION FAK(0:MXPA13),CMBIN(0:MXPA13,0:MXPA13)
      DOUBLE PRECISION
     &       EXPSOP,EXPSOH,EXMSOP,EXMSOH,EXNSOP,EXNSOH,EXOSOP,EXOSOH,
     &       EXPHAP,EXPHAH,EXMHAP,EXMHAH,EXNHAP,EXNHAH,EXOHAP,EXOHAH,
     &       EXPTRP,EXPTRH,EXMTRP,EXMTRH,EXNTRP,EXNTRH,EXOTRP,EXOTRH,
     &       EXPLOP,EXPLOH,EXMLOP,EXMLOH,EXNLOP,EXNLOH,EXOLOP,EXOLOH,
     &       EXPEXH,EXMEXH,EXNEXH,EXOEXH,EXPEXP,EXMEXP,EXNEXP,EXOEXP
      DOUBLE PRECISION  FAPSOF,FAMSOF,FANSOF,FAOSOF,
     &                  FAPHAR,FAMHAR,FANHAR,FAOHAR,
     &                  FAPTRP,FAMTRP,FANTRP,FAOTRP,
     &                  FAPLOO,FAMLOO,FANLOO,FAOLOO
      DOUBLE PRECISION  DENOM,DENOMI,XPNTK,WGHTK,RMXLMN
     &                  ,SIGSUM,SIGINL,SIGHRI
*
*---------------------------------------------------------------------------
*
*     externe ICON option to internes NMAX=1,2,free
      IF(ICON/10.EQ.4) NMAX=2
      IF(ICON/10.EQ.5) NMAX=1
*
*     for safty
      IF( NMAX.GT.MXPA13) THEN
        WRITE(6,*)' arrays limit NMAX set to' , MXPA13
        NMAX=MXPA13
      ENDIF
      IF( MMAX.GT.MXPA50) THEN
        WRITE(6,*)' arrays limit MMAX set to' , MXPA50
        MMAX=MXPA50
      ENDIF
      IF( lMAX.GT.MXPA25) THEN
        WRITE(6,*)' arrays limit LMAX set to' , MXPA25
        LMAX=MXPA25
      ENDIF
*
      LMAXI = LMAX
      MMAXI = MMAX
      IF( NMAX.GE.3)THEN
        NMAXI = NMAX
        NNMAXI=(MXPA13-NMAXI)/(1+NMAXI)
C       aim: MXPA13 =!= NNNMAX =  NMAXI+(NMAXI+1)*NNMAXI
        NLMAXI=0
      ELSEIF( NMAX.EQ.2)THEN
        NMAXI=1
        NNMAXI=1
        NLMAXI=1
      ELSEIF( NMAX.EQ.1)THEN
        NMAXI=1
        NNMAXI=0
        NLMAXI=1
      ELSEIF( NMAX.LE.0)THEN
        NMAXI=0
        NNMAXI=0
        NLMAXI=0
      ENDIF
*
*
      LENTRY=0
*
      GOTO 111
*
*----------------------------------------------------------------------
*
      ENTRY SIGMA2(ECM)
*
*- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
*
      LENTRY=1
*     externe ICON option to internes NMAX=1,2,free
      IF(ICON/10.EQ.4) NMAX=2
      IF(ICON/10.EQ.5) NMAX=1
*     we drop L,M..dependent quantities, the rest is integrated for L=1,rest=0
      LMAXI = 1
      MMAXI = 0
      NMAXI = 0
      NNMAXI= 0
      NLMAXI= 0
*
*----------------------------------------------------------------------
*
* *** calculate the B-space integral for L/M soft/hard cut-pom.
* *** NPNT is the number of integration points of B-space integ.
*
 111  SIGTOT=0.0
      SIGINL=0.0
      SIGEL =0.0
      SIGELE=0.0
      SIGD  =0.0
      SIGDD =0.0
      SIGDI =0.0
      SIGDDI=0.0
      SIGINE=0.0
      SIHMDD=0.0
      SIGHMD=0.
      SIGLMD=0.
      SIGHIN=0.
      SIGIN=0.
      SIGSIN=0.0
      SIGHRI=0.0
      SIGSUM=0.0
      SIGSME=0.0
      SILMSD=0.0
      SILMDD=0.
      SLHMDD=0.
      DO 10 L=0,LMAXI
       SSOFT(L)=0.
       STRPL(L)=0.
       DO 10 M=0,MMAXI
        SHARD(M)=0.
        DO 10 N=0, MXPA13
          SIG(L,M,N)=0.
          SIGP(L,M,N)=0.
          SIGM(L,M,N)=0.
          SIGN(L,M,N)=0.
          SIGO(L,M,N)=0.
          PLMN(L,M,N)=0.
          PLMNCU(L,M,N)=0.
10    CONTINUE
*
*     get bare X-sections
      S=ECM**2
      CALL SIGSHD(ECM)
*
      IF(ALALAM.LE.1.D-2) THEN
        ALAM=0.60
      ELSE
        ALAM=ALALAM
      ENDIF
*
*     prepare integration:
      PI4 = 4.*PI
*
      IF(ECM.LT.2000.D0)THEN
        NPNT=96
        CALL GSET(ZERO,ONE,NPNT,XPNT,WGHT)
      ELSE
        NPNT=MXPA96
        CALL GSET(ZERO,ONE,NPNT,XPNT,WGHT)
      ENDIF
*
*     as low mass diffraction extra, high mass reduced:
      REDU = 1.0
      IF(IOUTPO.GE.0) WRITE (6,*) ' ALAM,REDU= ',ALAM,REDU
*
*     --here the versions started--
*     prepare factors to enter sum:
*     notation: Z(HARd/SOFt/LOOp)(Plus/Minus/N=mixed/O=mixed)
*
      ZHARP=(1.+ALAM)**2*ZHAR
      ZSOFP=(1.+ALAM)**2*ZSOF
      ZLOOP=(1.+ALAM)**2*ZLOO * REDU
      ZHARM=(1.-ALAM)**2*ZHAR
      ZSOFM=(1.-ALAM)**2*ZSOF
      ZLOOM=(1.-ALAM)**2*ZLOO * REDU
      ZHARN=(1.-ALAM**2)*ZHAR
      ZSOFN=(1.-ALAM**2)*ZSOF
      ZLOON=(1.-ALAM**2)*ZLOO * REDU
      ZHARO=(1.-ALAM**2)*ZHAR
      ZSOFO=(1.-ALAM**2)*ZSOF
      ZLOOO=(1.-ALAM**2)*ZLOO * REDU
*     one more factor at the top or at the bottom:
      ZTRPP=(1.+ALAM)**3*ZTRP * REDU
      ZTRPM=(1.-ALAM)**3*ZTRP * REDU
      ZTRPN=(1.-ALAM**2)*(1.+ALAM)*ZTRP * REDU
      ZTRPO=(1.-ALAM**2)*(1.-ALAM)*ZTRP * REDU
*
*     begin M,N,L,LL loop
*
      DO 720 L=0,LMAXI
        IF(L.EQ.0) THEN
          FAPSOF=1.
          FAMSOF=1.
          FANSOF=1.
          FAOSOF=1.
        ELSEIF(LSQRT) THEN
          FAPSOF=FAPSOF* SQRT( ZSOFP/FLOAT(L))
          FAMSOF=FAMSOF* SQRT( ZSOFM/FLOAT(L))
          FANSOF=FANSOF* SQRT( ZSOFN/FLOAT(L))
          FAOSOF=FAOSOF* SQRT( ZSOFO/FLOAT(L))
          IF (    FAPSOF .LT.DTINY )     FAPSOF=0.
          IF (    FAMSOF .LT.DTINY )     FAMSOF=0.
          IF (    FANSOF .LT.DTINY )     FANSOF=0.
          IF (    FAOSOF .LT.DTINY )     FAOSOF=0.
        ELSEIF(.NOT.LSQRT) THEN
          FAPSOF=FAPSOF*ZSOFP/FLOAT(L)
          FAMSOF=FAMSOF*ZSOFM/FLOAT(L)
          FANSOF=FANSOF*ZSOFN/FLOAT(L)
          FAOSOF=FAOSOF*ZSOFO/FLOAT(L)
          IF (FAPSOF.LT.DTINY )     FAPSOF=0.
          IF (FAMSOF.LT.DTINY )     FAMSOF=0.
          IF (FANSOF.LT.DTINY )     FANSOF=0.
          IF (FAOSOF.LT.DTINY )     FAOSOF=0.
        ENDIF
        DO 730 M=0,MMAXI
          IF(M.EQ.0) THEN
             FAPHAR=1.
             FAMHAR=1.
             FANHAR=1.
             FAOHAR=1.
          ELSEIF(LSQRT) THEN
C           WRITE(6,*)FAPHAR,ZHARP/FLOAT(M),FAMHAR,ZHARM/FLOAT(M)
            FAPHAR=FAPHAR* SQRT( ZHARP/FLOAT(M) )
            FAMHAR=FAMHAR* SQRT( ZHARM/FLOAT(M) )
            FANHAR=FANHAR* SQRT( ZHARN/FLOAT(M) )
            FAOHAR=FAOHAR* SQRT( ZHARO/FLOAT(M) )
            IF (    FAPSOF*FAPHAR .LT.DTINY )     FAPHAR=0.
            IF (    FAMSOF*FAMHAR .LT.DTINY )     FAMHAR=0.
            IF (    FANSOF*FANHAR .LT.DTINY )     FANHAR=0.
            IF (    FAOSOF*FAOHAR .LT.DTINY )     FAOHAR=0.
          ELSEIF(.NOT.LSQRT) THEN
            FAPHAR=FAPHAR*ZHARP/FLOAT(M)
            FAMHAR=FAMHAR*ZHARM/FLOAT(M)
            FANHAR=FANHAR*ZHARN/FLOAT(M)
            FAOHAR=FAOHAR*ZHARO/FLOAT(M)
            IF (FAPSOF*FAPHAR.LT.DTINY )     FAPHAR=0.
            IF (FAMSOF*FAMHAR.LT.DTINY )     FAMHAR=0.
            IF (FANSOF*FANHAR.LT.DTINY )     FANHAR=0.
            IF (FAOSOF*FAOHAR.LT.DTINY )     FAOHAR=0.
          ENDIF
          DO 740 N=0,NMAXI
            IF( N.EQ.0) THEN
               FAPTRP=1.
               FAMTRP=1.
               FANTRP=1.
               FAOTRP=1.
            ELSEIF(LSQRT) THEN
               FAPTRP=-FAPTRP* SQRT( ZTRPP/FLOAT(N) )
               FAMTRP=-FAMTRP* SQRT( ZTRPM/FLOAT(N) )
               FANTRP=-FANTRP* SQRT( ZTRPN/FLOAT(N) )
               FAOTRP=-FAOTRP* SQRT( ZTRPO/FLOAT(N) )
               IF (ABS(FAPTRP*FAPSOF*FAPHAR).LT.DTINY )     FAPTRP=0.
               IF (ABS(FAMTRP*FAMSOF*FAMHAR).LT.DTINY )     FAMTRP=0.
               IF (ABS(FANTRP*FANSOF*FANHAR).LT.DTINY )     FANTRP=0.
               IF (ABS(FAOTRP*FAOSOF*FAOHAR).LT.DTINY )     FAOTRP=0.
            ELSEIF(.NOT.LSQRT) THEN
               FAPTRP=-FAPTRP*ZTRPP/FLOAT(N)
               FAMTRP=-FAMTRP*ZTRPM/FLOAT(N)
               FANTRP=-FANTRP*ZTRPN/FLOAT(N)
               FAOTRP=-FAOTRP*ZTRPO/FLOAT(N)
               IF (ABS(FAPTRP*FAPSOF*FAPHAR).LT.DTINY )     FAPTRP=0.
               IF (ABS(FAMTRP*FAMSOF*FAMHAR).LT.DTINY )     FAMTRP=0.
               IF (ABS(FANTRP*FANSOF*FANHAR).LT.DTINY )     FANTRP=0.
               IF (ABS(FAOTRP*FAOSOF*FAOHAR).LT.DTINY )     FAOTRP=0.
            ENDIF
            DO 750 NN=0,NNMAXI
*             for compatibility no new subscript is introduced in some arrays:
              NNN=N+(NMAXI+1)*NN
*             if only first order option jump out of second order contr.:
              IF( NMAX.LE.2   .AND. N.EQ.1 .AND. NN.EQ.1 ) GO TO 750
              IF(NN.EQ.0) THEN
                FAPLOO=1.
                FAMLOO=1.
                FANLOO=1.
                FAOLOO=1.
              ELSEIF(LSQRT) THEN
                FAPLOO=-FAPLOO* SQRT( ZLOOP/FLOAT(NN))
                FAMLOO=-FAMLOO* SQRT( ZLOOM/FLOAT(NN))
                FANLOO=-FANLOO* SQRT( ZLOON/FLOAT(NN))
                FAOLOO=-FAOLOO* SQRT( ZLOOO/FLOAT(NN))
                IF(ABS(FAPLOO*FAPTRP*FAPSOF*FAPHAR).LT.DTINY )FAPLOO=0.
                IF(ABS(FAMLOO*FAMTRP*FAMSOF*FAMHAR).LT.DTINY )FAMLOO=0.
                IF(ABS(FANLOO*FANTRP*FANSOF*FANHAR).LT.DTINY )FANLOO=0.
                IF(ABS(FAOLOO*FAOTRP*FAOSOF*FAOHAR).LT.DTINY )FAOLOO=0.
              ELSEIF(.NOT.LSQRT) THEN
                FAPLOO=-FAPLOO*ZLOOP/FLOAT(NN)
                FAMLOO=-FAMLOO*ZLOOM/FLOAT(NN)
                FANLOO=-FANLOO*ZLOON/FLOAT(NN)
                FAOLOO=-FAOLOO*ZLOOO/FLOAT(NN)
                IF(ABS(FAPLOO*FAPTRP*FAPSOF*FAPHAR).LT.DTINY )FAPLOO=0.
                IF(ABS(FAMLOO*FAMTRP*FAMSOF*FAMHAR).LT.DTINY )FAMLOO=0.
                IF(ABS(FANLOO*FANTRP*FANSOF*FANHAR).LT.DTINY )FANLOO=0.
                IF(ABS(FAOLOO*FAOTRP*FAOSOF*FAOHAR).LT.DTINY )FAOLOO=0.
              ENDIF
*
*         elastic processes are not generated
          IF(L.EQ.0.AND.M.EQ.0.AND.N.EQ.0.AND.NN.EQ.0) GO TO 750
*
          DENOM=DBLE(M)/DBLE(BH)+DBLE(L)/DBLE(BS)+DBLE(N)/DBLE(BT)
     &    +DBLE(NN)/DBLE(BT)
*
          DO 735 K=1,NPNT
*
C           change intergration for large L+M+N+NN?
            IF ( (M+L+N+NN) .LE. MXLMN  ) THEN
              XPNTK=DBLE(XPNT(K))
              WGHTK=DBLE(WGHT(K))
              DENOMI=DENOM
            ELSE
              RMXLMN = DBLE(M+L+N+NN) /DBLE(MXLMN)
              XPNTK=DBLE(XPNT(K))
              WGHTK= DBLE(WGHT(K)) * XPNTK**(RMXLMN-1.)
              DENOMI= DENOM / RMXLMN
            ENDIF
*
            EXPOSP=-ZSOFP*XPNTK**(1./(DENOMI*DBLE(BS)))
            EXPOSM=-ZSOFM*XPNTK**(1./(DENOMI*DBLE(BS)))
            EXPOSN=-ZSOFN*XPNTK**(1./(DENOMI*DBLE(BS)))
            EXPOSO=-ZSOFO*XPNTK**(1./(DENOMI*DBLE(BS)))
*
            EXPOHP=-ZHARP*XPNTK**(1./(DENOMI*DBLE(BH)))
            EXPOHM=-ZHARM*XPNTK**(1./(DENOMI*DBLE(BH)))
            EXPOHN=-ZHARN*XPNTK**(1./(DENOMI*DBLE(BH)))
            EXPOHO=-ZHARO*XPNTK**(1./(DENOMI*DBLE(BH)))
*
            EXPOTP=+ZTRPP*XPNTK**(1./(DENOMI*DBLE(BT)))
            EXPOTM=+ZTRPM*XPNTK**(1./(DENOMI*DBLE(BT)))
            EXPOTN=+ZTRPN*XPNTK**(1./(DENOMI*DBLE(BT)))
            EXPOTO=+ZTRPO*XPNTK**(1./(DENOMI*DBLE(BT)))
*
            EXPOLP=+ZLOOP*XPNTK**(1./(DENOMI*DBLE(BT)))
            EXPOLM=+ZLOOM*XPNTK**(1./(DENOMI*DBLE(BT)))
            EXPOLN=+ZLOON*XPNTK**(1./(DENOMI*DBLE(BT)))
            EXPOLO=+ZLOOO*XPNTK**(1./(DENOMI*DBLE(BT)))
*
            IF(IOUTPO.GE.7) THEN
              WRITE(6,*)
     *         ' K=',K,' EXPOS/H=',EXPOSP,EXPOHP,' DENOMI/BH=',DENOMI,BH
              WRITE(6,*)
     *         ' K=',K,' EXPOS/H=',EXPOSM,EXPOHM,' DENOMI/BH=',DENOMI,BH
              WRITE(6,*)
     *         ' K=',K,' EXPOS/H=',EXPOSN,EXPOHN,' DENOMI/BH=',DENOMI,BH
              WRITE(6,*)
     *          ' K=',K,'XPNT=',XPNTK,'WGHT=',WGHTK,'DENO=',DENOMI
            ENDIF
*
*           notation:
*           EX(P=+/M=-/N=mixed/O=mixed)(EX=all/HArd,TRippel,LOop)(P/Half)
*
            IF(     EXPOSP .GT. TINEXP) THEN
              EXPSOH=EXP(0.5D00*EXPOSP)
              EXMSOH=EXP(0.5D00*EXPOSM)
              EXNSOH=EXP(0.5D00*EXPOSN)
              EXOSOH=EXP(0.5D00*EXPOSO)
            ELSE
              EXPSOH=0.
              EXMSOH=0.
              EXNSOH=0.
              EXOSOH=0.
            ENDIF
            EXPSOP=EXPSOH**2
            EXMSOP=EXMSOH**2
            EXNSOP=EXNSOH**2
            EXOSOP=EXOSOH**2
*
            IF(    EXPOHP .GT. TINEXP) THEN
              EXPHAH=EXP(0.5D00*EXPOHP)
              EXMHAH=EXP(0.5D00*EXPOHM)
              EXNHAH=EXP(0.5D00*EXPOHN)
              EXOHAH=EXP(0.5D00*EXPOHO)
            ELSE
              EXPHAH=0.
              EXMHAH=0.
              EXNHAH=0.
              EXOHAH=0.
            ENDIF
            EXPHAP=EXPHAH**2
            EXMHAP=EXMHAH**2
            EXNHAP=EXNHAH**2
            EXOHAP=EXOHAH**2
*
            IF( NMAX.GE.3) THEN
              IF( EXPOTP .GT. TINEXP) THEN
                EXPTRH=EXP(0.5D00*EXPOTP)
                EXMTRH=EXP(0.5D00*EXPOTM)
                EXNTRH=EXP(0.5D00*EXPOTN)
                EXOTRH=EXP(0.5D00*EXPOTO)
              ELSE
                EXPTRH=0.
                EXMTRH=0.
                EXNTRH=0.
                EXOTRH=0.
              ENDIF
              EXPTRP= EXPTRH**2
              EXMTRP= EXMTRH**2
              EXNTRP= EXNTRH**2
              EXOTRP= EXOTRH**2
            ELSEIF( NMAX.LE.2) THEN
                EXPTRH= 1 + 0.5*EXPOTP
                EXMTRH= 1 + 0.5*EXPOTM
                EXNTRH= 1 + 0.5*EXPOTN
                EXOTRH= 1 + 0.5*EXPOTO
                EXPTRP= 1 + EXPOTP
                EXMTRP= 1 + EXPOTM
                EXNTRP= 1 + EXPOTN
                EXOTRP= 1 + EXPOTO
            ENDIF
*
            IF( NMAX.GE.3) THEN
              IF( EXPOLP .GT. TINEXP) THEN
                EXPLOH=EXP(0.5D00*EXPOLP)
                EXMLOH=EXP(0.5D00*EXPOLM)
                EXNLOH=EXP(0.5D00*EXPOLN)
                EXOLOH=EXP(0.5D00*EXPOLO)
              ELSE
                EXPLOH=0.
                EXMLOH=0.
                EXNLOH=0.
                EXOLOH=0.
              ENDIF
              EXPLOP=EXPLOH**2
              EXMLOP=EXMLOH**2
              EXNLOP=EXNLOH**2
              EXOLOP=EXOLOH**2
            ELSEIF( NMAX.EQ.2 ) THEN
                EXPLOH= 1 + 0.5*EXPOLP
                EXMLOH= 1 + 0.5*EXPOLM
                EXNLOH= 1 + 0.5*EXPOLN
                EXOLOH= 1 + 0.5*EXPOLO
                EXPLOP= 1 + EXPOLP
                EXMLOP= 1 + EXPOLM
                EXNLOP= 1 + EXPOLN
                EXOLOP= 1 + EXPOLO
            ELSEIF( NMAX.LE.1 ) THEN
                EXPLOH= 1
                EXMLOH= 1
                EXNLOH= 1
                EXOLOH= 1
                EXPLOP= 1
                EXMLOP= 1
                EXNLOP= 1
                EXOLOP= 1
            ENDIF
*
            EXPEXH = EXPSOH *EXPHAH *EXPTRH *EXPLOH
            EXMEXH = EXMSOH *EXMHAH *EXMTRH *EXMLOH
            EXNEXH = EXNSOH *EXNHAH *EXNTRH *EXNLOH
            EXOEXH = EXOSOH *EXOHAH *EXOTRH *EXOLOH
            EXPEXP = EXPSOP *EXPHAP *EXPTRP *EXPLOP
            EXMEXP = EXMSOP *EXMHAP *EXMTRP *EXMLOP
            EXNEXP = EXNSOP *EXNHAP *EXNTRP *EXNLOP
            EXOEXP = EXOSOP *EXOHAP *EXOTRP *EXOLOP
*
            IF( ( NMAX.LE.2  .AND.  N.EQ.1 ) .OR.
     *          ( NMAX.EQ.2  .AND. NN.EQ.1 ) .OR.
     *            NMAX.EQ.0                      ) THEN
               SIGP(L,M,NNN)=SIGP(L,M,NNN)+EXPSOP *EXPHAP *WGHTK
               SIGM(L,M,NNN)=SIGM(L,M,NNN)+EXMSOP *EXMHAP *WGHTK
               SIGN(L,M,NNN)=SIGN(L,M,NNN)+EXNSOP *EXNHAP *WGHTK
               SIGO(L,M,NNN)=SIGO(L,M,NNN)+EXOSOP *EXOHAP *WGHTK
             ELSE
               SIGP(L,M,NNN)=SIGP(L,M,NNN)+EXPEXP*WGHTK
               SIGM(L,M,NNN)=SIGM(L,M,NNN)+EXMEXP*WGHTK
               SIGN(L,M,NNN)=SIGN(L,M,NNN)+EXNEXP*WGHTK
               SIGO(L,M,NNN)=SIGO(L,M,NNN)+EXOEXP*WGHTK
             ENDIF
*
*           quantities without L,M,N,NN dependence considered ones
*                              (when, chosen to get suitable weights)
            IF(L.EQ.1.AND.M.EQ.0.AND.N.EQ.0.AND.NN.EQ.0) THEN
*
              IF ( (M+L+N+NN) .GT. MXLMN  ) THEN
                WRITE(6,*)' MXLMN too low ' , MXLMN,M,L,N,NN
                RETURN
              ENDIF
              WGHFAC = WGHTK/XPNTK *PI4/DENOMI
              IF     ( NMAX.GE.3 ) THEN
                SIGELE = SIGELE + WGHFAC *
     *              0.0625*(   1.-EXPEXH   +  1.-EXMEXH
     *                        +1.-EXNEXH   +  1.-EXOEXH )**2
*               low mass diffraction:
                SILMSD = SILMSD + WGHFAC *
     *                0.125*(EXPEXH -EXMEXH)**2
                SILMDD = SILMDD + WGHFAC *
     *                0.0625*(EXPEXH+EXMEXH-EXNEXH-EXOEXH)**2
              ELSEIF( NMAX.LE.2 ) THEN
                SIGELE = SIGELE + WGHFAC *
     *           0.0625*( (   1.-EXPEXH   +  1.-EXMEXH
     *                       +1.-EXNEXH   +  1.-EXOEXH
*                            subtract second order terms in each factor:
C////CHANGED - TO + BRACKET UNNECESSARY
     *                      +(1.-EXPTRH)*(1-EXPLOH) *EXPSOH *EXPHAH
     *                      +(1.-EXMTRH)*(1-EXMLOH) *EXMSOH *EXMHAH
     *                      +(1.-EXNTRH)*(1-EXNLOH) *EXNSOH *EXNHAH
     *                      +(1.-EXOTRH)*(1-EXOLOH) *EXOSOH *EXOHAH)**2
*                            subtract second order terms of product:
     *                   - (  (2.-EXPTRH-EXPLOH) *EXPSOH *EXPHAH
     *                       +(2.-EXMTRH-EXMLOH) *EXMSOH *EXMHAH
     *                       +(2.-EXNTRH-EXNLOH) *EXNSOH *EXNHAH
     *                       +(2.-EXOTRH-EXOLOH) *EXOSOH *EXOHAH ) **2)
*               low mass diffraction:
                SILMSD = SILMSD + WGHFAC *
     *            0.125*( ( EXPEXH -EXMEXH
*                           subtract second order terms in each factor:
     *                     -(1.-EXPTRH)*(1-EXPLOH) *EXPSOH*EXPHAH
     *                     +(1.-EXMTRH)*(1-EXMLOH) *EXMSOH*EXMHAH )**2
*                           subtract second order terms of product:
     *                     -(  (2.-EXPTRH-EXPLOH) *EXPSOH *EXPHAH
     *                        -(2.-EXMTRH-EXMLOH) *EXMSOH*EXMHAH ) **2)
                SILMDD = SILMDD + WGHFAC *
     *           0.0625*( (EXPEXH+EXMEXH-EXNEXH-EXOEXH
*                         subtract second order terms in each factor:
     *                   -(1.-EXPTRH)*(1-EXPLOH) *EXPSOH *EXPHAH
     *                   -(1.-EXMTRH)*(1-EXMLOH) *EXMSOH *EXMHAH
     *                   +(1.-EXNTRH)*(1-EXNLOH) *EXNSOH *EXNHAH
     *                   +(1.-EXOTRH)*(1-EXOLOH) *EXOSOH *EXOHAH)**2
*                         subtract second order terms of product:
     *                - (  (2.-EXPTRH-EXPLOH) *EXPSOH *EXPHAH
     *                    +(2.-EXMTRH-EXMLOH) *EXMSOH *EXMHAH
     *                    -(2.-EXNTRH-EXNLOH) *EXNSOH *EXNHAH
     *                    -(2.-EXOTRH-EXOLOH) *EXOSOH *EXOHAH ) **2)
              ENDIF
              IF( NMAX.NE.2 ) THEN
                SIGTOT=SIGTOT+2.*WGHFAC*
     *              0.25*(  1.-EXPEXH  +  1.-EXMEXH +
     *                      1.-EXNEXH  +  1.-EXOEXH  )
                SIGINE = SIGINE +  WGHFAC *
     *              0.25*(  1.-EXPEXP  +  1.-EXMEXP +
     *                      1.-EXNEXP  +  1.-EXOEXP  )
*               pure-soft-inelastic (hard scatterring is included as absorbtion)
                SIGSIN=SIGSIN+ WGHFAC *
     *              0.25*(    (EXPHAP-EXPEXP)
     *                       +(EXMHAP-EXMEXP)
     *                       +(EXNHAP-EXNEXP)
     *                       +(EXOHAP-EXOEXP) )
*               hard-inelastic (soft scatterring disregarded)
                SIGHIN=SIGHIN+ WGHFAC*
     *              0.25*(  1.-EXPHAP  +  1.-EXMHAP +
     *                      1.-EXNHAP  +  1.-EXOHAP  )
              ELSEIF(  NMAX.EQ.2  ) THEN
                SIGTOT=SIGTOT+2.*WGHFAC*
     *              0.25*(  1.-EXPEXH  +  1.-EXMEXH +
     *                      1.-EXNEXH  +  1.-EXOEXH
*                            subtract second order terms in .TRH and LOH:
C/////CHANGED - TO +
     *                      +(1.-EXPTRH)*(1-EXPLOH) *EXPSOH *EXPHAH
     *                      +(1.-EXMTRH)*(1-EXMLOH) *EXMSOH *EXMHAH
     *                      +(1.-EXNTRH)*(1-EXNLOH) *EXNSOH *EXNHAH
     *                      +(1.-EXOTRH)*(1-EXOLOH) *EXOSOH *EXOHAH )
                SIGINE = SIGINE +  WGHFAC *
     *              0.25*(  1.-EXPEXP  +  1.-EXMEXP +
     *                      1.-EXNEXP  +  1.-EXOEXP
*                            subtract second order terms in .TRP and LOP:
C/////CHANGED - TO +
     *                      +(1.-EXPTRP)*(1-EXPLOP) *EXPSOP *EXPHAP
     *                      +(1.-EXMTRP)*(1-EXMLOP) *EXMSOP *EXMHAP
     *                      +(1.-EXNTRP)*(1-EXNLOP) *EXNSOP *EXNHAP
     *                      +(1.-EXOTRP)*(1-EXOLOP) *EXOSOP *EXOHAP )
*               pure-soft-inelastic (hard scatterring is included as absorbtion)
                SIGSIN=SIGSIN+ WGHFAC *
     *              0.25*(    (EXPHAP-EXPEXP)
     *                       +(EXMHAP-EXMEXP)
     *                       +(EXNHAP-EXNEXP)
     *                       +(EXOHAP-EXOEXP)
*                            subtract second order terms of 2nd column:
     *                      +(1.-EXPTRP)*(1-EXPLOP) *EXPSOP *EXPHAP
     *                      +(1.-EXMTRP)*(1-EXMLOP) *EXMSOP *EXMHAP
     *                      +(1.-EXNTRP)*(1-EXNLOP) *EXNSOP *EXNHAP
     *                      +(1.-EXOTRP)*(1-EXOLOP) *EXOSOP *EXOHAP)
*               hard-inelastic (soft scatterring disregarded)
                SIGHIN=SIGHIN+ WGHFAC*
     *              0.25*(  1.-EXPHAP  +  1.-EXMHAP +
     *                      1.-EXNHAP  +  1.-EXOHAP  )
              ENDIF
*             high mass diffraction (sep.low mass diffr. arbitrary)
*                          (naive 1/EX?TRP -> EX?TR as selected cut counts -1)
              IF( NMAX.GE.3 ) THEN
                SIGHMD=SIGHMD + WGHFAC  *
     *                       0.25*( (EXPTRP-1.)*EXPEXP
     *                             +(EXMTRP-1.)*EXMEXP
     *                             +(EXNTRP-1.)*EXNEXP
     *                             +(EXOTRP-1.)*EXOEXP)
              ELSE
                SIGHMD=SIGHMD + WGHFAC  *
     *                       0.25*( EXPOTP * EXPSOP*EXPHAP
     *                             +EXPOTM * EXMSOP*EXMHAP
     *                             +EXPOTN * EXNSOP*EXNHAP
     *                             +EXPOTO * EXOSOP*EXOHAP )
              ENDIF
              IF( NMAX.GE.3  ) THEN
                SIHMDD=SIHMDD + WGHFAC  *
     *                       0.25*( (EXPLOP-1.)*EXPEXP
     *                             +(EXMLOP-1.)*EXMEXP
     *                             +(EXNLOP-1.)*EXNEXP
     *                             +(EXOLOP-1.)*EXOEXP)
              ELSEIF (NMAX.EQ.2 ) THEN
                SIHMDD=SIHMDD + WGHFAC  *
     *                       0.25*( EXPOLP * EXPSOP*EXPHAP
     *                             +EXPOLM * EXMSOP*EXMHAP
     *                             +EXPOLN * EXNSOP*EXNHAP
     *                             +EXPOLO * EXOSOP*EXOHAP )
*              no action:
*              ELSEIF (NMAX.LE.1 ) THEN
*                SIHMDD=SIHMDD + WGHFAC  *
*     *                       0.25*(   0.   * EXPSOP*EXPHAP
*     *                             +  0.   * EXMSOP*EXMHAP
*     *                             +  0.   * EXNSOP*EXNHAP
*     *                             +  0.   * EXOSOP*EXOHAP )
              ENDIF
            ENDIF
*           ending non L,M,N,NN depending part
*
735      CONTINUE
*         ending impact-integral loop
*
          IF(ABS(FAPHAR*FAPSOF*FAPTRP*FAPLOO*SIGP(L,M,NNN)).LT.DTINY)
     &    THEN
            SIGP(L,M,NNN)=0.
          ELSEIF(LSQRT) THEN
            SIGP(L,M,NNN)=FAPHAR*FAPSOF*FAPTRP*FAPLOO*SIGP(L,M,NNN)
     *         * abs(FAPHAR*FAPSOF*FAPTRP*FAPLOO)/DENOMI*PI4
          ELSEIF(.NOT.LSQRT) THEN
            SIGP(L,M,NNN)=FAPHAR*FAPSOF*FAPTRP*FAPLOO*SIGP(L,M,NNN)
     *         /DENOMI*PI4
          ENDIF
          IF(ABS(FAMHAR*FAMSOF*FAMTRP*FAMLOO*SIGM(L,M,NNN)).LT.DTINY)
     &    THEN
            SIGM(L,M,NNN)=0.
          ELSEIF(LSQRT) THEN
            SIGM(L,M,NNN)=FAMHAR*FAMSOF*FAMTRP*FAMLOO*SIGM(L,M,NNN)
     *           * abs( FAMHAR*FAMSOF*FAMTRP*FAMLOO)/DENOMI*PI4
          ELSEIF(.NOT.LSQRT) THEN
            SIGM(L,M,NNN)=FAMHAR*FAMSOF*FAMTRP*FAMLOO*SIGM(L,M,NNN)
     *         /DENOMI*PI4
          ENDIF
          IF(ABS(FANHAR*FANSOF*FANTRP*FANLOO*SIGN(L,M,NNN)).LT.DTINY)
     &    THEN
            SIGN(L,M,NNN)=0.
          ELSEIF(LSQRT) THEN
            SIGN(L,M,NNN)=FANHAR*FANSOF*FANTRP*FANLOO*SIGN(L,M,NNN)
     *           * abs( FANHAR*FANSOF*FANTRP*FANLOO)/DENOMI*PI4
          ELSEIF(.NOT.LSQRT) THEN
            SIGN(L,M,NNN)=FANHAR*FANSOF*FANTRP*FANLOO*SIGN(L,M,NNN)
     *         /DENOMI*PI4
          ENDIF
          IF(ABS(FAOHAR*FAOSOF*FAOTRP*FAOLOO*SIGO(L,M,NNN)).LT.DTINY)
     &    THEN
           SIGO(L,M,NNN)=0.
          ELSEIF(LSQRT) THEN
            SIGO(L,M,NNN)=FAOHAR*FAOSOF*FAOTRP*FAOLOO*SIGO(L,M,NNN)
     *          * abs( FAOHAR*FAOSOF*FAOTRP*FAOLOO/DENOMI)*PI4
          ELSEIF(.NOT.LSQRT) THEN
            SIGO(L,M,NNN)=FAOHAR*FAOSOF*FAOTRP*FAOLOO*SIGO(L,M,NNN)
     *          /DENOMI*PI4
          ENDIF
*
750        CONTINUE
740      CONTINUE
730    CONTINUE
720   CONTINUE
*
* *** summing up the three contributions
*
      NNNMAX=NMAXI+(NMAXI+1)*NNMAXI
      DO 820 L=0,LMAXI
        DO 830 M=0,MMAXI
         DO 830 NNN=0,NNNMAX
          SIG(L,M,NNN)=(SIGP(L,M,NNN)+SIGM(L,M,NNN)+
     *                  SIGN(L,M,NNN)+SIGO(L,M,NNN) )/4.
830     CONTINUE
820    CONTINUE
*
*
* *** calculate summed quantities for print out
*
      DO 3 L=0,LMAXI
        DO 4 M=0,MMAXI
         DO 4 N=0,NMAXI
          DO 4 NN=0,NNMAXI
            IF( NMAX.LE.2 .AND. N.EQ.1 .AND. NN.EQ.1 ) GO TO 4
            NNN=N+(NMAXI+1)*NN
            SIGSUM=SIGSUM + SIG(L,M,NNN)
*           for options outlawing hard without soft:
            IF(M.EQ.0.OR.L.GE.1) SIGSME=SIGSME + SIG(L,M,NNN)
            SHARD(M)=SHARD(M)+SIG(L,M,NNN)
            SSOFT(L)=SSOFT(L)+SIG(L,M,NNN)
            STRPL(N)=STRPL(N)+SIG(L,M,NNN)
            SIGINL = SIGINL + SIG(L,M,NNN)
            IF(M.GE.1) SIGHRI = SIGHRI + SIG(L,M,NNN)
            IF(L.EQ.0.AND.M.EQ.0.AND.NN.EQ.0.AND.N.GE.1) THEN
              SIGDI = SIGDI  + (-1)**N*SIG(L,M,NNN)
            ELSEIF(L.EQ.0.AND.M.EQ.0.AND.N.EQ.0.AND.NN.GE.1) THEN
              SIGDDI= SIGDDI + (-1)**NN*SIG(L,M,NNN)
            ENDIF
    4   CONTINUE
    3 CONTINUE
*   elastic processes were not generated, L,M,N,NN=0 no problem
*
      SIGLMD=SILMSD+SILMDD
      SITHMD=SIGHMD+SIHMDD
      SIGD = SIGLMD + SITHMD
      SLHMDD =  SQRT(ABS(SILMDD*SIHMDD))
      SIGDD= SILMDD + SIHMDD + SLHMDD
      SIGIN=SIGINE+SIGLMD
      SIGEL=SIGTOT-SIGIN
*
* ***  print out
*
      IF(LENTRY.EQ.1.AND.IOUTPO.LE.1) RETURN
*
      WRITE(6,*)' '
      WRITE(6,*)'  --- properties of events ---'
      WRITE (6,102)
      WRITE(6,*)'  Energy=',ECM
      WRITE (6,102)
      WRITE(6,*)'  max.contributing soft/hard/diffr./doubl.diffr. cuts'
      WRITE(6,*)'                     LMAXI=  MMAXI=  NMAXI=   NNMAXI='
      WRITE(6,'(15X,4I9)')              LMAXI,MMAXI,NMAXI,NNMAXI
      WRITE(6,*)'  methode used:  '
      WRITE(6,*)'                     ISIG=   ICON=   IPIM=     '
      WRITE(6,'(15X,3I9)')                     ISIG,ICON,IPIM
      WRITE (6,102)
      WRITE(6,*)'  --- bare cross section and eikonal constants ---'
C     COMMON/POMPAR/ALFA,ALFAP,A,C,AK
C     COMMON /SIGMA/SIGSOF,BS,ZSOF,SIGHAR,BH,ZHAR,SIGTRP,BT,ZTRP,
C    *              SIGLOO,ZLOO
      WRITE(6,*)'    ALFA =',ALFA,' ALFAP =',ALFAP,' A =',A
      WRITE(6,*)'    C =',C,' AK =',AK
      WRITE(6,*)'    ALALAM =',ALALAM
      WRITE (6,102)
      WRITE(6,*)'     SIGSOF=',SIGSOF,'  BS=',BS,'  ZSOF=',ZSOF
      WRITE(6,*)'     SIGHAR=',SIGHAR,'  BH=',BH,'  ZHAR=',ZHAR
      WRITE(6,*)'     SIGTRP=',SIGTRP,'  BT=',BT,'  ZTRP=',ZTRP
      WRITE(6,*)'     SIGLOO=',SIGLOO,'  BT=',BT,'  ZLOO=',ZLOO
      WRITE (6,102)
      WRITE(6,*)'  --- observable cross sections ---'
      WRITE (6,102)
      WRITE(6,*)'     TOTAL X-SECTION         = ',SIGTOT
      WRITE(6,*)'     ELASTIC X-SECTION       = ',SIGELE
      WRITE(6,*)'     INELASTIC X-SECTION-LMD = ',SIGINE
      WRITE(6,*)'     INELASTIC X-SECTION     = ',SIGIN
      WRITE(6,*)'     HARD INEL. X-SECTION    = ',SIGHIN
      WRITE (6,102)
      WRITE(6,*)'  LOW MASS SING./DOUB.DIFFR.X-SECTION= ',SILMSD,SILMDD
      WRITE(6,*)'  => LOW MASS TOTAL DIFFRACTIV.X-SECTION=     ',SIGLMD
      WRITE(6,*)'  HIGH MASS SING./DOUB.DIFFR.X-SECTION= ',SIGDI,SIGDDI
      WRITE(6,*)'  => HIGH MASS TOTAL DIFFRACTIV.X-SECTION=    ',SITHMD
      WRITE(6,*)'  ESTIMAT.MIXED (LM+HM) DOUBL.DIFFRAC.X.SEC.= ',SLHMDD
      WRITE(6,*)'  => '
      WRITE(6,*)'     DIFFRACTIVE  X-SECTION =    ',SIGD
      WRITE(6,*)'     DOUBLY DIFFRACTIVE X-SECT. =',SIGDD
      WRITE (6,102)
*
      IF(IOUTPO.GE.0) THEN
       WRITE(6,*)'  --- observ. x-sections, altern. calculated ---'
       WRITE(6,*)'     ELASTIC X-SECTION   = ',SIGEL
       WRITE(6,*)'     INELASTIC X-SECTION-LMD = ',SIGINL
       WRITE(6,*)'     HARD INEL. X-SECTION= ',SIGHRI
       WRITE(6,*)'  HIGH MASS SING./DOUB.DIFFR.X-SECT.=',SIGHMD,SIHMDD
      WRITE(6,*)'     X-SECTION FOR (L,M,N,NN)= 1000 0100 0010 0001'
      WRITE(6,*)'            ',SIG(1,0,0),SIG(0,1,0)
     *                        ,SIG(0,0,1),SIG(0,0,2)
       WRITE (6,102)
      ENDIF
*
      IF(IOUTPO.GE.2) THEN
         WRITE (6,102)
         NNMAXP=NMAXI/2
         IF( NMAXI.LT.2)NNMAXP=1
         DO 52 N=0,NNMAXP
*          printout loops:
           DO 48 L=0,LMAXI
 48          WRITE(6,101)(SIG(L,M,N),M=0,7)
           WRITE (6,102)
           DO 50 L=0,LMAXI
 50          WRITE(6,101)(SIG(L,M,N),M=8,15)
           WRITE (6,102)
           WRITE(6,*)
     &       '  # CUT-POMERON  SSOFT X-SECT.  SHARD X-SECT.'
           DO 58 L=0,LMAXI
 58          WRITE (6,103)L,SSOFT(L),SHARD(L)
           WRITE (6,102)
*        printoutloop ends
52       CONTINUE
      ENDIF
*
* *** attribute x-sections (SIG) for CUT objects ('s and PHI's)
*                            to string configurations (PLMN) s:  **********
*
C                               CHANGED 10.1.90 BY J.R.
*     preparations:
C     just for Y and (Phi) - cuts:
      FAK(0)=1
      DO 500 I=1,NMAXI
        FAK(I)=FAK(I-1)*I
  500 CONTINUE
      DO 501 I=0,NMAXI
        DO 501 J=0,I
          CMBIN(I,J)=FAK(I)/(FAK(J)*FAK(I-J))
  501 CONTINUE
*
      TMMP=0.
      DO 5 L=0,LMAXI
      DO 5 M=0,MMAXI
       IF(ICON.EQ.44.OR.ICON.EQ.46.OR.ICON.EQ.48.
     *                             OR.ICON.EQ.54) THEN
C///test:
*        no Y or PHI cut
           PLMNTM=SIG(L,M,0)/(SIGSUM+TIN)
           PLMN(L,M,0) =  PLMNTM + PLMN(L,M,0)
           TMMP=TMMP+PLMNTM
*        Y but no PHI cut
           PLMNTM=SIG(L,M,1)/(SIGSUM+TIN)
           TMMP=TMMP+PLMNTM
           IF(L+2.LE.LMAXI) THEN
               PLMN(L+2,M,0) = (-2.)* PLMNTM + PLMN(L+2,M,0)
               PLMN(L+1,M,0) =  4.  * PLMNTM + PLMN(L+1,M,0)
           ELSE
               PLMN(LMAXI,M,0) = (-2.)* PLMNTM + PLMN(LMAXI,M,0)
               PLMN(LMAXI,M,0) =  4.  * PLMNTM + PLMN(LMAXI,M,0)
           ENDIF
           IF(L.EQ.0 .AND. M.EQ.0) THEN
             PLMN(L  ,M,1) = (-1.)* PLMNTM + PLMN(L  ,M,1)
           ELSE
             PLMN(L  ,M,0) = (-1.)* PLMNTM + PLMN(L  ,M,0)
           ENDIF
*        no Y but PHI cut
           PLMNTM=SIG(L,M,2)/(SIGSUM+TIN)
           TMMP=TMMP+PLMNTM
           IF(L+2.LE.LMAXI) THEN
               PLMN(L+2,M,0) = (-2.)* PLMNTM + PLMN(L+2,M,0)
               PLMN(L+1,M,0) =  4.  * PLMNTM + PLMN(L+1,M,0)
           ELSE
               PLMN(LMAXI,M,0) = (-2.)* PLMNTM + PLMN(LMAXI,M,0)
               PLMN(LMAXI,M,0) =  4.  * PLMNTM + PLMN(LMAXI,M,0)
           ENDIF
           IF(L.EQ.0 .AND. M.EQ.0) THEN
             PLMN(L  ,M,2) = (-1.)* PLMNTM + PLMN(L  ,M,2)
           ELSE
             PLMN(L  ,M,0) = (-1.)* PLMNTM + PLMN(L  ,M,0)
           ENDIF
C/// test end
       ELSE
        DO 51  N=0,NMAXI
         DO 51 NN=0,NNMAXI
           IF(NMAX.LE.2 .AND. N.EQ.1 .AND. NN.EQ.1) GO TO 51
           NNN=N+(NMAXI+1)*NN
*
*          to be attributed::
           PLMNTM=SIG(L,M,NNN)/(SIGSUM+TIN)
           TMMP=TMMP+PLMNTM
*
*          attribution loop for Y-cuts
           DO 511  N0CUT=0,N
           DO 511  N1CUT=0,N-N0CUT
                 N2CUT=N-N0CUT-N1CUT
*            combinatoric weight:
             CMB0=CMBIN(N,N2CUT)
             CMB1=CMBIN(N-N2CUT,N1CUT)
*
*          attribution loop for PHI-cuts
           DO 511  NN0CUT=0,NN
           DO 511  NN1CUT=0,NN-NN0CUT
                 NN2CUT=NN-NN0CUT-NN1CUT
*            combinatoric weight:
             CMBN0=CMBIN(NN,NN2CUT)
             CMBN1=CMBIN(NN-NN2CUT,NN1CUT)
*
*            attributions matrix:
*            ("L"soft,"M"hard,"N"1-diffr.,"NN"2-dif.,"NL"diffr.long in.part ):
*            obviously:
               L2STR = L
               M2STR = M
               N2STR = N0CUT
               NN2STR= NN0CUT
               NL2STR=  0
*            specialties for Y's and PHI's:
               L2STR=L2STR + N1CUT + NN1CUT +  N2CUT + NN2CUT
               IF(NMAX.LE.2)THEN
*                room to have NL2STR's:
                 NL2STR= N2CUT + NN2CUT
               ELSEIF(NMAX.GE.3)THEN
*                the extra inner piece counts here like long strings:
                 L2STR=L2STR+N2CUT+NN2CUT
               ENDIF
               IF((ICON.EQ.26.OR.ICON.EQ.36.OR.ICON.EQ.46.OR.ICON.EQ.56)
     &           .AND. (L2STR.GE.1.OR.M2STR.GE.1))THEN
                 L2STR=L2STR +  NL2STR
                 N2STR  = 0
                 NN2STR  = 0
                 NL2STR  = 0
               ENDIF
*
*            getting and checking parameter for storing:
               IF(L2STR.GT.LMAXI) L2STR=LMAXI
               IF(M2STR.GT.LMAXI) M2STR=LMAXI
               NNNSTR =N2STR +(NMAXI+1)*NN2STR
     *                       +(NNMAXI+1)*(NMAXI+1)*NL2STR
               IF(NNNSTR.GT.MXPA13) NNNSTR=MXPA13
*
*            summing contributions
               PLMN(L2STR,M2STR,NNNSTR) =  PLMNTM
     *             *CMB0*CMB1 * (-2)**N2CUT * (4)**N1CUT * (-1)**N0CUT
     *             *CMBN0*CMBN1*(-2)**NN2CUT* (4)**NN1CUT* (-1)**NN0CUT
     &           +  PLMN(L2STR,M2STR,NNNSTR)
*
  511   CONTINUE
  51    CONTINUE
      ENDIF
C///// initial general methode ends
    5 CONTINUE
       IF(ABS(TMMP-1.D0).GT..03D0)THEN
          WRITE(6,*)
     &     ' NORMALISATION ERROR SUM PLM before LMD reatribution=',TMMP
       ENDIF
*
* *** built in low mass diffraction, get averages and check normalisation:
*
*       low mass diffraction was SIGLMD=SILMSD+SILMDD
*       and mixed LM/HM diffraction SLHMDD=SQRT(SILMDD*SIHMDD)
        PLMFAC= (SIGSUM+TIN) / (SIGSUM+TIN +SIGLMD)
        PLMN(0,0,1)= PLMN(0,0,1) +
     &      ( SILMSD - SLHMDD ) / (SIGSUM+TIN)
        PLMN(0,0,2)= PLMN(0,0,2) +
     &      ( SILMDD + SLHMDD ) / (SIGSUM+TIN)
 661    CONTINUE
*     AVerage_SOft_N,AVerage_HaRD_N,SUM_over_Pl
      AVSOFN=0.
      AVHARN=0.
      AVDIFN=0.
      AVDDFN=0.
      AVDLFN=0.
      PSOFT=0.
      TEMP=0.
      TMP=0.
      TMMP=0.
      TMMP1=0.
*
*     (L,M,N,NN,NL repl. L2STR,M2... for s.,h.,Y-dif.,PHI-dif.,i.Y-dif.str.#)
      DO 6 NL=0,NLMAXI
      DO 6 NN=0,NNMAXI
      DO 6 N=0,NMAXI
        IF(NMAX.LE.2 .AND. N+NN+NL.GE.2) GO TO 6
        NNN =N +(NMAXI+1)*NN +(NNMAXI+1)*(NMAXI+1)* NL
        DO 63 M=0,MMAXI
        DO 63 L=0,LMAXI
           IF(NL.EQ.0)TMMP1  = TMMP1  + SIG(L,M,NNN)
           TMMP  = TMMP  + SIG(L,M,NNN)
           PLMN(L,M,NNN)=PLMN(L,M,NNN) * PLMFAC
           TMP  = TMP  + PLMN(L,M,NNN)
C          IF(PLMN(L,M,NNN).LT.-.000001D0)
           IF(PLMN(L,M,NNN).LT.-.000005D0)
     &             WRITE(6,*)' 0>PLMN',PLMN(L,M,NNN),L,M,N,NN,NL
           AVSOFN=AVSOFN+PLMN(L,M,NNN)*L
           AVHARN=AVHARN+PLMN(L,M,NNN)*M
           AVDIFN=AVDIFN+PLMN(L,M,NNN)*N
           AVDDFN=AVDDFN+PLMN(L,M,NNN)*NN
           AVDLFN=AVDLFN+PLMN(L,M,NNN)*NL
           IF (M.EQ.0)PSOFT=PSOFT+PLMN(L,M,NNN)
 63    CONTINUE
  6    CONTINUE
       IF(ABS(TMP-1.D0).GT..01D0)THEN
          WRITE(6,*)
     &     ' NORMALISATION ERROR SUM PLM before M reatribution=',TMP
       ENDIF
       TMMP=TMMP/SIGSUM
       TMMP1=TMMP1/SIGSUM
       IF(ABS(TMMP-1.D0).GT..01D0 .OR.ABS(TMMP1-1.D0).GT..01D0)THEN
          WRITE(6,*)
     &     ' NORMALISATION ERROR TMMP,TMMP1=',TMMP,TMMP1
       ENDIF
*
* *** reattribute purely hard scattering and get cummulant distribution
*
*     (L,M,N,NN,NL repl. L2STR,M2...
*          for soft,hard,Y-diffr.,PHI-diffr.,inner diffr.  string #)
      DO 61 NL=0,NLMAXI
      DO 61 NN=0,NNMAXI
      DO 61 N=0,NMAXI
        IF(NMAX.LE.2 .AND. N+NN+NL.GE.2) GO TO 61
        NNN =N +(NMAXI+1)*NN +(NNMAXI+1)*(NMAXI+1)* NL
        DO 612 M=0,MMAXI
        DO 611 L=0,LMAXI
* -- hard:  a pure hard scattering gets an extra soft chain, it is considered
*           a specialty of fragmentation and therefor implemented only here
*           there are are number of other options which are dropped as they
*           are hard to implement at this point
           IF (L.EQ.0.AND.M.GE.1)THEN
             PLMN(1,M,NNN)=PLMN(1,M,NNN)+PLMN(0,M,NNN)
             PLMN(0,M,NNN)=0.
           ENDIF
* -- cummulant of distribution
           TEMP  = TEMP  + PLMN(L,M,NNN)
           PLMNCU(L,M,NNN)=TEMP
  611   CONTINUE
*
          IF(IOUTPO.GE.3)WRITE (6,*)' M,(L,PLMN(L,M,N),L=0,LMAX)'
          IF(IOUTPO.GE.3)WRITE (6,106) M,(L,PLMN(L,M,N),L=0,LMAXI)
          IF(IOUTPO.GE.2)WRITE (6,*)' M,(L,PLMNCU(L,M,N),L=0,LMAX/2)'
          IF(IOUTPO.GE.2)WRITE (6,106) M,(L,PLMNCU(L,M,N),L=0,LMAXI/2)
  106     FORMAT (I3,9(I3,E11.2))
*
  612  CONTINUE
   61  CONTINUE
*
       IF(ABS(TEMP-1.D0).GT..01D0)THEN
          WRITE(6,*)' NORMALISATION ERROR SUM PLM=',TEMP
          PLMFAC=1./(TEMP+TIN)
          GO TO 661
       ENDIF
*
         IF(IOUTPO.GE.1)WRITE (6,*)
     &   '(((L,M,N,PLMN(L,M,N),N=0,2),M=0,5),L=0,7)'
         IF(IOUTPO.GE.1)WRITE (6,1106)
     &   (((L,M,N,PLMN(L,M,N),N=0,2),M=0,5),L=0,7)
         IF(IOUTPO.GE.1)WRITE (6,*)
     &   '(((L,M,N,SIG(L,M,N),N=0,2),M=0,5),L=0,7)'
         IF(IOUTPO.GE.1)WRITE (6,1106)
     &   (((L,M,N,SIG(L,M,N),N=0,2),M=0,5),L=0,7)
 1106    FORMAT (1X,3(I5,I5,I5,G12.5))
*
      PHARD=1.-PSOFT
      ALFAH=SIGHIN/(SIGINE+0.00001)
      BETAH=1.-ALFAH
      WRITE(6,116)AVSOFN,AVHARN,AVDIFN,AVDDFN,AVDLFN,
     &        PHARD,PSOFT,ALFAH,BETAH
  116 FORMAT(/'--- various averages:'/
     &       /'    AVSOFN=    AVHARN=    AVDIFN=    AVDDFN=    AVDLFN='
     &       /'   ',5F11.3
     &       /'    PHARD=     PSOFT=     ALFAH=     BETAH= '
     &       /'   ',4F11.3)
      IF(IOUTPO.GE.1)WRITE(6,*)'SIGSUM=SIGINL-LMD',SIGSUM
*
        IF(IOUTPO.GE.1)WRITE(6,610) SIGTOT,SIGINE,SIGD,SIGDD,SIGHIN
  610    FORMAT (' SIGTOT,SIGINE,SIGD,SIGDD,SIGHIN= '/' ',5E18.6)
*
101   FORMAT(' ',10E10.3)
102   FORMAT(' ')
103   FORMAT(' ',5X,I4,5X,2E15.3)
*
      RETURN
      END
*     ende problm
*
************************************************************************
*
*
      SUBROUTINE SAMPLX(L2STR,M2STR,N2STR,NN2STR,NL2STR)
*
*     input:
*        PLMNCU
*     output:
*        samples number of soft (L) and hard (M) cut pomerons from PLMNC
*                   and of (N=0/1/2) diffractive excitations (for L=M=0
*
*----------------------------------------------------------------------
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      COMMON /NNCMS/ GAMCM,BGCM,UMO,PCM,EPROJ,PPROJ  
C     COMMON /POMENE/POEN(20),POEN1(20),POEN2(20),NESTEP
       COMMON /POMENE/POEN(28),POEN1(28),POEN2(28),NESTEP
      PARAMETER (MXPU50=100,MXPU51=MXPU50+1)
      PARAMETER (MXPA25=30,MXPA26=MXPA25+1,MXPA13=13)
*     PARAMETRIZATION FOR PTMIN= 3. GEV
      PARAMETER (MXPA50=250,MXPA51=MXPA50+1)
*     PARAMETRIZATION FOR PTMIN= 2. GEV
C     PARAMETER (MXPA50=350,MXPA51=MXPA50+1)
* *** /OUTLEV/ controls output level for POMDI and parton X distribution
      COMMON /OUTLEV/IOUTPO,IOUTPA,IOUXEV,IOUCOL
      COMMON /POMTYP/IPIM,ICON,ISIG,LMAX,MMAX,NMAX,DIFEL,DIFNU
* *** /POLMN/ arrays having to do with cut soft and hard Pomerons
      COMMON /POLMN/PLMN(0:MXPA25,0:MXPA50,0:MXPA13),
     *              PLMNCU(0:MXPA25,0:MXPA50,0:MXPA13)
C     COMMON /POLMN1/ PLMNEE(0:MXPA25,0:MXPU50,0:MXPA13,20)
      COMMON /POLMN1/ PLMNEE(0:MXPA25,0:MXPU50,0:MXPA13,28)
      COMMON /POLMN0/PDIFR,PHARD,PSOFT,ALFAH,BETAH,
     *              SIGTOT,SIGQEL,SIGEL,SIGINE,SIGHIN,SIGD,SIGDD
*
      PARAMETER (PI=3.141592654D0)
      DATA NPRINT/0/
C                               Determine the energy index
      IPOEN=1
      DO 20 II=1,NESTEP
	IF(UMO.GE.POEN1(II).AND.UMO.LT.POEN2(II))THEN
          IPOEN=II
	  GO TO 22
        ENDIF
   20 CONTINUE
   22 CONTINUE
*     "L"SOFT,"M"HARD
      LMAXI = LMAX
      MMAXI = MMAX
      IF(IPIM.NE.2) THEN
*       "N"diffr.,"NN"dou.dif.,("NL"long inner contr. for 2*cut Y or PHI)
        NMAXI = NMAX
        NNMAXI=0
        NLMAXI=0
      ELSEIF(IPIM.EQ.2) THEN
        IF( NMAX.GE.3)THEN
          NMAXI = NMAX
          NNMAXI=(13-NMAXI)/(1+NMAXI)
*         13 =!= NNNMAX =  NMAXI+(NMAXI+1)*NNMAXI
          NLMAXI=0
        ELSEIF( NMAX.EQ.2)THEN
          NMAXI=1
          NNMAXI=1
          NLMAXI=1
        ELSEIF( NMAX.EQ.1)THEN
          NMAXI=1
          NNMAXI=0
          NLMAXI=1
        ENDIF
      ENDIF
  111 CONTINUE
*
      X=RNDM(V)
*
      IF (X.LE.PLMNCU(0,0,0) .AND. NPRINT.LT.100)THEN
        WRITE(6,*) ' No generator of elastic events '
        WRITE(6,*) ' PLMNCU (0,0,0)  =!= 0 = ',PLMNCU(0,0,0)
        NPRINT=NPRINT+1
        GOTO 111
      ENDIF
*
      DO 5 NL=0,NLMAXI
      DO 5 NN=0,NNMAXI
      DO 5 N=0,NMAXI
        NNN =N +(NMAXI+1)*NN +(NNMAXI+1)*(NMAXI+1)* NL
        DO 6 M=0,MMAXI
        DO 7 L=0,LMAXI
*
C         IF (X.LE.PLMNCU(L,M,NNN)) THEN
          IF (X.LE.PLMNEE(L,M,NNN,IPOEN)) THEN
	    L2STR=L
            M2STR=M
            N2STR=N
            NN2STR=NN
            NL2STR=NL
            RETURN
*
          ENDIF
    7    CONTINUE
    6  CONTINUE
    5 CONTINUE
*
      NPRINT=NPRINT+1
      IF(NPRINT.LT.100)  WRITE(6,*)' RAR.IN SAMPLM,PLMNCU,RND=',
     &  PLMNCU(LMAX, MMAX,NNN),X,NPRINT
      IF( PLMNCU(LMAX,MMAX,NNN) .GT. 0.1D0 ) RETURN
      IF( PLMNCU(LMAX,0,0) .GT. 0.1D0 ) RETURN
      WRITE(6,*)' RAR.IN SAMPLM- PROBLEM SEEMS BAD, DECIDE TO STOP'
      STOP
      END
*
*
************************************************************************
*
      SUBROUTINE SAMPLM(L2STR,M2STR,N2STR)
*
*     input:
*        PLMNCU
*     output:
*        samples number of soft (L) and hard (M) cut pomerons from PLMNC
*                   and of (N=0/1/2) diffractive excitations (for L=M=0
*
*----------------------------------------------------------------------
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      COMMON /NNCMS/ GAMCM,BGCM,UMO,PCM,EPROJ,PPROJ  
C     COMMON /POMENE/POEN(20),POEN1(20),POEN2(20),NESTEP
       COMMON /POMENE/POEN(28),POEN1(28),POEN2(28),NESTEP
      PARAMETER (MXPU50=100,MXPU51=MXPU50+1)
* *** /OUTLEV/ controls output level for POMDI and parton X distribution
      COMMON /OUTLEV/IOUTPO,IOUTPA,IOUXEV,IOUCOL
      COMMON /POMTYP/IPIM,ICON,ISIG,LMAX,MMAX,NMAX,DIFEL,DIFNU
* *** /POLMN/ arrays having to do with cut soft and hard Pomerons
      PARAMETER (MXPA25=30,MXPA26=MXPA25+1,MXPA13=13)
*     PARAMETRIZATION FOR PTMIN= 3. GEV
      PARAMETER (MXPA50=250,MXPA51=MXPA50+1)
*     PARAMETRIZATION FOR PTMIN= 2. GEV
C     PARAMETER (MXPA50=350,MXPA51=MXPA50+1)
      COMMON /POLMN/PLMN(0:MXPA25,0:MXPA50,0:MXPA13),
     *              PLMNCU(0:MXPA25,0:MXPA50,0:MXPA13)
C     COMMON /POLMN1/ PLMNEE(0:MXPA25,0:MXPU50,0:MXPA13,20)
      COMMON /POLMN1/ PLMNEE(0:MXPA25,0:MXPU50,0:MXPA13,28)
      COMMON /POLMN0/PDIFR,PHARD,PSOFT,ALFAH,BETAH,
     *              SIGTOT,SIGQEL,SIGEL,SIGINE,SIGHIN,SIGD,SIGDD
*
      PARAMETER (PI=3.141592654D0)
      IPOEN=1
      DO 20 II=1,NESTEP
	IF(UMO.GE.POEN1(II).AND.UMO.LT.POEN2(II))THEN
          IPOEN=II
	  GO TO 22
        ENDIF
   20 CONTINUE
   22 CONTINUE
  111 CONTINUE
*
      X=RNDM(V)
*
      IF (X.LE.PLMNCU(0,0,0))THEN
        WRITE(6,*) ' No generator of elastic events '
        WRITE(6,*) ' PLMNCU (0,0,0)  =!= 0 = ',PLMNCU(0,0,0)
        GOTO 111
      ENDIF
*
      DO 5 N=0,NMAX
C      IF (N.GT.1) GO TO 111
       DO 6 M=0,MMAX
         DO 7 L=0,LMAX
*
C         IF (X.LE.PLMNCU(L,M,N)) THEN
          IF (X.LE.PLMNEE(L,M,N,IPOEN)) THEN
	    L2STR=L
            M2STR=M
            N2STR=N
            RETURN
*
          ENDIF
    7    CONTINUE
    6  CONTINUE
    5 CONTINUE
*
      WRITE(6,*)' RAR.IN SAMPLM,PLMNCU,RND=',PLMNCU(LMAX,MMAX,NMAX),X
      IF( PLMNCU(LMAX,MMAX,NMAX) .GT. 0.1D0 ) RETURN
      IF( PLMNCU(LMAX,0,0) .GT. 0.1D0 ) RETURN
      WRITE(6,*)' RAR.IN SAMPLM- PROBLEM SEEMS BAD, DECIDE TO STOP'
      STOP
      END
*
*
*
*
************************************************************************
C--------------------------------------------------------------------
C
C                      dtUpom9h.for
C
C---------------------------------------------------------------------
************************************************************************
*
*         POMDI,SIGMAS,SIGSHD,PRBLM0..9,SAMPLM,SIGMA1
*
*                  routines called by code word
*                            SIGMAPOM :
*

C--------------------------------------------------------------------
C
C                      dtUpom9h.for
C
C---------------------------------------------------------------------
************************************************************************
*
*         POMDI,SIGMAS,SIGSHD,PRBLM0..9,SAMPLX,SIGMA1
*
*                  routines called by code word
*                            SIGMAPOM :
*
************************************************************************
*
*                                                 J.RANFT September 1987
      SUBROUTINE POMDI
*
*        to calculate the s-dependent  X-sections
*
*  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
*
*     input:
*       ISIG  characterizing X sections, transmitted to SIGSHD
*       IPIM  characterizes the method to calculate SIGMA(LSOFT,mhard)
*                        IPIM=1 : integral method with low mass dif.matr
*                        IPIM=2 : int.meth.with low mass dif.matr.(2*2)
*                                 and reduced high mass diffraction
*                        IPIM=3 : integral methode
*                        IPIM=4 : integral methode with Y -cuts
*                        IPIM=5 : integral methode with Y-cuts + 2 CHANNEL EIK.
*                        rest   : not implemented or
*                                 special cases for checking
*       LMAX < MXPA25 maximal number of considered soft pomerons
*       MMAX < MXPA50 maximal number of considered hard pomerons
*       NMAX < MXPA13 maximal number of considered trippel pomerons
*                 (not used in low masss diffraction formalism)
*     output: printet and plottet in SIGMAS and
*             printed on the end of this subroutine
*
*        card XSECTION causes call to POMDI
*        card SIGMAPOM with ITEST=1 causes call to POMDI
*        POMDI calling
*           SIGMAS (  SIGMA1..3( SIGSD, (1:/3:)GSET ), PLOT)
*           PRBLM..  ( SIGSHD,  (1:)GSET )
*           (2:)SAMPLX, (1:/3:)SAMPLM
*
*----------------------------------------------------------------------
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
*
* *** /POLMN/ arrays having to do with cut soft and hard Pomerons
      PARAMETER (MXPA25=30,MXPA26=MXPA25+1,MXPA13=13)
*     PARAMETRIZATION FOR PTMIN= 3. GEV
      PARAMETER (MXPA50=250,MXPA51=MXPA50+1)
*     PARAMETRIZATION FOR PTMIN= 2. GEV
C     PARAMETER (MXPA50=350,MXPA51=MXPA50+1)
      COMMON /POLMN/PLMN(0:MXPA25,0:MXPA50,0:MXPA13),
     *              PLMNCU(0:MXPA25,0:MXPA50,0:MXPA13)
      COMMON /POLMN0/PDIFR,PHARD,PSOFT,ALFAH,BETAH,
     *              SIGTOT,SIGQEL,SIGEL,SIGINE,SIGHIN,SIGD,SIGDD
* *** /HISTOO/
      INTEGER*2 NDISLM
      COMMON /HISTOO/AS(50,9),AECM(50,9),ASIG(50,9),ALOS(50,9),
     *    ALOECM(50,9),NDISLM(0:MXPA25,0:MXPA50,0:MXPA13)
* *** /OUTLEV/ controls output level for POMDI and parton X distribution
      COMMON /OUTLEV/IOUTPO,IOUTPA,IOUXEV,IOUCOL
* --- used only in SIGMAPOM-routines
* *** /POMPAR/ contains pomeron parameters used in some options
*     ALFA,ALFAP,A,BH,C,BS are soft Pomeron parameters chosen in SIGMAS
*     appearing in SIGMAS, PRBLM..,  AK is K-factor
      COMMON/POMPAR/ALFA,ALFAP,A,C,AK
* *** /SIGMA/ contains variables actually used in iteration
*     ZSOF, ZHAR, BS, BH, SIGSOF,SIGHAR ( for soft, hard, trippel-Pom.)
*     are input for X-section calculated in SIGSHD
C     (/sigma/ is out of P.A.'s CM88, containing variables used in iter.
      COMMON /SIGMA/SIGSOF,BS,ZSOF,SIGHAR,BH,ZHAR,SIGTRP,BT,ZTRP,
     *              SIGLOO,ZLOO
* *** /POMTYP/ contains parameters determining X-sections
*     IPIM,ISIG,LMAX,MMAX,NMAX  as described at "CODEWD = SIGMAPOM"
C     LMAX,MMAX,NMAX kept open to enable avoiding of numerical problem
      COMMON /POMTYP/IPIM,ICON,ISIG,LMAX,MMAX,NMAX,DIFEL,DIFNU
      COMMON /ALALA/ALALAM
C     COMMON/COLLIS/SS,IJPROJ,IJTAR,PTTHR,PTTHR2,IOPHRD,IJPRLU,IJTALU
C
      COMMON /COLLPO/S,PTTHR,PTTHR2
C     COMMON /COLLIS/SS,IJPROJ,IJTAR,PTTPO,IOPHRD,IJPRLU,IJTALU,PTTPO2
      COMMON /COLLIS/SS,IJPROJ,IJTAR,PTTPO,PTTPO2,IOPHRD,IJPRLU,IJTALU
C
C      ECM calculated as SQRT
*  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      PARAMETER (PI=3.141592654D0)
      LMAXI = LMAX
      MMAXI = MMAX
      NMAXI = NMAX
      SKEEP=SS
*
*---------------------------------------------------------------------
*                                                 CALL SIGMAS
*
*  calculates and plotts out X-section at various energies
*  runs thru energies independent of the rest
*                       and contains no preperation for other work
*
          WRITE(6,'(1X/1X)')
          WRITE(6,*)' '
          WRITE(6,*)
     *' ------ testing the energy dependence of x-sections ----------'
          WRITE(6,*)' '
          IF(IOUTPO.GT.-1) WRITE(6,*)
     *'          (as function of ALAM i.e.a low mass diffr.parameter)'
          WRITE(6,*)' -----------------------------------------------'
          WRITE(6,'(1X)')
*
          DO 1007 IIJJ=1,10
          IF(IOUTPO.GT.-1 .OR. IIJJ.EQ.6)THEN
C         WITHOUT SIMGMAS FOR NORMAL USERS
C         IF(IOUTPO.GT.-1 )THEN
            ALALAM=IIJJ*0.1
            IF(IOUTPO.GT.-1) WRITE(6,1008)ALALAM
 1008       FORMAT (' ALAM= ',F10.3)
            CALL SIGMAS
          ENDIF
 1007     CONTINUE
*
*---------------------------------------------------------------------
*                                                  test sampling L,M
*
 1111   CONTINUE
*                            looping thru the energies
*
C       DO 100 III=3,9
C         S=10.**III
C         ECM=SQRT(S)
*
          S=SKEEP
          ECM=SQRT(S)
*
*                            chosing one options with a standard call
*
          IF(IPIM.EQ.2) THEN
            IF( NMAX.GE.3)THEN
              NNMAXI=(13-NMAXI)/(1+NMAXI)
*             13 =!= NNNMAX =  NMAXI+(NMAXI+1)*NNMAXI
              NLMAXI=0
            ELSEIF( NMAX.EQ.2)THEN
              NMAXI=1
              NNMAXI=1
              NLMAXI=1
            ELSEIF( NMAX.EQ.1)THEN
              NMAXI=1
              NNMAXI=0
              NLMAXI=1
            ENDIF
            CALL PRBLM2(ECM)
          ENDIF
          IF(IPIM.LT.1.AND.IPIM.GT.9)THEN
                 WRITE(6,*) 'RETURN caused by IPIM=',IPIM
                 RETURN
          ENDIF
*
*                            randomly sample events and printout
*
          WRITE (6,'(1X)' )
          WRITE (6,102)ECM,S
  102     FORMAT
     *    ('--- sample distribution for L soft and M hard inelastic'
     *   , ' pomerons (string pairs)--- '
     *    / 20X,'at ECM  = ',F10.2,' S  = ',F12.1)
          DO 31 L=0,LMAXI
            DO 32 M=0,MMAXI
            DO 32 N=0,13
              NDISLM(L,M,N)=0
   32       CONTINUE
   31     CONTINUE
*
          IF(ICON.EQ.12)GO TO 100
          DO 320 II=1,10000
            IF(IPIM.EQ.2) THEN
              CALL SAMPLX(L2STR,M2STR,N2STR,NN2STR,NL2STR)
                 NNNSTR =N2STR +(NMAXI+1)*NN2STR
     *                         +(NNMAXI+1)*(NMAXI+1)*NL2STR
              NDISLM(L2STR,M2STR,NNNSTR)=NDISLM(L2STR,M2STR,NNNSTR)+1
            ELSE
              CALL SAMPLM(L2STR,M2STR,N2STR)
              NDISLM(L2STR,M2STR,N2STR)=NDISLM(L2STR,M2STR,N2STR)+1
            ENDIF
  320     CONTINUE
*
            WRITE(6,*)
     *      '                    with no diffractive contribution'
            WRITE(6,*) ' '
            WRITE(6,*)
     *   '     ....... vertical: NSTR, horizontal MSTR .........'
            DO 3344 L=0,MIN(20,LMAXI)
 3344          WRITE(6,34)L,(NDISLM(L,M,0),M=0,20)
            WRITE(6,*) ' '
          IF(IOUTPO.GE.0)THEN
            DO 333 N=0,5
              IF(N.NE.0)THEN
               WRITE(6,*)'               WITH NSTR=',N
               DO 334 L=0,MIN(20,LMAXI)
                 WRITE(6,34)L,(NDISLM(L,M,N),M=0,20)
  334          CONTINUE
               WRITE(6,*) ' '
              ENDIF
              JMPA50 = INT(MXPA50/25)
C             WRITE(6,*) 'WIDE PLOT 0<L<25, 0<M<'
              WRITE(6,*) 'WIDE PLOT 0<L<',MXPA25,' 0<M<'
     &                   ,MXPA50,' IN STEPS OF ',JMPA50
C             DO 335 L=0,MIN(25,LMAXI)
              DO 335 L=0,MXPA25
                WRITE(6,35)L,(NDISLM(L,M,N),M=0,MXPA50,JMPA50)
  335         CONTINUE
              WRITE(6,*) ' '
  333       CONTINUE
          ENDIF
   34         FORMAT (I5,':',21I4)
   35         FORMAT (I5,26I4)
  100   CONTINUE
*     energy loop has ended
      RETURN
      END
*
*
************************************************************************
*
      SUBROUTINE SIGMAS
*
*     output:
*       energy dependence of
*       SIGMa-TOT, SIGma-INel, SIGma-Diffractive, SIGma-Hard-INelastic
*       print- and plott-out
*     using:
*       called routines  SIGSHD , SIGMA1..3 , PLOT
*
*     runs thru energies independent of the rest
*                            and contains no preperation for other parts
*
*---------------------------------------------------------------------
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
*
* *** /OUTLEV/ controls output level for POMDI and parton X distribution
      COMMON /OUTLEV/IOUTPO,IOUTPA,IOUXEV,IOUCOL
* *** /POLMN/ arrays having to do with cut soft and hard Pomerons
      PARAMETER (MXPA25=30,MXPA26=MXPA25+1,MXPA13=13)
      PARAMETER ( ZERO=0.D0, ONE=1.D0)
*     PARAMETRIZATION FOR PTMIN= 3. GEV
      PARAMETER (MXPA50=250,MXPA51=MXPA50+1)
*     PARAMETRIZATION FOR PTMIN= 2. GEV
C     PARAMETER (MXPA50=350,MXPA51=MXPA50+1)
      COMMON /POLMN/PLMN(0:MXPA25,0:MXPA50,0:MXPA13),
     *              PLMNCU(0:MXPA25,0:MXPA50,0:MXPA13)
      COMMON /POLMN0/PDIFR,PHARD,PSOFT,ALFAH,BETAH,
     *              SIGTOT,SIGQEL,SIGEL,SIGINE,SIGHIN,SIGD,SIGDD
*
* *** /POMPAR/*/SIGMA/*/POMTYP/ used only in SIGMAPOM-routines (->POMDI)
      COMMON /POMTYP/IPIM,ICON,ISIG,LMAX,MMAX,NMAX,DIFEL,DIFNU
      COMMON/POMPAR/ALFA,ALFAP,A,C,AK
      COMMON /SIGMA/SIGSOF,BS,ZSOF,SIGHAR,BH,ZHAR,SIGTRP,BT,ZTRP,
     *              SIGLOO,ZLOO
* ***
      COMMON /TOPDR/ITOPD,IDUMTP
* ***
      INTEGER*2 NDISLM
      COMMON /HISTOO/AS(50,9),AECM(50,9),ASIG(50,9),ALOS(50,9),
     *    ALOECM(50,9),NDISLM(0:MXPA25,0:MXPA50,0:MXPA13)
*  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      PARAMETER (PI=3.141592654D0)
*
*---------------------------------------------------------------------
*                  run thru energies
*    ------------------------------------------------------------------
*
      ISTEP=2
      IF(IOUTPO.GT.-1)ISTEP=7
      DO 100 I=1,50,ISTEP
        S=1.6**I
        ECM=SQRT(S)+3.4
        S=ECM**2
*
* *** running thru energies initializing AS,AECM,ASIG,ALOS,ALOECM *****
*
        DO 111 III=1,9
          AS(I,III)=S
          AECM(I,III)=ECM
          ALOS(I,III)=LOG10(S)
          ALOECM(I,III)=LOG10(ECM)
          ASIG(I,III)=0.
  111   CONTINUE
*
* *** calling calculation of x- section
*
        IF(IPIM.EQ.2 )THEN
          CALL SIGMA2(ECM)
          IF(I.EQ.1 .AND. IOUTPO.GE.0 ) WRITE(6,*)
     &     ' s-dep. by integr.with Y,PHI,LMD'
        ELSE
          CALL SIGMA2(ECM)
          IF(I.EQ.1 .AND. IOUTPO.GE.0 ) WRITE(6,*)
     &      ' s-dep. by integr.with Y,PHI,LMD  (DEFAULT)'
        ENDIF
*
*
C*       the preceeding coresponds to a call to SIGMA2 except extra prin
* ***   getting plot array ASIG(I,J) :
        ASIG(I,1)=SIGTOT
        ASIG(I,2)=SIGINE
        ASIG(I,3)=SIGHIN
        ASIG(I,4)=SIGSOF
        ASIG(I,5)=SIGHAR
        ASIG(I,6)=SIGTRP
        ASIG(I,7)=SIGTOT-SIGINE
        ASIG(I,8)=SIGINE-SIGHIN
        ASIG(I,9)=SIGD
        WRITE (6,1007)ECM,SIGTOT,SIGINE,SIGEL,SIGD
 1007   FORMAT (' ECM,SIGTOT,SIGINE,SIGEL,SIGD',F10.1,4E14.3)
  100 CONTINUE
*
*     energy loop ends
*---------------------------------------------------------------------
*                  print out results
*    ------------------------------------------------------------------
      WRITE (6,991)
  991 FORMAT (//' shown as line printer plott'/' with'/
*    J: drawn quantities:
     1 '  (*) SIGTOT total x-section',
     2 '  (2) SIGINE inelastic x-section'/
     3 '  (3) SIGHIN hard inelastic cross section, one or more jets',
     4 '  (4) SIGSOF   input soft x-section'/
     5 '  (5) SIGHAR   input hard x-sections',
     6 '  (6) SIGTRP   input diffractive x-section (triple pomeron)'/
     7 '  (7) SIGTOT-SIGINE  elastic x-section',
     8 '  (8) SIGINE-SIGHIN  non-hard inelastic x-section, (no jets)'/
     9 '  (9) SIGD   diffractive xross section '/
     * '  are plotted against LOG(10)of(CMENERGY)' //)
*
      CALL PLOT(ALOECM,ASIG,450,9,50,ZERO, 0.1D0*ONE,ZERO, 2.0D0*ONE)
*
*  special output on unit number 7
C  I kept it as it was
      IF (ITOPD.EQ.1) THEN
        WRITE(7,95)
   95   FORMAT(' NEW FRAME'/' SET FONT DUPLEX'/' SET SCALE X LOG'/
     *  ' SET LIMITS X FROM 1.0 TO 1E5 Y FROM 0. TO 200'/
     *  ' TITLE TOP < TOTAL,INEL. AND HARD (MINIJET) CROSS SECT.<'/
     *  ' TITLE BOTTOM <C.M.ENERGY [GEV]<'/
     *  ' TITLE < DUAL UNITARIZATION OF SOFT AND HARD CROSS SECTIONS<'/
     *  ' TITLE LEFT LINES=-1 <CROSS SECTION [MB]<'/
     *  ' TITLE 3 8.5 < SOLID = TOTAL X.S. <'/
     *  ' TITLE  < DASHED= INELASTIC X.S. <'/
     *  ' TITLE  < DOTTED= HARD X.S.<'/
     *  ' TITLE  < DOT-DASH= HARD INPUT X.S. <'/
     *  ' TITLE  < DOT-DASH= ELASTIC X.S. <')
   92   FORMAT (5F15.5)
        DO 94 IUU=1,7
          IF (IUU.EQ.4)GO TO 94
          IF (IUU.EQ.6)GO TO 94
          IF (IUU.EQ.1) WRITE(7,97)
   97           FORMAT (' SET TEXTURE SOLID')
          IF (IUU.EQ.2) WRITE(7,98)
   98           FORMAT (' SET TEXTURE DASHES')
          IF (IUU.EQ.3) WRITE(7,99)
   99           FORMAT (' SET TEXTURE DOTS')
          IF (IUU.EQ.5) WRITE(7,197)
  197           FORMAT (' SET TEXTURE DOTDASH')
          DO 93 IU=2,46
            WRITE(7,92)AECM(IU,IUU),ASIG(IU,IUU)
   93     CONTINUE
          WRITE(7,96)
   96           FORMAT (' JOIN')
   94   CONTINUE
      ENDIF
*     ending IF(ITOP=1) special output
      RETURN
      END
*
******************************************************************
*  end dtupom90
******************************************************************

